/* Automatically @generated by tree-sitter v0.25.6 */

#include "tree_sitter/parser.h"

#if defined(__GNUC__) || defined(__clang__)
#pragma GCC diagnostic ignored "-Wmissing-field-initializers"
#endif

#define LANGUAGE_VERSION 15
#define STATE_COUNT 1523
#define LARGE_STATE_COUNT 167
#define SYMBOL_COUNT 218
#define ALIAS_COUNT 1
#define TOKEN_COUNT 96
#define EXTERNAL_TOKEN_COUNT 15
#define FIELD_COUNT 10
#define MAX_ALIAS_SEQUENCE_LENGTH 10
#define MAX_RESERVED_WORD_SET_SIZE 0
#define PRODUCTION_ID_COUNT 29
#define SUPERTYPE_COUNT 0

enum ts_symbol_identifiers {
  anon_sym_SEMI = 1,
  anon_sym_COMMA = 2,
  anon_sym_LPAREN = 3,
  anon_sym_RPAREN = 4,
  anon_sym_PLUS = 5,
  anon_sym_DOT_PLUS = 6,
  anon_sym_DASH = 7,
  anon_sym_DOT_DASH = 8,
  anon_sym_STAR = 9,
  anon_sym_DOT_STAR = 10,
  anon_sym_SLASH = 11,
  anon_sym_DOT_SLASH = 12,
  anon_sym_BSLASH = 13,
  anon_sym_DOT_BSLASH = 14,
  anon_sym_CARET = 15,
  anon_sym_DOT_CARET = 16,
  anon_sym_PIPE = 17,
  anon_sym_AMP = 18,
  anon_sym_DOT = 19,
  anon_sym_TILDE = 20,
  anon_sym_QMARK = 21,
  anon_sym_AT = 22,
  anon_sym_LT = 23,
  anon_sym_LT_EQ = 24,
  anon_sym_EQ_EQ = 25,
  anon_sym_TILDE_EQ = 26,
  anon_sym_GT_EQ = 27,
  anon_sym_GT = 28,
  anon_sym_AMP_AMP = 29,
  anon_sym_PIPE_PIPE = 30,
  anon_sym_DOT_SQUOTE = 31,
  anon_sym_SQUOTE = 32,
  anon_sym_LBRACK = 33,
  anon_sym_LF = 34,
  aux_sym_matrix_token1 = 35,
  anon_sym_RBRACK = 36,
  anon_sym_LBRACE = 37,
  anon_sym_RBRACE = 38,
  anon_sym_EQ = 39,
  anon_sym_COLON = 40,
  anon_sym_return = 41,
  anon_sym_continue = 42,
  anon_sym_break = 43,
  anon_sym_elseif = 44,
  anon_sym_else = 45,
  anon_sym_if = 46,
  anon_sym_end = 47,
  anon_sym_for = 48,
  anon_sym_parfor = 49,
  anon_sym_while = 50,
  anon_sym_case = 51,
  anon_sym_otherwise = 52,
  anon_sym_switch = 53,
  anon_sym_global = 54,
  anon_sym_persistent = 55,
  anon_sym_DOT_QMARK = 56,
  anon_sym_arguments = 57,
  anon_sym_function = 58,
  anon_sym_get_DOT = 59,
  anon_sym_set_DOT = 60,
  anon_sym_endfunction = 61,
  anon_sym_vector = 62,
  anon_sym_matrix = 63,
  anon_sym_scalar = 64,
  anon_sym_properties = 65,
  anon_sym_get = 66,
  anon_sym_set = 67,
  anon_sym_methods = 68,
  anon_sym_events = 69,
  anon_sym_enumeration = 70,
  anon_sym_classdef = 71,
  anon_sym_catch = 72,
  anon_sym_try = 73,
  anon_sym_spmd = 74,
  aux_sym_number_token1 = 75,
  aux_sym_number_token2 = 76,
  aux_sym_number_token3 = 77,
  anon_sym_true = 78,
  anon_sym_false = 79,
  anon_sym_CR = 80,
  sym_comment = 81,
  sym_line_continuation = 82,
  sym_command_name = 83,
  sym_command_argument = 84,
  sym__single_quote_string_start = 85,
  sym__single_quote_string_end = 86,
  sym__double_quote_string_start = 87,
  sym__double_quote_string_end = 88,
  sym_formatting_sequence = 89,
  sym_escape_sequence = 90,
  sym_string_content = 91,
  sym__entry_delimiter = 92,
  sym__multioutput_variable_start = 93,
  sym__external_identifier = 94,
  sym_error_sentinel = 95,
  sym_source_file = 96,
  aux_sym__block = 97,
  sym_block = 98,
  sym_identifier = 99,
  sym__statement = 100,
  sym__expression = 101,
  sym_parenthesis = 102,
  sym__binary_expression = 103,
  sym_binary_operator = 104,
  sym_unary_operator = 105,
  sym_indirect_access = 106,
  sym_field_expression = 107,
  sym_not_operator = 108,
  sym_metaclass_operator = 109,
  sym_handle_operator = 110,
  sym_comparison_operator = 111,
  sym_boolean_operator = 112,
  sym_postfix_operator = 113,
  sym_string = 114,
  sym_row = 115,
  sym_matrix = 116,
  sym_cell = 117,
  sym_ignored_argument = 118,
  sym_assignment = 119,
  sym_multioutput_variable = 120,
  sym_spread_operator = 121,
  sym__index_row = 122,
  sym__index_matrix = 123,
  sym__index_range_element = 124,
  sym__index_range = 125,
  sym__index_parenthesis = 126,
  sym__index_expression = 127,
  sym__index_binary_expression = 128,
  sym__index_binary_operator = 129,
  sym__index_argument = 130,
  sym__index_arguments = 131,
  sym_arguments = 132,
  sym__args = 133,
  sym_function_call = 134,
  sym_command = 135,
  sym__range_element = 136,
  sym_range = 137,
  sym_return_statement = 138,
  sym_continue_statement = 139,
  sym_break_statement = 140,
  sym_elseif_clause = 141,
  sym_else_clause = 142,
  sym_if_statement = 143,
  sym_iterator = 144,
  sym_parfor_options = 145,
  sym_for_statement = 146,
  sym_while_statement = 147,
  sym_case_clause = 148,
  sym_otherwise_clause = 149,
  sym_switch_statement = 150,
  sym__lambda_arguments = 151,
  sym_lambda = 152,
  sym_global_operator = 153,
  sym_persistent_operator = 154,
  sym__argument_attributes = 155,
  sym_class_property = 156,
  sym_arguments_statement = 157,
  sym_function_output = 158,
  sym_function_arguments = 159,
  sym_function_definition = 160,
  sym__function_definition_with_end = 161,
  sym_attribute = 162,
  sym_attributes = 163,
  sym_superclasses = 164,
  sym_dimensions = 165,
  sym_validation_functions = 166,
  sym_default_value = 167,
  sym_property_name = 168,
  sym_property = 169,
  sym_properties = 170,
  sym_function_signature = 171,
  sym_methods = 172,
  sym_events = 173,
  sym_enum = 174,
  sym_enumeration = 175,
  sym_class_definition = 176,
  sym_catch_clause = 177,
  sym_try_statement = 178,
  sym_spmd_statement = 179,
  sym_number = 180,
  sym_boolean = 181,
  sym_end_keyword = 182,
  sym__keywords = 183,
  sym__extended_keywords = 184,
  sym__end_of_line = 185,
  aux_sym_source_file_repeat1 = 186,
  aux_sym__block_repeat1 = 187,
  aux_sym_field_expression_repeat1 = 188,
  aux_sym_metaclass_operator_repeat1 = 189,
  aux_sym_string_repeat1 = 190,
  aux_sym_row_repeat1 = 191,
  aux_sym_matrix_repeat1 = 192,
  aux_sym_matrix_repeat2 = 193,
  aux_sym_multioutput_variable_repeat1 = 194,
  aux_sym__index_row_repeat1 = 195,
  aux_sym__index_matrix_repeat1 = 196,
  aux_sym__index_arguments_repeat1 = 197,
  aux_sym_arguments_repeat1 = 198,
  aux_sym_command_repeat1 = 199,
  aux_sym_elseif_clause_repeat1 = 200,
  aux_sym_if_statement_repeat1 = 201,
  aux_sym_switch_statement_repeat1 = 202,
  aux_sym__lambda_arguments_repeat1 = 203,
  aux_sym_global_operator_repeat1 = 204,
  aux_sym__argument_attributes_repeat1 = 205,
  aux_sym_arguments_statement_repeat1 = 206,
  aux_sym_function_definition_repeat1 = 207,
  aux_sym_attributes_repeat1 = 208,
  aux_sym_superclasses_repeat1 = 209,
  aux_sym_dimensions_repeat1 = 210,
  aux_sym_validation_functions_repeat1 = 211,
  aux_sym_properties_repeat1 = 212,
  aux_sym_methods_repeat1 = 213,
  aux_sym_events_repeat1 = 214,
  aux_sym_enum_repeat1 = 215,
  aux_sym_enumeration_repeat1 = 216,
  aux_sym_class_definition_repeat1 = 217,
  alias_sym_superclass = 218,
};

static const char * const ts_symbol_names[] = {
  [ts_builtin_sym_end] = "end",
  [anon_sym_SEMI] = ";",
  [anon_sym_COMMA] = ",",
  [anon_sym_LPAREN] = "(",
  [anon_sym_RPAREN] = ")",
  [anon_sym_PLUS] = "+",
  [anon_sym_DOT_PLUS] = ".+",
  [anon_sym_DASH] = "-",
  [anon_sym_DOT_DASH] = ".-",
  [anon_sym_STAR] = "*",
  [anon_sym_DOT_STAR] = ".*",
  [anon_sym_SLASH] = "/",
  [anon_sym_DOT_SLASH] = "./",
  [anon_sym_BSLASH] = "\\",
  [anon_sym_DOT_BSLASH] = ".\\",
  [anon_sym_CARET] = "^",
  [anon_sym_DOT_CARET] = ".^",
  [anon_sym_PIPE] = "|",
  [anon_sym_AMP] = "&",
  [anon_sym_DOT] = ".",
  [anon_sym_TILDE] = "~",
  [anon_sym_QMARK] = "\?",
  [anon_sym_AT] = "@",
  [anon_sym_LT] = "<",
  [anon_sym_LT_EQ] = "<=",
  [anon_sym_EQ_EQ] = "==",
  [anon_sym_TILDE_EQ] = "~=",
  [anon_sym_GT_EQ] = ">=",
  [anon_sym_GT] = ">",
  [anon_sym_AMP_AMP] = "&&",
  [anon_sym_PIPE_PIPE] = "||",
  [anon_sym_DOT_SQUOTE] = ".'",
  [anon_sym_SQUOTE] = "'",
  [anon_sym_LBRACK] = "[",
  [anon_sym_LF] = "\n",
  [aux_sym_matrix_token1] = "matrix_token1",
  [anon_sym_RBRACK] = "]",
  [anon_sym_LBRACE] = "{",
  [anon_sym_RBRACE] = "}",
  [anon_sym_EQ] = "=",
  [anon_sym_COLON] = ":",
  [anon_sym_return] = "return",
  [anon_sym_continue] = "continue",
  [anon_sym_break] = "break",
  [anon_sym_elseif] = "elseif",
  [anon_sym_else] = "else",
  [anon_sym_if] = "if",
  [anon_sym_end] = "end",
  [anon_sym_for] = "for",
  [anon_sym_parfor] = "parfor",
  [anon_sym_while] = "while",
  [anon_sym_case] = "case",
  [anon_sym_otherwise] = "otherwise",
  [anon_sym_switch] = "switch",
  [anon_sym_global] = "global",
  [anon_sym_persistent] = "persistent",
  [anon_sym_DOT_QMARK] = ".\?",
  [anon_sym_arguments] = "arguments",
  [anon_sym_function] = "function",
  [anon_sym_get_DOT] = "get.",
  [anon_sym_set_DOT] = "set.",
  [anon_sym_endfunction] = "endfunction",
  [anon_sym_vector] = "identifier",
  [anon_sym_matrix] = "identifier",
  [anon_sym_scalar] = "identifier",
  [anon_sym_properties] = "properties",
  [anon_sym_get] = "get",
  [anon_sym_set] = "set",
  [anon_sym_methods] = "methods",
  [anon_sym_events] = "events",
  [anon_sym_enumeration] = "enumeration",
  [anon_sym_classdef] = "classdef",
  [anon_sym_catch] = "catch",
  [anon_sym_try] = "try",
  [anon_sym_spmd] = "spmd",
  [aux_sym_number_token1] = "number_token1",
  [aux_sym_number_token2] = "number_token2",
  [aux_sym_number_token3] = "number_token3",
  [anon_sym_true] = "true",
  [anon_sym_false] = "false",
  [anon_sym_CR] = "\r",
  [sym_comment] = "comment",
  [sym_line_continuation] = "line_continuation",
  [sym_command_name] = "command_name",
  [sym_command_argument] = "command_argument",
  [sym__single_quote_string_start] = "'",
  [sym__single_quote_string_end] = "'",
  [sym__double_quote_string_start] = "\"",
  [sym__double_quote_string_end] = "\"",
  [sym_formatting_sequence] = "formatting_sequence",
  [sym_escape_sequence] = "escape_sequence",
  [sym_string_content] = "string_content",
  [sym__entry_delimiter] = ",",
  [sym__multioutput_variable_start] = "[",
  [sym__external_identifier] = "_external_identifier",
  [sym_error_sentinel] = "error_sentinel",
  [sym_source_file] = "source_file",
  [aux_sym__block] = "_block",
  [sym_block] = "block",
  [sym_identifier] = "identifier",
  [sym__statement] = "_statement",
  [sym__expression] = "_expression",
  [sym_parenthesis] = "parenthesis",
  [sym__binary_expression] = "_binary_expression",
  [sym_binary_operator] = "binary_operator",
  [sym_unary_operator] = "unary_operator",
  [sym_indirect_access] = "indirect_access",
  [sym_field_expression] = "field_expression",
  [sym_not_operator] = "not_operator",
  [sym_metaclass_operator] = "metaclass_operator",
  [sym_handle_operator] = "handle_operator",
  [sym_comparison_operator] = "comparison_operator",
  [sym_boolean_operator] = "boolean_operator",
  [sym_postfix_operator] = "postfix_operator",
  [sym_string] = "string",
  [sym_row] = "row",
  [sym_matrix] = "matrix",
  [sym_cell] = "cell",
  [sym_ignored_argument] = "ignored_argument",
  [sym_assignment] = "assignment",
  [sym_multioutput_variable] = "multioutput_variable",
  [sym_spread_operator] = "spread_operator",
  [sym__index_row] = "row",
  [sym__index_matrix] = "matrix",
  [sym__index_range_element] = "_index_range_element",
  [sym__index_range] = "range",
  [sym__index_parenthesis] = "parenthesis",
  [sym__index_expression] = "_index_expression",
  [sym__index_binary_expression] = "_index_binary_expression",
  [sym__index_binary_operator] = "binary_operator",
  [sym__index_argument] = "_index_argument",
  [sym__index_arguments] = "_index_arguments",
  [sym_arguments] = "arguments",
  [sym__args] = "_args",
  [sym_function_call] = "function_call",
  [sym_command] = "command",
  [sym__range_element] = "_range_element",
  [sym_range] = "range",
  [sym_return_statement] = "return_statement",
  [sym_continue_statement] = "continue_statement",
  [sym_break_statement] = "break_statement",
  [sym_elseif_clause] = "elseif_clause",
  [sym_else_clause] = "else_clause",
  [sym_if_statement] = "if_statement",
  [sym_iterator] = "iterator",
  [sym_parfor_options] = "parfor_options",
  [sym_for_statement] = "for_statement",
  [sym_while_statement] = "while_statement",
  [sym_case_clause] = "case_clause",
  [sym_otherwise_clause] = "otherwise_clause",
  [sym_switch_statement] = "switch_statement",
  [sym__lambda_arguments] = "_lambda_arguments",
  [sym_lambda] = "lambda",
  [sym_global_operator] = "global_operator",
  [sym_persistent_operator] = "persistent_operator",
  [sym__argument_attributes] = "attributes",
  [sym_class_property] = "class_property",
  [sym_arguments_statement] = "arguments_statement",
  [sym_function_output] = "function_output",
  [sym_function_arguments] = "function_arguments",
  [sym_function_definition] = "function_definition",
  [sym__function_definition_with_end] = "function_definition",
  [sym_attribute] = "attribute",
  [sym_attributes] = "attributes",
  [sym_superclasses] = "superclasses",
  [sym_dimensions] = "dimensions",
  [sym_validation_functions] = "validation_functions",
  [sym_default_value] = "default_value",
  [sym_property_name] = "property_name",
  [sym_property] = "property",
  [sym_properties] = "properties",
  [sym_function_signature] = "function_signature",
  [sym_methods] = "methods",
  [sym_events] = "events",
  [sym_enum] = "enum",
  [sym_enumeration] = "enumeration",
  [sym_class_definition] = "class_definition",
  [sym_catch_clause] = "catch_clause",
  [sym_try_statement] = "try_statement",
  [sym_spmd_statement] = "spmd_statement",
  [sym_number] = "number",
  [sym_boolean] = "boolean",
  [sym_end_keyword] = "end_keyword",
  [sym__keywords] = "_keywords",
  [sym__extended_keywords] = "identifier",
  [sym__end_of_line] = "_end_of_line",
  [aux_sym_source_file_repeat1] = "source_file_repeat1",
  [aux_sym__block_repeat1] = "_block_repeat1",
  [aux_sym_field_expression_repeat1] = "field_expression_repeat1",
  [aux_sym_metaclass_operator_repeat1] = "metaclass_operator_repeat1",
  [aux_sym_string_repeat1] = "string_repeat1",
  [aux_sym_row_repeat1] = "row_repeat1",
  [aux_sym_matrix_repeat1] = "matrix_repeat1",
  [aux_sym_matrix_repeat2] = "matrix_repeat2",
  [aux_sym_multioutput_variable_repeat1] = "multioutput_variable_repeat1",
  [aux_sym__index_row_repeat1] = "_index_row_repeat1",
  [aux_sym__index_matrix_repeat1] = "_index_matrix_repeat1",
  [aux_sym__index_arguments_repeat1] = "_index_arguments_repeat1",
  [aux_sym_arguments_repeat1] = "arguments_repeat1",
  [aux_sym_command_repeat1] = "command_repeat1",
  [aux_sym_elseif_clause_repeat1] = "elseif_clause_repeat1",
  [aux_sym_if_statement_repeat1] = "if_statement_repeat1",
  [aux_sym_switch_statement_repeat1] = "switch_statement_repeat1",
  [aux_sym__lambda_arguments_repeat1] = "_lambda_arguments_repeat1",
  [aux_sym_global_operator_repeat1] = "global_operator_repeat1",
  [aux_sym__argument_attributes_repeat1] = "_argument_attributes_repeat1",
  [aux_sym_arguments_statement_repeat1] = "arguments_statement_repeat1",
  [aux_sym_function_definition_repeat1] = "function_definition_repeat1",
  [aux_sym_attributes_repeat1] = "attributes_repeat1",
  [aux_sym_superclasses_repeat1] = "superclasses_repeat1",
  [aux_sym_dimensions_repeat1] = "dimensions_repeat1",
  [aux_sym_validation_functions_repeat1] = "validation_functions_repeat1",
  [aux_sym_properties_repeat1] = "properties_repeat1",
  [aux_sym_methods_repeat1] = "methods_repeat1",
  [aux_sym_events_repeat1] = "events_repeat1",
  [aux_sym_enum_repeat1] = "enum_repeat1",
  [aux_sym_enumeration_repeat1] = "enumeration_repeat1",
  [aux_sym_class_definition_repeat1] = "class_definition_repeat1",
  [alias_sym_superclass] = "superclass",
};

static const TSSymbol ts_symbol_map[] = {
  [ts_builtin_sym_end] = ts_builtin_sym_end,
  [anon_sym_SEMI] = anon_sym_SEMI,
  [anon_sym_COMMA] = anon_sym_COMMA,
  [anon_sym_LPAREN] = anon_sym_LPAREN,
  [anon_sym_RPAREN] = anon_sym_RPAREN,
  [anon_sym_PLUS] = anon_sym_PLUS,
  [anon_sym_DOT_PLUS] = anon_sym_DOT_PLUS,
  [anon_sym_DASH] = anon_sym_DASH,
  [anon_sym_DOT_DASH] = anon_sym_DOT_DASH,
  [anon_sym_STAR] = anon_sym_STAR,
  [anon_sym_DOT_STAR] = anon_sym_DOT_STAR,
  [anon_sym_SLASH] = anon_sym_SLASH,
  [anon_sym_DOT_SLASH] = anon_sym_DOT_SLASH,
  [anon_sym_BSLASH] = anon_sym_BSLASH,
  [anon_sym_DOT_BSLASH] = anon_sym_DOT_BSLASH,
  [anon_sym_CARET] = anon_sym_CARET,
  [anon_sym_DOT_CARET] = anon_sym_DOT_CARET,
  [anon_sym_PIPE] = anon_sym_PIPE,
  [anon_sym_AMP] = anon_sym_AMP,
  [anon_sym_DOT] = anon_sym_DOT,
  [anon_sym_TILDE] = anon_sym_TILDE,
  [anon_sym_QMARK] = anon_sym_QMARK,
  [anon_sym_AT] = anon_sym_AT,
  [anon_sym_LT] = anon_sym_LT,
  [anon_sym_LT_EQ] = anon_sym_LT_EQ,
  [anon_sym_EQ_EQ] = anon_sym_EQ_EQ,
  [anon_sym_TILDE_EQ] = anon_sym_TILDE_EQ,
  [anon_sym_GT_EQ] = anon_sym_GT_EQ,
  [anon_sym_GT] = anon_sym_GT,
  [anon_sym_AMP_AMP] = anon_sym_AMP_AMP,
  [anon_sym_PIPE_PIPE] = anon_sym_PIPE_PIPE,
  [anon_sym_DOT_SQUOTE] = anon_sym_DOT_SQUOTE,
  [anon_sym_SQUOTE] = anon_sym_SQUOTE,
  [anon_sym_LBRACK] = anon_sym_LBRACK,
  [anon_sym_LF] = anon_sym_LF,
  [aux_sym_matrix_token1] = aux_sym_matrix_token1,
  [anon_sym_RBRACK] = anon_sym_RBRACK,
  [anon_sym_LBRACE] = anon_sym_LBRACE,
  [anon_sym_RBRACE] = anon_sym_RBRACE,
  [anon_sym_EQ] = anon_sym_EQ,
  [anon_sym_COLON] = anon_sym_COLON,
  [anon_sym_return] = anon_sym_return,
  [anon_sym_continue] = anon_sym_continue,
  [anon_sym_break] = anon_sym_break,
  [anon_sym_elseif] = anon_sym_elseif,
  [anon_sym_else] = anon_sym_else,
  [anon_sym_if] = anon_sym_if,
  [anon_sym_end] = anon_sym_end,
  [anon_sym_for] = anon_sym_for,
  [anon_sym_parfor] = anon_sym_parfor,
  [anon_sym_while] = anon_sym_while,
  [anon_sym_case] = anon_sym_case,
  [anon_sym_otherwise] = anon_sym_otherwise,
  [anon_sym_switch] = anon_sym_switch,
  [anon_sym_global] = anon_sym_global,
  [anon_sym_persistent] = anon_sym_persistent,
  [anon_sym_DOT_QMARK] = anon_sym_DOT_QMARK,
  [anon_sym_arguments] = anon_sym_arguments,
  [anon_sym_function] = anon_sym_function,
  [anon_sym_get_DOT] = anon_sym_get_DOT,
  [anon_sym_set_DOT] = anon_sym_set_DOT,
  [anon_sym_endfunction] = anon_sym_endfunction,
  [anon_sym_vector] = sym_identifier,
  [anon_sym_matrix] = sym_identifier,
  [anon_sym_scalar] = sym_identifier,
  [anon_sym_properties] = anon_sym_properties,
  [anon_sym_get] = anon_sym_get,
  [anon_sym_set] = anon_sym_set,
  [anon_sym_methods] = anon_sym_methods,
  [anon_sym_events] = anon_sym_events,
  [anon_sym_enumeration] = anon_sym_enumeration,
  [anon_sym_classdef] = anon_sym_classdef,
  [anon_sym_catch] = anon_sym_catch,
  [anon_sym_try] = anon_sym_try,
  [anon_sym_spmd] = anon_sym_spmd,
  [aux_sym_number_token1] = aux_sym_number_token1,
  [aux_sym_number_token2] = aux_sym_number_token2,
  [aux_sym_number_token3] = aux_sym_number_token3,
  [anon_sym_true] = anon_sym_true,
  [anon_sym_false] = anon_sym_false,
  [anon_sym_CR] = anon_sym_CR,
  [sym_comment] = sym_comment,
  [sym_line_continuation] = sym_line_continuation,
  [sym_command_name] = sym_command_name,
  [sym_command_argument] = sym_command_argument,
  [sym__single_quote_string_start] = anon_sym_SQUOTE,
  [sym__single_quote_string_end] = anon_sym_SQUOTE,
  [sym__double_quote_string_start] = sym__double_quote_string_start,
  [sym__double_quote_string_end] = sym__double_quote_string_start,
  [sym_formatting_sequence] = sym_formatting_sequence,
  [sym_escape_sequence] = sym_escape_sequence,
  [sym_string_content] = sym_string_content,
  [sym__entry_delimiter] = anon_sym_COMMA,
  [sym__multioutput_variable_start] = anon_sym_LBRACK,
  [sym__external_identifier] = sym__external_identifier,
  [sym_error_sentinel] = sym_error_sentinel,
  [sym_source_file] = sym_source_file,
  [aux_sym__block] = aux_sym__block,
  [sym_block] = sym_block,
  [sym_identifier] = sym_identifier,
  [sym__statement] = sym__statement,
  [sym__expression] = sym__expression,
  [sym_parenthesis] = sym_parenthesis,
  [sym__binary_expression] = sym__binary_expression,
  [sym_binary_operator] = sym_binary_operator,
  [sym_unary_operator] = sym_unary_operator,
  [sym_indirect_access] = sym_indirect_access,
  [sym_field_expression] = sym_field_expression,
  [sym_not_operator] = sym_not_operator,
  [sym_metaclass_operator] = sym_metaclass_operator,
  [sym_handle_operator] = sym_handle_operator,
  [sym_comparison_operator] = sym_comparison_operator,
  [sym_boolean_operator] = sym_boolean_operator,
  [sym_postfix_operator] = sym_postfix_operator,
  [sym_string] = sym_string,
  [sym_row] = sym_row,
  [sym_matrix] = sym_matrix,
  [sym_cell] = sym_cell,
  [sym_ignored_argument] = sym_ignored_argument,
  [sym_assignment] = sym_assignment,
  [sym_multioutput_variable] = sym_multioutput_variable,
  [sym_spread_operator] = sym_spread_operator,
  [sym__index_row] = sym_row,
  [sym__index_matrix] = sym_matrix,
  [sym__index_range_element] = sym__index_range_element,
  [sym__index_range] = sym_range,
  [sym__index_parenthesis] = sym_parenthesis,
  [sym__index_expression] = sym__index_expression,
  [sym__index_binary_expression] = sym__index_binary_expression,
  [sym__index_binary_operator] = sym_binary_operator,
  [sym__index_argument] = sym__index_argument,
  [sym__index_arguments] = sym__index_arguments,
  [sym_arguments] = sym_arguments,
  [sym__args] = sym__args,
  [sym_function_call] = sym_function_call,
  [sym_command] = sym_command,
  [sym__range_element] = sym__range_element,
  [sym_range] = sym_range,
  [sym_return_statement] = sym_return_statement,
  [sym_continue_statement] = sym_continue_statement,
  [sym_break_statement] = sym_break_statement,
  [sym_elseif_clause] = sym_elseif_clause,
  [sym_else_clause] = sym_else_clause,
  [sym_if_statement] = sym_if_statement,
  [sym_iterator] = sym_iterator,
  [sym_parfor_options] = sym_parfor_options,
  [sym_for_statement] = sym_for_statement,
  [sym_while_statement] = sym_while_statement,
  [sym_case_clause] = sym_case_clause,
  [sym_otherwise_clause] = sym_otherwise_clause,
  [sym_switch_statement] = sym_switch_statement,
  [sym__lambda_arguments] = sym__lambda_arguments,
  [sym_lambda] = sym_lambda,
  [sym_global_operator] = sym_global_operator,
  [sym_persistent_operator] = sym_persistent_operator,
  [sym__argument_attributes] = sym_attributes,
  [sym_class_property] = sym_class_property,
  [sym_arguments_statement] = sym_arguments_statement,
  [sym_function_output] = sym_function_output,
  [sym_function_arguments] = sym_function_arguments,
  [sym_function_definition] = sym_function_definition,
  [sym__function_definition_with_end] = sym_function_definition,
  [sym_attribute] = sym_attribute,
  [sym_attributes] = sym_attributes,
  [sym_superclasses] = sym_superclasses,
  [sym_dimensions] = sym_dimensions,
  [sym_validation_functions] = sym_validation_functions,
  [sym_default_value] = sym_default_value,
  [sym_property_name] = sym_property_name,
  [sym_property] = sym_property,
  [sym_properties] = sym_properties,
  [sym_function_signature] = sym_function_signature,
  [sym_methods] = sym_methods,
  [sym_events] = sym_events,
  [sym_enum] = sym_enum,
  [sym_enumeration] = sym_enumeration,
  [sym_class_definition] = sym_class_definition,
  [sym_catch_clause] = sym_catch_clause,
  [sym_try_statement] = sym_try_statement,
  [sym_spmd_statement] = sym_spmd_statement,
  [sym_number] = sym_number,
  [sym_boolean] = sym_boolean,
  [sym_end_keyword] = sym_end_keyword,
  [sym__keywords] = sym__keywords,
  [sym__extended_keywords] = sym_identifier,
  [sym__end_of_line] = sym__end_of_line,
  [aux_sym_source_file_repeat1] = aux_sym_source_file_repeat1,
  [aux_sym__block_repeat1] = aux_sym__block_repeat1,
  [aux_sym_field_expression_repeat1] = aux_sym_field_expression_repeat1,
  [aux_sym_metaclass_operator_repeat1] = aux_sym_metaclass_operator_repeat1,
  [aux_sym_string_repeat1] = aux_sym_string_repeat1,
  [aux_sym_row_repeat1] = aux_sym_row_repeat1,
  [aux_sym_matrix_repeat1] = aux_sym_matrix_repeat1,
  [aux_sym_matrix_repeat2] = aux_sym_matrix_repeat2,
  [aux_sym_multioutput_variable_repeat1] = aux_sym_multioutput_variable_repeat1,
  [aux_sym__index_row_repeat1] = aux_sym__index_row_repeat1,
  [aux_sym__index_matrix_repeat1] = aux_sym__index_matrix_repeat1,
  [aux_sym__index_arguments_repeat1] = aux_sym__index_arguments_repeat1,
  [aux_sym_arguments_repeat1] = aux_sym_arguments_repeat1,
  [aux_sym_command_repeat1] = aux_sym_command_repeat1,
  [aux_sym_elseif_clause_repeat1] = aux_sym_elseif_clause_repeat1,
  [aux_sym_if_statement_repeat1] = aux_sym_if_statement_repeat1,
  [aux_sym_switch_statement_repeat1] = aux_sym_switch_statement_repeat1,
  [aux_sym__lambda_arguments_repeat1] = aux_sym__lambda_arguments_repeat1,
  [aux_sym_global_operator_repeat1] = aux_sym_global_operator_repeat1,
  [aux_sym__argument_attributes_repeat1] = aux_sym__argument_attributes_repeat1,
  [aux_sym_arguments_statement_repeat1] = aux_sym_arguments_statement_repeat1,
  [aux_sym_function_definition_repeat1] = aux_sym_function_definition_repeat1,
  [aux_sym_attributes_repeat1] = aux_sym_attributes_repeat1,
  [aux_sym_superclasses_repeat1] = aux_sym_superclasses_repeat1,
  [aux_sym_dimensions_repeat1] = aux_sym_dimensions_repeat1,
  [aux_sym_validation_functions_repeat1] = aux_sym_validation_functions_repeat1,
  [aux_sym_properties_repeat1] = aux_sym_properties_repeat1,
  [aux_sym_methods_repeat1] = aux_sym_methods_repeat1,
  [aux_sym_events_repeat1] = aux_sym_events_repeat1,
  [aux_sym_enum_repeat1] = aux_sym_enum_repeat1,
  [aux_sym_enumeration_repeat1] = aux_sym_enumeration_repeat1,
  [aux_sym_class_definition_repeat1] = aux_sym_class_definition_repeat1,
  [alias_sym_superclass] = alias_sym_superclass,
};

static const TSSymbolMetadata ts_symbol_metadata[] = {
  [ts_builtin_sym_end] = {
    .visible = false,
    .named = true,
  },
  [anon_sym_SEMI] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COMMA] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT_PLUS] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT_DASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT_STAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SLASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT_SLASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BSLASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT_BSLASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_CARET] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT_CARET] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_TILDE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_QMARK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_TILDE_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP_AMP] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE_PIPE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT_SQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LF] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_matrix_token1] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_RBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_return] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_continue] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_break] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_elseif] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_else] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_if] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_end] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_for] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_parfor] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_while] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_case] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_otherwise] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_switch] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_global] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_persistent] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT_QMARK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_arguments] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_function] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_get_DOT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_set_DOT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_endfunction] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_vector] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_matrix] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_scalar] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_properties] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_get] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_set] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_methods] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_events] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_enumeration] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_classdef] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_catch] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_try] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_spmd] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_number_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_number_token2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_number_token3] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_true] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_false] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_CR] = {
    .visible = true,
    .named = false,
  },
  [sym_comment] = {
    .visible = true,
    .named = true,
  },
  [sym_line_continuation] = {
    .visible = true,
    .named = true,
  },
  [sym_command_name] = {
    .visible = true,
    .named = true,
  },
  [sym_command_argument] = {
    .visible = true,
    .named = true,
  },
  [sym__single_quote_string_start] = {
    .visible = true,
    .named = false,
  },
  [sym__single_quote_string_end] = {
    .visible = true,
    .named = false,
  },
  [sym__double_quote_string_start] = {
    .visible = true,
    .named = false,
  },
  [sym__double_quote_string_end] = {
    .visible = true,
    .named = false,
  },
  [sym_formatting_sequence] = {
    .visible = true,
    .named = true,
  },
  [sym_escape_sequence] = {
    .visible = true,
    .named = true,
  },
  [sym_string_content] = {
    .visible = true,
    .named = true,
  },
  [sym__entry_delimiter] = {
    .visible = true,
    .named = false,
  },
  [sym__multioutput_variable_start] = {
    .visible = true,
    .named = false,
  },
  [sym__external_identifier] = {
    .visible = false,
    .named = true,
  },
  [sym_error_sentinel] = {
    .visible = true,
    .named = true,
  },
  [sym_source_file] = {
    .visible = true,
    .named = true,
  },
  [aux_sym__block] = {
    .visible = false,
    .named = false,
  },
  [sym_block] = {
    .visible = true,
    .named = true,
  },
  [sym_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym__statement] = {
    .visible = false,
    .named = true,
  },
  [sym__expression] = {
    .visible = false,
    .named = true,
  },
  [sym_parenthesis] = {
    .visible = true,
    .named = true,
  },
  [sym__binary_expression] = {
    .visible = false,
    .named = true,
  },
  [sym_binary_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_unary_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_indirect_access] = {
    .visible = true,
    .named = true,
  },
  [sym_field_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_not_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_metaclass_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_handle_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_comparison_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_boolean_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_postfix_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_string] = {
    .visible = true,
    .named = true,
  },
  [sym_row] = {
    .visible = true,
    .named = true,
  },
  [sym_matrix] = {
    .visible = true,
    .named = true,
  },
  [sym_cell] = {
    .visible = true,
    .named = true,
  },
  [sym_ignored_argument] = {
    .visible = true,
    .named = true,
  },
  [sym_assignment] = {
    .visible = true,
    .named = true,
  },
  [sym_multioutput_variable] = {
    .visible = true,
    .named = true,
  },
  [sym_spread_operator] = {
    .visible = true,
    .named = true,
  },
  [sym__index_row] = {
    .visible = true,
    .named = true,
  },
  [sym__index_matrix] = {
    .visible = true,
    .named = true,
  },
  [sym__index_range_element] = {
    .visible = false,
    .named = true,
  },
  [sym__index_range] = {
    .visible = true,
    .named = true,
  },
  [sym__index_parenthesis] = {
    .visible = true,
    .named = true,
  },
  [sym__index_expression] = {
    .visible = false,
    .named = true,
  },
  [sym__index_binary_expression] = {
    .visible = false,
    .named = true,
  },
  [sym__index_binary_operator] = {
    .visible = true,
    .named = true,
  },
  [sym__index_argument] = {
    .visible = false,
    .named = true,
  },
  [sym__index_arguments] = {
    .visible = false,
    .named = true,
  },
  [sym_arguments] = {
    .visible = true,
    .named = true,
  },
  [sym__args] = {
    .visible = false,
    .named = true,
  },
  [sym_function_call] = {
    .visible = true,
    .named = true,
  },
  [sym_command] = {
    .visible = true,
    .named = true,
  },
  [sym__range_element] = {
    .visible = false,
    .named = true,
  },
  [sym_range] = {
    .visible = true,
    .named = true,
  },
  [sym_return_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_continue_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_break_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_elseif_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_else_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_if_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_iterator] = {
    .visible = true,
    .named = true,
  },
  [sym_parfor_options] = {
    .visible = true,
    .named = true,
  },
  [sym_for_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_while_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_case_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_otherwise_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_switch_statement] = {
    .visible = true,
    .named = true,
  },
  [sym__lambda_arguments] = {
    .visible = false,
    .named = true,
  },
  [sym_lambda] = {
    .visible = true,
    .named = true,
  },
  [sym_global_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_persistent_operator] = {
    .visible = true,
    .named = true,
  },
  [sym__argument_attributes] = {
    .visible = true,
    .named = true,
  },
  [sym_class_property] = {
    .visible = true,
    .named = true,
  },
  [sym_arguments_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_function_output] = {
    .visible = true,
    .named = true,
  },
  [sym_function_arguments] = {
    .visible = true,
    .named = true,
  },
  [sym_function_definition] = {
    .visible = true,
    .named = true,
  },
  [sym__function_definition_with_end] = {
    .visible = true,
    .named = true,
  },
  [sym_attribute] = {
    .visible = true,
    .named = true,
  },
  [sym_attributes] = {
    .visible = true,
    .named = true,
  },
  [sym_superclasses] = {
    .visible = true,
    .named = true,
  },
  [sym_dimensions] = {
    .visible = true,
    .named = true,
  },
  [sym_validation_functions] = {
    .visible = true,
    .named = true,
  },
  [sym_default_value] = {
    .visible = true,
    .named = true,
  },
  [sym_property_name] = {
    .visible = true,
    .named = true,
  },
  [sym_property] = {
    .visible = true,
    .named = true,
  },
  [sym_properties] = {
    .visible = true,
    .named = true,
  },
  [sym_function_signature] = {
    .visible = true,
    .named = true,
  },
  [sym_methods] = {
    .visible = true,
    .named = true,
  },
  [sym_events] = {
    .visible = true,
    .named = true,
  },
  [sym_enum] = {
    .visible = true,
    .named = true,
  },
  [sym_enumeration] = {
    .visible = true,
    .named = true,
  },
  [sym_class_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_catch_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_try_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_spmd_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_number] = {
    .visible = true,
    .named = true,
  },
  [sym_boolean] = {
    .visible = true,
    .named = true,
  },
  [sym_end_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym__keywords] = {
    .visible = false,
    .named = true,
  },
  [sym__extended_keywords] = {
    .visible = true,
    .named = true,
  },
  [sym__end_of_line] = {
    .visible = false,
    .named = true,
  },
  [aux_sym_source_file_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__block_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_field_expression_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_metaclass_operator_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_string_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_row_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_matrix_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_matrix_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_multioutput_variable_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__index_row_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__index_matrix_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__index_arguments_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_arguments_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_command_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_elseif_clause_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_if_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_switch_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__lambda_arguments_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_global_operator_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__argument_attributes_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_arguments_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_function_definition_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_attributes_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_superclasses_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_dimensions_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_validation_functions_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_properties_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_methods_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_events_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_enum_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_enumeration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_class_definition_repeat1] = {
    .visible = false,
    .named = false,
  },
  [alias_sym_superclass] = {
    .visible = true,
    .named = true,
  },
};

enum ts_field_identifiers {
  field_argument = 1,
  field_arguments = 2,
  field_condition = 3,
  field_expression = 4,
  field_field = 5,
  field_left = 6,
  field_name = 7,
  field_object = 8,
  field_operand = 9,
  field_right = 10,
};

static const char * const ts_field_names[] = {
  [0] = NULL,
  [field_argument] = "argument",
  [field_arguments] = "arguments",
  [field_condition] = "condition",
  [field_expression] = "expression",
  [field_field] = "field",
  [field_left] = "left",
  [field_name] = "name",
  [field_object] = "object",
  [field_operand] = "operand",
  [field_right] = "right",
};

static const TSMapSlice ts_field_map_slices[PRODUCTION_ID_COUNT] = {
  [1] = {.index = 0, .length = 1},
  [2] = {.index = 1, .length = 1},
  [3] = {.index = 2, .length = 1},
  [4] = {.index = 3, .length = 2},
  [5] = {.index = 5, .length = 1},
  [6] = {.index = 2, .length = 1},
  [7] = {.index = 6, .length = 1},
  [8] = {.index = 7, .length = 1},
  [9] = {.index = 8, .length = 2},
  [10] = {.index = 10, .length = 1},
  [11] = {.index = 11, .length = 1},
  [12] = {.index = 12, .length = 1},
  [13] = {.index = 13, .length = 2},
  [14] = {.index = 15, .length = 2},
  [15] = {.index = 17, .length = 1},
  [16] = {.index = 18, .length = 1},
  [17] = {.index = 19, .length = 2},
  [18] = {.index = 2, .length = 1},
  [19] = {.index = 2, .length = 1},
  [20] = {.index = 21, .length = 1},
  [21] = {.index = 22, .length = 1},
  [22] = {.index = 23, .length = 1},
  [23] = {.index = 24, .length = 1},
  [24] = {.index = 25, .length = 2},
  [25] = {.index = 27, .length = 1},
  [26] = {.index = 7, .length = 1},
  [27] = {.index = 28, .length = 2},
  [28] = {.index = 18, .length = 1},
};

static const TSFieldMapEntry ts_field_map_entries[] = {
  [0] =
    {field_operand, 1},
  [1] =
    {field_operand, 0},
  [2] =
    {field_name, 0},
  [3] =
    {field_field, 1, .inherited = true},
    {field_object, 0},
  [5] =
    {field_name, 0, .inherited = true},
  [6] =
    {field_condition, 1},
  [7] =
    {field_name, 1},
  [8] =
    {field_left, 0, .inherited = true},
    {field_right, 0, .inherited = true},
  [10] =
    {field_argument, 0},
  [11] =
    {field_argument, 0, .inherited = true},
  [12] =
    {field_field, 1},
  [13] =
    {field_left, 0},
    {field_right, 2},
  [15] =
    {field_field, 0, .inherited = true},
    {field_field, 1, .inherited = true},
  [17] =
    {field_expression, 3},
  [18] =
    {field_name, 2},
  [19] =
    {field_argument, 0},
    {field_argument, 1, .inherited = true},
  [21] =
    {field_expression, 4},
  [22] =
    {field_arguments, 1},
  [23] =
    {field_name, 3},
  [24] =
    {field_argument, 1},
  [25] =
    {field_argument, 0, .inherited = true},
    {field_argument, 1, .inherited = true},
  [27] =
    {field_argument, 1, .inherited = true},
  [28] =
    {field_argument, 1},
    {field_argument, 2, .inherited = true},
};

static const TSSymbol ts_alias_sequences[PRODUCTION_ID_COUNT][MAX_ALIAS_SEQUENCE_LENGTH] = {
  [0] = {0},
  [6] = {
    [0] = sym_identifier,
  },
  [18] = {
    [2] = alias_sym_superclass,
  },
  [19] = {
    [0] = sym_identifier,
    [2] = alias_sym_superclass,
  },
  [20] = {
    [2] = sym_arguments,
  },
  [26] = {
    [1] = sym_identifier,
  },
  [28] = {
    [2] = sym_identifier,
  },
};

static const uint16_t ts_non_terminal_alias_map[] = {
  sym__lambda_arguments, 2,
    sym__lambda_arguments,
    sym_arguments,
  sym_property_name, 2,
    sym_property_name,
    alias_sym_superclass,
  sym_boolean, 2,
    sym_boolean,
    sym_identifier,
  0,
};

static const TSStateId ts_primary_state_ids[STATE_COUNT] = {
  [0] = 0,
  [1] = 1,
  [2] = 2,
  [3] = 3,
  [4] = 4,
  [5] = 5,
  [6] = 6,
  [7] = 7,
  [8] = 8,
  [9] = 9,
  [10] = 10,
  [11] = 11,
  [12] = 12,
  [13] = 13,
  [14] = 14,
  [15] = 15,
  [16] = 16,
  [17] = 17,
  [18] = 18,
  [19] = 19,
  [20] = 20,
  [21] = 21,
  [22] = 22,
  [23] = 23,
  [24] = 24,
  [25] = 25,
  [26] = 26,
  [27] = 27,
  [28] = 28,
  [29] = 29,
  [30] = 30,
  [31] = 31,
  [32] = 32,
  [33] = 33,
  [34] = 34,
  [35] = 35,
  [36] = 36,
  [37] = 37,
  [38] = 38,
  [39] = 39,
  [40] = 40,
  [41] = 41,
  [42] = 42,
  [43] = 43,
  [44] = 44,
  [45] = 45,
  [46] = 46,
  [47] = 47,
  [48] = 48,
  [49] = 49,
  [50] = 50,
  [51] = 51,
  [52] = 52,
  [53] = 53,
  [54] = 54,
  [55] = 55,
  [56] = 56,
  [57] = 57,
  [58] = 58,
  [59] = 59,
  [60] = 60,
  [61] = 61,
  [62] = 62,
  [63] = 63,
  [64] = 64,
  [65] = 65,
  [66] = 66,
  [67] = 67,
  [68] = 46,
  [69] = 54,
  [70] = 46,
  [71] = 54,
  [72] = 72,
  [73] = 73,
  [74] = 73,
  [75] = 73,
  [76] = 73,
  [77] = 77,
  [78] = 78,
  [79] = 79,
  [80] = 80,
  [81] = 81,
  [82] = 82,
  [83] = 83,
  [84] = 84,
  [85] = 85,
  [86] = 86,
  [87] = 87,
  [88] = 88,
  [89] = 89,
  [90] = 90,
  [91] = 91,
  [92] = 92,
  [93] = 93,
  [94] = 94,
  [95] = 95,
  [96] = 95,
  [97] = 97,
  [98] = 95,
  [99] = 99,
  [100] = 95,
  [101] = 101,
  [102] = 102,
  [103] = 103,
  [104] = 104,
  [105] = 105,
  [106] = 106,
  [107] = 107,
  [108] = 108,
  [109] = 109,
  [110] = 110,
  [111] = 111,
  [112] = 112,
  [113] = 113,
  [114] = 114,
  [115] = 115,
  [116] = 116,
  [117] = 117,
  [118] = 118,
  [119] = 119,
  [120] = 120,
  [121] = 121,
  [122] = 122,
  [123] = 123,
  [124] = 124,
  [125] = 125,
  [126] = 126,
  [127] = 127,
  [128] = 128,
  [129] = 129,
  [130] = 130,
  [131] = 131,
  [132] = 132,
  [133] = 133,
  [134] = 105,
  [135] = 132,
  [136] = 136,
  [137] = 107,
  [138] = 133,
  [139] = 132,
  [140] = 105,
  [141] = 132,
  [142] = 105,
  [143] = 136,
  [144] = 133,
  [145] = 133,
  [146] = 146,
  [147] = 147,
  [148] = 148,
  [149] = 149,
  [150] = 136,
  [151] = 146,
  [152] = 147,
  [153] = 124,
  [154] = 148,
  [155] = 155,
  [156] = 155,
  [157] = 157,
  [158] = 157,
  [159] = 155,
  [160] = 155,
  [161] = 157,
  [162] = 157,
  [163] = 155,
  [164] = 157,
  [165] = 155,
  [166] = 157,
  [167] = 167,
  [168] = 168,
  [169] = 169,
  [170] = 169,
  [171] = 171,
  [172] = 171,
  [173] = 169,
  [174] = 171,
  [175] = 171,
  [176] = 169,
  [177] = 169,
  [178] = 171,
  [179] = 179,
  [180] = 180,
  [181] = 181,
  [182] = 182,
  [183] = 183,
  [184] = 184,
  [185] = 185,
  [186] = 186,
  [187] = 187,
  [188] = 188,
  [189] = 188,
  [190] = 81,
  [191] = 83,
  [192] = 77,
  [193] = 82,
  [194] = 80,
  [195] = 188,
  [196] = 97,
  [197] = 93,
  [198] = 198,
  [199] = 199,
  [200] = 200,
  [201] = 200,
  [202] = 198,
  [203] = 203,
  [204] = 204,
  [205] = 205,
  [206] = 206,
  [207] = 207,
  [208] = 208,
  [209] = 203,
  [210] = 210,
  [211] = 203,
  [212] = 212,
  [213] = 213,
  [214] = 204,
  [215] = 210,
  [216] = 203,
  [217] = 212,
  [218] = 213,
  [219] = 204,
  [220] = 210,
  [221] = 212,
  [222] = 205,
  [223] = 206,
  [224] = 205,
  [225] = 206,
  [226] = 207,
  [227] = 208,
  [228] = 210,
  [229] = 213,
  [230] = 207,
  [231] = 205,
  [232] = 206,
  [233] = 207,
  [234] = 208,
  [235] = 213,
  [236] = 208,
  [237] = 204,
  [238] = 212,
  [239] = 239,
  [240] = 240,
  [241] = 241,
  [242] = 242,
  [243] = 243,
  [244] = 244,
  [245] = 245,
  [246] = 246,
  [247] = 247,
  [248] = 248,
  [249] = 249,
  [250] = 250,
  [251] = 251,
  [252] = 240,
  [253] = 253,
  [254] = 254,
  [255] = 255,
  [256] = 255,
  [257] = 257,
  [258] = 258,
  [259] = 259,
  [260] = 260,
  [261] = 261,
  [262] = 262,
  [263] = 263,
  [264] = 264,
  [265] = 265,
  [266] = 266,
  [267] = 267,
  [268] = 268,
  [269] = 254,
  [270] = 261,
  [271] = 271,
  [272] = 272,
  [273] = 273,
  [274] = 274,
  [275] = 275,
  [276] = 276,
  [277] = 277,
  [278] = 278,
  [279] = 279,
  [280] = 280,
  [281] = 255,
  [282] = 282,
  [283] = 283,
  [284] = 262,
  [285] = 285,
  [286] = 271,
  [287] = 272,
  [288] = 273,
  [289] = 274,
  [290] = 275,
  [291] = 276,
  [292] = 277,
  [293] = 278,
  [294] = 279,
  [295] = 280,
  [296] = 296,
  [297] = 255,
  [298] = 262,
  [299] = 271,
  [300] = 272,
  [301] = 273,
  [302] = 274,
  [303] = 275,
  [304] = 276,
  [305] = 277,
  [306] = 278,
  [307] = 279,
  [308] = 271,
  [309] = 272,
  [310] = 273,
  [311] = 274,
  [312] = 275,
  [313] = 276,
  [314] = 277,
  [315] = 296,
  [316] = 279,
  [317] = 280,
  [318] = 255,
  [319] = 280,
  [320] = 262,
  [321] = 321,
  [322] = 296,
  [323] = 280,
  [324] = 324,
  [325] = 255,
  [326] = 326,
  [327] = 259,
  [328] = 261,
  [329] = 271,
  [330] = 272,
  [331] = 273,
  [332] = 324,
  [333] = 254,
  [334] = 271,
  [335] = 272,
  [336] = 273,
  [337] = 280,
  [338] = 255,
  [339] = 271,
  [340] = 272,
  [341] = 273,
  [342] = 280,
  [343] = 255,
  [344] = 271,
  [345] = 272,
  [346] = 273,
  [347] = 280,
  [348] = 255,
  [349] = 280,
  [350] = 255,
  [351] = 259,
  [352] = 261,
  [353] = 254,
  [354] = 259,
  [355] = 259,
  [356] = 296,
  [357] = 280,
  [358] = 255,
  [359] = 280,
  [360] = 255,
  [361] = 280,
  [362] = 278,
  [363] = 245,
  [364] = 248,
  [365] = 246,
  [366] = 247,
  [367] = 249,
  [368] = 368,
  [369] = 369,
  [370] = 370,
  [371] = 371,
  [372] = 372,
  [373] = 93,
  [374] = 73,
  [375] = 73,
  [376] = 73,
  [377] = 73,
  [378] = 78,
  [379] = 72,
  [380] = 87,
  [381] = 99,
  [382] = 382,
  [383] = 383,
  [384] = 90,
  [385] = 382,
  [386] = 91,
  [387] = 85,
  [388] = 382,
  [389] = 92,
  [390] = 382,
  [391] = 101,
  [392] = 86,
  [393] = 382,
  [394] = 95,
  [395] = 73,
  [396] = 73,
  [397] = 95,
  [398] = 73,
  [399] = 73,
  [400] = 72,
  [401] = 401,
  [402] = 95,
  [403] = 94,
  [404] = 95,
  [405] = 405,
  [406] = 406,
  [407] = 406,
  [408] = 408,
  [409] = 104,
  [410] = 79,
  [411] = 411,
  [412] = 84,
  [413] = 78,
  [414] = 405,
  [415] = 408,
  [416] = 89,
  [417] = 94,
  [418] = 408,
  [419] = 73,
  [420] = 77,
  [421] = 73,
  [422] = 73,
  [423] = 73,
  [424] = 95,
  [425] = 95,
  [426] = 72,
  [427] = 95,
  [428] = 82,
  [429] = 405,
  [430] = 408,
  [431] = 90,
  [432] = 406,
  [433] = 88,
  [434] = 91,
  [435] = 80,
  [436] = 101,
  [437] = 437,
  [438] = 99,
  [439] = 92,
  [440] = 95,
  [441] = 81,
  [442] = 87,
  [443] = 86,
  [444] = 83,
  [445] = 93,
  [446] = 85,
  [447] = 405,
  [448] = 448,
  [449] = 448,
  [450] = 450,
  [451] = 451,
  [452] = 93,
  [453] = 104,
  [454] = 78,
  [455] = 97,
  [456] = 456,
  [457] = 450,
  [458] = 451,
  [459] = 459,
  [460] = 459,
  [461] = 132,
  [462] = 133,
  [463] = 136,
  [464] = 459,
  [465] = 99,
  [466] = 450,
  [467] = 101,
  [468] = 451,
  [469] = 87,
  [470] = 86,
  [471] = 107,
  [472] = 126,
  [473] = 131,
  [474] = 114,
  [475] = 90,
  [476] = 91,
  [477] = 92,
  [478] = 111,
  [479] = 450,
  [480] = 451,
  [481] = 102,
  [482] = 459,
  [483] = 84,
  [484] = 108,
  [485] = 116,
  [486] = 79,
  [487] = 85,
  [488] = 117,
  [489] = 113,
  [490] = 115,
  [491] = 107,
  [492] = 118,
  [493] = 459,
  [494] = 119,
  [495] = 103,
  [496] = 95,
  [497] = 110,
  [498] = 106,
  [499] = 82,
  [500] = 80,
  [501] = 81,
  [502] = 83,
  [503] = 105,
  [504] = 132,
  [505] = 105,
  [506] = 132,
  [507] = 136,
  [508] = 95,
  [509] = 133,
  [510] = 95,
  [511] = 133,
  [512] = 132,
  [513] = 105,
  [514] = 146,
  [515] = 147,
  [516] = 456,
  [517] = 148,
  [518] = 95,
  [519] = 133,
  [520] = 124,
  [521] = 459,
  [522] = 94,
  [523] = 112,
  [524] = 127,
  [525] = 448,
  [526] = 129,
  [527] = 130,
  [528] = 105,
  [529] = 120,
  [530] = 128,
  [531] = 121,
  [532] = 122,
  [533] = 123,
  [534] = 149,
  [535] = 125,
  [536] = 109,
  [537] = 77,
  [538] = 97,
  [539] = 88,
  [540] = 104,
  [541] = 89,
  [542] = 81,
  [543] = 130,
  [544] = 103,
  [545] = 131,
  [546] = 132,
  [547] = 133,
  [548] = 105,
  [549] = 136,
  [550] = 106,
  [551] = 107,
  [552] = 108,
  [553] = 109,
  [554] = 110,
  [555] = 111,
  [556] = 112,
  [557] = 113,
  [558] = 114,
  [559] = 105,
  [560] = 102,
  [561] = 77,
  [562] = 82,
  [563] = 80,
  [564] = 83,
  [565] = 132,
  [566] = 136,
  [567] = 115,
  [568] = 84,
  [569] = 107,
  [570] = 116,
  [571] = 133,
  [572] = 117,
  [573] = 118,
  [574] = 132,
  [575] = 105,
  [576] = 132,
  [577] = 105,
  [578] = 136,
  [579] = 133,
  [580] = 133,
  [581] = 79,
  [582] = 120,
  [583] = 121,
  [584] = 122,
  [585] = 123,
  [586] = 149,
  [587] = 587,
  [588] = 146,
  [589] = 147,
  [590] = 148,
  [591] = 125,
  [592] = 124,
  [593] = 126,
  [594] = 594,
  [595] = 127,
  [596] = 128,
  [597] = 129,
  [598] = 119,
  [599] = 599,
  [600] = 600,
  [601] = 601,
  [602] = 602,
  [603] = 603,
  [604] = 604,
  [605] = 605,
  [606] = 604,
  [607] = 607,
  [608] = 88,
  [609] = 609,
  [610] = 610,
  [611] = 89,
  [612] = 148,
  [613] = 605,
  [614] = 97,
  [615] = 600,
  [616] = 600,
  [617] = 603,
  [618] = 603,
  [619] = 124,
  [620] = 609,
  [621] = 601,
  [622] = 146,
  [623] = 147,
  [624] = 602,
  [625] = 610,
  [626] = 127,
  [627] = 103,
  [628] = 607,
  [629] = 133,
  [630] = 603,
  [631] = 132,
  [632] = 132,
  [633] = 105,
  [634] = 602,
  [635] = 106,
  [636] = 107,
  [637] = 105,
  [638] = 602,
  [639] = 133,
  [640] = 607,
  [641] = 136,
  [642] = 136,
  [643] = 108,
  [644] = 610,
  [645] = 132,
  [646] = 610,
  [647] = 146,
  [648] = 147,
  [649] = 148,
  [650] = 120,
  [651] = 605,
  [652] = 604,
  [653] = 124,
  [654] = 109,
  [655] = 110,
  [656] = 111,
  [657] = 112,
  [658] = 128,
  [659] = 105,
  [660] = 130,
  [661] = 132,
  [662] = 121,
  [663] = 113,
  [664] = 114,
  [665] = 102,
  [666] = 105,
  [667] = 115,
  [668] = 136,
  [669] = 123,
  [670] = 149,
  [671] = 129,
  [672] = 125,
  [673] = 133,
  [674] = 603,
  [675] = 600,
  [676] = 601,
  [677] = 600,
  [678] = 609,
  [679] = 133,
  [680] = 126,
  [681] = 107,
  [682] = 601,
  [683] = 603,
  [684] = 116,
  [685] = 600,
  [686] = 131,
  [687] = 117,
  [688] = 609,
  [689] = 118,
  [690] = 119,
  [691] = 122,
  [692] = 692,
  [693] = 693,
  [694] = 693,
  [695] = 148,
  [696] = 696,
  [697] = 607,
  [698] = 698,
  [699] = 699,
  [700] = 700,
  [701] = 124,
  [702] = 702,
  [703] = 703,
  [704] = 704,
  [705] = 705,
  [706] = 706,
  [707] = 698,
  [708] = 146,
  [709] = 147,
  [710] = 692,
  [711] = 711,
  [712] = 693,
  [713] = 704,
  [714] = 705,
  [715] = 706,
  [716] = 706,
  [717] = 706,
  [718] = 704,
  [719] = 705,
  [720] = 706,
  [721] = 692,
  [722] = 698,
  [723] = 704,
  [724] = 699,
  [725] = 704,
  [726] = 705,
  [727] = 706,
  [728] = 699,
  [729] = 136,
  [730] = 705,
  [731] = 731,
  [732] = 692,
  [733] = 704,
  [734] = 705,
  [735] = 693,
  [736] = 124,
  [737] = 133,
  [738] = 146,
  [739] = 699,
  [740] = 132,
  [741] = 147,
  [742] = 133,
  [743] = 133,
  [744] = 148,
  [745] = 107,
  [746] = 746,
  [747] = 607,
  [748] = 107,
  [749] = 749,
  [750] = 107,
  [751] = 751,
  [752] = 752,
  [753] = 753,
  [754] = 754,
  [755] = 755,
  [756] = 756,
  [757] = 757,
  [758] = 758,
  [759] = 759,
  [760] = 760,
  [761] = 761,
  [762] = 762,
  [763] = 763,
  [764] = 764,
  [765] = 765,
  [766] = 766,
  [767] = 767,
  [768] = 768,
  [769] = 769,
  [770] = 770,
  [771] = 771,
  [772] = 772,
  [773] = 773,
  [774] = 774,
  [775] = 83,
  [776] = 776,
  [777] = 777,
  [778] = 778,
  [779] = 779,
  [780] = 780,
  [781] = 781,
  [782] = 782,
  [783] = 93,
  [784] = 784,
  [785] = 785,
  [786] = 786,
  [787] = 787,
  [788] = 97,
  [789] = 789,
  [790] = 790,
  [791] = 791,
  [792] = 792,
  [793] = 793,
  [794] = 794,
  [795] = 795,
  [796] = 796,
  [797] = 244,
  [798] = 798,
  [799] = 799,
  [800] = 87,
  [801] = 787,
  [802] = 802,
  [803] = 790,
  [804] = 92,
  [805] = 798,
  [806] = 792,
  [807] = 807,
  [808] = 808,
  [809] = 93,
  [810] = 793,
  [811] = 811,
  [812] = 812,
  [813] = 784,
  [814] = 786,
  [815] = 787,
  [816] = 789,
  [817] = 789,
  [818] = 78,
  [819] = 778,
  [820] = 791,
  [821] = 779,
  [822] = 93,
  [823] = 90,
  [824] = 782,
  [825] = 796,
  [826] = 99,
  [827] = 827,
  [828] = 91,
  [829] = 784,
  [830] = 794,
  [831] = 831,
  [832] = 785,
  [833] = 101,
  [834] = 83,
  [835] = 786,
  [836] = 790,
  [837] = 787,
  [838] = 838,
  [839] = 789,
  [840] = 790,
  [841] = 82,
  [842] = 842,
  [843] = 784,
  [844] = 844,
  [845] = 86,
  [846] = 786,
  [847] = 847,
  [848] = 848,
  [849] = 849,
  [850] = 850,
  [851] = 851,
  [852] = 80,
  [853] = 97,
  [854] = 854,
  [855] = 81,
  [856] = 85,
  [857] = 77,
  [858] = 858,
  [859] = 859,
  [860] = 860,
  [861] = 244,
  [862] = 84,
  [863] = 79,
  [864] = 864,
  [865] = 865,
  [866] = 866,
  [867] = 867,
  [868] = 868,
  [869] = 869,
  [870] = 870,
  [871] = 871,
  [872] = 872,
  [873] = 873,
  [874] = 874,
  [875] = 875,
  [876] = 876,
  [877] = 77,
  [878] = 878,
  [879] = 879,
  [880] = 88,
  [881] = 81,
  [882] = 599,
  [883] = 883,
  [884] = 884,
  [885] = 885,
  [886] = 831,
  [887] = 887,
  [888] = 83,
  [889] = 83,
  [890] = 82,
  [891] = 891,
  [892] = 892,
  [893] = 80,
  [894] = 83,
  [895] = 89,
  [896] = 896,
  [897] = 872,
  [898] = 898,
  [899] = 899,
  [900] = 97,
  [901] = 901,
  [902] = 902,
  [903] = 903,
  [904] = 93,
  [905] = 905,
  [906] = 93,
  [907] = 97,
  [908] = 908,
  [909] = 896,
  [910] = 908,
  [911] = 911,
  [912] = 896,
  [913] = 911,
  [914] = 908,
  [915] = 97,
  [916] = 896,
  [917] = 911,
  [918] = 908,
  [919] = 896,
  [920] = 896,
  [921] = 921,
  [922] = 896,
  [923] = 896,
  [924] = 896,
  [925] = 896,
  [926] = 911,
  [927] = 896,
  [928] = 896,
  [929] = 874,
  [930] = 930,
  [931] = 867,
  [932] = 932,
  [933] = 80,
  [934] = 81,
  [935] = 935,
  [936] = 936,
  [937] = 937,
  [938] = 930,
  [939] = 930,
  [940] = 82,
  [941] = 77,
  [942] = 942,
  [943] = 943,
  [944] = 944,
  [945] = 945,
  [946] = 946,
  [947] = 947,
  [948] = 948,
  [949] = 949,
  [950] = 950,
  [951] = 951,
  [952] = 952,
  [953] = 953,
  [954] = 954,
  [955] = 955,
  [956] = 956,
  [957] = 957,
  [958] = 958,
  [959] = 959,
  [960] = 960,
  [961] = 955,
  [962] = 962,
  [963] = 963,
  [964] = 964,
  [965] = 965,
  [966] = 966,
  [967] = 955,
  [968] = 968,
  [969] = 969,
  [970] = 970,
  [971] = 971,
  [972] = 972,
  [973] = 973,
  [974] = 974,
  [975] = 975,
  [976] = 976,
  [977] = 977,
  [978] = 978,
  [979] = 957,
  [980] = 955,
  [981] = 975,
  [982] = 973,
  [983] = 975,
  [984] = 955,
  [985] = 985,
  [986] = 973,
  [987] = 975,
  [988] = 955,
  [989] = 955,
  [990] = 955,
  [991] = 973,
  [992] = 955,
  [993] = 955,
  [994] = 955,
  [995] = 956,
  [996] = 985,
  [997] = 957,
  [998] = 955,
  [999] = 985,
  [1000] = 957,
  [1001] = 985,
  [1002] = 957,
  [1003] = 985,
  [1004] = 1004,
  [1005] = 1005,
  [1006] = 1006,
  [1007] = 1007,
  [1008] = 1008,
  [1009] = 1009,
  [1010] = 1010,
  [1011] = 1011,
  [1012] = 1012,
  [1013] = 1013,
  [1014] = 1009,
  [1015] = 1015,
  [1016] = 1005,
  [1017] = 1017,
  [1018] = 1009,
  [1019] = 1019,
  [1020] = 1005,
  [1021] = 1005,
  [1022] = 1022,
  [1023] = 1023,
  [1024] = 1024,
  [1025] = 1009,
  [1026] = 1005,
  [1027] = 1009,
  [1028] = 1028,
  [1029] = 1005,
  [1030] = 1005,
  [1031] = 1009,
  [1032] = 1005,
  [1033] = 1033,
  [1034] = 1009,
  [1035] = 1035,
  [1036] = 1005,
  [1037] = 1009,
  [1038] = 1038,
  [1039] = 1039,
  [1040] = 1005,
  [1041] = 1041,
  [1042] = 831,
  [1043] = 243,
  [1044] = 1044,
  [1045] = 1044,
  [1046] = 1044,
  [1047] = 1044,
  [1048] = 1048,
  [1049] = 244,
  [1050] = 1050,
  [1051] = 1050,
  [1052] = 1052,
  [1053] = 1053,
  [1054] = 1054,
  [1055] = 1050,
  [1056] = 1056,
  [1057] = 1057,
  [1058] = 1050,
  [1059] = 1050,
  [1060] = 1060,
  [1061] = 1061,
  [1062] = 1062,
  [1063] = 1063,
  [1064] = 1050,
  [1065] = 1065,
  [1066] = 874,
  [1067] = 1067,
  [1068] = 1068,
  [1069] = 1069,
  [1070] = 1070,
  [1071] = 1071,
  [1072] = 1072,
  [1073] = 1073,
  [1074] = 1074,
  [1075] = 1075,
  [1076] = 1076,
  [1077] = 1077,
  [1078] = 1078,
  [1079] = 1079,
  [1080] = 1080,
  [1081] = 867,
  [1082] = 1082,
  [1083] = 1083,
  [1084] = 1084,
  [1085] = 1085,
  [1086] = 1086,
  [1087] = 1087,
  [1088] = 1088,
  [1089] = 1089,
  [1090] = 1090,
  [1091] = 1091,
  [1092] = 1092,
  [1093] = 1093,
  [1094] = 1094,
  [1095] = 1095,
  [1096] = 1096,
  [1097] = 1097,
  [1098] = 1098,
  [1099] = 1099,
  [1100] = 1100,
  [1101] = 1101,
  [1102] = 1102,
  [1103] = 1103,
  [1104] = 1104,
  [1105] = 1105,
  [1106] = 1106,
  [1107] = 1107,
  [1108] = 1108,
  [1109] = 1109,
  [1110] = 1110,
  [1111] = 1111,
  [1112] = 1112,
  [1113] = 1113,
  [1114] = 1114,
  [1115] = 1115,
  [1116] = 1116,
  [1117] = 1117,
  [1118] = 1118,
  [1119] = 1119,
  [1120] = 1120,
  [1121] = 1121,
  [1122] = 1122,
  [1123] = 1123,
  [1124] = 1124,
  [1125] = 1125,
  [1126] = 1126,
  [1127] = 1127,
  [1128] = 1128,
  [1129] = 1129,
  [1130] = 1130,
  [1131] = 1131,
  [1132] = 1132,
  [1133] = 1133,
  [1134] = 1134,
  [1135] = 1135,
  [1136] = 1136,
  [1137] = 1137,
  [1138] = 1138,
  [1139] = 1139,
  [1140] = 1140,
  [1141] = 1141,
  [1142] = 1142,
  [1143] = 1143,
  [1144] = 1144,
  [1145] = 1145,
  [1146] = 1146,
  [1147] = 1147,
  [1148] = 1148,
  [1149] = 1149,
  [1150] = 1150,
  [1151] = 1151,
  [1152] = 1152,
  [1153] = 1153,
  [1154] = 1154,
  [1155] = 1155,
  [1156] = 1156,
  [1157] = 1157,
  [1158] = 1158,
  [1159] = 1159,
  [1160] = 1160,
  [1161] = 1161,
  [1162] = 1162,
  [1163] = 1163,
  [1164] = 1164,
  [1165] = 1155,
  [1166] = 1166,
  [1167] = 1167,
  [1168] = 1155,
  [1169] = 1169,
  [1170] = 1170,
  [1171] = 1171,
  [1172] = 1157,
  [1173] = 1173,
  [1174] = 1167,
  [1175] = 1175,
  [1176] = 1176,
  [1177] = 1177,
  [1178] = 1178,
  [1179] = 1179,
  [1180] = 1157,
  [1181] = 1158,
  [1182] = 1169,
  [1183] = 1183,
  [1184] = 1184,
  [1185] = 1185,
  [1186] = 1167,
  [1187] = 1187,
  [1188] = 1188,
  [1189] = 1189,
  [1190] = 1190,
  [1191] = 1191,
  [1192] = 1192,
  [1193] = 1157,
  [1194] = 1158,
  [1195] = 1195,
  [1196] = 1196,
  [1197] = 1197,
  [1198] = 1159,
  [1199] = 1199,
  [1200] = 1200,
  [1201] = 1191,
  [1202] = 1202,
  [1203] = 1158,
  [1204] = 1204,
  [1205] = 1205,
  [1206] = 1155,
  [1207] = 1169,
  [1208] = 1169,
  [1209] = 1191,
  [1210] = 1210,
  [1211] = 1211,
  [1212] = 1212,
  [1213] = 1213,
  [1214] = 1214,
  [1215] = 1215,
  [1216] = 1216,
  [1217] = 1217,
  [1218] = 1218,
  [1219] = 1219,
  [1220] = 1220,
  [1221] = 1221,
  [1222] = 1222,
  [1223] = 1223,
  [1224] = 1224,
  [1225] = 1225,
  [1226] = 1226,
  [1227] = 1227,
  [1228] = 1228,
  [1229] = 1229,
  [1230] = 1230,
  [1231] = 1231,
  [1232] = 1232,
  [1233] = 1233,
  [1234] = 1234,
  [1235] = 1235,
  [1236] = 1236,
  [1237] = 1237,
  [1238] = 1238,
  [1239] = 1239,
  [1240] = 1240,
  [1241] = 1241,
  [1242] = 1242,
  [1243] = 1243,
  [1244] = 1244,
  [1245] = 1245,
  [1246] = 1246,
  [1247] = 1247,
  [1248] = 1248,
  [1249] = 1210,
  [1250] = 1250,
  [1251] = 1251,
  [1252] = 1252,
  [1253] = 1253,
  [1254] = 1254,
  [1255] = 1224,
  [1256] = 1256,
  [1257] = 1257,
  [1258] = 1258,
  [1259] = 1259,
  [1260] = 1260,
  [1261] = 1261,
  [1262] = 1262,
  [1263] = 1263,
  [1264] = 1264,
  [1265] = 1265,
  [1266] = 1266,
  [1267] = 1267,
  [1268] = 831,
  [1269] = 1269,
  [1270] = 1270,
  [1271] = 1271,
  [1272] = 1272,
  [1273] = 1273,
  [1274] = 1274,
  [1275] = 1275,
  [1276] = 1276,
  [1277] = 1260,
  [1278] = 1278,
  [1279] = 1261,
  [1280] = 1257,
  [1281] = 1281,
  [1282] = 1282,
  [1283] = 1176,
  [1284] = 1284,
  [1285] = 1285,
  [1286] = 1286,
  [1287] = 1287,
  [1288] = 1288,
  [1289] = 1289,
  [1290] = 1245,
  [1291] = 1246,
  [1292] = 1247,
  [1293] = 1248,
  [1294] = 1294,
  [1295] = 1295,
  [1296] = 1296,
  [1297] = 1297,
  [1298] = 1298,
  [1299] = 1299,
  [1300] = 1300,
  [1301] = 1301,
  [1302] = 1238,
  [1303] = 1303,
  [1304] = 1304,
  [1305] = 1305,
  [1306] = 1240,
  [1307] = 1210,
  [1308] = 1308,
  [1309] = 1238,
  [1310] = 1245,
  [1311] = 1246,
  [1312] = 1247,
  [1313] = 1248,
  [1314] = 1224,
  [1315] = 1256,
  [1316] = 1316,
  [1317] = 1062,
  [1318] = 1256,
  [1319] = 1319,
  [1320] = 1078,
  [1321] = 1235,
  [1322] = 1265,
  [1323] = 1323,
  [1324] = 1324,
  [1325] = 1238,
  [1326] = 1326,
  [1327] = 1240,
  [1328] = 1210,
  [1329] = 1329,
  [1330] = 1330,
  [1331] = 1245,
  [1332] = 1246,
  [1333] = 1247,
  [1334] = 1248,
  [1335] = 1335,
  [1336] = 1224,
  [1337] = 1256,
  [1338] = 1338,
  [1339] = 1339,
  [1340] = 1340,
  [1341] = 1341,
  [1342] = 1235,
  [1343] = 1343,
  [1344] = 1238,
  [1345] = 1345,
  [1346] = 1346,
  [1347] = 1347,
  [1348] = 1348,
  [1349] = 1349,
  [1350] = 1350,
  [1351] = 1351,
  [1352] = 1352,
  [1353] = 1353,
  [1354] = 1354,
  [1355] = 1355,
  [1356] = 1356,
  [1357] = 1240,
  [1358] = 1052,
  [1359] = 1359,
  [1360] = 1360,
  [1361] = 1235,
  [1362] = 1362,
  [1363] = 1363,
  [1364] = 1364,
  [1365] = 1365,
  [1366] = 1366,
  [1367] = 1367,
  [1368] = 1368,
  [1369] = 1369,
  [1370] = 1235,
  [1371] = 1371,
  [1372] = 1372,
  [1373] = 1373,
  [1374] = 1374,
  [1375] = 1375,
  [1376] = 1376,
  [1377] = 1377,
  [1378] = 1378,
  [1379] = 1379,
  [1380] = 1380,
  [1381] = 1381,
  [1382] = 1373,
  [1383] = 1375,
  [1384] = 1384,
  [1385] = 1385,
  [1386] = 1386,
  [1387] = 1387,
  [1388] = 1373,
  [1389] = 1389,
  [1390] = 1373,
  [1391] = 1375,
  [1392] = 1392,
  [1393] = 1393,
  [1394] = 1394,
  [1395] = 1395,
  [1396] = 1396,
  [1397] = 1375,
  [1398] = 1398,
  [1399] = 1395,
  [1400] = 1400,
  [1401] = 1373,
  [1402] = 1375,
  [1403] = 1377,
  [1404] = 1404,
  [1405] = 1405,
  [1406] = 1406,
  [1407] = 1407,
  [1408] = 1408,
  [1409] = 1409,
  [1410] = 1410,
  [1411] = 1411,
  [1412] = 1252,
  [1413] = 1413,
  [1414] = 1414,
  [1415] = 1415,
  [1416] = 1416,
  [1417] = 1417,
  [1418] = 1418,
  [1419] = 1419,
  [1420] = 1420,
  [1421] = 1421,
  [1422] = 1422,
  [1423] = 1423,
  [1424] = 1424,
  [1425] = 1425,
  [1426] = 1426,
  [1427] = 1427,
  [1428] = 1428,
  [1429] = 1429,
  [1430] = 1430,
  [1431] = 872,
  [1432] = 1432,
  [1433] = 874,
  [1434] = 1434,
  [1435] = 1435,
  [1436] = 1436,
  [1437] = 1437,
  [1438] = 1438,
  [1439] = 867,
  [1440] = 1440,
  [1441] = 1441,
  [1442] = 1442,
  [1443] = 1443,
  [1444] = 1444,
  [1445] = 1445,
  [1446] = 1446,
  [1447] = 1447,
  [1448] = 1448,
  [1449] = 1449,
  [1450] = 1450,
  [1451] = 1451,
  [1452] = 1452,
  [1453] = 1453,
  [1454] = 1454,
  [1455] = 1455,
  [1456] = 1456,
  [1457] = 1448,
  [1458] = 1458,
  [1459] = 1459,
  [1460] = 1460,
  [1461] = 1461,
  [1462] = 1462,
  [1463] = 1463,
  [1464] = 1458,
  [1465] = 1461,
  [1466] = 1448,
  [1467] = 1467,
  [1468] = 1468,
  [1469] = 1469,
  [1470] = 1461,
  [1471] = 1468,
  [1472] = 1472,
  [1473] = 1468,
  [1474] = 1474,
  [1475] = 1458,
  [1476] = 1476,
  [1477] = 1477,
  [1478] = 1478,
  [1479] = 1458,
  [1480] = 1480,
  [1481] = 1468,
  [1482] = 1458,
  [1483] = 1483,
  [1484] = 1484,
  [1485] = 1485,
  [1486] = 1458,
  [1487] = 1487,
  [1488] = 1488,
  [1489] = 1489,
  [1490] = 1458,
  [1491] = 1491,
  [1492] = 1492,
  [1493] = 1458,
  [1494] = 1494,
  [1495] = 1495,
  [1496] = 1496,
  [1497] = 1497,
  [1498] = 1498,
  [1499] = 1499,
  [1500] = 1494,
  [1501] = 1501,
  [1502] = 1502,
  [1503] = 1458,
  [1504] = 1504,
  [1505] = 1452,
  [1506] = 1506,
  [1507] = 1507,
  [1508] = 1458,
  [1509] = 1461,
  [1510] = 1458,
  [1511] = 1448,
  [1512] = 1458,
  [1513] = 1485,
  [1514] = 1514,
  [1515] = 1515,
  [1516] = 1516,
  [1517] = 1517,
  [1518] = 1468,
  [1519] = 1519,
  [1520] = 1520,
  [1521] = 1448,
  [1522] = 1522,
};

static bool ts_lex(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      if (eof) ADVANCE(183);
      ADVANCE_MAP(
        '&', 203,
        '\'', 223,
        '(', 186,
        ')', 187,
        '*', 192,
        '+', 188,
        ',', 185,
        '-', 190,
        '.', 205,
        '/', 194,
        '0', 272,
        ':', 233,
        ';', 184,
        '<', 214,
        '=', 232,
        '>', 219,
        '?', 212,
        '@', 213,
        '[', 224,
        '\\', 196,
        ']', 228,
        '^', 198,
        'a', 117,
        'b', 126,
        'c', 13,
        'e', 86,
        'f', 15,
        'g', 47,
        'i', 64,
        'm', 19,
        'o', 151,
        'p', 21,
        'r', 50,
        's', 26,
        't', 118,
        'v', 38,
        'w', 71,
        '{', 229,
        '|', 201,
        '}', 230,
        '~', 211,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(0);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(273);
      END_STATE();
    case 1:
      ADVANCE_MAP(
        '\n', 225,
        '\r', 280,
        '&', 203,
        '(', 186,
        '+', 188,
        ',', 185,
        '-', 190,
        '.', 209,
        '0', 272,
        ';', 184,
        '<', 214,
        '=', 232,
        '>', 219,
        '?', 212,
        '@', 213,
        '[', 224,
        'a', 117,
        'b', 126,
        'c', 24,
        'e', 87,
        'f', 15,
        'g', 57,
        'i', 64,
        'm', 60,
        'o', 151,
        'p', 21,
        'r', 50,
        's', 59,
        't', 118,
        'w', 71,
        '{', 229,
        '|', 174,
        '~', 211,
      );
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(1);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(273);
      END_STATE();
    case 2:
      ADVANCE_MAP(
        '\n', 225,
        '\r', 280,
        '&', 202,
        '(', 186,
        '+', 188,
        ',', 185,
        '-', 190,
        '.', 208,
        '0', 272,
        ';', 184,
        '=', 231,
        '?', 212,
        '@', 213,
        '[', 224,
        'a', 117,
        'b', 126,
        'c', 13,
        'e', 87,
        'f', 15,
        'g', 57,
        'i', 64,
        'm', 60,
        'o', 151,
        'p', 21,
        'r', 50,
        's', 59,
        't', 118,
        'w', 71,
        '{', 229,
        '~', 210,
      );
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(2);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(273);
      END_STATE();
    case 3:
      ADVANCE_MAP(
        '\n', 225,
        '\r', 280,
        ',', 185,
        ';', 184,
        'a', 117,
        'e', 100,
        'f', 165,
        'g', 46,
        'm', 60,
        'p', 125,
        's', 51,
      );
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(3);
      END_STATE();
    case 4:
      ADVANCE_MAP(
        '\n', 226,
        '(', 186,
        '+', 188,
        ',', 185,
        '-', 190,
        '.', 177,
        '0', 272,
        '?', 212,
        '@', 213,
        '[', 224,
        ']', 228,
        'a', 117,
        'e', 100,
        'f', 14,
        'g', 56,
        'm', 60,
        'p', 125,
        's', 58,
        't', 132,
        '{', 229,
        '}', 230,
        '~', 210,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(4);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(273);
      END_STATE();
    case 5:
      ADVANCE_MAP(
        '&', 203,
        '\'', 223,
        '(', 186,
        '*', 192,
        '+', 188,
        '-', 190,
        '.', 206,
        '/', 194,
        ':', 233,
        ';', 184,
        '<', 214,
        '=', 11,
        '>', 219,
        '@', 213,
        '\\', 196,
        ']', 228,
        '^', 198,
        '{', 229,
        '|', 201,
        '}', 230,
        '~', 12,
        '\n', 227,
        '\r', 227,
      );
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(5);
      END_STATE();
    case 6:
      if (lookahead == '&') ADVANCE(220);
      END_STATE();
    case 7:
      ADVANCE_MAP(
        '&', 202,
        '(', 186,
        '*', 192,
        '+', 188,
        ',', 185,
        '-', 190,
        '.', 10,
        '/', 194,
        '0', 272,
        ':', 233,
        ';', 184,
        '?', 212,
        '@', 213,
        '[', 224,
        '\\', 196,
        ']', 228,
        '^', 198,
        'a', 117,
        'e', 100,
        'f', 14,
        'g', 56,
        'm', 60,
        'p', 125,
        's', 58,
        't', 132,
        '{', 229,
        '|', 200,
        '}', 230,
        '~', 210,
        '\n', 227,
        '\r', 227,
      );
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(7);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(273);
      END_STATE();
    case 8:
      ADVANCE_MAP(
        '&', 6,
        '(', 186,
        ')', 187,
        ',', 185,
        '.', 204,
        '<', 214,
        '=', 11,
        '>', 219,
        'a', 117,
        'e', 100,
        'f', 165,
        'g', 46,
        'm', 60,
        'p', 125,
        's', 51,
        '{', 229,
        '|', 174,
        '}', 230,
        '~', 12,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(8);
      END_STATE();
    case 9:
      ADVANCE_MAP(
        '&', 6,
        '.', 204,
        ';', 184,
        '<', 214,
        '=', 11,
        '>', 219,
        ']', 228,
        '|', 174,
        '}', 230,
        '~', 12,
        '\n', 227,
        '\r', 227,
      );
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(9);
      END_STATE();
    case 10:
      if (lookahead == '*') ADVANCE(193);
      if (lookahead == '+') ADVANCE(189);
      if (lookahead == '-') ADVANCE(191);
      if (lookahead == '/') ADVANCE(195);
      if (lookahead == '\\') ADVANCE(197);
      if (lookahead == '^') ADVANCE(199);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(274);
      END_STATE();
    case 11:
      if (lookahead == '=') ADVANCE(216);
      END_STATE();
    case 12:
      if (lookahead == '=') ADVANCE(217);
      END_STATE();
    case 13:
      if (lookahead == 'a') ADVANCE(140);
      if (lookahead == 'l') ADVANCE(17);
      if (lookahead == 'o') ADVANCE(102);
      END_STATE();
    case 14:
      if (lookahead == 'a') ADVANCE(91);
      END_STATE();
    case 15:
      if (lookahead == 'a') ADVANCE(91);
      if (lookahead == 'o') ADVANCE(119);
      if (lookahead == 'u') ADVANCE(106);
      END_STATE();
    case 16:
      if (lookahead == 'a') ADVANCE(84);
      END_STATE();
    case 17:
      if (lookahead == 'a') ADVANCE(138);
      END_STATE();
    case 18:
      if (lookahead == 'a') ADVANCE(89);
      END_STATE();
    case 19:
      if (lookahead == 'a') ADVANCE(157);
      if (lookahead == 'e') ADVANCE(153);
      END_STATE();
    case 20:
      if (lookahead == 'a') ADVANCE(88);
      END_STATE();
    case 21:
      if (lookahead == 'a') ADVANCE(124);
      if (lookahead == 'e') ADVANCE(127);
      if (lookahead == 'r') ADVANCE(109);
      END_STATE();
    case 22:
      if (lookahead == 'a') ADVANCE(122);
      END_STATE();
    case 23:
      if (lookahead == 'a') ADVANCE(161);
      END_STATE();
    case 24:
      if (lookahead == 'a') ADVANCE(139);
      if (lookahead == 'l') ADVANCE(17);
      if (lookahead == 'o') ADVANCE(102);
      END_STATE();
    case 25:
      if (lookahead == 'b') ADVANCE(20);
      END_STATE();
    case 26:
      if (lookahead == 'c') ADVANCE(18);
      if (lookahead == 'e') ADVANCE(147);
      if (lookahead == 'p') ADVANCE(92);
      if (lookahead == 'w') ADVANCE(80);
      END_STATE();
    case 27:
      if (lookahead == 'c') ADVANCE(18);
      if (lookahead == 'e') ADVANCE(150);
      if (lookahead == 'p') ADVANCE(92);
      if (lookahead == 'w') ADVANCE(80);
      END_STATE();
    case 28:
      if (lookahead == 'c') ADVANCE(69);
      END_STATE();
    case 29:
      if (lookahead == 'c') ADVANCE(70);
      END_STATE();
    case 30:
      if (lookahead == 'c') ADVANCE(163);
      END_STATE();
    case 31:
      if (lookahead == 'c') ADVANCE(156);
      END_STATE();
    case 32:
      if (lookahead == 'c') ADVANCE(160);
      END_STATE();
    case 33:
      if (lookahead == 'd') ADVANCE(241);
      if (lookahead == 'u') ADVANCE(93);
      END_STATE();
    case 34:
      if (lookahead == 'd') ADVANCE(270);
      END_STATE();
    case 35:
      if (lookahead == 'd') ADVANCE(240);
      if (lookahead == 'u') ADVANCE(93);
      END_STATE();
    case 36:
      if (lookahead == 'd') ADVANCE(134);
      END_STATE();
    case 37:
      if (lookahead == 'd') ADVANCE(49);
      END_STATE();
    case 38:
      if (lookahead == 'e') ADVANCE(30);
      END_STATE();
    case 39:
      if (lookahead == 'e') ADVANCE(245);
      END_STATE();
    case 40:
      if (lookahead == 'e') ADVANCE(238);
      END_STATE();
    case 41:
      if (lookahead == 'e') ADVANCE(278);
      END_STATE();
    case 42:
      if (lookahead == 'e') ADVANCE(279);
      END_STATE();
    case 43:
      if (lookahead == 'e') ADVANCE(244);
      END_STATE();
    case 44:
      if (lookahead == 'e') ADVANCE(235);
      END_STATE();
    case 45:
      if (lookahead == 'e') ADVANCE(246);
      END_STATE();
    case 46:
      if (lookahead == 'e') ADVANCE(146);
      END_STATE();
    case 47:
      if (lookahead == 'e') ADVANCE(146);
      if (lookahead == 'l') ADVANCE(108);
      END_STATE();
    case 48:
      if (lookahead == 'e') ADVANCE(16);
      END_STATE();
    case 49:
      if (lookahead == 'e') ADVANCE(66);
      END_STATE();
    case 50:
      if (lookahead == 'e') ADVANCE(152);
      END_STATE();
    case 51:
      if (lookahead == 'e') ADVANCE(147);
      END_STATE();
    case 52:
      if (lookahead == 'e') ADVANCE(120);
      END_STATE();
    case 53:
      if (lookahead == 'e') ADVANCE(136);
      END_STATE();
    case 54:
      if (lookahead == 'e') ADVANCE(130);
      END_STATE();
    case 55:
      if (lookahead == 'e') ADVANCE(131);
      END_STATE();
    case 56:
      if (lookahead == 'e') ADVANCE(149);
      END_STATE();
    case 57:
      if (lookahead == 'e') ADVANCE(149);
      if (lookahead == 'l') ADVANCE(108);
      END_STATE();
    case 58:
      if (lookahead == 'e') ADVANCE(150);
      END_STATE();
    case 59:
      if (lookahead == 'e') ADVANCE(150);
      if (lookahead == 'p') ADVANCE(92);
      if (lookahead == 'w') ADVANCE(80);
      END_STATE();
    case 60:
      if (lookahead == 'e') ADVANCE(153);
      END_STATE();
    case 61:
      if (lookahead == 'e') ADVANCE(103);
      END_STATE();
    case 62:
      if (lookahead == 'e') ADVANCE(104);
      END_STATE();
    case 63:
      if (lookahead == 'e') ADVANCE(105);
      END_STATE();
    case 64:
      if (lookahead == 'f') ADVANCE(239);
      END_STATE();
    case 65:
      if (lookahead == 'f') ADVANCE(237);
      END_STATE();
    case 66:
      if (lookahead == 'f') ADVANCE(267);
      END_STATE();
    case 67:
      if (lookahead == 'f') ADVANCE(114);
      END_STATE();
    case 68:
      if (lookahead == 'g') ADVANCE(170);
      END_STATE();
    case 69:
      if (lookahead == 'h') ADVANCE(268);
      END_STATE();
    case 70:
      if (lookahead == 'h') ADVANCE(247);
      END_STATE();
    case 71:
      if (lookahead == 'h') ADVANCE(76);
      END_STATE();
    case 72:
      if (lookahead == 'h') ADVANCE(110);
      END_STATE();
    case 73:
      if (lookahead == 'h') ADVANCE(52);
      END_STATE();
    case 74:
      if (lookahead == 'i') ADVANCE(173);
      END_STATE();
    case 75:
      if (lookahead == 'i') ADVANCE(101);
      END_STATE();
    case 76:
      if (lookahead == 'i') ADVANCE(90);
      END_STATE();
    case 77:
      if (lookahead == 'i') ADVANCE(111);
      END_STATE();
    case 78:
      if (lookahead == 'i') ADVANCE(144);
      END_STATE();
    case 79:
      if (lookahead == 'i') ADVANCE(112);
      END_STATE();
    case 80:
      if (lookahead == 'i') ADVANCE(162);
      END_STATE();
    case 81:
      if (lookahead == 'i') ADVANCE(113);
      END_STATE();
    case 82:
      if (lookahead == 'i') ADVANCE(53);
      END_STATE();
    case 83:
      if (lookahead == 'i') ADVANCE(145);
      END_STATE();
    case 84:
      if (lookahead == 'k') ADVANCE(236);
      END_STATE();
    case 85:
      if (lookahead == 'l') ADVANCE(17);
      if (lookahead == 'o') ADVANCE(102);
      END_STATE();
    case 86:
      if (lookahead == 'l') ADVANCE(142);
      if (lookahead == 'n') ADVANCE(33);
      if (lookahead == 'v') ADVANCE(61);
      END_STATE();
    case 87:
      if (lookahead == 'l') ADVANCE(142);
      if (lookahead == 'n') ADVANCE(35);
      if (lookahead == 'v') ADVANCE(61);
      END_STATE();
    case 88:
      if (lookahead == 'l') ADVANCE(248);
      END_STATE();
    case 89:
      if (lookahead == 'l') ADVANCE(22);
      END_STATE();
    case 90:
      if (lookahead == 'l') ADVANCE(43);
      END_STATE();
    case 91:
      if (lookahead == 'l') ADVANCE(143);
      END_STATE();
    case 92:
      if (lookahead == 'm') ADVANCE(34);
      END_STATE();
    case 93:
      if (lookahead == 'm') ADVANCE(54);
      END_STATE();
    case 94:
      if (lookahead == 'm') ADVANCE(62);
      END_STATE();
    case 95:
      if (lookahead == 'n') ADVANCE(33);
      if (lookahead == 'v') ADVANCE(61);
      END_STATE();
    case 96:
      if (lookahead == 'n') ADVANCE(234);
      END_STATE();
    case 97:
      if (lookahead == 'n') ADVANCE(252);
      END_STATE();
    case 98:
      if (lookahead == 'n') ADVANCE(255);
      END_STATE();
    case 99:
      if (lookahead == 'n') ADVANCE(266);
      END_STATE();
    case 100:
      if (lookahead == 'n') ADVANCE(35);
      if (lookahead == 'v') ADVANCE(61);
      END_STATE();
    case 101:
      if (lookahead == 'n') ADVANCE(169);
      END_STATE();
    case 102:
      if (lookahead == 'n') ADVANCE(154);
      END_STATE();
    case 103:
      if (lookahead == 'n') ADVANCE(155);
      END_STATE();
    case 104:
      if (lookahead == 'n') ADVANCE(158);
      END_STATE();
    case 105:
      if (lookahead == 'n') ADVANCE(148);
      END_STATE();
    case 106:
      if (lookahead == 'n') ADVANCE(31);
      END_STATE();
    case 107:
      if (lookahead == 'n') ADVANCE(32);
      END_STATE();
    case 108:
      if (lookahead == 'o') ADVANCE(25);
      END_STATE();
    case 109:
      if (lookahead == 'o') ADVANCE(116);
      END_STATE();
    case 110:
      if (lookahead == 'o') ADVANCE(36);
      END_STATE();
    case 111:
      if (lookahead == 'o') ADVANCE(97);
      END_STATE();
    case 112:
      if (lookahead == 'o') ADVANCE(98);
      END_STATE();
    case 113:
      if (lookahead == 'o') ADVANCE(99);
      END_STATE();
    case 114:
      if (lookahead == 'o') ADVANCE(121);
      END_STATE();
    case 115:
      if (lookahead == 'o') ADVANCE(123);
      END_STATE();
    case 116:
      if (lookahead == 'p') ADVANCE(55);
      END_STATE();
    case 117:
      if (lookahead == 'r') ADVANCE(68);
      END_STATE();
    case 118:
      if (lookahead == 'r') ADVANCE(167);
      END_STATE();
    case 119:
      if (lookahead == 'r') ADVANCE(242);
      END_STATE();
    case 120:
      if (lookahead == 'r') ADVANCE(172);
      END_STATE();
    case 121:
      if (lookahead == 'r') ADVANCE(243);
      END_STATE();
    case 122:
      if (lookahead == 'r') ADVANCE(258);
      END_STATE();
    case 123:
      if (lookahead == 'r') ADVANCE(256);
      END_STATE();
    case 124:
      if (lookahead == 'r') ADVANCE(67);
      END_STATE();
    case 125:
      if (lookahead == 'r') ADVANCE(109);
      END_STATE();
    case 126:
      if (lookahead == 'r') ADVANCE(48);
      END_STATE();
    case 127:
      if (lookahead == 'r') ADVANCE(141);
      END_STATE();
    case 128:
      if (lookahead == 'r') ADVANCE(96);
      END_STATE();
    case 129:
      if (lookahead == 'r') ADVANCE(74);
      END_STATE();
    case 130:
      if (lookahead == 'r') ADVANCE(23);
      END_STATE();
    case 131:
      if (lookahead == 'r') ADVANCE(159);
      END_STATE();
    case 132:
      if (lookahead == 'r') ADVANCE(166);
      END_STATE();
    case 133:
      if (lookahead == 's') ADVANCE(265);
      END_STATE();
    case 134:
      if (lookahead == 's') ADVANCE(264);
      END_STATE();
    case 135:
      if (lookahead == 's') ADVANCE(251);
      END_STATE();
    case 136:
      if (lookahead == 's') ADVANCE(259);
      END_STATE();
    case 137:
      if (lookahead == 's') ADVANCE(37);
      END_STATE();
    case 138:
      if (lookahead == 's') ADVANCE(137);
      END_STATE();
    case 139:
      if (lookahead == 's') ADVANCE(39);
      END_STATE();
    case 140:
      if (lookahead == 's') ADVANCE(39);
      if (lookahead == 't') ADVANCE(28);
      END_STATE();
    case 141:
      if (lookahead == 's') ADVANCE(78);
      END_STATE();
    case 142:
      if (lookahead == 's') ADVANCE(40);
      END_STATE();
    case 143:
      if (lookahead == 's') ADVANCE(42);
      END_STATE();
    case 144:
      if (lookahead == 's') ADVANCE(164);
      END_STATE();
    case 145:
      if (lookahead == 's') ADVANCE(45);
      END_STATE();
    case 146:
      if (lookahead == 't') ADVANCE(261);
      END_STATE();
    case 147:
      if (lookahead == 't') ADVANCE(263);
      END_STATE();
    case 148:
      if (lookahead == 't') ADVANCE(249);
      END_STATE();
    case 149:
      if (lookahead == 't') ADVANCE(260);
      END_STATE();
    case 150:
      if (lookahead == 't') ADVANCE(262);
      END_STATE();
    case 151:
      if (lookahead == 't') ADVANCE(73);
      END_STATE();
    case 152:
      if (lookahead == 't') ADVANCE(168);
      END_STATE();
    case 153:
      if (lookahead == 't') ADVANCE(72);
      END_STATE();
    case 154:
      if (lookahead == 't') ADVANCE(75);
      END_STATE();
    case 155:
      if (lookahead == 't') ADVANCE(133);
      END_STATE();
    case 156:
      if (lookahead == 't') ADVANCE(77);
      END_STATE();
    case 157:
      if (lookahead == 't') ADVANCE(129);
      END_STATE();
    case 158:
      if (lookahead == 't') ADVANCE(135);
      END_STATE();
    case 159:
      if (lookahead == 't') ADVANCE(82);
      END_STATE();
    case 160:
      if (lookahead == 't') ADVANCE(79);
      END_STATE();
    case 161:
      if (lookahead == 't') ADVANCE(81);
      END_STATE();
    case 162:
      if (lookahead == 't') ADVANCE(29);
      END_STATE();
    case 163:
      if (lookahead == 't') ADVANCE(115);
      END_STATE();
    case 164:
      if (lookahead == 't') ADVANCE(63);
      END_STATE();
    case 165:
      if (lookahead == 'u') ADVANCE(106);
      END_STATE();
    case 166:
      if (lookahead == 'u') ADVANCE(41);
      END_STATE();
    case 167:
      if (lookahead == 'u') ADVANCE(41);
      if (lookahead == 'y') ADVANCE(269);
      END_STATE();
    case 168:
      if (lookahead == 'u') ADVANCE(128);
      END_STATE();
    case 169:
      if (lookahead == 'u') ADVANCE(44);
      END_STATE();
    case 170:
      if (lookahead == 'u') ADVANCE(94);
      END_STATE();
    case 171:
      if (lookahead == 'u') ADVANCE(107);
      END_STATE();
    case 172:
      if (lookahead == 'w') ADVANCE(83);
      END_STATE();
    case 173:
      if (lookahead == 'x') ADVANCE(257);
      END_STATE();
    case 174:
      if (lookahead == '|') ADVANCE(221);
      END_STATE();
    case 175:
      if (lookahead == '+' ||
          lookahead == '-') ADVANCE(178);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(275);
      END_STATE();
    case 176:
      if (lookahead == '0' ||
          lookahead == '1') ADVANCE(277);
      END_STATE();
    case 177:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(274);
      END_STATE();
    case 178:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(275);
      END_STATE();
    case 179:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(276);
      END_STATE();
    case 180:
      if (eof) ADVANCE(183);
      ADVANCE_MAP(
        '\n', 225,
        '\r', 280,
        '&', 203,
        '\'', 223,
        '(', 186,
        '*', 192,
        '+', 188,
        ',', 185,
        '-', 190,
        '.', 207,
        '/', 194,
        '0', 272,
        ':', 233,
        ';', 184,
        '<', 214,
        '=', 232,
        '>', 219,
        '?', 212,
        '@', 213,
        '[', 224,
        '\\', 196,
        '^', 198,
        'a', 117,
        'b', 126,
        'c', 24,
        'e', 87,
        'f', 15,
        'g', 57,
        'i', 64,
        'm', 19,
        'o', 151,
        'p', 21,
        'r', 50,
        's', 27,
        't', 118,
        'v', 38,
        'w', 71,
        '{', 229,
        '|', 201,
        '~', 211,
      );
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(180);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(273);
      END_STATE();
    case 181:
      if (eof) ADVANCE(183);
      ADVANCE_MAP(
        '(', 186,
        ')', 187,
        '*', 192,
        '+', 188,
        ',', 185,
        '-', 190,
        '.', 209,
        '0', 272,
        ';', 184,
        '=', 231,
        '?', 212,
        '@', 213,
        '[', 224,
        ']', 228,
        'a', 117,
        'b', 126,
        'c', 85,
        'e', 95,
        'f', 15,
        'g', 57,
        'i', 64,
        'm', 60,
        'p', 21,
        'r', 50,
        's', 59,
        't', 118,
        'w', 71,
        '{', 229,
        '}', 230,
        '~', 210,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(181);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(273);
      END_STATE();
    case 182:
      if (eof) ADVANCE(183);
      ADVANCE_MAP(
        '(', 186,
        ')', 187,
        '+', 188,
        ',', 185,
        '-', 190,
        '.', 177,
        '0', 272,
        ':', 233,
        ';', 184,
        '?', 212,
        '@', 213,
        '[', 224,
        'a', 117,
        'b', 126,
        'c', 13,
        'e', 87,
        'f', 15,
        'g', 57,
        'i', 64,
        'm', 60,
        'o', 151,
        'p', 21,
        'r', 50,
        's', 59,
        't', 118,
        'w', 71,
        '{', 229,
        '}', 230,
        '~', 210,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(182);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(273);
      END_STATE();
    case 183:
      ACCEPT_TOKEN(ts_builtin_sym_end);
      END_STATE();
    case 184:
      ACCEPT_TOKEN(anon_sym_SEMI);
      END_STATE();
    case 185:
      ACCEPT_TOKEN(anon_sym_COMMA);
      END_STATE();
    case 186:
      ACCEPT_TOKEN(anon_sym_LPAREN);
      END_STATE();
    case 187:
      ACCEPT_TOKEN(anon_sym_RPAREN);
      END_STATE();
    case 188:
      ACCEPT_TOKEN(anon_sym_PLUS);
      END_STATE();
    case 189:
      ACCEPT_TOKEN(anon_sym_DOT_PLUS);
      END_STATE();
    case 190:
      ACCEPT_TOKEN(anon_sym_DASH);
      END_STATE();
    case 191:
      ACCEPT_TOKEN(anon_sym_DOT_DASH);
      END_STATE();
    case 192:
      ACCEPT_TOKEN(anon_sym_STAR);
      END_STATE();
    case 193:
      ACCEPT_TOKEN(anon_sym_DOT_STAR);
      END_STATE();
    case 194:
      ACCEPT_TOKEN(anon_sym_SLASH);
      END_STATE();
    case 195:
      ACCEPT_TOKEN(anon_sym_DOT_SLASH);
      END_STATE();
    case 196:
      ACCEPT_TOKEN(anon_sym_BSLASH);
      END_STATE();
    case 197:
      ACCEPT_TOKEN(anon_sym_DOT_BSLASH);
      END_STATE();
    case 198:
      ACCEPT_TOKEN(anon_sym_CARET);
      END_STATE();
    case 199:
      ACCEPT_TOKEN(anon_sym_DOT_CARET);
      END_STATE();
    case 200:
      ACCEPT_TOKEN(anon_sym_PIPE);
      END_STATE();
    case 201:
      ACCEPT_TOKEN(anon_sym_PIPE);
      if (lookahead == '|') ADVANCE(221);
      END_STATE();
    case 202:
      ACCEPT_TOKEN(anon_sym_AMP);
      END_STATE();
    case 203:
      ACCEPT_TOKEN(anon_sym_AMP);
      if (lookahead == '&') ADVANCE(220);
      END_STATE();
    case 204:
      ACCEPT_TOKEN(anon_sym_DOT);
      END_STATE();
    case 205:
      ACCEPT_TOKEN(anon_sym_DOT);
      ADVANCE_MAP(
        '\'', 222,
        '*', 193,
        '+', 189,
        '-', 191,
        '/', 195,
        '?', 250,
        '\\', 197,
        '^', 199,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(274);
      END_STATE();
    case 206:
      ACCEPT_TOKEN(anon_sym_DOT);
      if (lookahead == '\'') ADVANCE(222);
      if (lookahead == '*') ADVANCE(193);
      if (lookahead == '+') ADVANCE(189);
      if (lookahead == '-') ADVANCE(191);
      if (lookahead == '/') ADVANCE(195);
      if (lookahead == '\\') ADVANCE(197);
      if (lookahead == '^') ADVANCE(199);
      END_STATE();
    case 207:
      ACCEPT_TOKEN(anon_sym_DOT);
      if (lookahead == '\'') ADVANCE(222);
      if (lookahead == '*') ADVANCE(193);
      if (lookahead == '+') ADVANCE(189);
      if (lookahead == '-') ADVANCE(191);
      if (lookahead == '/') ADVANCE(195);
      if (lookahead == '\\') ADVANCE(197);
      if (lookahead == '^') ADVANCE(199);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(274);
      END_STATE();
    case 208:
      ACCEPT_TOKEN(anon_sym_DOT);
      if (lookahead == '?') ADVANCE(250);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(274);
      END_STATE();
    case 209:
      ACCEPT_TOKEN(anon_sym_DOT);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(274);
      END_STATE();
    case 210:
      ACCEPT_TOKEN(anon_sym_TILDE);
      END_STATE();
    case 211:
      ACCEPT_TOKEN(anon_sym_TILDE);
      if (lookahead == '=') ADVANCE(217);
      END_STATE();
    case 212:
      ACCEPT_TOKEN(anon_sym_QMARK);
      END_STATE();
    case 213:
      ACCEPT_TOKEN(anon_sym_AT);
      END_STATE();
    case 214:
      ACCEPT_TOKEN(anon_sym_LT);
      if (lookahead == '=') ADVANCE(215);
      END_STATE();
    case 215:
      ACCEPT_TOKEN(anon_sym_LT_EQ);
      END_STATE();
    case 216:
      ACCEPT_TOKEN(anon_sym_EQ_EQ);
      END_STATE();
    case 217:
      ACCEPT_TOKEN(anon_sym_TILDE_EQ);
      END_STATE();
    case 218:
      ACCEPT_TOKEN(anon_sym_GT_EQ);
      END_STATE();
    case 219:
      ACCEPT_TOKEN(anon_sym_GT);
      if (lookahead == '=') ADVANCE(218);
      END_STATE();
    case 220:
      ACCEPT_TOKEN(anon_sym_AMP_AMP);
      END_STATE();
    case 221:
      ACCEPT_TOKEN(anon_sym_PIPE_PIPE);
      END_STATE();
    case 222:
      ACCEPT_TOKEN(anon_sym_DOT_SQUOTE);
      END_STATE();
    case 223:
      ACCEPT_TOKEN(anon_sym_SQUOTE);
      END_STATE();
    case 224:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      END_STATE();
    case 225:
      ACCEPT_TOKEN(anon_sym_LF);
      if (lookahead == '\n') ADVANCE(225);
      if (lookahead == '\r') ADVANCE(280);
      END_STATE();
    case 226:
      ACCEPT_TOKEN(anon_sym_LF);
      if (lookahead == '\n') ADVANCE(226);
      END_STATE();
    case 227:
      ACCEPT_TOKEN(aux_sym_matrix_token1);
      if (lookahead == '\n' ||
          lookahead == '\r') ADVANCE(227);
      END_STATE();
    case 228:
      ACCEPT_TOKEN(anon_sym_RBRACK);
      END_STATE();
    case 229:
      ACCEPT_TOKEN(anon_sym_LBRACE);
      END_STATE();
    case 230:
      ACCEPT_TOKEN(anon_sym_RBRACE);
      END_STATE();
    case 231:
      ACCEPT_TOKEN(anon_sym_EQ);
      END_STATE();
    case 232:
      ACCEPT_TOKEN(anon_sym_EQ);
      if (lookahead == '=') ADVANCE(216);
      END_STATE();
    case 233:
      ACCEPT_TOKEN(anon_sym_COLON);
      END_STATE();
    case 234:
      ACCEPT_TOKEN(anon_sym_return);
      END_STATE();
    case 235:
      ACCEPT_TOKEN(anon_sym_continue);
      END_STATE();
    case 236:
      ACCEPT_TOKEN(anon_sym_break);
      END_STATE();
    case 237:
      ACCEPT_TOKEN(anon_sym_elseif);
      END_STATE();
    case 238:
      ACCEPT_TOKEN(anon_sym_else);
      if (lookahead == 'i') ADVANCE(65);
      END_STATE();
    case 239:
      ACCEPT_TOKEN(anon_sym_if);
      END_STATE();
    case 240:
      ACCEPT_TOKEN(anon_sym_end);
      END_STATE();
    case 241:
      ACCEPT_TOKEN(anon_sym_end);
      if (lookahead == 'f') ADVANCE(171);
      END_STATE();
    case 242:
      ACCEPT_TOKEN(anon_sym_for);
      END_STATE();
    case 243:
      ACCEPT_TOKEN(anon_sym_parfor);
      END_STATE();
    case 244:
      ACCEPT_TOKEN(anon_sym_while);
      END_STATE();
    case 245:
      ACCEPT_TOKEN(anon_sym_case);
      END_STATE();
    case 246:
      ACCEPT_TOKEN(anon_sym_otherwise);
      END_STATE();
    case 247:
      ACCEPT_TOKEN(anon_sym_switch);
      END_STATE();
    case 248:
      ACCEPT_TOKEN(anon_sym_global);
      END_STATE();
    case 249:
      ACCEPT_TOKEN(anon_sym_persistent);
      END_STATE();
    case 250:
      ACCEPT_TOKEN(anon_sym_DOT_QMARK);
      END_STATE();
    case 251:
      ACCEPT_TOKEN(anon_sym_arguments);
      END_STATE();
    case 252:
      ACCEPT_TOKEN(anon_sym_function);
      END_STATE();
    case 253:
      ACCEPT_TOKEN(anon_sym_get_DOT);
      END_STATE();
    case 254:
      ACCEPT_TOKEN(anon_sym_set_DOT);
      END_STATE();
    case 255:
      ACCEPT_TOKEN(anon_sym_endfunction);
      END_STATE();
    case 256:
      ACCEPT_TOKEN(anon_sym_vector);
      END_STATE();
    case 257:
      ACCEPT_TOKEN(anon_sym_matrix);
      END_STATE();
    case 258:
      ACCEPT_TOKEN(anon_sym_scalar);
      END_STATE();
    case 259:
      ACCEPT_TOKEN(anon_sym_properties);
      END_STATE();
    case 260:
      ACCEPT_TOKEN(anon_sym_get);
      END_STATE();
    case 261:
      ACCEPT_TOKEN(anon_sym_get);
      if (lookahead == '.') ADVANCE(253);
      END_STATE();
    case 262:
      ACCEPT_TOKEN(anon_sym_set);
      END_STATE();
    case 263:
      ACCEPT_TOKEN(anon_sym_set);
      if (lookahead == '.') ADVANCE(254);
      END_STATE();
    case 264:
      ACCEPT_TOKEN(anon_sym_methods);
      END_STATE();
    case 265:
      ACCEPT_TOKEN(anon_sym_events);
      END_STATE();
    case 266:
      ACCEPT_TOKEN(anon_sym_enumeration);
      END_STATE();
    case 267:
      ACCEPT_TOKEN(anon_sym_classdef);
      END_STATE();
    case 268:
      ACCEPT_TOKEN(anon_sym_catch);
      END_STATE();
    case 269:
      ACCEPT_TOKEN(anon_sym_try);
      END_STATE();
    case 270:
      ACCEPT_TOKEN(anon_sym_spmd);
      END_STATE();
    case 271:
      ACCEPT_TOKEN(aux_sym_number_token1);
      END_STATE();
    case 272:
      ACCEPT_TOKEN(aux_sym_number_token1);
      if (lookahead == '.') ADVANCE(274);
      if (lookahead == 'b') ADVANCE(176);
      if (lookahead == 'x') ADVANCE(179);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(175);
      if (lookahead == 'i' ||
          lookahead == 'j') ADVANCE(271);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(273);
      END_STATE();
    case 273:
      ACCEPT_TOKEN(aux_sym_number_token1);
      if (lookahead == '.') ADVANCE(274);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(175);
      if (lookahead == 'i' ||
          lookahead == 'j') ADVANCE(271);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(273);
      END_STATE();
    case 274:
      ACCEPT_TOKEN(aux_sym_number_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(175);
      if (lookahead == 'i' ||
          lookahead == 'j') ADVANCE(271);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(274);
      END_STATE();
    case 275:
      ACCEPT_TOKEN(aux_sym_number_token1);
      if (lookahead == 'i' ||
          lookahead == 'j') ADVANCE(271);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(275);
      END_STATE();
    case 276:
      ACCEPT_TOKEN(aux_sym_number_token2);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(276);
      END_STATE();
    case 277:
      ACCEPT_TOKEN(aux_sym_number_token3);
      if (lookahead == '0' ||
          lookahead == '1') ADVANCE(277);
      END_STATE();
    case 278:
      ACCEPT_TOKEN(anon_sym_true);
      END_STATE();
    case 279:
      ACCEPT_TOKEN(anon_sym_false);
      END_STATE();
    case 280:
      ACCEPT_TOKEN(anon_sym_CR);
      if (lookahead == '\n') ADVANCE(225);
      if (lookahead == '\r') ADVANCE(280);
      END_STATE();
    default:
      return false;
  }
}

static const TSLexerMode ts_lex_modes[STATE_COUNT] = {
  [0] = {.lex_state = 0, .external_lex_state = 1},
  [1] = {.lex_state = 181, .external_lex_state = 2},
  [2] = {.lex_state = 180, .external_lex_state = 2},
  [3] = {.lex_state = 180, .external_lex_state = 2},
  [4] = {.lex_state = 180, .external_lex_state = 2},
  [5] = {.lex_state = 180, .external_lex_state = 2},
  [6] = {.lex_state = 2, .external_lex_state = 2},
  [7] = {.lex_state = 2, .external_lex_state = 2},
  [8] = {.lex_state = 2, .external_lex_state = 2},
  [9] = {.lex_state = 2, .external_lex_state = 2},
  [10] = {.lex_state = 2, .external_lex_state = 2},
  [11] = {.lex_state = 2, .external_lex_state = 2},
  [12] = {.lex_state = 2, .external_lex_state = 2},
  [13] = {.lex_state = 2, .external_lex_state = 2},
  [14] = {.lex_state = 2, .external_lex_state = 2},
  [15] = {.lex_state = 2, .external_lex_state = 2},
  [16] = {.lex_state = 2, .external_lex_state = 2},
  [17] = {.lex_state = 2, .external_lex_state = 2},
  [18] = {.lex_state = 2, .external_lex_state = 2},
  [19] = {.lex_state = 2, .external_lex_state = 2},
  [20] = {.lex_state = 2, .external_lex_state = 2},
  [21] = {.lex_state = 2, .external_lex_state = 2},
  [22] = {.lex_state = 2, .external_lex_state = 2},
  [23] = {.lex_state = 2, .external_lex_state = 2},
  [24] = {.lex_state = 2, .external_lex_state = 2},
  [25] = {.lex_state = 2, .external_lex_state = 2},
  [26] = {.lex_state = 2, .external_lex_state = 2},
  [27] = {.lex_state = 2, .external_lex_state = 2},
  [28] = {.lex_state = 2, .external_lex_state = 2},
  [29] = {.lex_state = 181, .external_lex_state = 2},
  [30] = {.lex_state = 181, .external_lex_state = 2},
  [31] = {.lex_state = 181, .external_lex_state = 2},
  [32] = {.lex_state = 181, .external_lex_state = 2},
  [33] = {.lex_state = 181, .external_lex_state = 2},
  [34] = {.lex_state = 181, .external_lex_state = 2},
  [35] = {.lex_state = 181, .external_lex_state = 2},
  [36] = {.lex_state = 181, .external_lex_state = 2},
  [37] = {.lex_state = 181, .external_lex_state = 2},
  [38] = {.lex_state = 181, .external_lex_state = 2},
  [39] = {.lex_state = 181, .external_lex_state = 2},
  [40] = {.lex_state = 181, .external_lex_state = 2},
  [41] = {.lex_state = 181, .external_lex_state = 2},
  [42] = {.lex_state = 181, .external_lex_state = 2},
  [43] = {.lex_state = 181, .external_lex_state = 2},
  [44] = {.lex_state = 181, .external_lex_state = 2},
  [45] = {.lex_state = 181, .external_lex_state = 2},
  [46] = {.lex_state = 182, .external_lex_state = 2},
  [47] = {.lex_state = 181, .external_lex_state = 2},
  [48] = {.lex_state = 181, .external_lex_state = 2},
  [49] = {.lex_state = 181, .external_lex_state = 2},
  [50] = {.lex_state = 181, .external_lex_state = 2},
  [51] = {.lex_state = 181, .external_lex_state = 2},
  [52] = {.lex_state = 181, .external_lex_state = 2},
  [53] = {.lex_state = 181, .external_lex_state = 2},
  [54] = {.lex_state = 182, .external_lex_state = 2},
  [55] = {.lex_state = 181, .external_lex_state = 2},
  [56] = {.lex_state = 181, .external_lex_state = 2},
  [57] = {.lex_state = 181, .external_lex_state = 2},
  [58] = {.lex_state = 181, .external_lex_state = 2},
  [59] = {.lex_state = 181, .external_lex_state = 2},
  [60] = {.lex_state = 181, .external_lex_state = 2},
  [61] = {.lex_state = 181, .external_lex_state = 2},
  [62] = {.lex_state = 181, .external_lex_state = 2},
  [63] = {.lex_state = 181, .external_lex_state = 2},
  [64] = {.lex_state = 181, .external_lex_state = 2},
  [65] = {.lex_state = 181, .external_lex_state = 2},
  [66] = {.lex_state = 181, .external_lex_state = 2},
  [67] = {.lex_state = 181, .external_lex_state = 2},
  [68] = {.lex_state = 181, .external_lex_state = 2},
  [69] = {.lex_state = 181, .external_lex_state = 2},
  [70] = {.lex_state = 181, .external_lex_state = 2},
  [71] = {.lex_state = 181, .external_lex_state = 2},
  [72] = {.lex_state = 180, .external_lex_state = 2},
  [73] = {.lex_state = 180, .external_lex_state = 2},
  [74] = {.lex_state = 180, .external_lex_state = 2},
  [75] = {.lex_state = 180, .external_lex_state = 2},
  [76] = {.lex_state = 180, .external_lex_state = 2},
  [77] = {.lex_state = 180, .external_lex_state = 2},
  [78] = {.lex_state = 180, .external_lex_state = 2},
  [79] = {.lex_state = 180, .external_lex_state = 2},
  [80] = {.lex_state = 180, .external_lex_state = 2},
  [81] = {.lex_state = 180, .external_lex_state = 2},
  [82] = {.lex_state = 180, .external_lex_state = 2},
  [83] = {.lex_state = 180, .external_lex_state = 2},
  [84] = {.lex_state = 180, .external_lex_state = 2},
  [85] = {.lex_state = 180, .external_lex_state = 2},
  [86] = {.lex_state = 180, .external_lex_state = 2},
  [87] = {.lex_state = 180, .external_lex_state = 2},
  [88] = {.lex_state = 180, .external_lex_state = 2},
  [89] = {.lex_state = 180, .external_lex_state = 2},
  [90] = {.lex_state = 180, .external_lex_state = 2},
  [91] = {.lex_state = 180, .external_lex_state = 2},
  [92] = {.lex_state = 180, .external_lex_state = 2},
  [93] = {.lex_state = 180, .external_lex_state = 2},
  [94] = {.lex_state = 180, .external_lex_state = 2},
  [95] = {.lex_state = 180, .external_lex_state = 2},
  [96] = {.lex_state = 180, .external_lex_state = 2},
  [97] = {.lex_state = 180, .external_lex_state = 2},
  [98] = {.lex_state = 180, .external_lex_state = 2},
  [99] = {.lex_state = 180, .external_lex_state = 2},
  [100] = {.lex_state = 180, .external_lex_state = 2},
  [101] = {.lex_state = 180, .external_lex_state = 2},
  [102] = {.lex_state = 180, .external_lex_state = 2},
  [103] = {.lex_state = 180, .external_lex_state = 2},
  [104] = {.lex_state = 180, .external_lex_state = 2},
  [105] = {.lex_state = 180, .external_lex_state = 2},
  [106] = {.lex_state = 180, .external_lex_state = 2},
  [107] = {.lex_state = 180, .external_lex_state = 2},
  [108] = {.lex_state = 180, .external_lex_state = 2},
  [109] = {.lex_state = 180, .external_lex_state = 2},
  [110] = {.lex_state = 180, .external_lex_state = 2},
  [111] = {.lex_state = 180, .external_lex_state = 2},
  [112] = {.lex_state = 180, .external_lex_state = 2},
  [113] = {.lex_state = 180, .external_lex_state = 2},
  [114] = {.lex_state = 180, .external_lex_state = 2},
  [115] = {.lex_state = 180, .external_lex_state = 2},
  [116] = {.lex_state = 180, .external_lex_state = 2},
  [117] = {.lex_state = 180, .external_lex_state = 2},
  [118] = {.lex_state = 180, .external_lex_state = 2},
  [119] = {.lex_state = 180, .external_lex_state = 2},
  [120] = {.lex_state = 180, .external_lex_state = 2},
  [121] = {.lex_state = 180, .external_lex_state = 2},
  [122] = {.lex_state = 180, .external_lex_state = 2},
  [123] = {.lex_state = 180, .external_lex_state = 2},
  [124] = {.lex_state = 180, .external_lex_state = 2},
  [125] = {.lex_state = 180, .external_lex_state = 2},
  [126] = {.lex_state = 180, .external_lex_state = 2},
  [127] = {.lex_state = 180, .external_lex_state = 2},
  [128] = {.lex_state = 180, .external_lex_state = 2},
  [129] = {.lex_state = 180, .external_lex_state = 2},
  [130] = {.lex_state = 180, .external_lex_state = 2},
  [131] = {.lex_state = 180, .external_lex_state = 2},
  [132] = {.lex_state = 180, .external_lex_state = 2},
  [133] = {.lex_state = 180, .external_lex_state = 2},
  [134] = {.lex_state = 180, .external_lex_state = 2},
  [135] = {.lex_state = 180, .external_lex_state = 2},
  [136] = {.lex_state = 180, .external_lex_state = 2},
  [137] = {.lex_state = 180, .external_lex_state = 2},
  [138] = {.lex_state = 180, .external_lex_state = 2},
  [139] = {.lex_state = 180, .external_lex_state = 2},
  [140] = {.lex_state = 180, .external_lex_state = 2},
  [141] = {.lex_state = 180, .external_lex_state = 2},
  [142] = {.lex_state = 180, .external_lex_state = 2},
  [143] = {.lex_state = 180, .external_lex_state = 2},
  [144] = {.lex_state = 180, .external_lex_state = 2},
  [145] = {.lex_state = 180, .external_lex_state = 2},
  [146] = {.lex_state = 180, .external_lex_state = 2},
  [147] = {.lex_state = 180, .external_lex_state = 2},
  [148] = {.lex_state = 180, .external_lex_state = 2},
  [149] = {.lex_state = 180, .external_lex_state = 2},
  [150] = {.lex_state = 180, .external_lex_state = 2},
  [151] = {.lex_state = 180, .external_lex_state = 2},
  [152] = {.lex_state = 180, .external_lex_state = 2},
  [153] = {.lex_state = 180, .external_lex_state = 2},
  [154] = {.lex_state = 180, .external_lex_state = 2},
  [155] = {.lex_state = 4, .external_lex_state = 3},
  [156] = {.lex_state = 4, .external_lex_state = 3},
  [157] = {.lex_state = 4, .external_lex_state = 3},
  [158] = {.lex_state = 4, .external_lex_state = 3},
  [159] = {.lex_state = 4, .external_lex_state = 3},
  [160] = {.lex_state = 4, .external_lex_state = 3},
  [161] = {.lex_state = 4, .external_lex_state = 3},
  [162] = {.lex_state = 4, .external_lex_state = 3},
  [163] = {.lex_state = 4, .external_lex_state = 3},
  [164] = {.lex_state = 4, .external_lex_state = 3},
  [165] = {.lex_state = 4, .external_lex_state = 3},
  [166] = {.lex_state = 4, .external_lex_state = 3},
  [167] = {.lex_state = 182, .external_lex_state = 3},
  [168] = {.lex_state = 7, .external_lex_state = 3},
  [169] = {.lex_state = 182, .external_lex_state = 3},
  [170] = {.lex_state = 182, .external_lex_state = 3},
  [171] = {.lex_state = 182, .external_lex_state = 3},
  [172] = {.lex_state = 182, .external_lex_state = 3},
  [173] = {.lex_state = 182, .external_lex_state = 3},
  [174] = {.lex_state = 182, .external_lex_state = 3},
  [175] = {.lex_state = 182, .external_lex_state = 3},
  [176] = {.lex_state = 182, .external_lex_state = 3},
  [177] = {.lex_state = 182, .external_lex_state = 3},
  [178] = {.lex_state = 182, .external_lex_state = 3},
  [179] = {.lex_state = 7, .external_lex_state = 3},
  [180] = {.lex_state = 7, .external_lex_state = 3},
  [181] = {.lex_state = 7, .external_lex_state = 3},
  [182] = {.lex_state = 7, .external_lex_state = 3},
  [183] = {.lex_state = 7, .external_lex_state = 3},
  [184] = {.lex_state = 182, .external_lex_state = 3},
  [185] = {.lex_state = 182, .external_lex_state = 3},
  [186] = {.lex_state = 182, .external_lex_state = 3},
  [187] = {.lex_state = 182, .external_lex_state = 3},
  [188] = {.lex_state = 182, .external_lex_state = 3},
  [189] = {.lex_state = 182, .external_lex_state = 3},
  [190] = {.lex_state = 1, .external_lex_state = 2},
  [191] = {.lex_state = 1, .external_lex_state = 2},
  [192] = {.lex_state = 1, .external_lex_state = 2},
  [193] = {.lex_state = 1, .external_lex_state = 2},
  [194] = {.lex_state = 1, .external_lex_state = 2},
  [195] = {.lex_state = 182, .external_lex_state = 3},
  [196] = {.lex_state = 1, .external_lex_state = 2},
  [197] = {.lex_state = 1, .external_lex_state = 2},
  [198] = {.lex_state = 182, .external_lex_state = 3},
  [199] = {.lex_state = 7, .external_lex_state = 3},
  [200] = {.lex_state = 182, .external_lex_state = 3},
  [201] = {.lex_state = 182, .external_lex_state = 3},
  [202] = {.lex_state = 182, .external_lex_state = 3},
  [203] = {.lex_state = 182, .external_lex_state = 3},
  [204] = {.lex_state = 182, .external_lex_state = 3},
  [205] = {.lex_state = 4, .external_lex_state = 3},
  [206] = {.lex_state = 4, .external_lex_state = 3},
  [207] = {.lex_state = 4, .external_lex_state = 3},
  [208] = {.lex_state = 4, .external_lex_state = 3},
  [209] = {.lex_state = 182, .external_lex_state = 3},
  [210] = {.lex_state = 182, .external_lex_state = 3},
  [211] = {.lex_state = 182, .external_lex_state = 3},
  [212] = {.lex_state = 182, .external_lex_state = 3},
  [213] = {.lex_state = 182, .external_lex_state = 3},
  [214] = {.lex_state = 182, .external_lex_state = 3},
  [215] = {.lex_state = 182, .external_lex_state = 3},
  [216] = {.lex_state = 182, .external_lex_state = 3},
  [217] = {.lex_state = 182, .external_lex_state = 3},
  [218] = {.lex_state = 182, .external_lex_state = 3},
  [219] = {.lex_state = 182, .external_lex_state = 3},
  [220] = {.lex_state = 182, .external_lex_state = 3},
  [221] = {.lex_state = 182, .external_lex_state = 3},
  [222] = {.lex_state = 4, .external_lex_state = 3},
  [223] = {.lex_state = 4, .external_lex_state = 3},
  [224] = {.lex_state = 4, .external_lex_state = 3},
  [225] = {.lex_state = 4, .external_lex_state = 3},
  [226] = {.lex_state = 4, .external_lex_state = 3},
  [227] = {.lex_state = 4, .external_lex_state = 3},
  [228] = {.lex_state = 182, .external_lex_state = 3},
  [229] = {.lex_state = 182, .external_lex_state = 3},
  [230] = {.lex_state = 4, .external_lex_state = 3},
  [231] = {.lex_state = 4, .external_lex_state = 3},
  [232] = {.lex_state = 4, .external_lex_state = 3},
  [233] = {.lex_state = 4, .external_lex_state = 3},
  [234] = {.lex_state = 4, .external_lex_state = 3},
  [235] = {.lex_state = 182, .external_lex_state = 3},
  [236] = {.lex_state = 4, .external_lex_state = 3},
  [237] = {.lex_state = 182, .external_lex_state = 3},
  [238] = {.lex_state = 182, .external_lex_state = 3},
  [239] = {.lex_state = 7, .external_lex_state = 3},
  [240] = {.lex_state = 7, .external_lex_state = 4},
  [241] = {.lex_state = 7, .external_lex_state = 3},
  [242] = {.lex_state = 7, .external_lex_state = 3},
  [243] = {.lex_state = 180, .external_lex_state = 2},
  [244] = {.lex_state = 2, .external_lex_state = 2},
  [245] = {.lex_state = 182, .external_lex_state = 2},
  [246] = {.lex_state = 182, .external_lex_state = 2},
  [247] = {.lex_state = 182, .external_lex_state = 2},
  [248] = {.lex_state = 182, .external_lex_state = 2},
  [249] = {.lex_state = 182, .external_lex_state = 2},
  [250] = {.lex_state = 181, .external_lex_state = 3},
  [251] = {.lex_state = 181, .external_lex_state = 3},
  [252] = {.lex_state = 181, .external_lex_state = 3},
  [253] = {.lex_state = 181, .external_lex_state = 3},
  [254] = {.lex_state = 181, .external_lex_state = 3},
  [255] = {.lex_state = 181, .external_lex_state = 3},
  [256] = {.lex_state = 181, .external_lex_state = 3},
  [257] = {.lex_state = 181, .external_lex_state = 3},
  [258] = {.lex_state = 181, .external_lex_state = 3},
  [259] = {.lex_state = 181, .external_lex_state = 3},
  [260] = {.lex_state = 181, .external_lex_state = 3},
  [261] = {.lex_state = 181, .external_lex_state = 3},
  [262] = {.lex_state = 181, .external_lex_state = 3},
  [263] = {.lex_state = 181, .external_lex_state = 3},
  [264] = {.lex_state = 181, .external_lex_state = 3},
  [265] = {.lex_state = 181, .external_lex_state = 3},
  [266] = {.lex_state = 181, .external_lex_state = 3},
  [267] = {.lex_state = 181, .external_lex_state = 3},
  [268] = {.lex_state = 181, .external_lex_state = 3},
  [269] = {.lex_state = 181, .external_lex_state = 3},
  [270] = {.lex_state = 181, .external_lex_state = 3},
  [271] = {.lex_state = 181, .external_lex_state = 3},
  [272] = {.lex_state = 181, .external_lex_state = 3},
  [273] = {.lex_state = 181, .external_lex_state = 3},
  [274] = {.lex_state = 181, .external_lex_state = 3},
  [275] = {.lex_state = 181, .external_lex_state = 3},
  [276] = {.lex_state = 181, .external_lex_state = 3},
  [277] = {.lex_state = 181, .external_lex_state = 3},
  [278] = {.lex_state = 181, .external_lex_state = 3},
  [279] = {.lex_state = 181, .external_lex_state = 3},
  [280] = {.lex_state = 181, .external_lex_state = 3},
  [281] = {.lex_state = 181, .external_lex_state = 3},
  [282] = {.lex_state = 181, .external_lex_state = 3},
  [283] = {.lex_state = 181, .external_lex_state = 3},
  [284] = {.lex_state = 181, .external_lex_state = 3},
  [285] = {.lex_state = 181, .external_lex_state = 3},
  [286] = {.lex_state = 181, .external_lex_state = 3},
  [287] = {.lex_state = 181, .external_lex_state = 3},
  [288] = {.lex_state = 181, .external_lex_state = 3},
  [289] = {.lex_state = 181, .external_lex_state = 3},
  [290] = {.lex_state = 181, .external_lex_state = 3},
  [291] = {.lex_state = 181, .external_lex_state = 3},
  [292] = {.lex_state = 181, .external_lex_state = 3},
  [293] = {.lex_state = 181, .external_lex_state = 3},
  [294] = {.lex_state = 181, .external_lex_state = 3},
  [295] = {.lex_state = 181, .external_lex_state = 3},
  [296] = {.lex_state = 181, .external_lex_state = 3},
  [297] = {.lex_state = 181, .external_lex_state = 3},
  [298] = {.lex_state = 181, .external_lex_state = 3},
  [299] = {.lex_state = 181, .external_lex_state = 3},
  [300] = {.lex_state = 181, .external_lex_state = 3},
  [301] = {.lex_state = 181, .external_lex_state = 3},
  [302] = {.lex_state = 181, .external_lex_state = 3},
  [303] = {.lex_state = 181, .external_lex_state = 3},
  [304] = {.lex_state = 181, .external_lex_state = 3},
  [305] = {.lex_state = 181, .external_lex_state = 3},
  [306] = {.lex_state = 181, .external_lex_state = 3},
  [307] = {.lex_state = 181, .external_lex_state = 3},
  [308] = {.lex_state = 181, .external_lex_state = 3},
  [309] = {.lex_state = 181, .external_lex_state = 3},
  [310] = {.lex_state = 181, .external_lex_state = 3},
  [311] = {.lex_state = 181, .external_lex_state = 3},
  [312] = {.lex_state = 181, .external_lex_state = 3},
  [313] = {.lex_state = 181, .external_lex_state = 3},
  [314] = {.lex_state = 181, .external_lex_state = 3},
  [315] = {.lex_state = 181, .external_lex_state = 3},
  [316] = {.lex_state = 181, .external_lex_state = 3},
  [317] = {.lex_state = 181, .external_lex_state = 3},
  [318] = {.lex_state = 181, .external_lex_state = 3},
  [319] = {.lex_state = 181, .external_lex_state = 3},
  [320] = {.lex_state = 181, .external_lex_state = 3},
  [321] = {.lex_state = 181, .external_lex_state = 3},
  [322] = {.lex_state = 181, .external_lex_state = 3},
  [323] = {.lex_state = 181, .external_lex_state = 3},
  [324] = {.lex_state = 181, .external_lex_state = 3},
  [325] = {.lex_state = 181, .external_lex_state = 3},
  [326] = {.lex_state = 181, .external_lex_state = 3},
  [327] = {.lex_state = 181, .external_lex_state = 3},
  [328] = {.lex_state = 181, .external_lex_state = 3},
  [329] = {.lex_state = 181, .external_lex_state = 3},
  [330] = {.lex_state = 181, .external_lex_state = 3},
  [331] = {.lex_state = 181, .external_lex_state = 3},
  [332] = {.lex_state = 181, .external_lex_state = 3},
  [333] = {.lex_state = 181, .external_lex_state = 3},
  [334] = {.lex_state = 181, .external_lex_state = 3},
  [335] = {.lex_state = 181, .external_lex_state = 3},
  [336] = {.lex_state = 181, .external_lex_state = 3},
  [337] = {.lex_state = 181, .external_lex_state = 3},
  [338] = {.lex_state = 181, .external_lex_state = 3},
  [339] = {.lex_state = 181, .external_lex_state = 3},
  [340] = {.lex_state = 181, .external_lex_state = 3},
  [341] = {.lex_state = 181, .external_lex_state = 3},
  [342] = {.lex_state = 181, .external_lex_state = 3},
  [343] = {.lex_state = 181, .external_lex_state = 3},
  [344] = {.lex_state = 181, .external_lex_state = 3},
  [345] = {.lex_state = 181, .external_lex_state = 3},
  [346] = {.lex_state = 181, .external_lex_state = 3},
  [347] = {.lex_state = 181, .external_lex_state = 3},
  [348] = {.lex_state = 181, .external_lex_state = 3},
  [349] = {.lex_state = 181, .external_lex_state = 3},
  [350] = {.lex_state = 181, .external_lex_state = 3},
  [351] = {.lex_state = 181, .external_lex_state = 3},
  [352] = {.lex_state = 181, .external_lex_state = 3},
  [353] = {.lex_state = 181, .external_lex_state = 3},
  [354] = {.lex_state = 181, .external_lex_state = 3},
  [355] = {.lex_state = 181, .external_lex_state = 3},
  [356] = {.lex_state = 181, .external_lex_state = 3},
  [357] = {.lex_state = 181, .external_lex_state = 3},
  [358] = {.lex_state = 181, .external_lex_state = 3},
  [359] = {.lex_state = 181, .external_lex_state = 3},
  [360] = {.lex_state = 181, .external_lex_state = 3},
  [361] = {.lex_state = 181, .external_lex_state = 3},
  [362] = {.lex_state = 181, .external_lex_state = 3},
  [363] = {.lex_state = 181, .external_lex_state = 2},
  [364] = {.lex_state = 181, .external_lex_state = 2},
  [365] = {.lex_state = 181, .external_lex_state = 2},
  [366] = {.lex_state = 181, .external_lex_state = 2},
  [367] = {.lex_state = 181, .external_lex_state = 2},
  [368] = {.lex_state = 181, .external_lex_state = 2},
  [369] = {.lex_state = 181, .external_lex_state = 2},
  [370] = {.lex_state = 181, .external_lex_state = 2},
  [371] = {.lex_state = 181, .external_lex_state = 2},
  [372] = {.lex_state = 181, .external_lex_state = 2},
  [373] = {.lex_state = 180, .external_lex_state = 5},
  [374] = {.lex_state = 180, .external_lex_state = 5},
  [375] = {.lex_state = 180, .external_lex_state = 5},
  [376] = {.lex_state = 180, .external_lex_state = 5},
  [377] = {.lex_state = 180, .external_lex_state = 5},
  [378] = {.lex_state = 180, .external_lex_state = 5},
  [379] = {.lex_state = 180, .external_lex_state = 5},
  [380] = {.lex_state = 180, .external_lex_state = 5},
  [381] = {.lex_state = 180, .external_lex_state = 5},
  [382] = {.lex_state = 182, .external_lex_state = 6},
  [383] = {.lex_state = 180, .external_lex_state = 5},
  [384] = {.lex_state = 180, .external_lex_state = 5},
  [385] = {.lex_state = 182, .external_lex_state = 6},
  [386] = {.lex_state = 180, .external_lex_state = 5},
  [387] = {.lex_state = 180, .external_lex_state = 5},
  [388] = {.lex_state = 182, .external_lex_state = 6},
  [389] = {.lex_state = 180, .external_lex_state = 5},
  [390] = {.lex_state = 182, .external_lex_state = 6},
  [391] = {.lex_state = 180, .external_lex_state = 5},
  [392] = {.lex_state = 180, .external_lex_state = 5},
  [393] = {.lex_state = 182, .external_lex_state = 6},
  [394] = {.lex_state = 180, .external_lex_state = 5},
  [395] = {.lex_state = 5, .external_lex_state = 7},
  [396] = {.lex_state = 5, .external_lex_state = 7},
  [397] = {.lex_state = 180, .external_lex_state = 5},
  [398] = {.lex_state = 5, .external_lex_state = 7},
  [399] = {.lex_state = 5, .external_lex_state = 7},
  [400] = {.lex_state = 5, .external_lex_state = 7},
  [401] = {.lex_state = 180, .external_lex_state = 5},
  [402] = {.lex_state = 180, .external_lex_state = 5},
  [403] = {.lex_state = 180, .external_lex_state = 5},
  [404] = {.lex_state = 180, .external_lex_state = 5},
  [405] = {.lex_state = 5, .external_lex_state = 7},
  [406] = {.lex_state = 5, .external_lex_state = 7},
  [407] = {.lex_state = 5, .external_lex_state = 7},
  [408] = {.lex_state = 5, .external_lex_state = 7},
  [409] = {.lex_state = 180, .external_lex_state = 5},
  [410] = {.lex_state = 180, .external_lex_state = 5},
  [411] = {.lex_state = 0, .external_lex_state = 5},
  [412] = {.lex_state = 180, .external_lex_state = 5},
  [413] = {.lex_state = 5, .external_lex_state = 7},
  [414] = {.lex_state = 5, .external_lex_state = 7},
  [415] = {.lex_state = 5, .external_lex_state = 7},
  [416] = {.lex_state = 180, .external_lex_state = 5},
  [417] = {.lex_state = 5, .external_lex_state = 7},
  [418] = {.lex_state = 0, .external_lex_state = 5},
  [419] = {.lex_state = 0, .external_lex_state = 5},
  [420] = {.lex_state = 180, .external_lex_state = 5},
  [421] = {.lex_state = 0, .external_lex_state = 5},
  [422] = {.lex_state = 0, .external_lex_state = 5},
  [423] = {.lex_state = 0, .external_lex_state = 5},
  [424] = {.lex_state = 5, .external_lex_state = 7},
  [425] = {.lex_state = 5, .external_lex_state = 7},
  [426] = {.lex_state = 0, .external_lex_state = 5},
  [427] = {.lex_state = 5, .external_lex_state = 7},
  [428] = {.lex_state = 180, .external_lex_state = 5},
  [429] = {.lex_state = 0, .external_lex_state = 5},
  [430] = {.lex_state = 0, .external_lex_state = 5},
  [431] = {.lex_state = 5, .external_lex_state = 7},
  [432] = {.lex_state = 0, .external_lex_state = 5},
  [433] = {.lex_state = 180, .external_lex_state = 5},
  [434] = {.lex_state = 5, .external_lex_state = 7},
  [435] = {.lex_state = 180, .external_lex_state = 5},
  [436] = {.lex_state = 5, .external_lex_state = 7},
  [437] = {.lex_state = 0, .external_lex_state = 5},
  [438] = {.lex_state = 5, .external_lex_state = 7},
  [439] = {.lex_state = 5, .external_lex_state = 7},
  [440] = {.lex_state = 5, .external_lex_state = 7},
  [441] = {.lex_state = 180, .external_lex_state = 5},
  [442] = {.lex_state = 5, .external_lex_state = 7},
  [443] = {.lex_state = 5, .external_lex_state = 7},
  [444] = {.lex_state = 180, .external_lex_state = 5},
  [445] = {.lex_state = 5, .external_lex_state = 7},
  [446] = {.lex_state = 5, .external_lex_state = 7},
  [447] = {.lex_state = 0, .external_lex_state = 5},
  [448] = {.lex_state = 5, .external_lex_state = 7},
  [449] = {.lex_state = 5, .external_lex_state = 7},
  [450] = {.lex_state = 5, .external_lex_state = 7},
  [451] = {.lex_state = 5, .external_lex_state = 7},
  [452] = {.lex_state = 0, .external_lex_state = 5},
  [453] = {.lex_state = 5, .external_lex_state = 7},
  [454] = {.lex_state = 0, .external_lex_state = 5},
  [455] = {.lex_state = 180, .external_lex_state = 5},
  [456] = {.lex_state = 0, .external_lex_state = 5},
  [457] = {.lex_state = 5, .external_lex_state = 7},
  [458] = {.lex_state = 5, .external_lex_state = 7},
  [459] = {.lex_state = 0, .external_lex_state = 5},
  [460] = {.lex_state = 0, .external_lex_state = 5},
  [461] = {.lex_state = 180, .external_lex_state = 5},
  [462] = {.lex_state = 180, .external_lex_state = 5},
  [463] = {.lex_state = 180, .external_lex_state = 5},
  [464] = {.lex_state = 0, .external_lex_state = 5},
  [465] = {.lex_state = 0, .external_lex_state = 5},
  [466] = {.lex_state = 0, .external_lex_state = 5},
  [467] = {.lex_state = 0, .external_lex_state = 5},
  [468] = {.lex_state = 0, .external_lex_state = 5},
  [469] = {.lex_state = 0, .external_lex_state = 5},
  [470] = {.lex_state = 0, .external_lex_state = 5},
  [471] = {.lex_state = 180, .external_lex_state = 5},
  [472] = {.lex_state = 180, .external_lex_state = 5},
  [473] = {.lex_state = 180, .external_lex_state = 5},
  [474] = {.lex_state = 180, .external_lex_state = 5},
  [475] = {.lex_state = 0, .external_lex_state = 5},
  [476] = {.lex_state = 0, .external_lex_state = 5},
  [477] = {.lex_state = 0, .external_lex_state = 5},
  [478] = {.lex_state = 180, .external_lex_state = 5},
  [479] = {.lex_state = 0, .external_lex_state = 5},
  [480] = {.lex_state = 0, .external_lex_state = 5},
  [481] = {.lex_state = 180, .external_lex_state = 5},
  [482] = {.lex_state = 0, .external_lex_state = 5},
  [483] = {.lex_state = 5, .external_lex_state = 7},
  [484] = {.lex_state = 180, .external_lex_state = 5},
  [485] = {.lex_state = 180, .external_lex_state = 5},
  [486] = {.lex_state = 5, .external_lex_state = 7},
  [487] = {.lex_state = 0, .external_lex_state = 5},
  [488] = {.lex_state = 180, .external_lex_state = 5},
  [489] = {.lex_state = 180, .external_lex_state = 5},
  [490] = {.lex_state = 180, .external_lex_state = 5},
  [491] = {.lex_state = 180, .external_lex_state = 5},
  [492] = {.lex_state = 180, .external_lex_state = 5},
  [493] = {.lex_state = 0, .external_lex_state = 5},
  [494] = {.lex_state = 180, .external_lex_state = 5},
  [495] = {.lex_state = 180, .external_lex_state = 5},
  [496] = {.lex_state = 0, .external_lex_state = 5},
  [497] = {.lex_state = 180, .external_lex_state = 5},
  [498] = {.lex_state = 180, .external_lex_state = 5},
  [499] = {.lex_state = 5, .external_lex_state = 7},
  [500] = {.lex_state = 5, .external_lex_state = 7},
  [501] = {.lex_state = 5, .external_lex_state = 7},
  [502] = {.lex_state = 5, .external_lex_state = 7},
  [503] = {.lex_state = 180, .external_lex_state = 5},
  [504] = {.lex_state = 180, .external_lex_state = 5},
  [505] = {.lex_state = 180, .external_lex_state = 5},
  [506] = {.lex_state = 180, .external_lex_state = 5},
  [507] = {.lex_state = 180, .external_lex_state = 5},
  [508] = {.lex_state = 0, .external_lex_state = 5},
  [509] = {.lex_state = 180, .external_lex_state = 5},
  [510] = {.lex_state = 0, .external_lex_state = 5},
  [511] = {.lex_state = 180, .external_lex_state = 5},
  [512] = {.lex_state = 180, .external_lex_state = 5},
  [513] = {.lex_state = 180, .external_lex_state = 5},
  [514] = {.lex_state = 180, .external_lex_state = 5},
  [515] = {.lex_state = 180, .external_lex_state = 5},
  [516] = {.lex_state = 0, .external_lex_state = 5},
  [517] = {.lex_state = 180, .external_lex_state = 5},
  [518] = {.lex_state = 0, .external_lex_state = 5},
  [519] = {.lex_state = 180, .external_lex_state = 5},
  [520] = {.lex_state = 180, .external_lex_state = 5},
  [521] = {.lex_state = 0, .external_lex_state = 5},
  [522] = {.lex_state = 0, .external_lex_state = 5},
  [523] = {.lex_state = 180, .external_lex_state = 5},
  [524] = {.lex_state = 180, .external_lex_state = 5},
  [525] = {.lex_state = 0, .external_lex_state = 5},
  [526] = {.lex_state = 180, .external_lex_state = 5},
  [527] = {.lex_state = 180, .external_lex_state = 5},
  [528] = {.lex_state = 180, .external_lex_state = 5},
  [529] = {.lex_state = 180, .external_lex_state = 5},
  [530] = {.lex_state = 180, .external_lex_state = 5},
  [531] = {.lex_state = 180, .external_lex_state = 5},
  [532] = {.lex_state = 180, .external_lex_state = 5},
  [533] = {.lex_state = 180, .external_lex_state = 5},
  [534] = {.lex_state = 180, .external_lex_state = 5},
  [535] = {.lex_state = 180, .external_lex_state = 5},
  [536] = {.lex_state = 180, .external_lex_state = 5},
  [537] = {.lex_state = 5, .external_lex_state = 7},
  [538] = {.lex_state = 5, .external_lex_state = 7},
  [539] = {.lex_state = 5, .external_lex_state = 7},
  [540] = {.lex_state = 0, .external_lex_state = 5},
  [541] = {.lex_state = 5, .external_lex_state = 7},
  [542] = {.lex_state = 0, .external_lex_state = 5},
  [543] = {.lex_state = 5, .external_lex_state = 7},
  [544] = {.lex_state = 5, .external_lex_state = 7},
  [545] = {.lex_state = 5, .external_lex_state = 7},
  [546] = {.lex_state = 5, .external_lex_state = 7},
  [547] = {.lex_state = 5, .external_lex_state = 7},
  [548] = {.lex_state = 5, .external_lex_state = 7},
  [549] = {.lex_state = 180, .external_lex_state = 5},
  [550] = {.lex_state = 5, .external_lex_state = 7},
  [551] = {.lex_state = 5, .external_lex_state = 7},
  [552] = {.lex_state = 5, .external_lex_state = 7},
  [553] = {.lex_state = 5, .external_lex_state = 7},
  [554] = {.lex_state = 5, .external_lex_state = 7},
  [555] = {.lex_state = 5, .external_lex_state = 7},
  [556] = {.lex_state = 5, .external_lex_state = 7},
  [557] = {.lex_state = 5, .external_lex_state = 7},
  [558] = {.lex_state = 5, .external_lex_state = 7},
  [559] = {.lex_state = 5, .external_lex_state = 7},
  [560] = {.lex_state = 5, .external_lex_state = 7},
  [561] = {.lex_state = 0, .external_lex_state = 5},
  [562] = {.lex_state = 0, .external_lex_state = 5},
  [563] = {.lex_state = 0, .external_lex_state = 5},
  [564] = {.lex_state = 0, .external_lex_state = 5},
  [565] = {.lex_state = 5, .external_lex_state = 7},
  [566] = {.lex_state = 5, .external_lex_state = 7},
  [567] = {.lex_state = 5, .external_lex_state = 7},
  [568] = {.lex_state = 0, .external_lex_state = 5},
  [569] = {.lex_state = 5, .external_lex_state = 7},
  [570] = {.lex_state = 5, .external_lex_state = 7},
  [571] = {.lex_state = 5, .external_lex_state = 7},
  [572] = {.lex_state = 5, .external_lex_state = 7},
  [573] = {.lex_state = 5, .external_lex_state = 7},
  [574] = {.lex_state = 5, .external_lex_state = 7},
  [575] = {.lex_state = 5, .external_lex_state = 7},
  [576] = {.lex_state = 5, .external_lex_state = 7},
  [577] = {.lex_state = 5, .external_lex_state = 7},
  [578] = {.lex_state = 5, .external_lex_state = 7},
  [579] = {.lex_state = 5, .external_lex_state = 7},
  [580] = {.lex_state = 5, .external_lex_state = 7},
  [581] = {.lex_state = 0, .external_lex_state = 5},
  [582] = {.lex_state = 5, .external_lex_state = 7},
  [583] = {.lex_state = 5, .external_lex_state = 7},
  [584] = {.lex_state = 5, .external_lex_state = 7},
  [585] = {.lex_state = 5, .external_lex_state = 7},
  [586] = {.lex_state = 5, .external_lex_state = 7},
  [587] = {.lex_state = 0, .external_lex_state = 5},
  [588] = {.lex_state = 5, .external_lex_state = 7},
  [589] = {.lex_state = 5, .external_lex_state = 7},
  [590] = {.lex_state = 5, .external_lex_state = 7},
  [591] = {.lex_state = 5, .external_lex_state = 7},
  [592] = {.lex_state = 5, .external_lex_state = 7},
  [593] = {.lex_state = 5, .external_lex_state = 7},
  [594] = {.lex_state = 180, .external_lex_state = 5},
  [595] = {.lex_state = 5, .external_lex_state = 7},
  [596] = {.lex_state = 5, .external_lex_state = 7},
  [597] = {.lex_state = 5, .external_lex_state = 7},
  [598] = {.lex_state = 5, .external_lex_state = 7},
  [599] = {.lex_state = 4, .external_lex_state = 3},
  [600] = {.lex_state = 5, .external_lex_state = 7},
  [601] = {.lex_state = 5, .external_lex_state = 7},
  [602] = {.lex_state = 5, .external_lex_state = 7},
  [603] = {.lex_state = 5, .external_lex_state = 7},
  [604] = {.lex_state = 5, .external_lex_state = 7},
  [605] = {.lex_state = 5, .external_lex_state = 7},
  [606] = {.lex_state = 5, .external_lex_state = 7},
  [607] = {.lex_state = 5, .external_lex_state = 7},
  [608] = {.lex_state = 0, .external_lex_state = 5},
  [609] = {.lex_state = 5, .external_lex_state = 7},
  [610] = {.lex_state = 5, .external_lex_state = 7},
  [611] = {.lex_state = 0, .external_lex_state = 5},
  [612] = {.lex_state = 180, .external_lex_state = 5},
  [613] = {.lex_state = 5, .external_lex_state = 7},
  [614] = {.lex_state = 0, .external_lex_state = 5},
  [615] = {.lex_state = 5, .external_lex_state = 7},
  [616] = {.lex_state = 5, .external_lex_state = 7},
  [617] = {.lex_state = 5, .external_lex_state = 7},
  [618] = {.lex_state = 5, .external_lex_state = 7},
  [619] = {.lex_state = 180, .external_lex_state = 5},
  [620] = {.lex_state = 5, .external_lex_state = 7},
  [621] = {.lex_state = 5, .external_lex_state = 7},
  [622] = {.lex_state = 180, .external_lex_state = 5},
  [623] = {.lex_state = 180, .external_lex_state = 5},
  [624] = {.lex_state = 5, .external_lex_state = 7},
  [625] = {.lex_state = 5, .external_lex_state = 7},
  [626] = {.lex_state = 0, .external_lex_state = 5},
  [627] = {.lex_state = 0, .external_lex_state = 5},
  [628] = {.lex_state = 0, .external_lex_state = 5},
  [629] = {.lex_state = 0, .external_lex_state = 5},
  [630] = {.lex_state = 0, .external_lex_state = 5},
  [631] = {.lex_state = 0, .external_lex_state = 5},
  [632] = {.lex_state = 0, .external_lex_state = 5},
  [633] = {.lex_state = 0, .external_lex_state = 5},
  [634] = {.lex_state = 0, .external_lex_state = 5},
  [635] = {.lex_state = 0, .external_lex_state = 5},
  [636] = {.lex_state = 0, .external_lex_state = 5},
  [637] = {.lex_state = 0, .external_lex_state = 5},
  [638] = {.lex_state = 0, .external_lex_state = 5},
  [639] = {.lex_state = 0, .external_lex_state = 5},
  [640] = {.lex_state = 5, .external_lex_state = 7},
  [641] = {.lex_state = 0, .external_lex_state = 5},
  [642] = {.lex_state = 5, .external_lex_state = 7},
  [643] = {.lex_state = 0, .external_lex_state = 5},
  [644] = {.lex_state = 0, .external_lex_state = 5},
  [645] = {.lex_state = 0, .external_lex_state = 5},
  [646] = {.lex_state = 0, .external_lex_state = 5},
  [647] = {.lex_state = 0, .external_lex_state = 5},
  [648] = {.lex_state = 0, .external_lex_state = 5},
  [649] = {.lex_state = 0, .external_lex_state = 5},
  [650] = {.lex_state = 0, .external_lex_state = 5},
  [651] = {.lex_state = 0, .external_lex_state = 5},
  [652] = {.lex_state = 0, .external_lex_state = 5},
  [653] = {.lex_state = 0, .external_lex_state = 5},
  [654] = {.lex_state = 0, .external_lex_state = 5},
  [655] = {.lex_state = 0, .external_lex_state = 5},
  [656] = {.lex_state = 0, .external_lex_state = 5},
  [657] = {.lex_state = 0, .external_lex_state = 5},
  [658] = {.lex_state = 0, .external_lex_state = 5},
  [659] = {.lex_state = 0, .external_lex_state = 5},
  [660] = {.lex_state = 0, .external_lex_state = 5},
  [661] = {.lex_state = 0, .external_lex_state = 5},
  [662] = {.lex_state = 0, .external_lex_state = 5},
  [663] = {.lex_state = 0, .external_lex_state = 5},
  [664] = {.lex_state = 0, .external_lex_state = 5},
  [665] = {.lex_state = 0, .external_lex_state = 5},
  [666] = {.lex_state = 0, .external_lex_state = 5},
  [667] = {.lex_state = 0, .external_lex_state = 5},
  [668] = {.lex_state = 0, .external_lex_state = 5},
  [669] = {.lex_state = 0, .external_lex_state = 5},
  [670] = {.lex_state = 0, .external_lex_state = 5},
  [671] = {.lex_state = 0, .external_lex_state = 5},
  [672] = {.lex_state = 0, .external_lex_state = 5},
  [673] = {.lex_state = 0, .external_lex_state = 5},
  [674] = {.lex_state = 0, .external_lex_state = 5},
  [675] = {.lex_state = 0, .external_lex_state = 5},
  [676] = {.lex_state = 0, .external_lex_state = 5},
  [677] = {.lex_state = 0, .external_lex_state = 5},
  [678] = {.lex_state = 0, .external_lex_state = 5},
  [679] = {.lex_state = 0, .external_lex_state = 5},
  [680] = {.lex_state = 0, .external_lex_state = 5},
  [681] = {.lex_state = 0, .external_lex_state = 5},
  [682] = {.lex_state = 0, .external_lex_state = 5},
  [683] = {.lex_state = 0, .external_lex_state = 5},
  [684] = {.lex_state = 0, .external_lex_state = 5},
  [685] = {.lex_state = 0, .external_lex_state = 5},
  [686] = {.lex_state = 0, .external_lex_state = 5},
  [687] = {.lex_state = 0, .external_lex_state = 5},
  [688] = {.lex_state = 0, .external_lex_state = 5},
  [689] = {.lex_state = 0, .external_lex_state = 5},
  [690] = {.lex_state = 0, .external_lex_state = 5},
  [691] = {.lex_state = 0, .external_lex_state = 5},
  [692] = {.lex_state = 5, .external_lex_state = 7},
  [693] = {.lex_state = 5, .external_lex_state = 7},
  [694] = {.lex_state = 5, .external_lex_state = 7},
  [695] = {.lex_state = 5, .external_lex_state = 7},
  [696] = {.lex_state = 181, .external_lex_state = 6},
  [697] = {.lex_state = 0, .external_lex_state = 5},
  [698] = {.lex_state = 5, .external_lex_state = 7},
  [699] = {.lex_state = 5, .external_lex_state = 7},
  [700] = {.lex_state = 0, .external_lex_state = 5},
  [701] = {.lex_state = 5, .external_lex_state = 7},
  [702] = {.lex_state = 181, .external_lex_state = 6},
  [703] = {.lex_state = 0, .external_lex_state = 5},
  [704] = {.lex_state = 0, .external_lex_state = 5},
  [705] = {.lex_state = 0, .external_lex_state = 5},
  [706] = {.lex_state = 0, .external_lex_state = 5},
  [707] = {.lex_state = 5, .external_lex_state = 7},
  [708] = {.lex_state = 5, .external_lex_state = 7},
  [709] = {.lex_state = 5, .external_lex_state = 7},
  [710] = {.lex_state = 5, .external_lex_state = 7},
  [711] = {.lex_state = 2, .external_lex_state = 6},
  [712] = {.lex_state = 0, .external_lex_state = 5},
  [713] = {.lex_state = 0, .external_lex_state = 5},
  [714] = {.lex_state = 0, .external_lex_state = 5},
  [715] = {.lex_state = 0, .external_lex_state = 5},
  [716] = {.lex_state = 0, .external_lex_state = 5},
  [717] = {.lex_state = 0, .external_lex_state = 5},
  [718] = {.lex_state = 0, .external_lex_state = 5},
  [719] = {.lex_state = 0, .external_lex_state = 5},
  [720] = {.lex_state = 0, .external_lex_state = 5},
  [721] = {.lex_state = 0, .external_lex_state = 5},
  [722] = {.lex_state = 0, .external_lex_state = 5},
  [723] = {.lex_state = 0, .external_lex_state = 5},
  [724] = {.lex_state = 0, .external_lex_state = 5},
  [725] = {.lex_state = 0, .external_lex_state = 5},
  [726] = {.lex_state = 0, .external_lex_state = 5},
  [727] = {.lex_state = 0, .external_lex_state = 5},
  [728] = {.lex_state = 5, .external_lex_state = 7},
  [729] = {.lex_state = 0, .external_lex_state = 5},
  [730] = {.lex_state = 0, .external_lex_state = 5},
  [731] = {.lex_state = 2, .external_lex_state = 6},
  [732] = {.lex_state = 0, .external_lex_state = 5},
  [733] = {.lex_state = 0, .external_lex_state = 5},
  [734] = {.lex_state = 0, .external_lex_state = 5},
  [735] = {.lex_state = 0, .external_lex_state = 5},
  [736] = {.lex_state = 0, .external_lex_state = 5},
  [737] = {.lex_state = 0, .external_lex_state = 5},
  [738] = {.lex_state = 0, .external_lex_state = 5},
  [739] = {.lex_state = 0, .external_lex_state = 5},
  [740] = {.lex_state = 0, .external_lex_state = 5},
  [741] = {.lex_state = 0, .external_lex_state = 5},
  [742] = {.lex_state = 0, .external_lex_state = 5},
  [743] = {.lex_state = 0, .external_lex_state = 5},
  [744] = {.lex_state = 0, .external_lex_state = 5},
  [745] = {.lex_state = 0, .external_lex_state = 5},
  [746] = {.lex_state = 181, .external_lex_state = 3},
  [747] = {.lex_state = 0, .external_lex_state = 5},
  [748] = {.lex_state = 0, .external_lex_state = 5},
  [749] = {.lex_state = 180, .external_lex_state = 6},
  [750] = {.lex_state = 0, .external_lex_state = 5},
  [751] = {.lex_state = 2, .external_lex_state = 6},
  [752] = {.lex_state = 181, .external_lex_state = 6},
  [753] = {.lex_state = 2, .external_lex_state = 6},
  [754] = {.lex_state = 4, .external_lex_state = 6},
  [755] = {.lex_state = 181, .external_lex_state = 6},
  [756] = {.lex_state = 2, .external_lex_state = 6},
  [757] = {.lex_state = 4, .external_lex_state = 6},
  [758] = {.lex_state = 181, .external_lex_state = 6},
  [759] = {.lex_state = 181, .external_lex_state = 6},
  [760] = {.lex_state = 181, .external_lex_state = 6},
  [761] = {.lex_state = 181, .external_lex_state = 6},
  [762] = {.lex_state = 2, .external_lex_state = 6},
  [763] = {.lex_state = 180, .external_lex_state = 6},
  [764] = {.lex_state = 180, .external_lex_state = 5},
  [765] = {.lex_state = 8, .external_lex_state = 8},
  [766] = {.lex_state = 181, .external_lex_state = 6},
  [767] = {.lex_state = 8, .external_lex_state = 8},
  [768] = {.lex_state = 181, .external_lex_state = 6},
  [769] = {.lex_state = 181, .external_lex_state = 6},
  [770] = {.lex_state = 8, .external_lex_state = 8},
  [771] = {.lex_state = 181, .external_lex_state = 6},
  [772] = {.lex_state = 8, .external_lex_state = 8},
  [773] = {.lex_state = 181, .external_lex_state = 6},
  [774] = {.lex_state = 181, .external_lex_state = 6},
  [775] = {.lex_state = 1, .external_lex_state = 5},
  [776] = {.lex_state = 8, .external_lex_state = 8},
  [777] = {.lex_state = 181, .external_lex_state = 6},
  [778] = {.lex_state = 7, .external_lex_state = 7},
  [779] = {.lex_state = 7, .external_lex_state = 7},
  [780] = {.lex_state = 3, .external_lex_state = 8},
  [781] = {.lex_state = 3, .external_lex_state = 8},
  [782] = {.lex_state = 7, .external_lex_state = 7},
  [783] = {.lex_state = 1, .external_lex_state = 5},
  [784] = {.lex_state = 7, .external_lex_state = 7},
  [785] = {.lex_state = 7, .external_lex_state = 7},
  [786] = {.lex_state = 7, .external_lex_state = 7},
  [787] = {.lex_state = 7, .external_lex_state = 7},
  [788] = {.lex_state = 1, .external_lex_state = 5},
  [789] = {.lex_state = 7, .external_lex_state = 7},
  [790] = {.lex_state = 7, .external_lex_state = 7},
  [791] = {.lex_state = 7, .external_lex_state = 7},
  [792] = {.lex_state = 7, .external_lex_state = 7},
  [793] = {.lex_state = 7, .external_lex_state = 7},
  [794] = {.lex_state = 7, .external_lex_state = 7},
  [795] = {.lex_state = 181, .external_lex_state = 6},
  [796] = {.lex_state = 7, .external_lex_state = 7},
  [797] = {.lex_state = 3, .external_lex_state = 8},
  [798] = {.lex_state = 7, .external_lex_state = 7},
  [799] = {.lex_state = 181, .external_lex_state = 6},
  [800] = {.lex_state = 181, .external_lex_state = 6},
  [801] = {.lex_state = 0, .external_lex_state = 5},
  [802] = {.lex_state = 180, .external_lex_state = 6},
  [803] = {.lex_state = 0, .external_lex_state = 5},
  [804] = {.lex_state = 181, .external_lex_state = 6},
  [805] = {.lex_state = 0, .external_lex_state = 5},
  [806] = {.lex_state = 0, .external_lex_state = 5},
  [807] = {.lex_state = 181, .external_lex_state = 6},
  [808] = {.lex_state = 180, .external_lex_state = 6},
  [809] = {.lex_state = 181, .external_lex_state = 6},
  [810] = {.lex_state = 0, .external_lex_state = 5},
  [811] = {.lex_state = 180, .external_lex_state = 6},
  [812] = {.lex_state = 180, .external_lex_state = 6},
  [813] = {.lex_state = 7, .external_lex_state = 7},
  [814] = {.lex_state = 7, .external_lex_state = 7},
  [815] = {.lex_state = 7, .external_lex_state = 7},
  [816] = {.lex_state = 7, .external_lex_state = 7},
  [817] = {.lex_state = 0, .external_lex_state = 5},
  [818] = {.lex_state = 181, .external_lex_state = 6},
  [819] = {.lex_state = 0, .external_lex_state = 5},
  [820] = {.lex_state = 0, .external_lex_state = 5},
  [821] = {.lex_state = 0, .external_lex_state = 5},
  [822] = {.lex_state = 2, .external_lex_state = 6},
  [823] = {.lex_state = 181, .external_lex_state = 6},
  [824] = {.lex_state = 0, .external_lex_state = 5},
  [825] = {.lex_state = 0, .external_lex_state = 5},
  [826] = {.lex_state = 181, .external_lex_state = 6},
  [827] = {.lex_state = 180, .external_lex_state = 6},
  [828] = {.lex_state = 181, .external_lex_state = 6},
  [829] = {.lex_state = 0, .external_lex_state = 5},
  [830] = {.lex_state = 0, .external_lex_state = 5},
  [831] = {.lex_state = 2, .external_lex_state = 6},
  [832] = {.lex_state = 0, .external_lex_state = 5},
  [833] = {.lex_state = 181, .external_lex_state = 6},
  [834] = {.lex_state = 2, .external_lex_state = 6},
  [835] = {.lex_state = 0, .external_lex_state = 5},
  [836] = {.lex_state = 7, .external_lex_state = 7},
  [837] = {.lex_state = 0, .external_lex_state = 5},
  [838] = {.lex_state = 181, .external_lex_state = 6},
  [839] = {.lex_state = 0, .external_lex_state = 5},
  [840] = {.lex_state = 0, .external_lex_state = 5},
  [841] = {.lex_state = 1, .external_lex_state = 5},
  [842] = {.lex_state = 182, .external_lex_state = 6},
  [843] = {.lex_state = 0, .external_lex_state = 5},
  [844] = {.lex_state = 180, .external_lex_state = 6},
  [845] = {.lex_state = 181, .external_lex_state = 6},
  [846] = {.lex_state = 0, .external_lex_state = 5},
  [847] = {.lex_state = 182, .external_lex_state = 6},
  [848] = {.lex_state = 180, .external_lex_state = 6},
  [849] = {.lex_state = 181, .external_lex_state = 6},
  [850] = {.lex_state = 180, .external_lex_state = 6},
  [851] = {.lex_state = 180, .external_lex_state = 6},
  [852] = {.lex_state = 1, .external_lex_state = 5},
  [853] = {.lex_state = 2, .external_lex_state = 6},
  [854] = {.lex_state = 180, .external_lex_state = 6},
  [855] = {.lex_state = 1, .external_lex_state = 5},
  [856] = {.lex_state = 181, .external_lex_state = 6},
  [857] = {.lex_state = 1, .external_lex_state = 5},
  [858] = {.lex_state = 182, .external_lex_state = 6},
  [859] = {.lex_state = 181, .external_lex_state = 6},
  [860] = {.lex_state = 2, .external_lex_state = 6},
  [861] = {.lex_state = 2, .external_lex_state = 6},
  [862] = {.lex_state = 181, .external_lex_state = 6},
  [863] = {.lex_state = 181, .external_lex_state = 6},
  [864] = {.lex_state = 2, .external_lex_state = 6},
  [865] = {.lex_state = 2, .external_lex_state = 6},
  [866] = {.lex_state = 2, .external_lex_state = 6},
  [867] = {.lex_state = 180, .external_lex_state = 6},
  [868] = {.lex_state = 2, .external_lex_state = 6},
  [869] = {.lex_state = 180, .external_lex_state = 6},
  [870] = {.lex_state = 182, .external_lex_state = 6},
  [871] = {.lex_state = 182, .external_lex_state = 6},
  [872] = {.lex_state = 180, .external_lex_state = 6},
  [873] = {.lex_state = 182, .external_lex_state = 6},
  [874] = {.lex_state = 180, .external_lex_state = 6},
  [875] = {.lex_state = 2, .external_lex_state = 6},
  [876] = {.lex_state = 181, .external_lex_state = 6},
  [877] = {.lex_state = 9, .external_lex_state = 7},
  [878] = {.lex_state = 180, .external_lex_state = 6},
  [879] = {.lex_state = 180, .external_lex_state = 6},
  [880] = {.lex_state = 181, .external_lex_state = 6},
  [881] = {.lex_state = 9, .external_lex_state = 7},
  [882] = {.lex_state = 4, .external_lex_state = 6},
  [883] = {.lex_state = 0, .external_lex_state = 8},
  [884] = {.lex_state = 180, .external_lex_state = 6},
  [885] = {.lex_state = 180, .external_lex_state = 6},
  [886] = {.lex_state = 181, .external_lex_state = 6},
  [887] = {.lex_state = 0, .external_lex_state = 8},
  [888] = {.lex_state = 9, .external_lex_state = 7},
  [889] = {.lex_state = 8, .external_lex_state = 5},
  [890] = {.lex_state = 9, .external_lex_state = 7},
  [891] = {.lex_state = 180, .external_lex_state = 6},
  [892] = {.lex_state = 0, .external_lex_state = 8},
  [893] = {.lex_state = 9, .external_lex_state = 7},
  [894] = {.lex_state = 181, .external_lex_state = 6},
  [895] = {.lex_state = 181, .external_lex_state = 6},
  [896] = {.lex_state = 181, .external_lex_state = 6},
  [897] = {.lex_state = 181, .external_lex_state = 6},
  [898] = {.lex_state = 181, .external_lex_state = 6},
  [899] = {.lex_state = 180, .external_lex_state = 5},
  [900] = {.lex_state = 9, .external_lex_state = 7},
  [901] = {.lex_state = 5, .external_lex_state = 7},
  [902] = {.lex_state = 180, .external_lex_state = 6},
  [903] = {.lex_state = 180, .external_lex_state = 6},
  [904] = {.lex_state = 8, .external_lex_state = 5},
  [905] = {.lex_state = 181, .external_lex_state = 6},
  [906] = {.lex_state = 9, .external_lex_state = 7},
  [907] = {.lex_state = 181, .external_lex_state = 6},
  [908] = {.lex_state = 0, .external_lex_state = 5},
  [909] = {.lex_state = 181, .external_lex_state = 6},
  [910] = {.lex_state = 0, .external_lex_state = 5},
  [911] = {.lex_state = 0, .external_lex_state = 5},
  [912] = {.lex_state = 181, .external_lex_state = 6},
  [913] = {.lex_state = 0, .external_lex_state = 5},
  [914] = {.lex_state = 0, .external_lex_state = 5},
  [915] = {.lex_state = 8, .external_lex_state = 5},
  [916] = {.lex_state = 181, .external_lex_state = 6},
  [917] = {.lex_state = 0, .external_lex_state = 5},
  [918] = {.lex_state = 0, .external_lex_state = 5},
  [919] = {.lex_state = 181, .external_lex_state = 6},
  [920] = {.lex_state = 181, .external_lex_state = 6},
  [921] = {.lex_state = 5, .external_lex_state = 7},
  [922] = {.lex_state = 181, .external_lex_state = 6},
  [923] = {.lex_state = 181, .external_lex_state = 6},
  [924] = {.lex_state = 181, .external_lex_state = 6},
  [925] = {.lex_state = 181, .external_lex_state = 6},
  [926] = {.lex_state = 0, .external_lex_state = 5},
  [927] = {.lex_state = 181, .external_lex_state = 6},
  [928] = {.lex_state = 181, .external_lex_state = 6},
  [929] = {.lex_state = 181, .external_lex_state = 6},
  [930] = {.lex_state = 180, .external_lex_state = 5},
  [931] = {.lex_state = 181, .external_lex_state = 6},
  [932] = {.lex_state = 5, .external_lex_state = 7},
  [933] = {.lex_state = 8, .external_lex_state = 5},
  [934] = {.lex_state = 8, .external_lex_state = 5},
  [935] = {.lex_state = 180, .external_lex_state = 6},
  [936] = {.lex_state = 180, .external_lex_state = 6},
  [937] = {.lex_state = 181, .external_lex_state = 6},
  [938] = {.lex_state = 180, .external_lex_state = 5},
  [939] = {.lex_state = 180, .external_lex_state = 5},
  [940] = {.lex_state = 8, .external_lex_state = 5},
  [941] = {.lex_state = 8, .external_lex_state = 5},
  [942] = {.lex_state = 181, .external_lex_state = 6},
  [943] = {.lex_state = 0, .external_lex_state = 6},
  [944] = {.lex_state = 181, .external_lex_state = 6},
  [945] = {.lex_state = 0, .external_lex_state = 5},
  [946] = {.lex_state = 0, .external_lex_state = 5},
  [947] = {.lex_state = 180, .external_lex_state = 5},
  [948] = {.lex_state = 0, .external_lex_state = 6},
  [949] = {.lex_state = 180, .external_lex_state = 5},
  [950] = {.lex_state = 0, .external_lex_state = 6},
  [951] = {.lex_state = 2, .external_lex_state = 5},
  [952] = {.lex_state = 180, .external_lex_state = 5},
  [953] = {.lex_state = 2, .external_lex_state = 5},
  [954] = {.lex_state = 181, .external_lex_state = 6},
  [955] = {.lex_state = 181, .external_lex_state = 6},
  [956] = {.lex_state = 181, .external_lex_state = 6},
  [957] = {.lex_state = 181, .external_lex_state = 6},
  [958] = {.lex_state = 180, .external_lex_state = 5},
  [959] = {.lex_state = 0, .external_lex_state = 5},
  [960] = {.lex_state = 0, .external_lex_state = 5},
  [961] = {.lex_state = 181, .external_lex_state = 6},
  [962] = {.lex_state = 181, .external_lex_state = 6},
  [963] = {.lex_state = 182, .external_lex_state = 5},
  [964] = {.lex_state = 181, .external_lex_state = 6},
  [965] = {.lex_state = 182, .external_lex_state = 5},
  [966] = {.lex_state = 182, .external_lex_state = 5},
  [967] = {.lex_state = 181, .external_lex_state = 6},
  [968] = {.lex_state = 181, .external_lex_state = 6},
  [969] = {.lex_state = 182, .external_lex_state = 5},
  [970] = {.lex_state = 182, .external_lex_state = 5},
  [971] = {.lex_state = 182, .external_lex_state = 5},
  [972] = {.lex_state = 0, .external_lex_state = 5},
  [973] = {.lex_state = 181, .external_lex_state = 6},
  [974] = {.lex_state = 181, .external_lex_state = 6},
  [975] = {.lex_state = 181, .external_lex_state = 6},
  [976] = {.lex_state = 181, .external_lex_state = 6},
  [977] = {.lex_state = 182, .external_lex_state = 5},
  [978] = {.lex_state = 182, .external_lex_state = 5},
  [979] = {.lex_state = 181, .external_lex_state = 6},
  [980] = {.lex_state = 181, .external_lex_state = 6},
  [981] = {.lex_state = 181, .external_lex_state = 6},
  [982] = {.lex_state = 181, .external_lex_state = 6},
  [983] = {.lex_state = 181, .external_lex_state = 6},
  [984] = {.lex_state = 181, .external_lex_state = 6},
  [985] = {.lex_state = 181, .external_lex_state = 6},
  [986] = {.lex_state = 181, .external_lex_state = 6},
  [987] = {.lex_state = 181, .external_lex_state = 6},
  [988] = {.lex_state = 181, .external_lex_state = 6},
  [989] = {.lex_state = 181, .external_lex_state = 6},
  [990] = {.lex_state = 181, .external_lex_state = 6},
  [991] = {.lex_state = 181, .external_lex_state = 6},
  [992] = {.lex_state = 181, .external_lex_state = 6},
  [993] = {.lex_state = 181, .external_lex_state = 6},
  [994] = {.lex_state = 181, .external_lex_state = 6},
  [995] = {.lex_state = 181, .external_lex_state = 6},
  [996] = {.lex_state = 181, .external_lex_state = 6},
  [997] = {.lex_state = 181, .external_lex_state = 6},
  [998] = {.lex_state = 181, .external_lex_state = 6},
  [999] = {.lex_state = 181, .external_lex_state = 6},
  [1000] = {.lex_state = 181, .external_lex_state = 6},
  [1001] = {.lex_state = 181, .external_lex_state = 6},
  [1002] = {.lex_state = 181, .external_lex_state = 6},
  [1003] = {.lex_state = 181, .external_lex_state = 6},
  [1004] = {.lex_state = 182, .external_lex_state = 5},
  [1005] = {.lex_state = 181, .external_lex_state = 6},
  [1006] = {.lex_state = 0, .external_lex_state = 6},
  [1007] = {.lex_state = 0, .external_lex_state = 5},
  [1008] = {.lex_state = 181, .external_lex_state = 6},
  [1009] = {.lex_state = 181, .external_lex_state = 6},
  [1010] = {.lex_state = 181, .external_lex_state = 6},
  [1011] = {.lex_state = 0, .external_lex_state = 5},
  [1012] = {.lex_state = 181, .external_lex_state = 6},
  [1013] = {.lex_state = 181, .external_lex_state = 6},
  [1014] = {.lex_state = 181, .external_lex_state = 6},
  [1015] = {.lex_state = 0, .external_lex_state = 5},
  [1016] = {.lex_state = 181, .external_lex_state = 6},
  [1017] = {.lex_state = 181, .external_lex_state = 6},
  [1018] = {.lex_state = 181, .external_lex_state = 6},
  [1019] = {.lex_state = 181, .external_lex_state = 6},
  [1020] = {.lex_state = 181, .external_lex_state = 6},
  [1021] = {.lex_state = 181, .external_lex_state = 6},
  [1022] = {.lex_state = 181, .external_lex_state = 6},
  [1023] = {.lex_state = 181, .external_lex_state = 6},
  [1024] = {.lex_state = 181, .external_lex_state = 6},
  [1025] = {.lex_state = 181, .external_lex_state = 6},
  [1026] = {.lex_state = 181, .external_lex_state = 6},
  [1027] = {.lex_state = 181, .external_lex_state = 6},
  [1028] = {.lex_state = 181, .external_lex_state = 6},
  [1029] = {.lex_state = 181, .external_lex_state = 6},
  [1030] = {.lex_state = 181, .external_lex_state = 6},
  [1031] = {.lex_state = 181, .external_lex_state = 6},
  [1032] = {.lex_state = 181, .external_lex_state = 6},
  [1033] = {.lex_state = 180, .external_lex_state = 5},
  [1034] = {.lex_state = 181, .external_lex_state = 6},
  [1035] = {.lex_state = 181, .external_lex_state = 6},
  [1036] = {.lex_state = 181, .external_lex_state = 6},
  [1037] = {.lex_state = 181, .external_lex_state = 6},
  [1038] = {.lex_state = 180, .external_lex_state = 5},
  [1039] = {.lex_state = 181, .external_lex_state = 6},
  [1040] = {.lex_state = 181, .external_lex_state = 6},
  [1041] = {.lex_state = 181, .external_lex_state = 6},
  [1042] = {.lex_state = 2, .external_lex_state = 5},
  [1043] = {.lex_state = 0, .external_lex_state = 5},
  [1044] = {.lex_state = 0, .external_lex_state = 5},
  [1045] = {.lex_state = 0, .external_lex_state = 5},
  [1046] = {.lex_state = 0, .external_lex_state = 5},
  [1047] = {.lex_state = 0, .external_lex_state = 5},
  [1048] = {.lex_state = 0, .external_lex_state = 5},
  [1049] = {.lex_state = 180, .external_lex_state = 5},
  [1050] = {.lex_state = 0, .external_lex_state = 5},
  [1051] = {.lex_state = 0, .external_lex_state = 5},
  [1052] = {.lex_state = 181, .external_lex_state = 6},
  [1053] = {.lex_state = 180, .external_lex_state = 5},
  [1054] = {.lex_state = 180, .external_lex_state = 5},
  [1055] = {.lex_state = 0, .external_lex_state = 5},
  [1056] = {.lex_state = 180, .external_lex_state = 5},
  [1057] = {.lex_state = 180, .external_lex_state = 5},
  [1058] = {.lex_state = 0, .external_lex_state = 5},
  [1059] = {.lex_state = 0, .external_lex_state = 5},
  [1060] = {.lex_state = 180, .external_lex_state = 5},
  [1061] = {.lex_state = 180, .external_lex_state = 5},
  [1062] = {.lex_state = 181, .external_lex_state = 6},
  [1063] = {.lex_state = 180, .external_lex_state = 5},
  [1064] = {.lex_state = 0, .external_lex_state = 5},
  [1065] = {.lex_state = 180, .external_lex_state = 5},
  [1066] = {.lex_state = 180, .external_lex_state = 5},
  [1067] = {.lex_state = 180, .external_lex_state = 5},
  [1068] = {.lex_state = 180, .external_lex_state = 5},
  [1069] = {.lex_state = 180, .external_lex_state = 5},
  [1070] = {.lex_state = 180, .external_lex_state = 5},
  [1071] = {.lex_state = 180, .external_lex_state = 5},
  [1072] = {.lex_state = 180, .external_lex_state = 5},
  [1073] = {.lex_state = 180, .external_lex_state = 5},
  [1074] = {.lex_state = 180, .external_lex_state = 5},
  [1075] = {.lex_state = 180, .external_lex_state = 5},
  [1076] = {.lex_state = 180, .external_lex_state = 5},
  [1077] = {.lex_state = 180, .external_lex_state = 5},
  [1078] = {.lex_state = 2, .external_lex_state = 5},
  [1079] = {.lex_state = 180, .external_lex_state = 5},
  [1080] = {.lex_state = 180, .external_lex_state = 5},
  [1081] = {.lex_state = 180, .external_lex_state = 5},
  [1082] = {.lex_state = 180, .external_lex_state = 5},
  [1083] = {.lex_state = 7, .external_lex_state = 7},
  [1084] = {.lex_state = 182, .external_lex_state = 5},
  [1085] = {.lex_state = 182, .external_lex_state = 5},
  [1086] = {.lex_state = 182, .external_lex_state = 5},
  [1087] = {.lex_state = 180, .external_lex_state = 5},
  [1088] = {.lex_state = 182, .external_lex_state = 5},
  [1089] = {.lex_state = 180, .external_lex_state = 5},
  [1090] = {.lex_state = 180, .external_lex_state = 5},
  [1091] = {.lex_state = 0, .external_lex_state = 5},
  [1092] = {.lex_state = 180, .external_lex_state = 5},
  [1093] = {.lex_state = 7, .external_lex_state = 7},
  [1094] = {.lex_state = 7, .external_lex_state = 7},
  [1095] = {.lex_state = 180, .external_lex_state = 5},
  [1096] = {.lex_state = 7, .external_lex_state = 7},
  [1097] = {.lex_state = 182, .external_lex_state = 5},
  [1098] = {.lex_state = 180, .external_lex_state = 5},
  [1099] = {.lex_state = 182, .external_lex_state = 5},
  [1100] = {.lex_state = 180, .external_lex_state = 9},
  [1101] = {.lex_state = 180, .external_lex_state = 5},
  [1102] = {.lex_state = 180, .external_lex_state = 5},
  [1103] = {.lex_state = 182, .external_lex_state = 5},
  [1104] = {.lex_state = 180, .external_lex_state = 5},
  [1105] = {.lex_state = 180, .external_lex_state = 5},
  [1106] = {.lex_state = 182, .external_lex_state = 5},
  [1107] = {.lex_state = 180, .external_lex_state = 5},
  [1108] = {.lex_state = 2, .external_lex_state = 5},
  [1109] = {.lex_state = 180, .external_lex_state = 5},
  [1110] = {.lex_state = 180, .external_lex_state = 9},
  [1111] = {.lex_state = 180, .external_lex_state = 5},
  [1112] = {.lex_state = 180, .external_lex_state = 5},
  [1113] = {.lex_state = 180, .external_lex_state = 5},
  [1114] = {.lex_state = 182, .external_lex_state = 5},
  [1115] = {.lex_state = 180, .external_lex_state = 5},
  [1116] = {.lex_state = 180, .external_lex_state = 5},
  [1117] = {.lex_state = 180, .external_lex_state = 5},
  [1118] = {.lex_state = 180, .external_lex_state = 5},
  [1119] = {.lex_state = 180, .external_lex_state = 5},
  [1120] = {.lex_state = 182, .external_lex_state = 5},
  [1121] = {.lex_state = 180, .external_lex_state = 5},
  [1122] = {.lex_state = 180, .external_lex_state = 5},
  [1123] = {.lex_state = 180, .external_lex_state = 5},
  [1124] = {.lex_state = 182, .external_lex_state = 5},
  [1125] = {.lex_state = 180, .external_lex_state = 5},
  [1126] = {.lex_state = 180, .external_lex_state = 5},
  [1127] = {.lex_state = 2, .external_lex_state = 5},
  [1128] = {.lex_state = 180, .external_lex_state = 9},
  [1129] = {.lex_state = 180, .external_lex_state = 5},
  [1130] = {.lex_state = 0, .external_lex_state = 5},
  [1131] = {.lex_state = 180, .external_lex_state = 5},
  [1132] = {.lex_state = 182, .external_lex_state = 5},
  [1133] = {.lex_state = 182, .external_lex_state = 5},
  [1134] = {.lex_state = 180, .external_lex_state = 5},
  [1135] = {.lex_state = 180, .external_lex_state = 5},
  [1136] = {.lex_state = 0, .external_lex_state = 6},
  [1137] = {.lex_state = 180, .external_lex_state = 5},
  [1138] = {.lex_state = 180, .external_lex_state = 5},
  [1139] = {.lex_state = 180, .external_lex_state = 5},
  [1140] = {.lex_state = 182, .external_lex_state = 5},
  [1141] = {.lex_state = 182, .external_lex_state = 5},
  [1142] = {.lex_state = 180, .external_lex_state = 5},
  [1143] = {.lex_state = 180, .external_lex_state = 5},
  [1144] = {.lex_state = 180, .external_lex_state = 5},
  [1145] = {.lex_state = 180, .external_lex_state = 5},
  [1146] = {.lex_state = 180, .external_lex_state = 5},
  [1147] = {.lex_state = 182, .external_lex_state = 5},
  [1148] = {.lex_state = 182, .external_lex_state = 5},
  [1149] = {.lex_state = 7, .external_lex_state = 7},
  [1150] = {.lex_state = 180, .external_lex_state = 5},
  [1151] = {.lex_state = 182, .external_lex_state = 5},
  [1152] = {.lex_state = 182, .external_lex_state = 5},
  [1153] = {.lex_state = 7, .external_lex_state = 7},
  [1154] = {.lex_state = 7, .external_lex_state = 7},
  [1155] = {.lex_state = 0, .external_lex_state = 10},
  [1156] = {.lex_state = 182, .external_lex_state = 5},
  [1157] = {.lex_state = 0, .external_lex_state = 10},
  [1158] = {.lex_state = 0, .external_lex_state = 11},
  [1159] = {.lex_state = 0, .external_lex_state = 10},
  [1160] = {.lex_state = 180, .external_lex_state = 5},
  [1161] = {.lex_state = 180, .external_lex_state = 5},
  [1162] = {.lex_state = 7, .external_lex_state = 7},
  [1163] = {.lex_state = 180, .external_lex_state = 5},
  [1164] = {.lex_state = 180, .external_lex_state = 5},
  [1165] = {.lex_state = 0, .external_lex_state = 10},
  [1166] = {.lex_state = 7, .external_lex_state = 7},
  [1167] = {.lex_state = 180, .external_lex_state = 5},
  [1168] = {.lex_state = 0, .external_lex_state = 10},
  [1169] = {.lex_state = 0, .external_lex_state = 11},
  [1170] = {.lex_state = 180, .external_lex_state = 5},
  [1171] = {.lex_state = 180, .external_lex_state = 5},
  [1172] = {.lex_state = 0, .external_lex_state = 10},
  [1173] = {.lex_state = 180, .external_lex_state = 5},
  [1174] = {.lex_state = 180, .external_lex_state = 5},
  [1175] = {.lex_state = 180, .external_lex_state = 5},
  [1176] = {.lex_state = 7, .external_lex_state = 7},
  [1177] = {.lex_state = 180, .external_lex_state = 5},
  [1178] = {.lex_state = 180, .external_lex_state = 5},
  [1179] = {.lex_state = 180, .external_lex_state = 5},
  [1180] = {.lex_state = 0, .external_lex_state = 10},
  [1181] = {.lex_state = 0, .external_lex_state = 11},
  [1182] = {.lex_state = 0, .external_lex_state = 11},
  [1183] = {.lex_state = 7, .external_lex_state = 7},
  [1184] = {.lex_state = 7, .external_lex_state = 5},
  [1185] = {.lex_state = 180, .external_lex_state = 5},
  [1186] = {.lex_state = 180, .external_lex_state = 5},
  [1187] = {.lex_state = 180, .external_lex_state = 5},
  [1188] = {.lex_state = 7, .external_lex_state = 7},
  [1189] = {.lex_state = 180, .external_lex_state = 5},
  [1190] = {.lex_state = 180, .external_lex_state = 5},
  [1191] = {.lex_state = 180, .external_lex_state = 5},
  [1192] = {.lex_state = 180, .external_lex_state = 5},
  [1193] = {.lex_state = 0, .external_lex_state = 10},
  [1194] = {.lex_state = 0, .external_lex_state = 11},
  [1195] = {.lex_state = 7, .external_lex_state = 7},
  [1196] = {.lex_state = 180, .external_lex_state = 5},
  [1197] = {.lex_state = 180, .external_lex_state = 5},
  [1198] = {.lex_state = 0, .external_lex_state = 11},
  [1199] = {.lex_state = 0, .external_lex_state = 5},
  [1200] = {.lex_state = 182, .external_lex_state = 5},
  [1201] = {.lex_state = 180, .external_lex_state = 5},
  [1202] = {.lex_state = 180, .external_lex_state = 5},
  [1203] = {.lex_state = 0, .external_lex_state = 11},
  [1204] = {.lex_state = 180, .external_lex_state = 5},
  [1205] = {.lex_state = 7, .external_lex_state = 7},
  [1206] = {.lex_state = 0, .external_lex_state = 10},
  [1207] = {.lex_state = 0, .external_lex_state = 11},
  [1208] = {.lex_state = 0, .external_lex_state = 11},
  [1209] = {.lex_state = 180, .external_lex_state = 5},
  [1210] = {.lex_state = 7, .external_lex_state = 5},
  [1211] = {.lex_state = 180, .external_lex_state = 5},
  [1212] = {.lex_state = 180, .external_lex_state = 5},
  [1213] = {.lex_state = 0, .external_lex_state = 5},
  [1214] = {.lex_state = 180, .external_lex_state = 5},
  [1215] = {.lex_state = 180, .external_lex_state = 5},
  [1216] = {.lex_state = 0, .external_lex_state = 5},
  [1217] = {.lex_state = 0, .external_lex_state = 5},
  [1218] = {.lex_state = 180, .external_lex_state = 5},
  [1219] = {.lex_state = 180, .external_lex_state = 5},
  [1220] = {.lex_state = 180, .external_lex_state = 5},
  [1221] = {.lex_state = 180, .external_lex_state = 5},
  [1222] = {.lex_state = 0, .external_lex_state = 5},
  [1223] = {.lex_state = 180, .external_lex_state = 5},
  [1224] = {.lex_state = 7, .external_lex_state = 5},
  [1225] = {.lex_state = 180, .external_lex_state = 5},
  [1226] = {.lex_state = 180, .external_lex_state = 5},
  [1227] = {.lex_state = 0, .external_lex_state = 5},
  [1228] = {.lex_state = 0, .external_lex_state = 5},
  [1229] = {.lex_state = 0, .external_lex_state = 5},
  [1230] = {.lex_state = 180, .external_lex_state = 5},
  [1231] = {.lex_state = 180, .external_lex_state = 5},
  [1232] = {.lex_state = 0, .external_lex_state = 5},
  [1233] = {.lex_state = 180, .external_lex_state = 5},
  [1234] = {.lex_state = 180, .external_lex_state = 5},
  [1235] = {.lex_state = 0, .external_lex_state = 5},
  [1236] = {.lex_state = 180, .external_lex_state = 5},
  [1237] = {.lex_state = 180, .external_lex_state = 5},
  [1238] = {.lex_state = 0, .external_lex_state = 5},
  [1239] = {.lex_state = 180, .external_lex_state = 5},
  [1240] = {.lex_state = 7, .external_lex_state = 5},
  [1241] = {.lex_state = 7, .external_lex_state = 5},
  [1242] = {.lex_state = 180, .external_lex_state = 5},
  [1243] = {.lex_state = 180, .external_lex_state = 5},
  [1244] = {.lex_state = 180, .external_lex_state = 5},
  [1245] = {.lex_state = 7, .external_lex_state = 5},
  [1246] = {.lex_state = 7, .external_lex_state = 5},
  [1247] = {.lex_state = 7, .external_lex_state = 5},
  [1248] = {.lex_state = 7, .external_lex_state = 5},
  [1249] = {.lex_state = 7, .external_lex_state = 5},
  [1250] = {.lex_state = 180, .external_lex_state = 5},
  [1251] = {.lex_state = 0, .external_lex_state = 5},
  [1252] = {.lex_state = 7, .external_lex_state = 7},
  [1253] = {.lex_state = 180, .external_lex_state = 5},
  [1254] = {.lex_state = 180, .external_lex_state = 5},
  [1255] = {.lex_state = 7, .external_lex_state = 5},
  [1256] = {.lex_state = 7, .external_lex_state = 5},
  [1257] = {.lex_state = 7, .external_lex_state = 5},
  [1258] = {.lex_state = 180, .external_lex_state = 5},
  [1259] = {.lex_state = 0, .external_lex_state = 5},
  [1260] = {.lex_state = 7, .external_lex_state = 5},
  [1261] = {.lex_state = 7, .external_lex_state = 5},
  [1262] = {.lex_state = 180, .external_lex_state = 5},
  [1263] = {.lex_state = 180, .external_lex_state = 5},
  [1264] = {.lex_state = 180, .external_lex_state = 5},
  [1265] = {.lex_state = 7, .external_lex_state = 5},
  [1266] = {.lex_state = 180, .external_lex_state = 5},
  [1267] = {.lex_state = 180, .external_lex_state = 5},
  [1268] = {.lex_state = 181, .external_lex_state = 5},
  [1269] = {.lex_state = 0, .external_lex_state = 5},
  [1270] = {.lex_state = 180, .external_lex_state = 5},
  [1271] = {.lex_state = 180, .external_lex_state = 5},
  [1272] = {.lex_state = 180, .external_lex_state = 5},
  [1273] = {.lex_state = 180, .external_lex_state = 5},
  [1274] = {.lex_state = 180, .external_lex_state = 5},
  [1275] = {.lex_state = 180, .external_lex_state = 5},
  [1276] = {.lex_state = 180, .external_lex_state = 5},
  [1277] = {.lex_state = 7, .external_lex_state = 5},
  [1278] = {.lex_state = 180, .external_lex_state = 5},
  [1279] = {.lex_state = 7, .external_lex_state = 5},
  [1280] = {.lex_state = 7, .external_lex_state = 5},
  [1281] = {.lex_state = 180, .external_lex_state = 5},
  [1282] = {.lex_state = 180, .external_lex_state = 5},
  [1283] = {.lex_state = 0, .external_lex_state = 5},
  [1284] = {.lex_state = 180, .external_lex_state = 5},
  [1285] = {.lex_state = 180, .external_lex_state = 5},
  [1286] = {.lex_state = 7, .external_lex_state = 7},
  [1287] = {.lex_state = 0, .external_lex_state = 5},
  [1288] = {.lex_state = 0, .external_lex_state = 5},
  [1289] = {.lex_state = 0, .external_lex_state = 5},
  [1290] = {.lex_state = 7, .external_lex_state = 5},
  [1291] = {.lex_state = 7, .external_lex_state = 5},
  [1292] = {.lex_state = 7, .external_lex_state = 5},
  [1293] = {.lex_state = 7, .external_lex_state = 5},
  [1294] = {.lex_state = 0, .external_lex_state = 5},
  [1295] = {.lex_state = 0, .external_lex_state = 5},
  [1296] = {.lex_state = 180, .external_lex_state = 5},
  [1297] = {.lex_state = 180, .external_lex_state = 5},
  [1298] = {.lex_state = 180, .external_lex_state = 5},
  [1299] = {.lex_state = 7, .external_lex_state = 7},
  [1300] = {.lex_state = 180, .external_lex_state = 5},
  [1301] = {.lex_state = 180, .external_lex_state = 5},
  [1302] = {.lex_state = 0, .external_lex_state = 5},
  [1303] = {.lex_state = 0, .external_lex_state = 5},
  [1304] = {.lex_state = 0, .external_lex_state = 5},
  [1305] = {.lex_state = 180, .external_lex_state = 5},
  [1306] = {.lex_state = 7, .external_lex_state = 5},
  [1307] = {.lex_state = 7, .external_lex_state = 5},
  [1308] = {.lex_state = 0, .external_lex_state = 5},
  [1309] = {.lex_state = 0, .external_lex_state = 5},
  [1310] = {.lex_state = 7, .external_lex_state = 5},
  [1311] = {.lex_state = 7, .external_lex_state = 5},
  [1312] = {.lex_state = 7, .external_lex_state = 5},
  [1313] = {.lex_state = 7, .external_lex_state = 5},
  [1314] = {.lex_state = 7, .external_lex_state = 5},
  [1315] = {.lex_state = 7, .external_lex_state = 5},
  [1316] = {.lex_state = 180, .external_lex_state = 5},
  [1317] = {.lex_state = 180, .external_lex_state = 5},
  [1318] = {.lex_state = 7, .external_lex_state = 5},
  [1319] = {.lex_state = 7, .external_lex_state = 5},
  [1320] = {.lex_state = 181, .external_lex_state = 5},
  [1321] = {.lex_state = 0, .external_lex_state = 5},
  [1322] = {.lex_state = 7, .external_lex_state = 5},
  [1323] = {.lex_state = 180, .external_lex_state = 5},
  [1324] = {.lex_state = 0, .external_lex_state = 5},
  [1325] = {.lex_state = 0, .external_lex_state = 5},
  [1326] = {.lex_state = 180, .external_lex_state = 5},
  [1327] = {.lex_state = 7, .external_lex_state = 5},
  [1328] = {.lex_state = 7, .external_lex_state = 5},
  [1329] = {.lex_state = 0, .external_lex_state = 5},
  [1330] = {.lex_state = 180, .external_lex_state = 5},
  [1331] = {.lex_state = 7, .external_lex_state = 5},
  [1332] = {.lex_state = 7, .external_lex_state = 5},
  [1333] = {.lex_state = 7, .external_lex_state = 5},
  [1334] = {.lex_state = 7, .external_lex_state = 5},
  [1335] = {.lex_state = 180, .external_lex_state = 5},
  [1336] = {.lex_state = 7, .external_lex_state = 5},
  [1337] = {.lex_state = 7, .external_lex_state = 5},
  [1338] = {.lex_state = 180, .external_lex_state = 5},
  [1339] = {.lex_state = 180, .external_lex_state = 5},
  [1340] = {.lex_state = 180, .external_lex_state = 5},
  [1341] = {.lex_state = 180, .external_lex_state = 5},
  [1342] = {.lex_state = 0, .external_lex_state = 5},
  [1343] = {.lex_state = 180, .external_lex_state = 5},
  [1344] = {.lex_state = 0, .external_lex_state = 5},
  [1345] = {.lex_state = 180, .external_lex_state = 5},
  [1346] = {.lex_state = 0, .external_lex_state = 5},
  [1347] = {.lex_state = 180, .external_lex_state = 5},
  [1348] = {.lex_state = 181, .external_lex_state = 6},
  [1349] = {.lex_state = 180, .external_lex_state = 5},
  [1350] = {.lex_state = 0, .external_lex_state = 5},
  [1351] = {.lex_state = 180, .external_lex_state = 5},
  [1352] = {.lex_state = 180, .external_lex_state = 5},
  [1353] = {.lex_state = 0, .external_lex_state = 5},
  [1354] = {.lex_state = 0, .external_lex_state = 5},
  [1355] = {.lex_state = 180, .external_lex_state = 5},
  [1356] = {.lex_state = 180, .external_lex_state = 5},
  [1357] = {.lex_state = 7, .external_lex_state = 5},
  [1358] = {.lex_state = 180, .external_lex_state = 5},
  [1359] = {.lex_state = 180, .external_lex_state = 5},
  [1360] = {.lex_state = 0, .external_lex_state = 5},
  [1361] = {.lex_state = 0, .external_lex_state = 5},
  [1362] = {.lex_state = 180, .external_lex_state = 5},
  [1363] = {.lex_state = 180, .external_lex_state = 5},
  [1364] = {.lex_state = 0, .external_lex_state = 5},
  [1365] = {.lex_state = 181, .external_lex_state = 6},
  [1366] = {.lex_state = 180, .external_lex_state = 5},
  [1367] = {.lex_state = 180, .external_lex_state = 5},
  [1368] = {.lex_state = 180, .external_lex_state = 5},
  [1369] = {.lex_state = 180, .external_lex_state = 5},
  [1370] = {.lex_state = 0, .external_lex_state = 5},
  [1371] = {.lex_state = 0, .external_lex_state = 5},
  [1372] = {.lex_state = 0, .external_lex_state = 5},
  [1373] = {.lex_state = 0, .external_lex_state = 5},
  [1374] = {.lex_state = 0, .external_lex_state = 5},
  [1375] = {.lex_state = 0, .external_lex_state = 5},
  [1376] = {.lex_state = 0, .external_lex_state = 5},
  [1377] = {.lex_state = 0, .external_lex_state = 5},
  [1378] = {.lex_state = 0, .external_lex_state = 5},
  [1379] = {.lex_state = 0, .external_lex_state = 5},
  [1380] = {.lex_state = 0, .external_lex_state = 5},
  [1381] = {.lex_state = 7, .external_lex_state = 5},
  [1382] = {.lex_state = 0, .external_lex_state = 5},
  [1383] = {.lex_state = 0, .external_lex_state = 5},
  [1384] = {.lex_state = 0, .external_lex_state = 5},
  [1385] = {.lex_state = 0, .external_lex_state = 5},
  [1386] = {.lex_state = 182, .external_lex_state = 5},
  [1387] = {.lex_state = 0, .external_lex_state = 5},
  [1388] = {.lex_state = 0, .external_lex_state = 5},
  [1389] = {.lex_state = 0, .external_lex_state = 5},
  [1390] = {.lex_state = 0, .external_lex_state = 5},
  [1391] = {.lex_state = 0, .external_lex_state = 5},
  [1392] = {.lex_state = 0, .external_lex_state = 5},
  [1393] = {.lex_state = 0, .external_lex_state = 5},
  [1394] = {.lex_state = 0, .external_lex_state = 5},
  [1395] = {.lex_state = 0, .external_lex_state = 5},
  [1396] = {.lex_state = 0, .external_lex_state = 5},
  [1397] = {.lex_state = 0, .external_lex_state = 5},
  [1398] = {.lex_state = 0, .external_lex_state = 5},
  [1399] = {.lex_state = 0, .external_lex_state = 5},
  [1400] = {.lex_state = 182, .external_lex_state = 5},
  [1401] = {.lex_state = 0, .external_lex_state = 5},
  [1402] = {.lex_state = 0, .external_lex_state = 5},
  [1403] = {.lex_state = 0, .external_lex_state = 5},
  [1404] = {.lex_state = 0, .external_lex_state = 5},
  [1405] = {.lex_state = 0, .external_lex_state = 5},
  [1406] = {.lex_state = 0, .external_lex_state = 5},
  [1407] = {.lex_state = 0, .external_lex_state = 5},
  [1408] = {.lex_state = 182, .external_lex_state = 5},
  [1409] = {.lex_state = 0, .external_lex_state = 5},
  [1410] = {.lex_state = 0, .external_lex_state = 5},
  [1411] = {.lex_state = 182, .external_lex_state = 5},
  [1412] = {.lex_state = 0, .external_lex_state = 5},
  [1413] = {.lex_state = 0, .external_lex_state = 5},
  [1414] = {.lex_state = 0, .external_lex_state = 5},
  [1415] = {.lex_state = 0, .external_lex_state = 5},
  [1416] = {.lex_state = 0, .external_lex_state = 5},
  [1417] = {.lex_state = 0, .external_lex_state = 5},
  [1418] = {.lex_state = 182, .external_lex_state = 5},
  [1419] = {.lex_state = 0, .external_lex_state = 5},
  [1420] = {.lex_state = 0, .external_lex_state = 5},
  [1421] = {.lex_state = 0, .external_lex_state = 5},
  [1422] = {.lex_state = 0, .external_lex_state = 5},
  [1423] = {.lex_state = 0, .external_lex_state = 5},
  [1424] = {.lex_state = 0, .external_lex_state = 5},
  [1425] = {.lex_state = 0, .external_lex_state = 5},
  [1426] = {.lex_state = 0, .external_lex_state = 5},
  [1427] = {.lex_state = 0, .external_lex_state = 5},
  [1428] = {.lex_state = 0, .external_lex_state = 5},
  [1429] = {.lex_state = 0, .external_lex_state = 5},
  [1430] = {.lex_state = 0, .external_lex_state = 5},
  [1431] = {.lex_state = 0, .external_lex_state = 5},
  [1432] = {.lex_state = 0, .external_lex_state = 5},
  [1433] = {.lex_state = 0, .external_lex_state = 5},
  [1434] = {.lex_state = 0, .external_lex_state = 5},
  [1435] = {.lex_state = 0, .external_lex_state = 5},
  [1436] = {.lex_state = 0, .external_lex_state = 5},
  [1437] = {.lex_state = 0, .external_lex_state = 5},
  [1438] = {.lex_state = 0, .external_lex_state = 5},
  [1439] = {.lex_state = 0, .external_lex_state = 5},
  [1440] = {.lex_state = 0, .external_lex_state = 5},
  [1441] = {.lex_state = 0, .external_lex_state = 5},
  [1442] = {.lex_state = 0, .external_lex_state = 5},
  [1443] = {.lex_state = 0, .external_lex_state = 5},
  [1444] = {.lex_state = 0, .external_lex_state = 5},
  [1445] = {.lex_state = 0, .external_lex_state = 5},
  [1446] = {.lex_state = 0, .external_lex_state = 5},
  [1447] = {.lex_state = 0, .external_lex_state = 5},
  [1448] = {.lex_state = 0, .external_lex_state = 5},
  [1449] = {.lex_state = 0, .external_lex_state = 5},
  [1450] = {.lex_state = 182, .external_lex_state = 5},
  [1451] = {.lex_state = 182, .external_lex_state = 5},
  [1452] = {.lex_state = 0, .external_lex_state = 5},
  [1453] = {.lex_state = 0, .external_lex_state = 5},
  [1454] = {.lex_state = 182, .external_lex_state = 5},
  [1455] = {.lex_state = 182, .external_lex_state = 5},
  [1456] = {.lex_state = 0, .external_lex_state = 5},
  [1457] = {.lex_state = 0, .external_lex_state = 5},
  [1458] = {.lex_state = 0, .external_lex_state = 5},
  [1459] = {.lex_state = 0, .external_lex_state = 5},
  [1460] = {.lex_state = 0, .external_lex_state = 5},
  [1461] = {.lex_state = 0, .external_lex_state = 5},
  [1462] = {.lex_state = 182, .external_lex_state = 5},
  [1463] = {.lex_state = 0, .external_lex_state = 5},
  [1464] = {.lex_state = 0, .external_lex_state = 5},
  [1465] = {.lex_state = 0, .external_lex_state = 5},
  [1466] = {.lex_state = 0, .external_lex_state = 5},
  [1467] = {.lex_state = 182, .external_lex_state = 5},
  [1468] = {.lex_state = 0, .external_lex_state = 5},
  [1469] = {.lex_state = 182, .external_lex_state = 5},
  [1470] = {.lex_state = 0, .external_lex_state = 5},
  [1471] = {.lex_state = 0, .external_lex_state = 5},
  [1472] = {.lex_state = 182, .external_lex_state = 5},
  [1473] = {.lex_state = 0, .external_lex_state = 5},
  [1474] = {.lex_state = 182, .external_lex_state = 5},
  [1475] = {.lex_state = 0, .external_lex_state = 5},
  [1476] = {.lex_state = 182, .external_lex_state = 5},
  [1477] = {.lex_state = 0, .external_lex_state = 5},
  [1478] = {.lex_state = 182, .external_lex_state = 5},
  [1479] = {.lex_state = 0, .external_lex_state = 5},
  [1480] = {.lex_state = 0, .external_lex_state = 5},
  [1481] = {.lex_state = 0, .external_lex_state = 5},
  [1482] = {.lex_state = 0, .external_lex_state = 5},
  [1483] = {.lex_state = 182, .external_lex_state = 5},
  [1484] = {.lex_state = 182, .external_lex_state = 5},
  [1485] = {.lex_state = 0, .external_lex_state = 5},
  [1486] = {.lex_state = 0, .external_lex_state = 5},
  [1487] = {.lex_state = 182, .external_lex_state = 5},
  [1488] = {.lex_state = 0, .external_lex_state = 5},
  [1489] = {.lex_state = 182, .external_lex_state = 5},
  [1490] = {.lex_state = 0, .external_lex_state = 5},
  [1491] = {.lex_state = 182, .external_lex_state = 5},
  [1492] = {.lex_state = 0, .external_lex_state = 5},
  [1493] = {.lex_state = 0, .external_lex_state = 5},
  [1494] = {.lex_state = 0, .external_lex_state = 5},
  [1495] = {.lex_state = 182, .external_lex_state = 5},
  [1496] = {.lex_state = 0, .external_lex_state = 5},
  [1497] = {.lex_state = 182, .external_lex_state = 5},
  [1498] = {.lex_state = 182, .external_lex_state = 5},
  [1499] = {.lex_state = 182, .external_lex_state = 5},
  [1500] = {.lex_state = 0, .external_lex_state = 5},
  [1501] = {.lex_state = 182, .external_lex_state = 5},
  [1502] = {.lex_state = 182, .external_lex_state = 5},
  [1503] = {.lex_state = 0, .external_lex_state = 5},
  [1504] = {.lex_state = 0, .external_lex_state = 5},
  [1505] = {.lex_state = 0, .external_lex_state = 5},
  [1506] = {.lex_state = 182, .external_lex_state = 5},
  [1507] = {.lex_state = 182, .external_lex_state = 5},
  [1508] = {.lex_state = 0, .external_lex_state = 5},
  [1509] = {.lex_state = 0, .external_lex_state = 5},
  [1510] = {.lex_state = 0, .external_lex_state = 5},
  [1511] = {.lex_state = 0, .external_lex_state = 5},
  [1512] = {.lex_state = 0, .external_lex_state = 5},
  [1513] = {.lex_state = 0, .external_lex_state = 5},
  [1514] = {.lex_state = 182, .external_lex_state = 5},
  [1515] = {.lex_state = 182, .external_lex_state = 5},
  [1516] = {.lex_state = 182, .external_lex_state = 5},
  [1517] = {.lex_state = 0, .external_lex_state = 5},
  [1518] = {.lex_state = 0, .external_lex_state = 5},
  [1519] = {.lex_state = 0, .external_lex_state = 5},
  [1520] = {.lex_state = 182, .external_lex_state = 5},
  [1521] = {.lex_state = 0, .external_lex_state = 5},
  [1522] = {.lex_state = 182, .external_lex_state = 5},
};

static const uint16_t ts_parse_table[LARGE_STATE_COUNT][SYMBOL_COUNT] = {
  [STATE(0)] = {
    [ts_builtin_sym_end] = ACTIONS(1),
    [anon_sym_SEMI] = ACTIONS(1),
    [anon_sym_COMMA] = ACTIONS(1),
    [anon_sym_LPAREN] = ACTIONS(1),
    [anon_sym_RPAREN] = ACTIONS(1),
    [anon_sym_PLUS] = ACTIONS(1),
    [anon_sym_DOT_PLUS] = ACTIONS(1),
    [anon_sym_DASH] = ACTIONS(1),
    [anon_sym_DOT_DASH] = ACTIONS(1),
    [anon_sym_STAR] = ACTIONS(1),
    [anon_sym_DOT_STAR] = ACTIONS(1),
    [anon_sym_SLASH] = ACTIONS(1),
    [anon_sym_DOT_SLASH] = ACTIONS(1),
    [anon_sym_BSLASH] = ACTIONS(1),
    [anon_sym_DOT_BSLASH] = ACTIONS(1),
    [anon_sym_CARET] = ACTIONS(1),
    [anon_sym_DOT_CARET] = ACTIONS(1),
    [anon_sym_PIPE] = ACTIONS(1),
    [anon_sym_AMP] = ACTIONS(1),
    [anon_sym_DOT] = ACTIONS(1),
    [anon_sym_TILDE] = ACTIONS(1),
    [anon_sym_QMARK] = ACTIONS(1),
    [anon_sym_AT] = ACTIONS(1),
    [anon_sym_LT] = ACTIONS(1),
    [anon_sym_LT_EQ] = ACTIONS(1),
    [anon_sym_EQ_EQ] = ACTIONS(1),
    [anon_sym_TILDE_EQ] = ACTIONS(1),
    [anon_sym_GT_EQ] = ACTIONS(1),
    [anon_sym_GT] = ACTIONS(1),
    [anon_sym_AMP_AMP] = ACTIONS(1),
    [anon_sym_PIPE_PIPE] = ACTIONS(1),
    [anon_sym_DOT_SQUOTE] = ACTIONS(1),
    [anon_sym_SQUOTE] = ACTIONS(1),
    [anon_sym_LBRACK] = ACTIONS(1),
    [anon_sym_RBRACK] = ACTIONS(1),
    [anon_sym_LBRACE] = ACTIONS(1),
    [anon_sym_RBRACE] = ACTIONS(1),
    [anon_sym_EQ] = ACTIONS(1),
    [anon_sym_COLON] = ACTIONS(1),
    [anon_sym_return] = ACTIONS(1),
    [anon_sym_continue] = ACTIONS(1),
    [anon_sym_break] = ACTIONS(1),
    [anon_sym_elseif] = ACTIONS(1),
    [anon_sym_else] = ACTIONS(1),
    [anon_sym_if] = ACTIONS(1),
    [anon_sym_end] = ACTIONS(1),
    [anon_sym_for] = ACTIONS(1),
    [anon_sym_parfor] = ACTIONS(1),
    [anon_sym_while] = ACTIONS(1),
    [anon_sym_case] = ACTIONS(1),
    [anon_sym_otherwise] = ACTIONS(1),
    [anon_sym_switch] = ACTIONS(1),
    [anon_sym_global] = ACTIONS(1),
    [anon_sym_persistent] = ACTIONS(1),
    [anon_sym_DOT_QMARK] = ACTIONS(1),
    [anon_sym_arguments] = ACTIONS(1),
    [anon_sym_function] = ACTIONS(1),
    [anon_sym_get_DOT] = ACTIONS(1),
    [anon_sym_set_DOT] = ACTIONS(1),
    [anon_sym_endfunction] = ACTIONS(1),
    [anon_sym_vector] = ACTIONS(1),
    [anon_sym_matrix] = ACTIONS(1),
    [anon_sym_scalar] = ACTIONS(1),
    [anon_sym_properties] = ACTIONS(1),
    [anon_sym_get] = ACTIONS(1),
    [anon_sym_set] = ACTIONS(1),
    [anon_sym_methods] = ACTIONS(1),
    [anon_sym_events] = ACTIONS(1),
    [anon_sym_enumeration] = ACTIONS(1),
    [anon_sym_classdef] = ACTIONS(1),
    [anon_sym_catch] = ACTIONS(1),
    [anon_sym_try] = ACTIONS(1),
    [anon_sym_spmd] = ACTIONS(1),
    [aux_sym_number_token1] = ACTIONS(1),
    [aux_sym_number_token2] = ACTIONS(1),
    [aux_sym_number_token3] = ACTIONS(1),
    [anon_sym_true] = ACTIONS(1),
    [anon_sym_false] = ACTIONS(1),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(1),
    [sym_command_argument] = ACTIONS(1),
    [sym__single_quote_string_start] = ACTIONS(1),
    [sym__single_quote_string_end] = ACTIONS(1),
    [sym__double_quote_string_start] = ACTIONS(1),
    [sym__double_quote_string_end] = ACTIONS(1),
    [sym_formatting_sequence] = ACTIONS(1),
    [sym_escape_sequence] = ACTIONS(1),
    [sym_string_content] = ACTIONS(1),
    [sym__entry_delimiter] = ACTIONS(1),
    [sym__multioutput_variable_start] = ACTIONS(1),
    [sym__external_identifier] = ACTIONS(1),
    [sym_error_sentinel] = ACTIONS(1),
  },
  [STATE(1)] = {
    [sym_source_file] = STATE(1517),
    [aux_sym__block] = STATE(67),
    [sym_identifier] = STATE(401),
    [sym__statement] = STATE(1167),
    [sym__expression] = STATE(938),
    [sym_parenthesis] = STATE(512),
    [sym__binary_expression] = STATE(910),
    [sym_binary_operator] = STATE(519),
    [sym_unary_operator] = STATE(528),
    [sym_indirect_access] = STATE(1361),
    [sym_field_expression] = STATE(594),
    [sym_not_operator] = STATE(549),
    [sym_metaclass_operator] = STATE(938),
    [sym_handle_operator] = STATE(938),
    [sym_comparison_operator] = STATE(498),
    [sym_boolean_operator] = STATE(498),
    [sym_postfix_operator] = STATE(512),
    [sym_string] = STATE(512),
    [sym_matrix] = STATE(512),
    [sym_cell] = STATE(471),
    [sym_ignored_argument] = STATE(1488),
    [sym_assignment] = STATE(1167),
    [sym_multioutput_variable] = STATE(1488),
    [sym_function_call] = STATE(401),
    [sym_command] = STATE(1167),
    [sym__range_element] = STATE(1509),
    [sym_range] = STATE(938),
    [sym_return_statement] = STATE(1167),
    [sym_continue_statement] = STATE(1167),
    [sym_break_statement] = STATE(1167),
    [sym_if_statement] = STATE(1167),
    [sym_for_statement] = STATE(1167),
    [sym_while_statement] = STATE(1167),
    [sym_switch_statement] = STATE(1167),
    [sym_lambda] = STATE(938),
    [sym_global_operator] = STATE(1167),
    [sym_persistent_operator] = STATE(1167),
    [sym_function_definition] = STATE(1289),
    [sym__function_definition_with_end] = STATE(1201),
    [sym_class_definition] = STATE(1167),
    [sym_try_statement] = STATE(1167),
    [sym_spmd_statement] = STATE(1167),
    [sym_number] = STATE(512),
    [sym_boolean] = STATE(397),
    [sym__keywords] = STATE(373),
    [aux_sym_source_file_repeat1] = STATE(1289),
    [ts_builtin_sym_end] = ACTIONS(5),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_for] = ACTIONS(29),
    [anon_sym_parfor] = ACTIONS(31),
    [anon_sym_while] = ACTIONS(33),
    [anon_sym_switch] = ACTIONS(35),
    [anon_sym_global] = ACTIONS(37),
    [anon_sym_persistent] = ACTIONS(39),
    [anon_sym_arguments] = ACTIONS(41),
    [anon_sym_function] = ACTIONS(43),
    [anon_sym_properties] = ACTIONS(41),
    [anon_sym_get] = ACTIONS(41),
    [anon_sym_set] = ACTIONS(41),
    [anon_sym_methods] = ACTIONS(41),
    [anon_sym_events] = ACTIONS(41),
    [anon_sym_enumeration] = ACTIONS(41),
    [anon_sym_classdef] = ACTIONS(45),
    [anon_sym_try] = ACTIONS(47),
    [anon_sym_spmd] = ACTIONS(49),
    [aux_sym_number_token1] = ACTIONS(51),
    [aux_sym_number_token2] = ACTIONS(53),
    [aux_sym_number_token3] = ACTIONS(53),
    [anon_sym_true] = ACTIONS(55),
    [anon_sym_false] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(41),
  },
  [STATE(2)] = {
    [aux_sym__block] = STATE(46),
    [sym_block] = STATE(1474),
    [sym_identifier] = STATE(401),
    [sym__statement] = STATE(1174),
    [sym__expression] = STATE(939),
    [sym_parenthesis] = STATE(512),
    [sym__binary_expression] = STATE(910),
    [sym_binary_operator] = STATE(519),
    [sym_unary_operator] = STATE(528),
    [sym_indirect_access] = STATE(1361),
    [sym_field_expression] = STATE(594),
    [sym_not_operator] = STATE(549),
    [sym_metaclass_operator] = STATE(939),
    [sym_handle_operator] = STATE(939),
    [sym_comparison_operator] = STATE(498),
    [sym_boolean_operator] = STATE(498),
    [sym_postfix_operator] = STATE(512),
    [sym_string] = STATE(512),
    [sym_matrix] = STATE(512),
    [sym_cell] = STATE(471),
    [sym_ignored_argument] = STATE(1488),
    [sym_assignment] = STATE(1174),
    [sym_multioutput_variable] = STATE(1488),
    [sym_function_call] = STATE(401),
    [sym_command] = STATE(1174),
    [sym__range_element] = STATE(1509),
    [sym_range] = STATE(939),
    [sym_return_statement] = STATE(1174),
    [sym_continue_statement] = STATE(1174),
    [sym_break_statement] = STATE(1174),
    [sym_if_statement] = STATE(1174),
    [sym_for_statement] = STATE(1174),
    [sym_while_statement] = STATE(1174),
    [sym_switch_statement] = STATE(1174),
    [sym_lambda] = STATE(939),
    [sym_global_operator] = STATE(1174),
    [sym_persistent_operator] = STATE(1174),
    [sym__function_definition_with_end] = STATE(1209),
    [sym_class_definition] = STATE(1174),
    [sym_try_statement] = STATE(1174),
    [sym_spmd_statement] = STATE(1174),
    [sym_number] = STATE(512),
    [sym_boolean] = STATE(397),
    [sym__keywords] = STATE(373),
    [sym__end_of_line] = STATE(23),
    [aux_sym_elseif_clause_repeat1] = STATE(23),
    [anon_sym_SEMI] = ACTIONS(65),
    [anon_sym_COMMA] = ACTIONS(65),
    [anon_sym_LPAREN] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(69),
    [anon_sym_DOT_PLUS] = ACTIONS(71),
    [anon_sym_DASH] = ACTIONS(69),
    [anon_sym_DOT_DASH] = ACTIONS(71),
    [anon_sym_STAR] = ACTIONS(71),
    [anon_sym_DOT_STAR] = ACTIONS(71),
    [anon_sym_SLASH] = ACTIONS(71),
    [anon_sym_DOT_SLASH] = ACTIONS(71),
    [anon_sym_BSLASH] = ACTIONS(71),
    [anon_sym_DOT_BSLASH] = ACTIONS(71),
    [anon_sym_CARET] = ACTIONS(71),
    [anon_sym_DOT_CARET] = ACTIONS(71),
    [anon_sym_PIPE] = ACTIONS(71),
    [anon_sym_AMP] = ACTIONS(71),
    [anon_sym_TILDE] = ACTIONS(73),
    [anon_sym_QMARK] = ACTIONS(75),
    [anon_sym_AT] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(71),
    [anon_sym_LT_EQ] = ACTIONS(71),
    [anon_sym_EQ_EQ] = ACTIONS(71),
    [anon_sym_TILDE_EQ] = ACTIONS(71),
    [anon_sym_GT_EQ] = ACTIONS(71),
    [anon_sym_GT] = ACTIONS(71),
    [anon_sym_AMP_AMP] = ACTIONS(71),
    [anon_sym_PIPE_PIPE] = ACTIONS(71),
    [anon_sym_DOT_SQUOTE] = ACTIONS(71),
    [anon_sym_SQUOTE] = ACTIONS(71),
    [anon_sym_LBRACK] = ACTIONS(79),
    [anon_sym_LF] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(81),
    [anon_sym_COLON] = ACTIONS(71),
    [anon_sym_return] = ACTIONS(83),
    [anon_sym_continue] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_if] = ACTIONS(89),
    [anon_sym_end] = ACTIONS(91),
    [anon_sym_for] = ACTIONS(93),
    [anon_sym_parfor] = ACTIONS(95),
    [anon_sym_while] = ACTIONS(97),
    [anon_sym_switch] = ACTIONS(99),
    [anon_sym_global] = ACTIONS(101),
    [anon_sym_persistent] = ACTIONS(103),
    [anon_sym_arguments] = ACTIONS(105),
    [anon_sym_function] = ACTIONS(107),
    [anon_sym_properties] = ACTIONS(105),
    [anon_sym_get] = ACTIONS(105),
    [anon_sym_set] = ACTIONS(105),
    [anon_sym_methods] = ACTIONS(105),
    [anon_sym_events] = ACTIONS(105),
    [anon_sym_enumeration] = ACTIONS(105),
    [anon_sym_classdef] = ACTIONS(109),
    [anon_sym_try] = ACTIONS(111),
    [anon_sym_spmd] = ACTIONS(113),
    [aux_sym_number_token1] = ACTIONS(51),
    [aux_sym_number_token2] = ACTIONS(51),
    [aux_sym_number_token3] = ACTIONS(51),
    [anon_sym_true] = ACTIONS(115),
    [anon_sym_false] = ACTIONS(115),
    [anon_sym_CR] = ACTIONS(65),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(41),
  },
  [STATE(3)] = {
    [aux_sym__block] = STATE(46),
    [sym_block] = STATE(1124),
    [sym_identifier] = STATE(401),
    [sym__statement] = STATE(1174),
    [sym__expression] = STATE(939),
    [sym_parenthesis] = STATE(512),
    [sym__binary_expression] = STATE(910),
    [sym_binary_operator] = STATE(519),
    [sym_unary_operator] = STATE(528),
    [sym_indirect_access] = STATE(1361),
    [sym_field_expression] = STATE(594),
    [sym_not_operator] = STATE(549),
    [sym_metaclass_operator] = STATE(939),
    [sym_handle_operator] = STATE(939),
    [sym_comparison_operator] = STATE(498),
    [sym_boolean_operator] = STATE(498),
    [sym_postfix_operator] = STATE(512),
    [sym_string] = STATE(512),
    [sym_matrix] = STATE(512),
    [sym_cell] = STATE(471),
    [sym_ignored_argument] = STATE(1488),
    [sym_assignment] = STATE(1174),
    [sym_multioutput_variable] = STATE(1488),
    [sym_function_call] = STATE(401),
    [sym_command] = STATE(1174),
    [sym__range_element] = STATE(1509),
    [sym_range] = STATE(939),
    [sym_return_statement] = STATE(1174),
    [sym_continue_statement] = STATE(1174),
    [sym_break_statement] = STATE(1174),
    [sym_elseif_clause] = STATE(1084),
    [sym_else_clause] = STATE(1476),
    [sym_if_statement] = STATE(1174),
    [sym_for_statement] = STATE(1174),
    [sym_while_statement] = STATE(1174),
    [sym_switch_statement] = STATE(1174),
    [sym_lambda] = STATE(939),
    [sym_global_operator] = STATE(1174),
    [sym_persistent_operator] = STATE(1174),
    [sym__function_definition_with_end] = STATE(1209),
    [sym_class_definition] = STATE(1174),
    [sym_try_statement] = STATE(1174),
    [sym_spmd_statement] = STATE(1174),
    [sym_number] = STATE(512),
    [sym_boolean] = STATE(397),
    [sym__keywords] = STATE(373),
    [sym__end_of_line] = STATE(6),
    [aux_sym_elseif_clause_repeat1] = STATE(6),
    [aux_sym_if_statement_repeat1] = STATE(1084),
    [anon_sym_SEMI] = ACTIONS(117),
    [anon_sym_COMMA] = ACTIONS(117),
    [anon_sym_LPAREN] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(69),
    [anon_sym_DASH] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(73),
    [anon_sym_QMARK] = ACTIONS(75),
    [anon_sym_AT] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(119),
    [anon_sym_LT_EQ] = ACTIONS(119),
    [anon_sym_EQ_EQ] = ACTIONS(119),
    [anon_sym_TILDE_EQ] = ACTIONS(119),
    [anon_sym_GT_EQ] = ACTIONS(119),
    [anon_sym_GT] = ACTIONS(119),
    [anon_sym_AMP_AMP] = ACTIONS(121),
    [anon_sym_PIPE_PIPE] = ACTIONS(123),
    [anon_sym_LBRACK] = ACTIONS(79),
    [anon_sym_LF] = ACTIONS(117),
    [anon_sym_LBRACE] = ACTIONS(81),
    [anon_sym_return] = ACTIONS(83),
    [anon_sym_continue] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_elseif] = ACTIONS(125),
    [anon_sym_else] = ACTIONS(127),
    [anon_sym_if] = ACTIONS(89),
    [anon_sym_end] = ACTIONS(129),
    [anon_sym_for] = ACTIONS(93),
    [anon_sym_parfor] = ACTIONS(95),
    [anon_sym_while] = ACTIONS(97),
    [anon_sym_switch] = ACTIONS(99),
    [anon_sym_global] = ACTIONS(101),
    [anon_sym_persistent] = ACTIONS(103),
    [anon_sym_arguments] = ACTIONS(105),
    [anon_sym_function] = ACTIONS(107),
    [anon_sym_properties] = ACTIONS(105),
    [anon_sym_get] = ACTIONS(105),
    [anon_sym_set] = ACTIONS(105),
    [anon_sym_methods] = ACTIONS(105),
    [anon_sym_events] = ACTIONS(105),
    [anon_sym_enumeration] = ACTIONS(105),
    [anon_sym_classdef] = ACTIONS(109),
    [anon_sym_try] = ACTIONS(111),
    [anon_sym_spmd] = ACTIONS(113),
    [aux_sym_number_token1] = ACTIONS(51),
    [aux_sym_number_token2] = ACTIONS(51),
    [aux_sym_number_token3] = ACTIONS(51),
    [anon_sym_true] = ACTIONS(115),
    [anon_sym_false] = ACTIONS(115),
    [anon_sym_CR] = ACTIONS(117),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(41),
  },
  [STATE(4)] = {
    [aux_sym__block] = STATE(46),
    [sym_block] = STATE(1400),
    [sym_identifier] = STATE(401),
    [sym__statement] = STATE(1174),
    [sym__expression] = STATE(939),
    [sym_parenthesis] = STATE(512),
    [sym__binary_expression] = STATE(910),
    [sym_binary_operator] = STATE(519),
    [sym_unary_operator] = STATE(528),
    [sym_indirect_access] = STATE(1361),
    [sym_field_expression] = STATE(594),
    [sym_not_operator] = STATE(549),
    [sym_metaclass_operator] = STATE(939),
    [sym_handle_operator] = STATE(939),
    [sym_comparison_operator] = STATE(498),
    [sym_boolean_operator] = STATE(498),
    [sym_postfix_operator] = STATE(512),
    [sym_string] = STATE(512),
    [sym_matrix] = STATE(512),
    [sym_cell] = STATE(471),
    [sym_ignored_argument] = STATE(1488),
    [sym_assignment] = STATE(1174),
    [sym_multioutput_variable] = STATE(1488),
    [sym_function_call] = STATE(401),
    [sym_command] = STATE(1174),
    [sym__range_element] = STATE(1509),
    [sym_range] = STATE(939),
    [sym_return_statement] = STATE(1174),
    [sym_continue_statement] = STATE(1174),
    [sym_break_statement] = STATE(1174),
    [sym_if_statement] = STATE(1174),
    [sym_for_statement] = STATE(1174),
    [sym_while_statement] = STATE(1174),
    [sym_switch_statement] = STATE(1174),
    [sym_lambda] = STATE(939),
    [sym_global_operator] = STATE(1174),
    [sym_persistent_operator] = STATE(1174),
    [sym__function_definition_with_end] = STATE(1209),
    [sym_class_definition] = STATE(1174),
    [sym_try_statement] = STATE(1174),
    [sym_spmd_statement] = STATE(1174),
    [sym_number] = STATE(512),
    [sym_boolean] = STATE(397),
    [sym__keywords] = STATE(373),
    [sym__end_of_line] = STATE(9),
    [aux_sym_elseif_clause_repeat1] = STATE(9),
    [anon_sym_SEMI] = ACTIONS(131),
    [anon_sym_COMMA] = ACTIONS(131),
    [anon_sym_LPAREN] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(69),
    [anon_sym_DASH] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(73),
    [anon_sym_QMARK] = ACTIONS(75),
    [anon_sym_AT] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(119),
    [anon_sym_LT_EQ] = ACTIONS(119),
    [anon_sym_EQ_EQ] = ACTIONS(119),
    [anon_sym_TILDE_EQ] = ACTIONS(119),
    [anon_sym_GT_EQ] = ACTIONS(119),
    [anon_sym_GT] = ACTIONS(119),
    [anon_sym_AMP_AMP] = ACTIONS(121),
    [anon_sym_PIPE_PIPE] = ACTIONS(123),
    [anon_sym_LBRACK] = ACTIONS(79),
    [anon_sym_LF] = ACTIONS(131),
    [anon_sym_LBRACE] = ACTIONS(81),
    [anon_sym_return] = ACTIONS(83),
    [anon_sym_continue] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_elseif] = ACTIONS(133),
    [anon_sym_else] = ACTIONS(133),
    [anon_sym_if] = ACTIONS(89),
    [anon_sym_end] = ACTIONS(133),
    [anon_sym_for] = ACTIONS(93),
    [anon_sym_parfor] = ACTIONS(95),
    [anon_sym_while] = ACTIONS(97),
    [anon_sym_switch] = ACTIONS(99),
    [anon_sym_global] = ACTIONS(101),
    [anon_sym_persistent] = ACTIONS(103),
    [anon_sym_arguments] = ACTIONS(105),
    [anon_sym_function] = ACTIONS(107),
    [anon_sym_properties] = ACTIONS(105),
    [anon_sym_get] = ACTIONS(105),
    [anon_sym_set] = ACTIONS(105),
    [anon_sym_methods] = ACTIONS(105),
    [anon_sym_events] = ACTIONS(105),
    [anon_sym_enumeration] = ACTIONS(105),
    [anon_sym_classdef] = ACTIONS(109),
    [anon_sym_try] = ACTIONS(111),
    [anon_sym_spmd] = ACTIONS(113),
    [aux_sym_number_token1] = ACTIONS(51),
    [aux_sym_number_token2] = ACTIONS(51),
    [aux_sym_number_token3] = ACTIONS(51),
    [anon_sym_true] = ACTIONS(115),
    [anon_sym_false] = ACTIONS(115),
    [anon_sym_CR] = ACTIONS(131),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(41),
  },
  [STATE(5)] = {
    [aux_sym__block] = STATE(46),
    [sym_block] = STATE(1507),
    [sym_identifier] = STATE(401),
    [sym__statement] = STATE(1174),
    [sym__expression] = STATE(939),
    [sym_parenthesis] = STATE(512),
    [sym__binary_expression] = STATE(910),
    [sym_binary_operator] = STATE(519),
    [sym_unary_operator] = STATE(528),
    [sym_indirect_access] = STATE(1361),
    [sym_field_expression] = STATE(594),
    [sym_not_operator] = STATE(549),
    [sym_metaclass_operator] = STATE(939),
    [sym_handle_operator] = STATE(939),
    [sym_comparison_operator] = STATE(498),
    [sym_boolean_operator] = STATE(498),
    [sym_postfix_operator] = STATE(512),
    [sym_string] = STATE(512),
    [sym_matrix] = STATE(512),
    [sym_cell] = STATE(471),
    [sym_ignored_argument] = STATE(1488),
    [sym_assignment] = STATE(1174),
    [sym_multioutput_variable] = STATE(1488),
    [sym_function_call] = STATE(401),
    [sym_command] = STATE(1174),
    [sym__range_element] = STATE(1509),
    [sym_range] = STATE(939),
    [sym_return_statement] = STATE(1174),
    [sym_continue_statement] = STATE(1174),
    [sym_break_statement] = STATE(1174),
    [sym_if_statement] = STATE(1174),
    [sym_for_statement] = STATE(1174),
    [sym_while_statement] = STATE(1174),
    [sym_switch_statement] = STATE(1174),
    [sym_lambda] = STATE(939),
    [sym_global_operator] = STATE(1174),
    [sym_persistent_operator] = STATE(1174),
    [sym__function_definition_with_end] = STATE(1209),
    [sym_class_definition] = STATE(1174),
    [sym_try_statement] = STATE(1174),
    [sym_spmd_statement] = STATE(1174),
    [sym_number] = STATE(512),
    [sym_boolean] = STATE(397),
    [sym__keywords] = STATE(373),
    [sym__end_of_line] = STATE(16),
    [aux_sym_elseif_clause_repeat1] = STATE(16),
    [anon_sym_SEMI] = ACTIONS(135),
    [anon_sym_COMMA] = ACTIONS(135),
    [anon_sym_LPAREN] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(69),
    [anon_sym_DASH] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(73),
    [anon_sym_QMARK] = ACTIONS(75),
    [anon_sym_AT] = ACTIONS(77),
    [anon_sym_LT] = ACTIONS(119),
    [anon_sym_LT_EQ] = ACTIONS(119),
    [anon_sym_EQ_EQ] = ACTIONS(119),
    [anon_sym_TILDE_EQ] = ACTIONS(119),
    [anon_sym_GT_EQ] = ACTIONS(119),
    [anon_sym_GT] = ACTIONS(119),
    [anon_sym_AMP_AMP] = ACTIONS(121),
    [anon_sym_PIPE_PIPE] = ACTIONS(123),
    [anon_sym_LBRACK] = ACTIONS(79),
    [anon_sym_LF] = ACTIONS(135),
    [anon_sym_LBRACE] = ACTIONS(81),
    [anon_sym_return] = ACTIONS(83),
    [anon_sym_continue] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_if] = ACTIONS(89),
    [anon_sym_end] = ACTIONS(137),
    [anon_sym_for] = ACTIONS(93),
    [anon_sym_parfor] = ACTIONS(95),
    [anon_sym_while] = ACTIONS(97),
    [anon_sym_switch] = ACTIONS(99),
    [anon_sym_global] = ACTIONS(101),
    [anon_sym_persistent] = ACTIONS(103),
    [anon_sym_arguments] = ACTIONS(105),
    [anon_sym_function] = ACTIONS(107),
    [anon_sym_properties] = ACTIONS(105),
    [anon_sym_get] = ACTIONS(105),
    [anon_sym_set] = ACTIONS(105),
    [anon_sym_methods] = ACTIONS(105),
    [anon_sym_events] = ACTIONS(105),
    [anon_sym_enumeration] = ACTIONS(105),
    [anon_sym_classdef] = ACTIONS(109),
    [anon_sym_try] = ACTIONS(111),
    [anon_sym_spmd] = ACTIONS(113),
    [aux_sym_number_token1] = ACTIONS(51),
    [aux_sym_number_token2] = ACTIONS(51),
    [aux_sym_number_token3] = ACTIONS(51),
    [anon_sym_true] = ACTIONS(115),
    [anon_sym_false] = ACTIONS(115),
    [anon_sym_CR] = ACTIONS(135),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(41),
  },
  [STATE(6)] = {
    [aux_sym__block] = STATE(46),
    [sym_block] = STATE(1151),
    [sym_identifier] = STATE(401),
    [sym__statement] = STATE(1174),
    [sym__expression] = STATE(939),
    [sym_parenthesis] = STATE(512),
    [sym__binary_expression] = STATE(910),
    [sym_binary_operator] = STATE(519),
    [sym_unary_operator] = STATE(528),
    [sym_indirect_access] = STATE(1361),
    [sym_field_expression] = STATE(594),
    [sym_not_operator] = STATE(549),
    [sym_metaclass_operator] = STATE(939),
    [sym_handle_operator] = STATE(939),
    [sym_comparison_operator] = STATE(498),
    [sym_boolean_operator] = STATE(498),
    [sym_postfix_operator] = STATE(512),
    [sym_string] = STATE(512),
    [sym_matrix] = STATE(512),
    [sym_cell] = STATE(471),
    [sym_ignored_argument] = STATE(1488),
    [sym_assignment] = STATE(1174),
    [sym_multioutput_variable] = STATE(1488),
    [sym_function_call] = STATE(401),
    [sym_command] = STATE(1174),
    [sym__range_element] = STATE(1509),
    [sym_range] = STATE(939),
    [sym_return_statement] = STATE(1174),
    [sym_continue_statement] = STATE(1174),
    [sym_break_statement] = STATE(1174),
    [sym_elseif_clause] = STATE(1103),
    [sym_else_clause] = STATE(1478),
    [sym_if_statement] = STATE(1174),
    [sym_for_statement] = STATE(1174),
    [sym_while_statement] = STATE(1174),
    [sym_switch_statement] = STATE(1174),
    [sym_lambda] = STATE(939),
    [sym_global_operator] = STATE(1174),
    [sym_persistent_operator] = STATE(1174),
    [sym__function_definition_with_end] = STATE(1209),
    [sym_class_definition] = STATE(1174),
    [sym_try_statement] = STATE(1174),
    [sym_spmd_statement] = STATE(1174),
    [sym_number] = STATE(512),
    [sym_boolean] = STATE(397),
    [sym__keywords] = STATE(373),
    [sym__end_of_line] = STATE(244),
    [aux_sym_elseif_clause_repeat1] = STATE(244),
    [aux_sym_if_statement_repeat1] = STATE(1103),
    [anon_sym_SEMI] = ACTIONS(139),
    [anon_sym_COMMA] = ACTIONS(139),
    [anon_sym_LPAREN] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(69),
    [anon_sym_DASH] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(73),
    [anon_sym_QMARK] = ACTIONS(75),
    [anon_sym_AT] = ACTIONS(77),
    [anon_sym_LBRACK] = ACTIONS(79),
    [anon_sym_LF] = ACTIONS(139),
    [anon_sym_LBRACE] = ACTIONS(81),
    [anon_sym_return] = ACTIONS(83),
    [anon_sym_continue] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_elseif] = ACTIONS(125),
    [anon_sym_else] = ACTIONS(127),
    [anon_sym_if] = ACTIONS(89),
    [anon_sym_end] = ACTIONS(141),
    [anon_sym_for] = ACTIONS(93),
    [anon_sym_parfor] = ACTIONS(95),
    [anon_sym_while] = ACTIONS(97),
    [anon_sym_switch] = ACTIONS(99),
    [anon_sym_global] = ACTIONS(101),
    [anon_sym_persistent] = ACTIONS(103),
    [anon_sym_arguments] = ACTIONS(105),
    [anon_sym_function] = ACTIONS(107),
    [anon_sym_properties] = ACTIONS(105),
    [anon_sym_get] = ACTIONS(105),
    [anon_sym_set] = ACTIONS(105),
    [anon_sym_methods] = ACTIONS(105),
    [anon_sym_events] = ACTIONS(105),
    [anon_sym_enumeration] = ACTIONS(105),
    [anon_sym_classdef] = ACTIONS(109),
    [anon_sym_try] = ACTIONS(111),
    [anon_sym_spmd] = ACTIONS(113),
    [aux_sym_number_token1] = ACTIONS(51),
    [aux_sym_number_token2] = ACTIONS(51),
    [aux_sym_number_token3] = ACTIONS(51),
    [anon_sym_true] = ACTIONS(115),
    [anon_sym_false] = ACTIONS(115),
    [anon_sym_CR] = ACTIONS(139),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(41),
  },
  [STATE(7)] = {
    [aux_sym__block] = STATE(46),
    [sym_block] = STATE(1418),
    [sym_identifier] = STATE(401),
    [sym__statement] = STATE(1174),
    [sym__expression] = STATE(939),
    [sym_parenthesis] = STATE(512),
    [sym__binary_expression] = STATE(910),
    [sym_binary_operator] = STATE(519),
    [sym_unary_operator] = STATE(528),
    [sym_indirect_access] = STATE(1361),
    [sym_field_expression] = STATE(594),
    [sym_not_operator] = STATE(549),
    [sym_metaclass_operator] = STATE(939),
    [sym_handle_operator] = STATE(939),
    [sym_comparison_operator] = STATE(498),
    [sym_boolean_operator] = STATE(498),
    [sym_postfix_operator] = STATE(512),
    [sym_string] = STATE(512),
    [sym_matrix] = STATE(512),
    [sym_cell] = STATE(471),
    [sym_ignored_argument] = STATE(1488),
    [sym_assignment] = STATE(1174),
    [sym_multioutput_variable] = STATE(1488),
    [sym_function_call] = STATE(401),
    [sym_command] = STATE(1174),
    [sym__range_element] = STATE(1509),
    [sym_range] = STATE(939),
    [sym_return_statement] = STATE(1174),
    [sym_continue_statement] = STATE(1174),
    [sym_break_statement] = STATE(1174),
    [sym_if_statement] = STATE(1174),
    [sym_for_statement] = STATE(1174),
    [sym_while_statement] = STATE(1174),
    [sym_switch_statement] = STATE(1174),
    [sym_lambda] = STATE(939),
    [sym_global_operator] = STATE(1174),
    [sym_persistent_operator] = STATE(1174),
    [sym__function_definition_with_end] = STATE(1209),
    [sym_class_definition] = STATE(1174),
    [sym_catch_clause] = STATE(1514),
    [sym_try_statement] = STATE(1174),
    [sym_spmd_statement] = STATE(1174),
    [sym_number] = STATE(512),
    [sym_boolean] = STATE(397),
    [sym__keywords] = STATE(373),
    [sym__end_of_line] = STATE(8),
    [aux_sym_elseif_clause_repeat1] = STATE(8),
    [anon_sym_SEMI] = ACTIONS(143),
    [anon_sym_COMMA] = ACTIONS(143),
    [anon_sym_LPAREN] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(69),
    [anon_sym_DASH] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(73),
    [anon_sym_QMARK] = ACTIONS(75),
    [anon_sym_AT] = ACTIONS(77),
    [anon_sym_LBRACK] = ACTIONS(79),
    [anon_sym_LF] = ACTIONS(143),
    [anon_sym_LBRACE] = ACTIONS(81),
    [anon_sym_return] = ACTIONS(83),
    [anon_sym_continue] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_if] = ACTIONS(89),
    [anon_sym_end] = ACTIONS(145),
    [anon_sym_for] = ACTIONS(93),
    [anon_sym_parfor] = ACTIONS(95),
    [anon_sym_while] = ACTIONS(97),
    [anon_sym_switch] = ACTIONS(99),
    [anon_sym_global] = ACTIONS(101),
    [anon_sym_persistent] = ACTIONS(103),
    [anon_sym_arguments] = ACTIONS(105),
    [anon_sym_function] = ACTIONS(107),
    [anon_sym_properties] = ACTIONS(105),
    [anon_sym_get] = ACTIONS(105),
    [anon_sym_set] = ACTIONS(105),
    [anon_sym_methods] = ACTIONS(105),
    [anon_sym_events] = ACTIONS(105),
    [anon_sym_enumeration] = ACTIONS(105),
    [anon_sym_classdef] = ACTIONS(109),
    [anon_sym_catch] = ACTIONS(147),
    [anon_sym_try] = ACTIONS(111),
    [anon_sym_spmd] = ACTIONS(113),
    [aux_sym_number_token1] = ACTIONS(51),
    [aux_sym_number_token2] = ACTIONS(51),
    [aux_sym_number_token3] = ACTIONS(51),
    [anon_sym_true] = ACTIONS(115),
    [anon_sym_false] = ACTIONS(115),
    [anon_sym_CR] = ACTIONS(143),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(41),
  },
  [STATE(8)] = {
    [aux_sym__block] = STATE(46),
    [sym_block] = STATE(1386),
    [sym_identifier] = STATE(401),
    [sym__statement] = STATE(1174),
    [sym__expression] = STATE(939),
    [sym_parenthesis] = STATE(512),
    [sym__binary_expression] = STATE(910),
    [sym_binary_operator] = STATE(519),
    [sym_unary_operator] = STATE(528),
    [sym_indirect_access] = STATE(1361),
    [sym_field_expression] = STATE(594),
    [sym_not_operator] = STATE(549),
    [sym_metaclass_operator] = STATE(939),
    [sym_handle_operator] = STATE(939),
    [sym_comparison_operator] = STATE(498),
    [sym_boolean_operator] = STATE(498),
    [sym_postfix_operator] = STATE(512),
    [sym_string] = STATE(512),
    [sym_matrix] = STATE(512),
    [sym_cell] = STATE(471),
    [sym_ignored_argument] = STATE(1488),
    [sym_assignment] = STATE(1174),
    [sym_multioutput_variable] = STATE(1488),
    [sym_function_call] = STATE(401),
    [sym_command] = STATE(1174),
    [sym__range_element] = STATE(1509),
    [sym_range] = STATE(939),
    [sym_return_statement] = STATE(1174),
    [sym_continue_statement] = STATE(1174),
    [sym_break_statement] = STATE(1174),
    [sym_if_statement] = STATE(1174),
    [sym_for_statement] = STATE(1174),
    [sym_while_statement] = STATE(1174),
    [sym_switch_statement] = STATE(1174),
    [sym_lambda] = STATE(939),
    [sym_global_operator] = STATE(1174),
    [sym_persistent_operator] = STATE(1174),
    [sym__function_definition_with_end] = STATE(1209),
    [sym_class_definition] = STATE(1174),
    [sym_catch_clause] = STATE(1515),
    [sym_try_statement] = STATE(1174),
    [sym_spmd_statement] = STATE(1174),
    [sym_number] = STATE(512),
    [sym_boolean] = STATE(397),
    [sym__keywords] = STATE(373),
    [sym__end_of_line] = STATE(244),
    [aux_sym_elseif_clause_repeat1] = STATE(244),
    [anon_sym_SEMI] = ACTIONS(139),
    [anon_sym_COMMA] = ACTIONS(139),
    [anon_sym_LPAREN] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(69),
    [anon_sym_DASH] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(73),
    [anon_sym_QMARK] = ACTIONS(75),
    [anon_sym_AT] = ACTIONS(77),
    [anon_sym_LBRACK] = ACTIONS(79),
    [anon_sym_LF] = ACTIONS(139),
    [anon_sym_LBRACE] = ACTIONS(81),
    [anon_sym_return] = ACTIONS(83),
    [anon_sym_continue] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_if] = ACTIONS(89),
    [anon_sym_end] = ACTIONS(149),
    [anon_sym_for] = ACTIONS(93),
    [anon_sym_parfor] = ACTIONS(95),
    [anon_sym_while] = ACTIONS(97),
    [anon_sym_switch] = ACTIONS(99),
    [anon_sym_global] = ACTIONS(101),
    [anon_sym_persistent] = ACTIONS(103),
    [anon_sym_arguments] = ACTIONS(105),
    [anon_sym_function] = ACTIONS(107),
    [anon_sym_properties] = ACTIONS(105),
    [anon_sym_get] = ACTIONS(105),
    [anon_sym_set] = ACTIONS(105),
    [anon_sym_methods] = ACTIONS(105),
    [anon_sym_events] = ACTIONS(105),
    [anon_sym_enumeration] = ACTIONS(105),
    [anon_sym_classdef] = ACTIONS(109),
    [anon_sym_catch] = ACTIONS(147),
    [anon_sym_try] = ACTIONS(111),
    [anon_sym_spmd] = ACTIONS(113),
    [aux_sym_number_token1] = ACTIONS(51),
    [aux_sym_number_token2] = ACTIONS(51),
    [aux_sym_number_token3] = ACTIONS(51),
    [anon_sym_true] = ACTIONS(115),
    [anon_sym_false] = ACTIONS(115),
    [anon_sym_CR] = ACTIONS(139),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(41),
  },
  [STATE(9)] = {
    [aux_sym__block] = STATE(46),
    [sym_block] = STATE(1408),
    [sym_identifier] = STATE(401),
    [sym__statement] = STATE(1174),
    [sym__expression] = STATE(939),
    [sym_parenthesis] = STATE(512),
    [sym__binary_expression] = STATE(910),
    [sym_binary_operator] = STATE(519),
    [sym_unary_operator] = STATE(528),
    [sym_indirect_access] = STATE(1361),
    [sym_field_expression] = STATE(594),
    [sym_not_operator] = STATE(549),
    [sym_metaclass_operator] = STATE(939),
    [sym_handle_operator] = STATE(939),
    [sym_comparison_operator] = STATE(498),
    [sym_boolean_operator] = STATE(498),
    [sym_postfix_operator] = STATE(512),
    [sym_string] = STATE(512),
    [sym_matrix] = STATE(512),
    [sym_cell] = STATE(471),
    [sym_ignored_argument] = STATE(1488),
    [sym_assignment] = STATE(1174),
    [sym_multioutput_variable] = STATE(1488),
    [sym_function_call] = STATE(401),
    [sym_command] = STATE(1174),
    [sym__range_element] = STATE(1509),
    [sym_range] = STATE(939),
    [sym_return_statement] = STATE(1174),
    [sym_continue_statement] = STATE(1174),
    [sym_break_statement] = STATE(1174),
    [sym_if_statement] = STATE(1174),
    [sym_for_statement] = STATE(1174),
    [sym_while_statement] = STATE(1174),
    [sym_switch_statement] = STATE(1174),
    [sym_lambda] = STATE(939),
    [sym_global_operator] = STATE(1174),
    [sym_persistent_operator] = STATE(1174),
    [sym__function_definition_with_end] = STATE(1209),
    [sym_class_definition] = STATE(1174),
    [sym_try_statement] = STATE(1174),
    [sym_spmd_statement] = STATE(1174),
    [sym_number] = STATE(512),
    [sym_boolean] = STATE(397),
    [sym__keywords] = STATE(373),
    [sym__end_of_line] = STATE(244),
    [aux_sym_elseif_clause_repeat1] = STATE(244),
    [anon_sym_SEMI] = ACTIONS(139),
    [anon_sym_COMMA] = ACTIONS(139),
    [anon_sym_LPAREN] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(69),
    [anon_sym_DASH] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(73),
    [anon_sym_QMARK] = ACTIONS(75),
    [anon_sym_AT] = ACTIONS(77),
    [anon_sym_LBRACK] = ACTIONS(79),
    [anon_sym_LF] = ACTIONS(139),
    [anon_sym_LBRACE] = ACTIONS(81),
    [anon_sym_return] = ACTIONS(83),
    [anon_sym_continue] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_elseif] = ACTIONS(151),
    [anon_sym_else] = ACTIONS(151),
    [anon_sym_if] = ACTIONS(89),
    [anon_sym_end] = ACTIONS(151),
    [anon_sym_for] = ACTIONS(93),
    [anon_sym_parfor] = ACTIONS(95),
    [anon_sym_while] = ACTIONS(97),
    [anon_sym_switch] = ACTIONS(99),
    [anon_sym_global] = ACTIONS(101),
    [anon_sym_persistent] = ACTIONS(103),
    [anon_sym_arguments] = ACTIONS(105),
    [anon_sym_function] = ACTIONS(107),
    [anon_sym_properties] = ACTIONS(105),
    [anon_sym_get] = ACTIONS(105),
    [anon_sym_set] = ACTIONS(105),
    [anon_sym_methods] = ACTIONS(105),
    [anon_sym_events] = ACTIONS(105),
    [anon_sym_enumeration] = ACTIONS(105),
    [anon_sym_classdef] = ACTIONS(109),
    [anon_sym_try] = ACTIONS(111),
    [anon_sym_spmd] = ACTIONS(113),
    [aux_sym_number_token1] = ACTIONS(51),
    [aux_sym_number_token2] = ACTIONS(51),
    [aux_sym_number_token3] = ACTIONS(51),
    [anon_sym_true] = ACTIONS(115),
    [anon_sym_false] = ACTIONS(115),
    [anon_sym_CR] = ACTIONS(139),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(41),
  },
  [STATE(10)] = {
    [aux_sym__block] = STATE(46),
    [sym_block] = STATE(1411),
    [sym_identifier] = STATE(401),
    [sym__statement] = STATE(1174),
    [sym__expression] = STATE(939),
    [sym_parenthesis] = STATE(512),
    [sym__binary_expression] = STATE(910),
    [sym_binary_operator] = STATE(519),
    [sym_unary_operator] = STATE(528),
    [sym_indirect_access] = STATE(1361),
    [sym_field_expression] = STATE(594),
    [sym_not_operator] = STATE(549),
    [sym_metaclass_operator] = STATE(939),
    [sym_handle_operator] = STATE(939),
    [sym_comparison_operator] = STATE(498),
    [sym_boolean_operator] = STATE(498),
    [sym_postfix_operator] = STATE(512),
    [sym_string] = STATE(512),
    [sym_matrix] = STATE(512),
    [sym_cell] = STATE(471),
    [sym_ignored_argument] = STATE(1488),
    [sym_assignment] = STATE(1174),
    [sym_multioutput_variable] = STATE(1488),
    [sym_function_call] = STATE(401),
    [sym_command] = STATE(1174),
    [sym__range_element] = STATE(1509),
    [sym_range] = STATE(939),
    [sym_return_statement] = STATE(1174),
    [sym_continue_statement] = STATE(1174),
    [sym_break_statement] = STATE(1174),
    [sym_if_statement] = STATE(1174),
    [sym_for_statement] = STATE(1174),
    [sym_while_statement] = STATE(1174),
    [sym_switch_statement] = STATE(1174),
    [sym_lambda] = STATE(939),
    [sym_global_operator] = STATE(1174),
    [sym_persistent_operator] = STATE(1174),
    [sym__function_definition_with_end] = STATE(1209),
    [sym_class_definition] = STATE(1174),
    [sym_try_statement] = STATE(1174),
    [sym_spmd_statement] = STATE(1174),
    [sym_number] = STATE(512),
    [sym_boolean] = STATE(397),
    [sym__keywords] = STATE(373),
    [sym__end_of_line] = STATE(244),
    [aux_sym_elseif_clause_repeat1] = STATE(244),
    [anon_sym_SEMI] = ACTIONS(139),
    [anon_sym_COMMA] = ACTIONS(139),
    [anon_sym_LPAREN] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(69),
    [anon_sym_DASH] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(73),
    [anon_sym_QMARK] = ACTIONS(75),
    [anon_sym_AT] = ACTIONS(77),
    [anon_sym_LBRACK] = ACTIONS(79),
    [anon_sym_LF] = ACTIONS(139),
    [anon_sym_LBRACE] = ACTIONS(81),
    [anon_sym_return] = ACTIONS(83),
    [anon_sym_continue] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_if] = ACTIONS(89),
    [anon_sym_end] = ACTIONS(153),
    [anon_sym_for] = ACTIONS(93),
    [anon_sym_parfor] = ACTIONS(95),
    [anon_sym_while] = ACTIONS(97),
    [anon_sym_case] = ACTIONS(153),
    [anon_sym_otherwise] = ACTIONS(153),
    [anon_sym_switch] = ACTIONS(99),
    [anon_sym_global] = ACTIONS(101),
    [anon_sym_persistent] = ACTIONS(103),
    [anon_sym_arguments] = ACTIONS(105),
    [anon_sym_function] = ACTIONS(107),
    [anon_sym_properties] = ACTIONS(105),
    [anon_sym_get] = ACTIONS(105),
    [anon_sym_set] = ACTIONS(105),
    [anon_sym_methods] = ACTIONS(105),
    [anon_sym_events] = ACTIONS(105),
    [anon_sym_enumeration] = ACTIONS(105),
    [anon_sym_classdef] = ACTIONS(109),
    [anon_sym_try] = ACTIONS(111),
    [anon_sym_spmd] = ACTIONS(113),
    [aux_sym_number_token1] = ACTIONS(51),
    [aux_sym_number_token2] = ACTIONS(51),
    [aux_sym_number_token3] = ACTIONS(51),
    [anon_sym_true] = ACTIONS(115),
    [anon_sym_false] = ACTIONS(115),
    [anon_sym_CR] = ACTIONS(139),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(41),
  },
  [STATE(11)] = {
    [aux_sym__block] = STATE(46),
    [sym_block] = STATE(1495),
    [sym_identifier] = STATE(401),
    [sym__statement] = STATE(1174),
    [sym__expression] = STATE(939),
    [sym_parenthesis] = STATE(512),
    [sym__binary_expression] = STATE(910),
    [sym_binary_operator] = STATE(519),
    [sym_unary_operator] = STATE(528),
    [sym_indirect_access] = STATE(1361),
    [sym_field_expression] = STATE(594),
    [sym_not_operator] = STATE(549),
    [sym_metaclass_operator] = STATE(939),
    [sym_handle_operator] = STATE(939),
    [sym_comparison_operator] = STATE(498),
    [sym_boolean_operator] = STATE(498),
    [sym_postfix_operator] = STATE(512),
    [sym_string] = STATE(512),
    [sym_matrix] = STATE(512),
    [sym_cell] = STATE(471),
    [sym_ignored_argument] = STATE(1488),
    [sym_assignment] = STATE(1174),
    [sym_multioutput_variable] = STATE(1488),
    [sym_function_call] = STATE(401),
    [sym_command] = STATE(1174),
    [sym__range_element] = STATE(1509),
    [sym_range] = STATE(939),
    [sym_return_statement] = STATE(1174),
    [sym_continue_statement] = STATE(1174),
    [sym_break_statement] = STATE(1174),
    [sym_if_statement] = STATE(1174),
    [sym_for_statement] = STATE(1174),
    [sym_while_statement] = STATE(1174),
    [sym_switch_statement] = STATE(1174),
    [sym_lambda] = STATE(939),
    [sym_global_operator] = STATE(1174),
    [sym_persistent_operator] = STATE(1174),
    [sym__function_definition_with_end] = STATE(1209),
    [sym_class_definition] = STATE(1174),
    [sym_try_statement] = STATE(1174),
    [sym_spmd_statement] = STATE(1174),
    [sym_number] = STATE(512),
    [sym_boolean] = STATE(397),
    [sym__keywords] = STATE(373),
    [sym__end_of_line] = STATE(15),
    [aux_sym_elseif_clause_repeat1] = STATE(15),
    [anon_sym_SEMI] = ACTIONS(155),
    [anon_sym_COMMA] = ACTIONS(155),
    [anon_sym_LPAREN] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(69),
    [anon_sym_DASH] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(73),
    [anon_sym_QMARK] = ACTIONS(75),
    [anon_sym_AT] = ACTIONS(77),
    [anon_sym_LBRACK] = ACTIONS(79),
    [anon_sym_LF] = ACTIONS(155),
    [anon_sym_LBRACE] = ACTIONS(81),
    [anon_sym_return] = ACTIONS(83),
    [anon_sym_continue] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_if] = ACTIONS(89),
    [anon_sym_end] = ACTIONS(157),
    [anon_sym_for] = ACTIONS(93),
    [anon_sym_parfor] = ACTIONS(95),
    [anon_sym_while] = ACTIONS(97),
    [anon_sym_switch] = ACTIONS(99),
    [anon_sym_global] = ACTIONS(101),
    [anon_sym_persistent] = ACTIONS(103),
    [anon_sym_arguments] = ACTIONS(105),
    [anon_sym_function] = ACTIONS(107),
    [anon_sym_properties] = ACTIONS(105),
    [anon_sym_get] = ACTIONS(105),
    [anon_sym_set] = ACTIONS(105),
    [anon_sym_methods] = ACTIONS(105),
    [anon_sym_events] = ACTIONS(105),
    [anon_sym_enumeration] = ACTIONS(105),
    [anon_sym_classdef] = ACTIONS(109),
    [anon_sym_try] = ACTIONS(111),
    [anon_sym_spmd] = ACTIONS(113),
    [aux_sym_number_token1] = ACTIONS(51),
    [aux_sym_number_token2] = ACTIONS(51),
    [aux_sym_number_token3] = ACTIONS(51),
    [anon_sym_true] = ACTIONS(115),
    [anon_sym_false] = ACTIONS(115),
    [anon_sym_CR] = ACTIONS(155),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(41),
  },
  [STATE(12)] = {
    [aux_sym__block] = STATE(46),
    [sym_block] = STATE(1450),
    [sym_identifier] = STATE(401),
    [sym__statement] = STATE(1174),
    [sym__expression] = STATE(939),
    [sym_parenthesis] = STATE(512),
    [sym__binary_expression] = STATE(910),
    [sym_binary_operator] = STATE(519),
    [sym_unary_operator] = STATE(528),
    [sym_indirect_access] = STATE(1361),
    [sym_field_expression] = STATE(594),
    [sym_not_operator] = STATE(549),
    [sym_metaclass_operator] = STATE(939),
    [sym_handle_operator] = STATE(939),
    [sym_comparison_operator] = STATE(498),
    [sym_boolean_operator] = STATE(498),
    [sym_postfix_operator] = STATE(512),
    [sym_string] = STATE(512),
    [sym_matrix] = STATE(512),
    [sym_cell] = STATE(471),
    [sym_ignored_argument] = STATE(1488),
    [sym_assignment] = STATE(1174),
    [sym_multioutput_variable] = STATE(1488),
    [sym_function_call] = STATE(401),
    [sym_command] = STATE(1174),
    [sym__range_element] = STATE(1509),
    [sym_range] = STATE(939),
    [sym_return_statement] = STATE(1174),
    [sym_continue_statement] = STATE(1174),
    [sym_break_statement] = STATE(1174),
    [sym_if_statement] = STATE(1174),
    [sym_for_statement] = STATE(1174),
    [sym_while_statement] = STATE(1174),
    [sym_switch_statement] = STATE(1174),
    [sym_lambda] = STATE(939),
    [sym_global_operator] = STATE(1174),
    [sym_persistent_operator] = STATE(1174),
    [sym__function_definition_with_end] = STATE(1209),
    [sym_class_definition] = STATE(1174),
    [sym_try_statement] = STATE(1174),
    [sym_spmd_statement] = STATE(1174),
    [sym_number] = STATE(512),
    [sym_boolean] = STATE(397),
    [sym__keywords] = STATE(373),
    [sym__end_of_line] = STATE(14),
    [aux_sym_elseif_clause_repeat1] = STATE(14),
    [anon_sym_SEMI] = ACTIONS(159),
    [anon_sym_COMMA] = ACTIONS(159),
    [anon_sym_LPAREN] = ACTIONS(161),
    [anon_sym_PLUS] = ACTIONS(69),
    [anon_sym_DASH] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(73),
    [anon_sym_QMARK] = ACTIONS(75),
    [anon_sym_AT] = ACTIONS(77),
    [anon_sym_LBRACK] = ACTIONS(79),
    [anon_sym_LF] = ACTIONS(159),
    [anon_sym_LBRACE] = ACTIONS(81),
    [anon_sym_return] = ACTIONS(83),
    [anon_sym_continue] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_if] = ACTIONS(89),
    [anon_sym_end] = ACTIONS(163),
    [anon_sym_for] = ACTIONS(93),
    [anon_sym_parfor] = ACTIONS(95),
    [anon_sym_while] = ACTIONS(97),
    [anon_sym_switch] = ACTIONS(99),
    [anon_sym_global] = ACTIONS(101),
    [anon_sym_persistent] = ACTIONS(103),
    [anon_sym_arguments] = ACTIONS(105),
    [anon_sym_function] = ACTIONS(107),
    [anon_sym_properties] = ACTIONS(105),
    [anon_sym_get] = ACTIONS(105),
    [anon_sym_set] = ACTIONS(105),
    [anon_sym_methods] = ACTIONS(105),
    [anon_sym_events] = ACTIONS(105),
    [anon_sym_enumeration] = ACTIONS(105),
    [anon_sym_classdef] = ACTIONS(109),
    [anon_sym_try] = ACTIONS(111),
    [anon_sym_spmd] = ACTIONS(113),
    [aux_sym_number_token1] = ACTIONS(51),
    [aux_sym_number_token2] = ACTIONS(51),
    [aux_sym_number_token3] = ACTIONS(51),
    [anon_sym_true] = ACTIONS(115),
    [anon_sym_false] = ACTIONS(115),
    [anon_sym_CR] = ACTIONS(159),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(41),
  },
  [STATE(13)] = {
    [aux_sym__block] = STATE(46),
    [sym_block] = STATE(1467),
    [sym_identifier] = STATE(401),
    [sym__statement] = STATE(1174),
    [sym__expression] = STATE(939),
    [sym_parenthesis] = STATE(512),
    [sym__binary_expression] = STATE(910),
    [sym_binary_operator] = STATE(519),
    [sym_unary_operator] = STATE(528),
    [sym_indirect_access] = STATE(1361),
    [sym_field_expression] = STATE(594),
    [sym_not_operator] = STATE(549),
    [sym_metaclass_operator] = STATE(939),
    [sym_handle_operator] = STATE(939),
    [sym_comparison_operator] = STATE(498),
    [sym_boolean_operator] = STATE(498),
    [sym_postfix_operator] = STATE(512),
    [sym_string] = STATE(512),
    [sym_matrix] = STATE(512),
    [sym_cell] = STATE(471),
    [sym_ignored_argument] = STATE(1488),
    [sym_assignment] = STATE(1174),
    [sym_multioutput_variable] = STATE(1488),
    [sym_function_call] = STATE(401),
    [sym_command] = STATE(1174),
    [sym__range_element] = STATE(1509),
    [sym_range] = STATE(939),
    [sym_return_statement] = STATE(1174),
    [sym_continue_statement] = STATE(1174),
    [sym_break_statement] = STATE(1174),
    [sym_if_statement] = STATE(1174),
    [sym_for_statement] = STATE(1174),
    [sym_while_statement] = STATE(1174),
    [sym_switch_statement] = STATE(1174),
    [sym_lambda] = STATE(939),
    [sym_global_operator] = STATE(1174),
    [sym_persistent_operator] = STATE(1174),
    [sym__function_definition_with_end] = STATE(1209),
    [sym_class_definition] = STATE(1174),
    [sym_try_statement] = STATE(1174),
    [sym_spmd_statement] = STATE(1174),
    [sym_number] = STATE(512),
    [sym_boolean] = STATE(397),
    [sym__keywords] = STATE(373),
    [sym__end_of_line] = STATE(21),
    [aux_sym_elseif_clause_repeat1] = STATE(21),
    [anon_sym_SEMI] = ACTIONS(165),
    [anon_sym_COMMA] = ACTIONS(165),
    [anon_sym_LPAREN] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(69),
    [anon_sym_DASH] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(73),
    [anon_sym_QMARK] = ACTIONS(75),
    [anon_sym_AT] = ACTIONS(77),
    [anon_sym_LBRACK] = ACTIONS(79),
    [anon_sym_LF] = ACTIONS(165),
    [anon_sym_LBRACE] = ACTIONS(81),
    [anon_sym_return] = ACTIONS(83),
    [anon_sym_continue] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_if] = ACTIONS(89),
    [anon_sym_end] = ACTIONS(167),
    [anon_sym_for] = ACTIONS(93),
    [anon_sym_parfor] = ACTIONS(95),
    [anon_sym_while] = ACTIONS(97),
    [anon_sym_switch] = ACTIONS(99),
    [anon_sym_global] = ACTIONS(101),
    [anon_sym_persistent] = ACTIONS(103),
    [anon_sym_arguments] = ACTIONS(105),
    [anon_sym_function] = ACTIONS(107),
    [anon_sym_properties] = ACTIONS(105),
    [anon_sym_get] = ACTIONS(105),
    [anon_sym_set] = ACTIONS(105),
    [anon_sym_methods] = ACTIONS(105),
    [anon_sym_events] = ACTIONS(105),
    [anon_sym_enumeration] = ACTIONS(105),
    [anon_sym_classdef] = ACTIONS(109),
    [anon_sym_try] = ACTIONS(111),
    [anon_sym_spmd] = ACTIONS(113),
    [aux_sym_number_token1] = ACTIONS(51),
    [aux_sym_number_token2] = ACTIONS(51),
    [aux_sym_number_token3] = ACTIONS(51),
    [anon_sym_true] = ACTIONS(115),
    [anon_sym_false] = ACTIONS(115),
    [anon_sym_CR] = ACTIONS(165),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(41),
  },
  [STATE(14)] = {
    [aux_sym__block] = STATE(46),
    [sym_block] = STATE(1483),
    [sym_identifier] = STATE(401),
    [sym__statement] = STATE(1174),
    [sym__expression] = STATE(939),
    [sym_parenthesis] = STATE(512),
    [sym__binary_expression] = STATE(910),
    [sym_binary_operator] = STATE(519),
    [sym_unary_operator] = STATE(528),
    [sym_indirect_access] = STATE(1361),
    [sym_field_expression] = STATE(594),
    [sym_not_operator] = STATE(549),
    [sym_metaclass_operator] = STATE(939),
    [sym_handle_operator] = STATE(939),
    [sym_comparison_operator] = STATE(498),
    [sym_boolean_operator] = STATE(498),
    [sym_postfix_operator] = STATE(512),
    [sym_string] = STATE(512),
    [sym_matrix] = STATE(512),
    [sym_cell] = STATE(471),
    [sym_ignored_argument] = STATE(1488),
    [sym_assignment] = STATE(1174),
    [sym_multioutput_variable] = STATE(1488),
    [sym_function_call] = STATE(401),
    [sym_command] = STATE(1174),
    [sym__range_element] = STATE(1509),
    [sym_range] = STATE(939),
    [sym_return_statement] = STATE(1174),
    [sym_continue_statement] = STATE(1174),
    [sym_break_statement] = STATE(1174),
    [sym_if_statement] = STATE(1174),
    [sym_for_statement] = STATE(1174),
    [sym_while_statement] = STATE(1174),
    [sym_switch_statement] = STATE(1174),
    [sym_lambda] = STATE(939),
    [sym_global_operator] = STATE(1174),
    [sym_persistent_operator] = STATE(1174),
    [sym__function_definition_with_end] = STATE(1209),
    [sym_class_definition] = STATE(1174),
    [sym_try_statement] = STATE(1174),
    [sym_spmd_statement] = STATE(1174),
    [sym_number] = STATE(512),
    [sym_boolean] = STATE(397),
    [sym__keywords] = STATE(373),
    [sym__end_of_line] = STATE(244),
    [aux_sym_elseif_clause_repeat1] = STATE(244),
    [anon_sym_SEMI] = ACTIONS(139),
    [anon_sym_COMMA] = ACTIONS(139),
    [anon_sym_LPAREN] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(69),
    [anon_sym_DASH] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(73),
    [anon_sym_QMARK] = ACTIONS(75),
    [anon_sym_AT] = ACTIONS(77),
    [anon_sym_LBRACK] = ACTIONS(79),
    [anon_sym_LF] = ACTIONS(139),
    [anon_sym_LBRACE] = ACTIONS(81),
    [anon_sym_return] = ACTIONS(83),
    [anon_sym_continue] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_if] = ACTIONS(89),
    [anon_sym_end] = ACTIONS(169),
    [anon_sym_for] = ACTIONS(93),
    [anon_sym_parfor] = ACTIONS(95),
    [anon_sym_while] = ACTIONS(97),
    [anon_sym_switch] = ACTIONS(99),
    [anon_sym_global] = ACTIONS(101),
    [anon_sym_persistent] = ACTIONS(103),
    [anon_sym_arguments] = ACTIONS(105),
    [anon_sym_function] = ACTIONS(107),
    [anon_sym_properties] = ACTIONS(105),
    [anon_sym_get] = ACTIONS(105),
    [anon_sym_set] = ACTIONS(105),
    [anon_sym_methods] = ACTIONS(105),
    [anon_sym_events] = ACTIONS(105),
    [anon_sym_enumeration] = ACTIONS(105),
    [anon_sym_classdef] = ACTIONS(109),
    [anon_sym_try] = ACTIONS(111),
    [anon_sym_spmd] = ACTIONS(113),
    [aux_sym_number_token1] = ACTIONS(51),
    [aux_sym_number_token2] = ACTIONS(51),
    [aux_sym_number_token3] = ACTIONS(51),
    [anon_sym_true] = ACTIONS(115),
    [anon_sym_false] = ACTIONS(115),
    [anon_sym_CR] = ACTIONS(139),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(41),
  },
  [STATE(15)] = {
    [aux_sym__block] = STATE(46),
    [sym_block] = STATE(1499),
    [sym_identifier] = STATE(401),
    [sym__statement] = STATE(1174),
    [sym__expression] = STATE(939),
    [sym_parenthesis] = STATE(512),
    [sym__binary_expression] = STATE(910),
    [sym_binary_operator] = STATE(519),
    [sym_unary_operator] = STATE(528),
    [sym_indirect_access] = STATE(1361),
    [sym_field_expression] = STATE(594),
    [sym_not_operator] = STATE(549),
    [sym_metaclass_operator] = STATE(939),
    [sym_handle_operator] = STATE(939),
    [sym_comparison_operator] = STATE(498),
    [sym_boolean_operator] = STATE(498),
    [sym_postfix_operator] = STATE(512),
    [sym_string] = STATE(512),
    [sym_matrix] = STATE(512),
    [sym_cell] = STATE(471),
    [sym_ignored_argument] = STATE(1488),
    [sym_assignment] = STATE(1174),
    [sym_multioutput_variable] = STATE(1488),
    [sym_function_call] = STATE(401),
    [sym_command] = STATE(1174),
    [sym__range_element] = STATE(1509),
    [sym_range] = STATE(939),
    [sym_return_statement] = STATE(1174),
    [sym_continue_statement] = STATE(1174),
    [sym_break_statement] = STATE(1174),
    [sym_if_statement] = STATE(1174),
    [sym_for_statement] = STATE(1174),
    [sym_while_statement] = STATE(1174),
    [sym_switch_statement] = STATE(1174),
    [sym_lambda] = STATE(939),
    [sym_global_operator] = STATE(1174),
    [sym_persistent_operator] = STATE(1174),
    [sym__function_definition_with_end] = STATE(1209),
    [sym_class_definition] = STATE(1174),
    [sym_try_statement] = STATE(1174),
    [sym_spmd_statement] = STATE(1174),
    [sym_number] = STATE(512),
    [sym_boolean] = STATE(397),
    [sym__keywords] = STATE(373),
    [sym__end_of_line] = STATE(244),
    [aux_sym_elseif_clause_repeat1] = STATE(244),
    [anon_sym_SEMI] = ACTIONS(139),
    [anon_sym_COMMA] = ACTIONS(139),
    [anon_sym_LPAREN] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(69),
    [anon_sym_DASH] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(73),
    [anon_sym_QMARK] = ACTIONS(75),
    [anon_sym_AT] = ACTIONS(77),
    [anon_sym_LBRACK] = ACTIONS(79),
    [anon_sym_LF] = ACTIONS(139),
    [anon_sym_LBRACE] = ACTIONS(81),
    [anon_sym_return] = ACTIONS(83),
    [anon_sym_continue] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_if] = ACTIONS(89),
    [anon_sym_end] = ACTIONS(171),
    [anon_sym_for] = ACTIONS(93),
    [anon_sym_parfor] = ACTIONS(95),
    [anon_sym_while] = ACTIONS(97),
    [anon_sym_switch] = ACTIONS(99),
    [anon_sym_global] = ACTIONS(101),
    [anon_sym_persistent] = ACTIONS(103),
    [anon_sym_arguments] = ACTIONS(105),
    [anon_sym_function] = ACTIONS(107),
    [anon_sym_properties] = ACTIONS(105),
    [anon_sym_get] = ACTIONS(105),
    [anon_sym_set] = ACTIONS(105),
    [anon_sym_methods] = ACTIONS(105),
    [anon_sym_events] = ACTIONS(105),
    [anon_sym_enumeration] = ACTIONS(105),
    [anon_sym_classdef] = ACTIONS(109),
    [anon_sym_try] = ACTIONS(111),
    [anon_sym_spmd] = ACTIONS(113),
    [aux_sym_number_token1] = ACTIONS(51),
    [aux_sym_number_token2] = ACTIONS(51),
    [aux_sym_number_token3] = ACTIONS(51),
    [anon_sym_true] = ACTIONS(115),
    [anon_sym_false] = ACTIONS(115),
    [anon_sym_CR] = ACTIONS(139),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(41),
  },
  [STATE(16)] = {
    [aux_sym__block] = STATE(46),
    [sym_block] = STATE(1506),
    [sym_identifier] = STATE(401),
    [sym__statement] = STATE(1174),
    [sym__expression] = STATE(939),
    [sym_parenthesis] = STATE(512),
    [sym__binary_expression] = STATE(910),
    [sym_binary_operator] = STATE(519),
    [sym_unary_operator] = STATE(528),
    [sym_indirect_access] = STATE(1361),
    [sym_field_expression] = STATE(594),
    [sym_not_operator] = STATE(549),
    [sym_metaclass_operator] = STATE(939),
    [sym_handle_operator] = STATE(939),
    [sym_comparison_operator] = STATE(498),
    [sym_boolean_operator] = STATE(498),
    [sym_postfix_operator] = STATE(512),
    [sym_string] = STATE(512),
    [sym_matrix] = STATE(512),
    [sym_cell] = STATE(471),
    [sym_ignored_argument] = STATE(1488),
    [sym_assignment] = STATE(1174),
    [sym_multioutput_variable] = STATE(1488),
    [sym_function_call] = STATE(401),
    [sym_command] = STATE(1174),
    [sym__range_element] = STATE(1509),
    [sym_range] = STATE(939),
    [sym_return_statement] = STATE(1174),
    [sym_continue_statement] = STATE(1174),
    [sym_break_statement] = STATE(1174),
    [sym_if_statement] = STATE(1174),
    [sym_for_statement] = STATE(1174),
    [sym_while_statement] = STATE(1174),
    [sym_switch_statement] = STATE(1174),
    [sym_lambda] = STATE(939),
    [sym_global_operator] = STATE(1174),
    [sym_persistent_operator] = STATE(1174),
    [sym__function_definition_with_end] = STATE(1209),
    [sym_class_definition] = STATE(1174),
    [sym_try_statement] = STATE(1174),
    [sym_spmd_statement] = STATE(1174),
    [sym_number] = STATE(512),
    [sym_boolean] = STATE(397),
    [sym__keywords] = STATE(373),
    [sym__end_of_line] = STATE(244),
    [aux_sym_elseif_clause_repeat1] = STATE(244),
    [anon_sym_SEMI] = ACTIONS(139),
    [anon_sym_COMMA] = ACTIONS(139),
    [anon_sym_LPAREN] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(69),
    [anon_sym_DASH] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(73),
    [anon_sym_QMARK] = ACTIONS(75),
    [anon_sym_AT] = ACTIONS(77),
    [anon_sym_LBRACK] = ACTIONS(79),
    [anon_sym_LF] = ACTIONS(139),
    [anon_sym_LBRACE] = ACTIONS(81),
    [anon_sym_return] = ACTIONS(83),
    [anon_sym_continue] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_if] = ACTIONS(89),
    [anon_sym_end] = ACTIONS(173),
    [anon_sym_for] = ACTIONS(93),
    [anon_sym_parfor] = ACTIONS(95),
    [anon_sym_while] = ACTIONS(97),
    [anon_sym_switch] = ACTIONS(99),
    [anon_sym_global] = ACTIONS(101),
    [anon_sym_persistent] = ACTIONS(103),
    [anon_sym_arguments] = ACTIONS(105),
    [anon_sym_function] = ACTIONS(107),
    [anon_sym_properties] = ACTIONS(105),
    [anon_sym_get] = ACTIONS(105),
    [anon_sym_set] = ACTIONS(105),
    [anon_sym_methods] = ACTIONS(105),
    [anon_sym_events] = ACTIONS(105),
    [anon_sym_enumeration] = ACTIONS(105),
    [anon_sym_classdef] = ACTIONS(109),
    [anon_sym_try] = ACTIONS(111),
    [anon_sym_spmd] = ACTIONS(113),
    [aux_sym_number_token1] = ACTIONS(51),
    [aux_sym_number_token2] = ACTIONS(51),
    [aux_sym_number_token3] = ACTIONS(51),
    [anon_sym_true] = ACTIONS(115),
    [anon_sym_false] = ACTIONS(115),
    [anon_sym_CR] = ACTIONS(139),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(41),
  },
  [STATE(17)] = {
    [aux_sym__block] = STATE(46),
    [sym_block] = STATE(1455),
    [sym_identifier] = STATE(401),
    [sym__statement] = STATE(1174),
    [sym__expression] = STATE(939),
    [sym_parenthesis] = STATE(512),
    [sym__binary_expression] = STATE(910),
    [sym_binary_operator] = STATE(519),
    [sym_unary_operator] = STATE(528),
    [sym_indirect_access] = STATE(1361),
    [sym_field_expression] = STATE(594),
    [sym_not_operator] = STATE(549),
    [sym_metaclass_operator] = STATE(939),
    [sym_handle_operator] = STATE(939),
    [sym_comparison_operator] = STATE(498),
    [sym_boolean_operator] = STATE(498),
    [sym_postfix_operator] = STATE(512),
    [sym_string] = STATE(512),
    [sym_matrix] = STATE(512),
    [sym_cell] = STATE(471),
    [sym_ignored_argument] = STATE(1488),
    [sym_assignment] = STATE(1174),
    [sym_multioutput_variable] = STATE(1488),
    [sym_function_call] = STATE(401),
    [sym_command] = STATE(1174),
    [sym__range_element] = STATE(1509),
    [sym_range] = STATE(939),
    [sym_return_statement] = STATE(1174),
    [sym_continue_statement] = STATE(1174),
    [sym_break_statement] = STATE(1174),
    [sym_if_statement] = STATE(1174),
    [sym_for_statement] = STATE(1174),
    [sym_while_statement] = STATE(1174),
    [sym_switch_statement] = STATE(1174),
    [sym_lambda] = STATE(939),
    [sym_global_operator] = STATE(1174),
    [sym_persistent_operator] = STATE(1174),
    [sym__function_definition_with_end] = STATE(1209),
    [sym_class_definition] = STATE(1174),
    [sym_try_statement] = STATE(1174),
    [sym_spmd_statement] = STATE(1174),
    [sym_number] = STATE(512),
    [sym_boolean] = STATE(397),
    [sym__keywords] = STATE(373),
    [sym__end_of_line] = STATE(20),
    [aux_sym_elseif_clause_repeat1] = STATE(20),
    [anon_sym_SEMI] = ACTIONS(175),
    [anon_sym_COMMA] = ACTIONS(175),
    [anon_sym_LPAREN] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(69),
    [anon_sym_DASH] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(73),
    [anon_sym_QMARK] = ACTIONS(75),
    [anon_sym_AT] = ACTIONS(77),
    [anon_sym_LBRACK] = ACTIONS(79),
    [anon_sym_LF] = ACTIONS(175),
    [anon_sym_LBRACE] = ACTIONS(81),
    [anon_sym_return] = ACTIONS(83),
    [anon_sym_continue] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_if] = ACTIONS(89),
    [anon_sym_end] = ACTIONS(177),
    [anon_sym_for] = ACTIONS(93),
    [anon_sym_parfor] = ACTIONS(95),
    [anon_sym_while] = ACTIONS(97),
    [anon_sym_switch] = ACTIONS(99),
    [anon_sym_global] = ACTIONS(101),
    [anon_sym_persistent] = ACTIONS(103),
    [anon_sym_arguments] = ACTIONS(105),
    [anon_sym_function] = ACTIONS(107),
    [anon_sym_properties] = ACTIONS(105),
    [anon_sym_get] = ACTIONS(105),
    [anon_sym_set] = ACTIONS(105),
    [anon_sym_methods] = ACTIONS(105),
    [anon_sym_events] = ACTIONS(105),
    [anon_sym_enumeration] = ACTIONS(105),
    [anon_sym_classdef] = ACTIONS(109),
    [anon_sym_try] = ACTIONS(111),
    [anon_sym_spmd] = ACTIONS(113),
    [aux_sym_number_token1] = ACTIONS(51),
    [aux_sym_number_token2] = ACTIONS(51),
    [aux_sym_number_token3] = ACTIONS(51),
    [anon_sym_true] = ACTIONS(115),
    [anon_sym_false] = ACTIONS(115),
    [anon_sym_CR] = ACTIONS(175),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(41),
  },
  [STATE(18)] = {
    [aux_sym__block] = STATE(46),
    [sym_block] = STATE(1520),
    [sym_identifier] = STATE(401),
    [sym__statement] = STATE(1174),
    [sym__expression] = STATE(939),
    [sym_parenthesis] = STATE(512),
    [sym__binary_expression] = STATE(910),
    [sym_binary_operator] = STATE(519),
    [sym_unary_operator] = STATE(528),
    [sym_indirect_access] = STATE(1361),
    [sym_field_expression] = STATE(594),
    [sym_not_operator] = STATE(549),
    [sym_metaclass_operator] = STATE(939),
    [sym_handle_operator] = STATE(939),
    [sym_comparison_operator] = STATE(498),
    [sym_boolean_operator] = STATE(498),
    [sym_postfix_operator] = STATE(512),
    [sym_string] = STATE(512),
    [sym_matrix] = STATE(512),
    [sym_cell] = STATE(471),
    [sym_ignored_argument] = STATE(1488),
    [sym_assignment] = STATE(1174),
    [sym_multioutput_variable] = STATE(1488),
    [sym_function_call] = STATE(401),
    [sym_command] = STATE(1174),
    [sym__range_element] = STATE(1509),
    [sym_range] = STATE(939),
    [sym_return_statement] = STATE(1174),
    [sym_continue_statement] = STATE(1174),
    [sym_break_statement] = STATE(1174),
    [sym_if_statement] = STATE(1174),
    [sym_for_statement] = STATE(1174),
    [sym_while_statement] = STATE(1174),
    [sym_switch_statement] = STATE(1174),
    [sym_lambda] = STATE(939),
    [sym_global_operator] = STATE(1174),
    [sym_persistent_operator] = STATE(1174),
    [sym__function_definition_with_end] = STATE(1209),
    [sym_class_definition] = STATE(1174),
    [sym_try_statement] = STATE(1174),
    [sym_spmd_statement] = STATE(1174),
    [sym_number] = STATE(512),
    [sym_boolean] = STATE(397),
    [sym__keywords] = STATE(373),
    [sym__end_of_line] = STATE(244),
    [aux_sym_elseif_clause_repeat1] = STATE(244),
    [anon_sym_SEMI] = ACTIONS(139),
    [anon_sym_COMMA] = ACTIONS(139),
    [anon_sym_LPAREN] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(69),
    [anon_sym_DASH] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(73),
    [anon_sym_QMARK] = ACTIONS(75),
    [anon_sym_AT] = ACTIONS(77),
    [anon_sym_LBRACK] = ACTIONS(79),
    [anon_sym_LF] = ACTIONS(139),
    [anon_sym_LBRACE] = ACTIONS(81),
    [anon_sym_return] = ACTIONS(83),
    [anon_sym_continue] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_if] = ACTIONS(89),
    [anon_sym_end] = ACTIONS(179),
    [anon_sym_for] = ACTIONS(93),
    [anon_sym_parfor] = ACTIONS(95),
    [anon_sym_while] = ACTIONS(97),
    [anon_sym_switch] = ACTIONS(99),
    [anon_sym_global] = ACTIONS(101),
    [anon_sym_persistent] = ACTIONS(103),
    [anon_sym_arguments] = ACTIONS(105),
    [anon_sym_function] = ACTIONS(107),
    [anon_sym_properties] = ACTIONS(105),
    [anon_sym_get] = ACTIONS(105),
    [anon_sym_set] = ACTIONS(105),
    [anon_sym_methods] = ACTIONS(105),
    [anon_sym_events] = ACTIONS(105),
    [anon_sym_enumeration] = ACTIONS(105),
    [anon_sym_classdef] = ACTIONS(109),
    [anon_sym_try] = ACTIONS(111),
    [anon_sym_spmd] = ACTIONS(113),
    [aux_sym_number_token1] = ACTIONS(51),
    [aux_sym_number_token2] = ACTIONS(51),
    [aux_sym_number_token3] = ACTIONS(51),
    [anon_sym_true] = ACTIONS(115),
    [anon_sym_false] = ACTIONS(115),
    [anon_sym_CR] = ACTIONS(139),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(41),
  },
  [STATE(19)] = {
    [aux_sym__block] = STATE(46),
    [sym_block] = STATE(1487),
    [sym_identifier] = STATE(401),
    [sym__statement] = STATE(1174),
    [sym__expression] = STATE(939),
    [sym_parenthesis] = STATE(512),
    [sym__binary_expression] = STATE(910),
    [sym_binary_operator] = STATE(519),
    [sym_unary_operator] = STATE(528),
    [sym_indirect_access] = STATE(1361),
    [sym_field_expression] = STATE(594),
    [sym_not_operator] = STATE(549),
    [sym_metaclass_operator] = STATE(939),
    [sym_handle_operator] = STATE(939),
    [sym_comparison_operator] = STATE(498),
    [sym_boolean_operator] = STATE(498),
    [sym_postfix_operator] = STATE(512),
    [sym_string] = STATE(512),
    [sym_matrix] = STATE(512),
    [sym_cell] = STATE(471),
    [sym_ignored_argument] = STATE(1488),
    [sym_assignment] = STATE(1174),
    [sym_multioutput_variable] = STATE(1488),
    [sym_function_call] = STATE(401),
    [sym_command] = STATE(1174),
    [sym__range_element] = STATE(1509),
    [sym_range] = STATE(939),
    [sym_return_statement] = STATE(1174),
    [sym_continue_statement] = STATE(1174),
    [sym_break_statement] = STATE(1174),
    [sym_if_statement] = STATE(1174),
    [sym_for_statement] = STATE(1174),
    [sym_while_statement] = STATE(1174),
    [sym_switch_statement] = STATE(1174),
    [sym_lambda] = STATE(939),
    [sym_global_operator] = STATE(1174),
    [sym_persistent_operator] = STATE(1174),
    [sym__function_definition_with_end] = STATE(1209),
    [sym_class_definition] = STATE(1174),
    [sym_try_statement] = STATE(1174),
    [sym_spmd_statement] = STATE(1174),
    [sym_number] = STATE(512),
    [sym_boolean] = STATE(397),
    [sym__keywords] = STATE(373),
    [sym__end_of_line] = STATE(26),
    [aux_sym_elseif_clause_repeat1] = STATE(26),
    [anon_sym_SEMI] = ACTIONS(181),
    [anon_sym_COMMA] = ACTIONS(181),
    [anon_sym_LPAREN] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(69),
    [anon_sym_DASH] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(73),
    [anon_sym_QMARK] = ACTIONS(75),
    [anon_sym_AT] = ACTIONS(77),
    [anon_sym_LBRACK] = ACTIONS(79),
    [anon_sym_LF] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(81),
    [anon_sym_return] = ACTIONS(83),
    [anon_sym_continue] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_if] = ACTIONS(89),
    [anon_sym_end] = ACTIONS(183),
    [anon_sym_for] = ACTIONS(93),
    [anon_sym_parfor] = ACTIONS(95),
    [anon_sym_while] = ACTIONS(97),
    [anon_sym_switch] = ACTIONS(99),
    [anon_sym_global] = ACTIONS(101),
    [anon_sym_persistent] = ACTIONS(103),
    [anon_sym_arguments] = ACTIONS(105),
    [anon_sym_function] = ACTIONS(107),
    [anon_sym_properties] = ACTIONS(105),
    [anon_sym_get] = ACTIONS(105),
    [anon_sym_set] = ACTIONS(105),
    [anon_sym_methods] = ACTIONS(105),
    [anon_sym_events] = ACTIONS(105),
    [anon_sym_enumeration] = ACTIONS(105),
    [anon_sym_classdef] = ACTIONS(109),
    [anon_sym_try] = ACTIONS(111),
    [anon_sym_spmd] = ACTIONS(113),
    [aux_sym_number_token1] = ACTIONS(51),
    [aux_sym_number_token2] = ACTIONS(51),
    [aux_sym_number_token3] = ACTIONS(51),
    [anon_sym_true] = ACTIONS(115),
    [anon_sym_false] = ACTIONS(115),
    [anon_sym_CR] = ACTIONS(181),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(41),
  },
  [STATE(20)] = {
    [aux_sym__block] = STATE(46),
    [sym_block] = STATE(1489),
    [sym_identifier] = STATE(401),
    [sym__statement] = STATE(1174),
    [sym__expression] = STATE(939),
    [sym_parenthesis] = STATE(512),
    [sym__binary_expression] = STATE(910),
    [sym_binary_operator] = STATE(519),
    [sym_unary_operator] = STATE(528),
    [sym_indirect_access] = STATE(1361),
    [sym_field_expression] = STATE(594),
    [sym_not_operator] = STATE(549),
    [sym_metaclass_operator] = STATE(939),
    [sym_handle_operator] = STATE(939),
    [sym_comparison_operator] = STATE(498),
    [sym_boolean_operator] = STATE(498),
    [sym_postfix_operator] = STATE(512),
    [sym_string] = STATE(512),
    [sym_matrix] = STATE(512),
    [sym_cell] = STATE(471),
    [sym_ignored_argument] = STATE(1488),
    [sym_assignment] = STATE(1174),
    [sym_multioutput_variable] = STATE(1488),
    [sym_function_call] = STATE(401),
    [sym_command] = STATE(1174),
    [sym__range_element] = STATE(1509),
    [sym_range] = STATE(939),
    [sym_return_statement] = STATE(1174),
    [sym_continue_statement] = STATE(1174),
    [sym_break_statement] = STATE(1174),
    [sym_if_statement] = STATE(1174),
    [sym_for_statement] = STATE(1174),
    [sym_while_statement] = STATE(1174),
    [sym_switch_statement] = STATE(1174),
    [sym_lambda] = STATE(939),
    [sym_global_operator] = STATE(1174),
    [sym_persistent_operator] = STATE(1174),
    [sym__function_definition_with_end] = STATE(1209),
    [sym_class_definition] = STATE(1174),
    [sym_try_statement] = STATE(1174),
    [sym_spmd_statement] = STATE(1174),
    [sym_number] = STATE(512),
    [sym_boolean] = STATE(397),
    [sym__keywords] = STATE(373),
    [sym__end_of_line] = STATE(244),
    [aux_sym_elseif_clause_repeat1] = STATE(244),
    [anon_sym_SEMI] = ACTIONS(139),
    [anon_sym_COMMA] = ACTIONS(139),
    [anon_sym_LPAREN] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(69),
    [anon_sym_DASH] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(73),
    [anon_sym_QMARK] = ACTIONS(75),
    [anon_sym_AT] = ACTIONS(77),
    [anon_sym_LBRACK] = ACTIONS(79),
    [anon_sym_LF] = ACTIONS(139),
    [anon_sym_LBRACE] = ACTIONS(81),
    [anon_sym_return] = ACTIONS(83),
    [anon_sym_continue] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_if] = ACTIONS(89),
    [anon_sym_end] = ACTIONS(185),
    [anon_sym_for] = ACTIONS(93),
    [anon_sym_parfor] = ACTIONS(95),
    [anon_sym_while] = ACTIONS(97),
    [anon_sym_switch] = ACTIONS(99),
    [anon_sym_global] = ACTIONS(101),
    [anon_sym_persistent] = ACTIONS(103),
    [anon_sym_arguments] = ACTIONS(105),
    [anon_sym_function] = ACTIONS(107),
    [anon_sym_properties] = ACTIONS(105),
    [anon_sym_get] = ACTIONS(105),
    [anon_sym_set] = ACTIONS(105),
    [anon_sym_methods] = ACTIONS(105),
    [anon_sym_events] = ACTIONS(105),
    [anon_sym_enumeration] = ACTIONS(105),
    [anon_sym_classdef] = ACTIONS(109),
    [anon_sym_try] = ACTIONS(111),
    [anon_sym_spmd] = ACTIONS(113),
    [aux_sym_number_token1] = ACTIONS(51),
    [aux_sym_number_token2] = ACTIONS(51),
    [aux_sym_number_token3] = ACTIONS(51),
    [anon_sym_true] = ACTIONS(115),
    [anon_sym_false] = ACTIONS(115),
    [anon_sym_CR] = ACTIONS(139),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(41),
  },
  [STATE(21)] = {
    [aux_sym__block] = STATE(46),
    [sym_block] = STATE(1484),
    [sym_identifier] = STATE(401),
    [sym__statement] = STATE(1174),
    [sym__expression] = STATE(939),
    [sym_parenthesis] = STATE(512),
    [sym__binary_expression] = STATE(910),
    [sym_binary_operator] = STATE(519),
    [sym_unary_operator] = STATE(528),
    [sym_indirect_access] = STATE(1361),
    [sym_field_expression] = STATE(594),
    [sym_not_operator] = STATE(549),
    [sym_metaclass_operator] = STATE(939),
    [sym_handle_operator] = STATE(939),
    [sym_comparison_operator] = STATE(498),
    [sym_boolean_operator] = STATE(498),
    [sym_postfix_operator] = STATE(512),
    [sym_string] = STATE(512),
    [sym_matrix] = STATE(512),
    [sym_cell] = STATE(471),
    [sym_ignored_argument] = STATE(1488),
    [sym_assignment] = STATE(1174),
    [sym_multioutput_variable] = STATE(1488),
    [sym_function_call] = STATE(401),
    [sym_command] = STATE(1174),
    [sym__range_element] = STATE(1509),
    [sym_range] = STATE(939),
    [sym_return_statement] = STATE(1174),
    [sym_continue_statement] = STATE(1174),
    [sym_break_statement] = STATE(1174),
    [sym_if_statement] = STATE(1174),
    [sym_for_statement] = STATE(1174),
    [sym_while_statement] = STATE(1174),
    [sym_switch_statement] = STATE(1174),
    [sym_lambda] = STATE(939),
    [sym_global_operator] = STATE(1174),
    [sym_persistent_operator] = STATE(1174),
    [sym__function_definition_with_end] = STATE(1209),
    [sym_class_definition] = STATE(1174),
    [sym_try_statement] = STATE(1174),
    [sym_spmd_statement] = STATE(1174),
    [sym_number] = STATE(512),
    [sym_boolean] = STATE(397),
    [sym__keywords] = STATE(373),
    [sym__end_of_line] = STATE(244),
    [aux_sym_elseif_clause_repeat1] = STATE(244),
    [anon_sym_SEMI] = ACTIONS(139),
    [anon_sym_COMMA] = ACTIONS(139),
    [anon_sym_LPAREN] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(69),
    [anon_sym_DASH] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(73),
    [anon_sym_QMARK] = ACTIONS(75),
    [anon_sym_AT] = ACTIONS(77),
    [anon_sym_LBRACK] = ACTIONS(79),
    [anon_sym_LF] = ACTIONS(139),
    [anon_sym_LBRACE] = ACTIONS(81),
    [anon_sym_return] = ACTIONS(83),
    [anon_sym_continue] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_if] = ACTIONS(89),
    [anon_sym_end] = ACTIONS(187),
    [anon_sym_for] = ACTIONS(93),
    [anon_sym_parfor] = ACTIONS(95),
    [anon_sym_while] = ACTIONS(97),
    [anon_sym_switch] = ACTIONS(99),
    [anon_sym_global] = ACTIONS(101),
    [anon_sym_persistent] = ACTIONS(103),
    [anon_sym_arguments] = ACTIONS(105),
    [anon_sym_function] = ACTIONS(107),
    [anon_sym_properties] = ACTIONS(105),
    [anon_sym_get] = ACTIONS(105),
    [anon_sym_set] = ACTIONS(105),
    [anon_sym_methods] = ACTIONS(105),
    [anon_sym_events] = ACTIONS(105),
    [anon_sym_enumeration] = ACTIONS(105),
    [anon_sym_classdef] = ACTIONS(109),
    [anon_sym_try] = ACTIONS(111),
    [anon_sym_spmd] = ACTIONS(113),
    [aux_sym_number_token1] = ACTIONS(51),
    [aux_sym_number_token2] = ACTIONS(51),
    [aux_sym_number_token3] = ACTIONS(51),
    [anon_sym_true] = ACTIONS(115),
    [anon_sym_false] = ACTIONS(115),
    [anon_sym_CR] = ACTIONS(139),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(41),
  },
  [STATE(22)] = {
    [aux_sym__block] = STATE(46),
    [sym_block] = STATE(1451),
    [sym_identifier] = STATE(401),
    [sym__statement] = STATE(1174),
    [sym__expression] = STATE(939),
    [sym_parenthesis] = STATE(512),
    [sym__binary_expression] = STATE(910),
    [sym_binary_operator] = STATE(519),
    [sym_unary_operator] = STATE(528),
    [sym_indirect_access] = STATE(1361),
    [sym_field_expression] = STATE(594),
    [sym_not_operator] = STATE(549),
    [sym_metaclass_operator] = STATE(939),
    [sym_handle_operator] = STATE(939),
    [sym_comparison_operator] = STATE(498),
    [sym_boolean_operator] = STATE(498),
    [sym_postfix_operator] = STATE(512),
    [sym_string] = STATE(512),
    [sym_matrix] = STATE(512),
    [sym_cell] = STATE(471),
    [sym_ignored_argument] = STATE(1488),
    [sym_assignment] = STATE(1174),
    [sym_multioutput_variable] = STATE(1488),
    [sym_function_call] = STATE(401),
    [sym_command] = STATE(1174),
    [sym__range_element] = STATE(1509),
    [sym_range] = STATE(939),
    [sym_return_statement] = STATE(1174),
    [sym_continue_statement] = STATE(1174),
    [sym_break_statement] = STATE(1174),
    [sym_if_statement] = STATE(1174),
    [sym_for_statement] = STATE(1174),
    [sym_while_statement] = STATE(1174),
    [sym_switch_statement] = STATE(1174),
    [sym_lambda] = STATE(939),
    [sym_global_operator] = STATE(1174),
    [sym_persistent_operator] = STATE(1174),
    [sym__function_definition_with_end] = STATE(1209),
    [sym_class_definition] = STATE(1174),
    [sym_try_statement] = STATE(1174),
    [sym_spmd_statement] = STATE(1174),
    [sym_number] = STATE(512),
    [sym_boolean] = STATE(397),
    [sym__keywords] = STATE(373),
    [sym__end_of_line] = STATE(244),
    [aux_sym_elseif_clause_repeat1] = STATE(244),
    [anon_sym_SEMI] = ACTIONS(139),
    [anon_sym_COMMA] = ACTIONS(139),
    [anon_sym_LPAREN] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(69),
    [anon_sym_DASH] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(73),
    [anon_sym_QMARK] = ACTIONS(75),
    [anon_sym_AT] = ACTIONS(77),
    [anon_sym_LBRACK] = ACTIONS(79),
    [anon_sym_LF] = ACTIONS(139),
    [anon_sym_LBRACE] = ACTIONS(81),
    [anon_sym_return] = ACTIONS(83),
    [anon_sym_continue] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_if] = ACTIONS(89),
    [anon_sym_end] = ACTIONS(189),
    [anon_sym_for] = ACTIONS(93),
    [anon_sym_parfor] = ACTIONS(95),
    [anon_sym_while] = ACTIONS(97),
    [anon_sym_switch] = ACTIONS(99),
    [anon_sym_global] = ACTIONS(101),
    [anon_sym_persistent] = ACTIONS(103),
    [anon_sym_arguments] = ACTIONS(105),
    [anon_sym_function] = ACTIONS(107),
    [anon_sym_properties] = ACTIONS(105),
    [anon_sym_get] = ACTIONS(105),
    [anon_sym_set] = ACTIONS(105),
    [anon_sym_methods] = ACTIONS(105),
    [anon_sym_events] = ACTIONS(105),
    [anon_sym_enumeration] = ACTIONS(105),
    [anon_sym_classdef] = ACTIONS(109),
    [anon_sym_try] = ACTIONS(111),
    [anon_sym_spmd] = ACTIONS(113),
    [aux_sym_number_token1] = ACTIONS(51),
    [aux_sym_number_token2] = ACTIONS(51),
    [aux_sym_number_token3] = ACTIONS(51),
    [anon_sym_true] = ACTIONS(115),
    [anon_sym_false] = ACTIONS(115),
    [anon_sym_CR] = ACTIONS(139),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(41),
  },
  [STATE(23)] = {
    [aux_sym__block] = STATE(46),
    [sym_block] = STATE(1462),
    [sym_identifier] = STATE(401),
    [sym__statement] = STATE(1174),
    [sym__expression] = STATE(939),
    [sym_parenthesis] = STATE(512),
    [sym__binary_expression] = STATE(910),
    [sym_binary_operator] = STATE(519),
    [sym_unary_operator] = STATE(528),
    [sym_indirect_access] = STATE(1361),
    [sym_field_expression] = STATE(594),
    [sym_not_operator] = STATE(549),
    [sym_metaclass_operator] = STATE(939),
    [sym_handle_operator] = STATE(939),
    [sym_comparison_operator] = STATE(498),
    [sym_boolean_operator] = STATE(498),
    [sym_postfix_operator] = STATE(512),
    [sym_string] = STATE(512),
    [sym_matrix] = STATE(512),
    [sym_cell] = STATE(471),
    [sym_ignored_argument] = STATE(1488),
    [sym_assignment] = STATE(1174),
    [sym_multioutput_variable] = STATE(1488),
    [sym_function_call] = STATE(401),
    [sym_command] = STATE(1174),
    [sym__range_element] = STATE(1509),
    [sym_range] = STATE(939),
    [sym_return_statement] = STATE(1174),
    [sym_continue_statement] = STATE(1174),
    [sym_break_statement] = STATE(1174),
    [sym_if_statement] = STATE(1174),
    [sym_for_statement] = STATE(1174),
    [sym_while_statement] = STATE(1174),
    [sym_switch_statement] = STATE(1174),
    [sym_lambda] = STATE(939),
    [sym_global_operator] = STATE(1174),
    [sym_persistent_operator] = STATE(1174),
    [sym__function_definition_with_end] = STATE(1209),
    [sym_class_definition] = STATE(1174),
    [sym_try_statement] = STATE(1174),
    [sym_spmd_statement] = STATE(1174),
    [sym_number] = STATE(512),
    [sym_boolean] = STATE(397),
    [sym__keywords] = STATE(373),
    [sym__end_of_line] = STATE(244),
    [aux_sym_elseif_clause_repeat1] = STATE(244),
    [anon_sym_SEMI] = ACTIONS(139),
    [anon_sym_COMMA] = ACTIONS(139),
    [anon_sym_LPAREN] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(69),
    [anon_sym_DASH] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(73),
    [anon_sym_QMARK] = ACTIONS(75),
    [anon_sym_AT] = ACTIONS(77),
    [anon_sym_LBRACK] = ACTIONS(79),
    [anon_sym_LF] = ACTIONS(139),
    [anon_sym_LBRACE] = ACTIONS(81),
    [anon_sym_return] = ACTIONS(83),
    [anon_sym_continue] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_if] = ACTIONS(89),
    [anon_sym_end] = ACTIONS(191),
    [anon_sym_for] = ACTIONS(93),
    [anon_sym_parfor] = ACTIONS(95),
    [anon_sym_while] = ACTIONS(97),
    [anon_sym_switch] = ACTIONS(99),
    [anon_sym_global] = ACTIONS(101),
    [anon_sym_persistent] = ACTIONS(103),
    [anon_sym_arguments] = ACTIONS(105),
    [anon_sym_function] = ACTIONS(107),
    [anon_sym_properties] = ACTIONS(105),
    [anon_sym_get] = ACTIONS(105),
    [anon_sym_set] = ACTIONS(105),
    [anon_sym_methods] = ACTIONS(105),
    [anon_sym_events] = ACTIONS(105),
    [anon_sym_enumeration] = ACTIONS(105),
    [anon_sym_classdef] = ACTIONS(109),
    [anon_sym_try] = ACTIONS(111),
    [anon_sym_spmd] = ACTIONS(113),
    [aux_sym_number_token1] = ACTIONS(51),
    [aux_sym_number_token2] = ACTIONS(51),
    [aux_sym_number_token3] = ACTIONS(51),
    [anon_sym_true] = ACTIONS(115),
    [anon_sym_false] = ACTIONS(115),
    [anon_sym_CR] = ACTIONS(139),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(41),
  },
  [STATE(24)] = {
    [aux_sym__block] = STATE(46),
    [sym_block] = STATE(1454),
    [sym_identifier] = STATE(401),
    [sym__statement] = STATE(1174),
    [sym__expression] = STATE(939),
    [sym_parenthesis] = STATE(512),
    [sym__binary_expression] = STATE(910),
    [sym_binary_operator] = STATE(519),
    [sym_unary_operator] = STATE(528),
    [sym_indirect_access] = STATE(1361),
    [sym_field_expression] = STATE(594),
    [sym_not_operator] = STATE(549),
    [sym_metaclass_operator] = STATE(939),
    [sym_handle_operator] = STATE(939),
    [sym_comparison_operator] = STATE(498),
    [sym_boolean_operator] = STATE(498),
    [sym_postfix_operator] = STATE(512),
    [sym_string] = STATE(512),
    [sym_matrix] = STATE(512),
    [sym_cell] = STATE(471),
    [sym_ignored_argument] = STATE(1488),
    [sym_assignment] = STATE(1174),
    [sym_multioutput_variable] = STATE(1488),
    [sym_function_call] = STATE(401),
    [sym_command] = STATE(1174),
    [sym__range_element] = STATE(1509),
    [sym_range] = STATE(939),
    [sym_return_statement] = STATE(1174),
    [sym_continue_statement] = STATE(1174),
    [sym_break_statement] = STATE(1174),
    [sym_if_statement] = STATE(1174),
    [sym_for_statement] = STATE(1174),
    [sym_while_statement] = STATE(1174),
    [sym_switch_statement] = STATE(1174),
    [sym_lambda] = STATE(939),
    [sym_global_operator] = STATE(1174),
    [sym_persistent_operator] = STATE(1174),
    [sym__function_definition_with_end] = STATE(1209),
    [sym_class_definition] = STATE(1174),
    [sym_try_statement] = STATE(1174),
    [sym_spmd_statement] = STATE(1174),
    [sym_number] = STATE(512),
    [sym_boolean] = STATE(397),
    [sym__keywords] = STATE(373),
    [sym__end_of_line] = STATE(27),
    [aux_sym_elseif_clause_repeat1] = STATE(27),
    [anon_sym_SEMI] = ACTIONS(193),
    [anon_sym_COMMA] = ACTIONS(193),
    [anon_sym_LPAREN] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(69),
    [anon_sym_DASH] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(73),
    [anon_sym_QMARK] = ACTIONS(75),
    [anon_sym_AT] = ACTIONS(77),
    [anon_sym_LBRACK] = ACTIONS(79),
    [anon_sym_LF] = ACTIONS(193),
    [anon_sym_LBRACE] = ACTIONS(81),
    [anon_sym_return] = ACTIONS(83),
    [anon_sym_continue] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_if] = ACTIONS(89),
    [anon_sym_end] = ACTIONS(195),
    [anon_sym_for] = ACTIONS(93),
    [anon_sym_parfor] = ACTIONS(95),
    [anon_sym_while] = ACTIONS(97),
    [anon_sym_switch] = ACTIONS(99),
    [anon_sym_global] = ACTIONS(101),
    [anon_sym_persistent] = ACTIONS(103),
    [anon_sym_arguments] = ACTIONS(105),
    [anon_sym_function] = ACTIONS(107),
    [anon_sym_properties] = ACTIONS(105),
    [anon_sym_get] = ACTIONS(105),
    [anon_sym_set] = ACTIONS(105),
    [anon_sym_methods] = ACTIONS(105),
    [anon_sym_events] = ACTIONS(105),
    [anon_sym_enumeration] = ACTIONS(105),
    [anon_sym_classdef] = ACTIONS(109),
    [anon_sym_try] = ACTIONS(111),
    [anon_sym_spmd] = ACTIONS(113),
    [aux_sym_number_token1] = ACTIONS(51),
    [aux_sym_number_token2] = ACTIONS(51),
    [aux_sym_number_token3] = ACTIONS(51),
    [anon_sym_true] = ACTIONS(115),
    [anon_sym_false] = ACTIONS(115),
    [anon_sym_CR] = ACTIONS(193),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(41),
  },
  [STATE(25)] = {
    [aux_sym__block] = STATE(46),
    [sym_block] = STATE(1469),
    [sym_identifier] = STATE(401),
    [sym__statement] = STATE(1174),
    [sym__expression] = STATE(939),
    [sym_parenthesis] = STATE(512),
    [sym__binary_expression] = STATE(910),
    [sym_binary_operator] = STATE(519),
    [sym_unary_operator] = STATE(528),
    [sym_indirect_access] = STATE(1361),
    [sym_field_expression] = STATE(594),
    [sym_not_operator] = STATE(549),
    [sym_metaclass_operator] = STATE(939),
    [sym_handle_operator] = STATE(939),
    [sym_comparison_operator] = STATE(498),
    [sym_boolean_operator] = STATE(498),
    [sym_postfix_operator] = STATE(512),
    [sym_string] = STATE(512),
    [sym_matrix] = STATE(512),
    [sym_cell] = STATE(471),
    [sym_ignored_argument] = STATE(1488),
    [sym_assignment] = STATE(1174),
    [sym_multioutput_variable] = STATE(1488),
    [sym_function_call] = STATE(401),
    [sym_command] = STATE(1174),
    [sym__range_element] = STATE(1509),
    [sym_range] = STATE(939),
    [sym_return_statement] = STATE(1174),
    [sym_continue_statement] = STATE(1174),
    [sym_break_statement] = STATE(1174),
    [sym_if_statement] = STATE(1174),
    [sym_for_statement] = STATE(1174),
    [sym_while_statement] = STATE(1174),
    [sym_switch_statement] = STATE(1174),
    [sym_lambda] = STATE(939),
    [sym_global_operator] = STATE(1174),
    [sym_persistent_operator] = STATE(1174),
    [sym__function_definition_with_end] = STATE(1209),
    [sym_class_definition] = STATE(1174),
    [sym_try_statement] = STATE(1174),
    [sym_spmd_statement] = STATE(1174),
    [sym_number] = STATE(512),
    [sym_boolean] = STATE(397),
    [sym__keywords] = STATE(373),
    [sym__end_of_line] = STATE(28),
    [aux_sym_elseif_clause_repeat1] = STATE(28),
    [anon_sym_SEMI] = ACTIONS(197),
    [anon_sym_COMMA] = ACTIONS(197),
    [anon_sym_LPAREN] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(69),
    [anon_sym_DASH] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(73),
    [anon_sym_QMARK] = ACTIONS(75),
    [anon_sym_AT] = ACTIONS(77),
    [anon_sym_LBRACK] = ACTIONS(79),
    [anon_sym_LF] = ACTIONS(197),
    [anon_sym_LBRACE] = ACTIONS(81),
    [anon_sym_return] = ACTIONS(83),
    [anon_sym_continue] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_if] = ACTIONS(89),
    [anon_sym_end] = ACTIONS(199),
    [anon_sym_for] = ACTIONS(93),
    [anon_sym_parfor] = ACTIONS(95),
    [anon_sym_while] = ACTIONS(97),
    [anon_sym_switch] = ACTIONS(99),
    [anon_sym_global] = ACTIONS(101),
    [anon_sym_persistent] = ACTIONS(103),
    [anon_sym_arguments] = ACTIONS(105),
    [anon_sym_function] = ACTIONS(107),
    [anon_sym_properties] = ACTIONS(105),
    [anon_sym_get] = ACTIONS(105),
    [anon_sym_set] = ACTIONS(105),
    [anon_sym_methods] = ACTIONS(105),
    [anon_sym_events] = ACTIONS(105),
    [anon_sym_enumeration] = ACTIONS(105),
    [anon_sym_classdef] = ACTIONS(109),
    [anon_sym_try] = ACTIONS(111),
    [anon_sym_spmd] = ACTIONS(113),
    [aux_sym_number_token1] = ACTIONS(51),
    [aux_sym_number_token2] = ACTIONS(51),
    [aux_sym_number_token3] = ACTIONS(51),
    [anon_sym_true] = ACTIONS(115),
    [anon_sym_false] = ACTIONS(115),
    [anon_sym_CR] = ACTIONS(197),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(41),
  },
  [STATE(26)] = {
    [aux_sym__block] = STATE(46),
    [sym_block] = STATE(1474),
    [sym_identifier] = STATE(401),
    [sym__statement] = STATE(1174),
    [sym__expression] = STATE(939),
    [sym_parenthesis] = STATE(512),
    [sym__binary_expression] = STATE(910),
    [sym_binary_operator] = STATE(519),
    [sym_unary_operator] = STATE(528),
    [sym_indirect_access] = STATE(1361),
    [sym_field_expression] = STATE(594),
    [sym_not_operator] = STATE(549),
    [sym_metaclass_operator] = STATE(939),
    [sym_handle_operator] = STATE(939),
    [sym_comparison_operator] = STATE(498),
    [sym_boolean_operator] = STATE(498),
    [sym_postfix_operator] = STATE(512),
    [sym_string] = STATE(512),
    [sym_matrix] = STATE(512),
    [sym_cell] = STATE(471),
    [sym_ignored_argument] = STATE(1488),
    [sym_assignment] = STATE(1174),
    [sym_multioutput_variable] = STATE(1488),
    [sym_function_call] = STATE(401),
    [sym_command] = STATE(1174),
    [sym__range_element] = STATE(1509),
    [sym_range] = STATE(939),
    [sym_return_statement] = STATE(1174),
    [sym_continue_statement] = STATE(1174),
    [sym_break_statement] = STATE(1174),
    [sym_if_statement] = STATE(1174),
    [sym_for_statement] = STATE(1174),
    [sym_while_statement] = STATE(1174),
    [sym_switch_statement] = STATE(1174),
    [sym_lambda] = STATE(939),
    [sym_global_operator] = STATE(1174),
    [sym_persistent_operator] = STATE(1174),
    [sym__function_definition_with_end] = STATE(1209),
    [sym_class_definition] = STATE(1174),
    [sym_try_statement] = STATE(1174),
    [sym_spmd_statement] = STATE(1174),
    [sym_number] = STATE(512),
    [sym_boolean] = STATE(397),
    [sym__keywords] = STATE(373),
    [sym__end_of_line] = STATE(244),
    [aux_sym_elseif_clause_repeat1] = STATE(244),
    [anon_sym_SEMI] = ACTIONS(139),
    [anon_sym_COMMA] = ACTIONS(139),
    [anon_sym_LPAREN] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(69),
    [anon_sym_DASH] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(73),
    [anon_sym_QMARK] = ACTIONS(75),
    [anon_sym_AT] = ACTIONS(77),
    [anon_sym_LBRACK] = ACTIONS(79),
    [anon_sym_LF] = ACTIONS(139),
    [anon_sym_LBRACE] = ACTIONS(81),
    [anon_sym_return] = ACTIONS(83),
    [anon_sym_continue] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_if] = ACTIONS(89),
    [anon_sym_end] = ACTIONS(91),
    [anon_sym_for] = ACTIONS(93),
    [anon_sym_parfor] = ACTIONS(95),
    [anon_sym_while] = ACTIONS(97),
    [anon_sym_switch] = ACTIONS(99),
    [anon_sym_global] = ACTIONS(101),
    [anon_sym_persistent] = ACTIONS(103),
    [anon_sym_arguments] = ACTIONS(105),
    [anon_sym_function] = ACTIONS(107),
    [anon_sym_properties] = ACTIONS(105),
    [anon_sym_get] = ACTIONS(105),
    [anon_sym_set] = ACTIONS(105),
    [anon_sym_methods] = ACTIONS(105),
    [anon_sym_events] = ACTIONS(105),
    [anon_sym_enumeration] = ACTIONS(105),
    [anon_sym_classdef] = ACTIONS(109),
    [anon_sym_try] = ACTIONS(111),
    [anon_sym_spmd] = ACTIONS(113),
    [aux_sym_number_token1] = ACTIONS(51),
    [aux_sym_number_token2] = ACTIONS(51),
    [aux_sym_number_token3] = ACTIONS(51),
    [anon_sym_true] = ACTIONS(115),
    [anon_sym_false] = ACTIONS(115),
    [anon_sym_CR] = ACTIONS(139),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(41),
  },
  [STATE(27)] = {
    [aux_sym__block] = STATE(46),
    [sym_block] = STATE(1497),
    [sym_identifier] = STATE(401),
    [sym__statement] = STATE(1174),
    [sym__expression] = STATE(939),
    [sym_parenthesis] = STATE(512),
    [sym__binary_expression] = STATE(910),
    [sym_binary_operator] = STATE(519),
    [sym_unary_operator] = STATE(528),
    [sym_indirect_access] = STATE(1361),
    [sym_field_expression] = STATE(594),
    [sym_not_operator] = STATE(549),
    [sym_metaclass_operator] = STATE(939),
    [sym_handle_operator] = STATE(939),
    [sym_comparison_operator] = STATE(498),
    [sym_boolean_operator] = STATE(498),
    [sym_postfix_operator] = STATE(512),
    [sym_string] = STATE(512),
    [sym_matrix] = STATE(512),
    [sym_cell] = STATE(471),
    [sym_ignored_argument] = STATE(1488),
    [sym_assignment] = STATE(1174),
    [sym_multioutput_variable] = STATE(1488),
    [sym_function_call] = STATE(401),
    [sym_command] = STATE(1174),
    [sym__range_element] = STATE(1509),
    [sym_range] = STATE(939),
    [sym_return_statement] = STATE(1174),
    [sym_continue_statement] = STATE(1174),
    [sym_break_statement] = STATE(1174),
    [sym_if_statement] = STATE(1174),
    [sym_for_statement] = STATE(1174),
    [sym_while_statement] = STATE(1174),
    [sym_switch_statement] = STATE(1174),
    [sym_lambda] = STATE(939),
    [sym_global_operator] = STATE(1174),
    [sym_persistent_operator] = STATE(1174),
    [sym__function_definition_with_end] = STATE(1209),
    [sym_class_definition] = STATE(1174),
    [sym_try_statement] = STATE(1174),
    [sym_spmd_statement] = STATE(1174),
    [sym_number] = STATE(512),
    [sym_boolean] = STATE(397),
    [sym__keywords] = STATE(373),
    [sym__end_of_line] = STATE(244),
    [aux_sym_elseif_clause_repeat1] = STATE(244),
    [anon_sym_SEMI] = ACTIONS(139),
    [anon_sym_COMMA] = ACTIONS(139),
    [anon_sym_LPAREN] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(69),
    [anon_sym_DASH] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(73),
    [anon_sym_QMARK] = ACTIONS(75),
    [anon_sym_AT] = ACTIONS(77),
    [anon_sym_LBRACK] = ACTIONS(79),
    [anon_sym_LF] = ACTIONS(139),
    [anon_sym_LBRACE] = ACTIONS(81),
    [anon_sym_return] = ACTIONS(83),
    [anon_sym_continue] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_if] = ACTIONS(89),
    [anon_sym_end] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(93),
    [anon_sym_parfor] = ACTIONS(95),
    [anon_sym_while] = ACTIONS(97),
    [anon_sym_switch] = ACTIONS(99),
    [anon_sym_global] = ACTIONS(101),
    [anon_sym_persistent] = ACTIONS(103),
    [anon_sym_arguments] = ACTIONS(105),
    [anon_sym_function] = ACTIONS(107),
    [anon_sym_properties] = ACTIONS(105),
    [anon_sym_get] = ACTIONS(105),
    [anon_sym_set] = ACTIONS(105),
    [anon_sym_methods] = ACTIONS(105),
    [anon_sym_events] = ACTIONS(105),
    [anon_sym_enumeration] = ACTIONS(105),
    [anon_sym_classdef] = ACTIONS(109),
    [anon_sym_try] = ACTIONS(111),
    [anon_sym_spmd] = ACTIONS(113),
    [aux_sym_number_token1] = ACTIONS(51),
    [aux_sym_number_token2] = ACTIONS(51),
    [aux_sym_number_token3] = ACTIONS(51),
    [anon_sym_true] = ACTIONS(115),
    [anon_sym_false] = ACTIONS(115),
    [anon_sym_CR] = ACTIONS(139),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(41),
  },
  [STATE(28)] = {
    [aux_sym__block] = STATE(46),
    [sym_block] = STATE(1502),
    [sym_identifier] = STATE(401),
    [sym__statement] = STATE(1174),
    [sym__expression] = STATE(939),
    [sym_parenthesis] = STATE(512),
    [sym__binary_expression] = STATE(910),
    [sym_binary_operator] = STATE(519),
    [sym_unary_operator] = STATE(528),
    [sym_indirect_access] = STATE(1361),
    [sym_field_expression] = STATE(594),
    [sym_not_operator] = STATE(549),
    [sym_metaclass_operator] = STATE(939),
    [sym_handle_operator] = STATE(939),
    [sym_comparison_operator] = STATE(498),
    [sym_boolean_operator] = STATE(498),
    [sym_postfix_operator] = STATE(512),
    [sym_string] = STATE(512),
    [sym_matrix] = STATE(512),
    [sym_cell] = STATE(471),
    [sym_ignored_argument] = STATE(1488),
    [sym_assignment] = STATE(1174),
    [sym_multioutput_variable] = STATE(1488),
    [sym_function_call] = STATE(401),
    [sym_command] = STATE(1174),
    [sym__range_element] = STATE(1509),
    [sym_range] = STATE(939),
    [sym_return_statement] = STATE(1174),
    [sym_continue_statement] = STATE(1174),
    [sym_break_statement] = STATE(1174),
    [sym_if_statement] = STATE(1174),
    [sym_for_statement] = STATE(1174),
    [sym_while_statement] = STATE(1174),
    [sym_switch_statement] = STATE(1174),
    [sym_lambda] = STATE(939),
    [sym_global_operator] = STATE(1174),
    [sym_persistent_operator] = STATE(1174),
    [sym__function_definition_with_end] = STATE(1209),
    [sym_class_definition] = STATE(1174),
    [sym_try_statement] = STATE(1174),
    [sym_spmd_statement] = STATE(1174),
    [sym_number] = STATE(512),
    [sym_boolean] = STATE(397),
    [sym__keywords] = STATE(373),
    [sym__end_of_line] = STATE(244),
    [aux_sym_elseif_clause_repeat1] = STATE(244),
    [anon_sym_SEMI] = ACTIONS(139),
    [anon_sym_COMMA] = ACTIONS(139),
    [anon_sym_LPAREN] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(69),
    [anon_sym_DASH] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(73),
    [anon_sym_QMARK] = ACTIONS(75),
    [anon_sym_AT] = ACTIONS(77),
    [anon_sym_LBRACK] = ACTIONS(79),
    [anon_sym_LF] = ACTIONS(139),
    [anon_sym_LBRACE] = ACTIONS(81),
    [anon_sym_return] = ACTIONS(83),
    [anon_sym_continue] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_if] = ACTIONS(89),
    [anon_sym_end] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(93),
    [anon_sym_parfor] = ACTIONS(95),
    [anon_sym_while] = ACTIONS(97),
    [anon_sym_switch] = ACTIONS(99),
    [anon_sym_global] = ACTIONS(101),
    [anon_sym_persistent] = ACTIONS(103),
    [anon_sym_arguments] = ACTIONS(105),
    [anon_sym_function] = ACTIONS(107),
    [anon_sym_properties] = ACTIONS(105),
    [anon_sym_get] = ACTIONS(105),
    [anon_sym_set] = ACTIONS(105),
    [anon_sym_methods] = ACTIONS(105),
    [anon_sym_events] = ACTIONS(105),
    [anon_sym_enumeration] = ACTIONS(105),
    [anon_sym_classdef] = ACTIONS(109),
    [anon_sym_try] = ACTIONS(111),
    [anon_sym_spmd] = ACTIONS(113),
    [aux_sym_number_token1] = ACTIONS(51),
    [aux_sym_number_token2] = ACTIONS(51),
    [aux_sym_number_token3] = ACTIONS(51),
    [anon_sym_true] = ACTIONS(115),
    [anon_sym_false] = ACTIONS(115),
    [anon_sym_CR] = ACTIONS(139),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(41),
  },
  [STATE(29)] = {
    [aux_sym__block] = STATE(68),
    [sym_block] = STATE(1228),
    [sym_identifier] = STATE(401),
    [sym__statement] = STATE(1186),
    [sym__expression] = STATE(930),
    [sym_parenthesis] = STATE(512),
    [sym__binary_expression] = STATE(910),
    [sym_binary_operator] = STATE(519),
    [sym_unary_operator] = STATE(528),
    [sym_indirect_access] = STATE(1361),
    [sym_field_expression] = STATE(594),
    [sym_not_operator] = STATE(549),
    [sym_metaclass_operator] = STATE(930),
    [sym_handle_operator] = STATE(930),
    [sym_comparison_operator] = STATE(498),
    [sym_boolean_operator] = STATE(498),
    [sym_postfix_operator] = STATE(512),
    [sym_string] = STATE(512),
    [sym_matrix] = STATE(512),
    [sym_cell] = STATE(471),
    [sym_ignored_argument] = STATE(1488),
    [sym_assignment] = STATE(1186),
    [sym_multioutput_variable] = STATE(1488),
    [sym_function_call] = STATE(401),
    [sym_command] = STATE(1186),
    [sym__range_element] = STATE(1509),
    [sym_range] = STATE(930),
    [sym_return_statement] = STATE(1186),
    [sym_continue_statement] = STATE(1186),
    [sym_break_statement] = STATE(1186),
    [sym_if_statement] = STATE(1186),
    [sym_for_statement] = STATE(1186),
    [sym_while_statement] = STATE(1186),
    [sym_switch_statement] = STATE(1186),
    [sym_lambda] = STATE(930),
    [sym_global_operator] = STATE(1186),
    [sym_persistent_operator] = STATE(1186),
    [sym_arguments_statement] = STATE(49),
    [sym__function_definition_with_end] = STATE(1191),
    [sym_class_definition] = STATE(1186),
    [sym_try_statement] = STATE(1186),
    [sym_spmd_statement] = STATE(1186),
    [sym_number] = STATE(512),
    [sym_boolean] = STATE(397),
    [sym__keywords] = STATE(373),
    [aux_sym_function_definition_repeat1] = STATE(49),
    [ts_builtin_sym_end] = ACTIONS(205),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(207),
    [anon_sym_for] = ACTIONS(29),
    [anon_sym_parfor] = ACTIONS(31),
    [anon_sym_while] = ACTIONS(33),
    [anon_sym_switch] = ACTIONS(35),
    [anon_sym_global] = ACTIONS(37),
    [anon_sym_persistent] = ACTIONS(39),
    [anon_sym_arguments] = ACTIONS(209),
    [anon_sym_function] = ACTIONS(211),
    [anon_sym_endfunction] = ACTIONS(213),
    [anon_sym_properties] = ACTIONS(41),
    [anon_sym_get] = ACTIONS(41),
    [anon_sym_set] = ACTIONS(41),
    [anon_sym_methods] = ACTIONS(41),
    [anon_sym_events] = ACTIONS(41),
    [anon_sym_enumeration] = ACTIONS(41),
    [anon_sym_classdef] = ACTIONS(45),
    [anon_sym_try] = ACTIONS(47),
    [anon_sym_spmd] = ACTIONS(49),
    [aux_sym_number_token1] = ACTIONS(51),
    [aux_sym_number_token2] = ACTIONS(53),
    [aux_sym_number_token3] = ACTIONS(53),
    [anon_sym_true] = ACTIONS(55),
    [anon_sym_false] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(41),
  },
  [STATE(30)] = {
    [aux_sym__block] = STATE(68),
    [sym_block] = STATE(1213),
    [sym_identifier] = STATE(401),
    [sym__statement] = STATE(1186),
    [sym__expression] = STATE(930),
    [sym_parenthesis] = STATE(512),
    [sym__binary_expression] = STATE(910),
    [sym_binary_operator] = STATE(519),
    [sym_unary_operator] = STATE(528),
    [sym_indirect_access] = STATE(1361),
    [sym_field_expression] = STATE(594),
    [sym_not_operator] = STATE(549),
    [sym_metaclass_operator] = STATE(930),
    [sym_handle_operator] = STATE(930),
    [sym_comparison_operator] = STATE(498),
    [sym_boolean_operator] = STATE(498),
    [sym_postfix_operator] = STATE(512),
    [sym_string] = STATE(512),
    [sym_matrix] = STATE(512),
    [sym_cell] = STATE(471),
    [sym_ignored_argument] = STATE(1488),
    [sym_assignment] = STATE(1186),
    [sym_multioutput_variable] = STATE(1488),
    [sym_function_call] = STATE(401),
    [sym_command] = STATE(1186),
    [sym__range_element] = STATE(1509),
    [sym_range] = STATE(930),
    [sym_return_statement] = STATE(1186),
    [sym_continue_statement] = STATE(1186),
    [sym_break_statement] = STATE(1186),
    [sym_if_statement] = STATE(1186),
    [sym_for_statement] = STATE(1186),
    [sym_while_statement] = STATE(1186),
    [sym_switch_statement] = STATE(1186),
    [sym_lambda] = STATE(930),
    [sym_global_operator] = STATE(1186),
    [sym_persistent_operator] = STATE(1186),
    [sym_arguments_statement] = STATE(32),
    [sym__function_definition_with_end] = STATE(1191),
    [sym_class_definition] = STATE(1186),
    [sym_try_statement] = STATE(1186),
    [sym_spmd_statement] = STATE(1186),
    [sym_number] = STATE(512),
    [sym_boolean] = STATE(397),
    [sym__keywords] = STATE(373),
    [aux_sym_function_definition_repeat1] = STATE(32),
    [ts_builtin_sym_end] = ACTIONS(215),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(217),
    [anon_sym_for] = ACTIONS(29),
    [anon_sym_parfor] = ACTIONS(31),
    [anon_sym_while] = ACTIONS(33),
    [anon_sym_switch] = ACTIONS(35),
    [anon_sym_global] = ACTIONS(37),
    [anon_sym_persistent] = ACTIONS(39),
    [anon_sym_arguments] = ACTIONS(209),
    [anon_sym_function] = ACTIONS(211),
    [anon_sym_endfunction] = ACTIONS(219),
    [anon_sym_properties] = ACTIONS(41),
    [anon_sym_get] = ACTIONS(41),
    [anon_sym_set] = ACTIONS(41),
    [anon_sym_methods] = ACTIONS(41),
    [anon_sym_events] = ACTIONS(41),
    [anon_sym_enumeration] = ACTIONS(41),
    [anon_sym_classdef] = ACTIONS(45),
    [anon_sym_try] = ACTIONS(47),
    [anon_sym_spmd] = ACTIONS(49),
    [aux_sym_number_token1] = ACTIONS(51),
    [aux_sym_number_token2] = ACTIONS(53),
    [aux_sym_number_token3] = ACTIONS(53),
    [anon_sym_true] = ACTIONS(55),
    [anon_sym_false] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(41),
  },
  [STATE(31)] = {
    [aux_sym__block] = STATE(68),
    [sym_block] = STATE(1364),
    [sym_identifier] = STATE(401),
    [sym__statement] = STATE(1186),
    [sym__expression] = STATE(930),
    [sym_parenthesis] = STATE(512),
    [sym__binary_expression] = STATE(910),
    [sym_binary_operator] = STATE(519),
    [sym_unary_operator] = STATE(528),
    [sym_indirect_access] = STATE(1361),
    [sym_field_expression] = STATE(594),
    [sym_not_operator] = STATE(549),
    [sym_metaclass_operator] = STATE(930),
    [sym_handle_operator] = STATE(930),
    [sym_comparison_operator] = STATE(498),
    [sym_boolean_operator] = STATE(498),
    [sym_postfix_operator] = STATE(512),
    [sym_string] = STATE(512),
    [sym_matrix] = STATE(512),
    [sym_cell] = STATE(471),
    [sym_ignored_argument] = STATE(1488),
    [sym_assignment] = STATE(1186),
    [sym_multioutput_variable] = STATE(1488),
    [sym_function_call] = STATE(401),
    [sym_command] = STATE(1186),
    [sym__range_element] = STATE(1509),
    [sym_range] = STATE(930),
    [sym_return_statement] = STATE(1186),
    [sym_continue_statement] = STATE(1186),
    [sym_break_statement] = STATE(1186),
    [sym_if_statement] = STATE(1186),
    [sym_for_statement] = STATE(1186),
    [sym_while_statement] = STATE(1186),
    [sym_switch_statement] = STATE(1186),
    [sym_lambda] = STATE(930),
    [sym_global_operator] = STATE(1186),
    [sym_persistent_operator] = STATE(1186),
    [sym_arguments_statement] = STATE(40),
    [sym__function_definition_with_end] = STATE(1191),
    [sym_class_definition] = STATE(1186),
    [sym_try_statement] = STATE(1186),
    [sym_spmd_statement] = STATE(1186),
    [sym_number] = STATE(512),
    [sym_boolean] = STATE(397),
    [sym__keywords] = STATE(373),
    [aux_sym_function_definition_repeat1] = STATE(40),
    [ts_builtin_sym_end] = ACTIONS(205),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(221),
    [anon_sym_for] = ACTIONS(29),
    [anon_sym_parfor] = ACTIONS(31),
    [anon_sym_while] = ACTIONS(33),
    [anon_sym_switch] = ACTIONS(35),
    [anon_sym_global] = ACTIONS(37),
    [anon_sym_persistent] = ACTIONS(39),
    [anon_sym_arguments] = ACTIONS(209),
    [anon_sym_function] = ACTIONS(211),
    [anon_sym_endfunction] = ACTIONS(223),
    [anon_sym_properties] = ACTIONS(41),
    [anon_sym_get] = ACTIONS(41),
    [anon_sym_set] = ACTIONS(41),
    [anon_sym_methods] = ACTIONS(41),
    [anon_sym_events] = ACTIONS(41),
    [anon_sym_enumeration] = ACTIONS(41),
    [anon_sym_classdef] = ACTIONS(45),
    [anon_sym_try] = ACTIONS(47),
    [anon_sym_spmd] = ACTIONS(49),
    [aux_sym_number_token1] = ACTIONS(51),
    [aux_sym_number_token2] = ACTIONS(53),
    [aux_sym_number_token3] = ACTIONS(53),
    [anon_sym_true] = ACTIONS(55),
    [anon_sym_false] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(41),
  },
  [STATE(32)] = {
    [aux_sym__block] = STATE(68),
    [sym_block] = STATE(1364),
    [sym_identifier] = STATE(401),
    [sym__statement] = STATE(1186),
    [sym__expression] = STATE(930),
    [sym_parenthesis] = STATE(512),
    [sym__binary_expression] = STATE(910),
    [sym_binary_operator] = STATE(519),
    [sym_unary_operator] = STATE(528),
    [sym_indirect_access] = STATE(1361),
    [sym_field_expression] = STATE(594),
    [sym_not_operator] = STATE(549),
    [sym_metaclass_operator] = STATE(930),
    [sym_handle_operator] = STATE(930),
    [sym_comparison_operator] = STATE(498),
    [sym_boolean_operator] = STATE(498),
    [sym_postfix_operator] = STATE(512),
    [sym_string] = STATE(512),
    [sym_matrix] = STATE(512),
    [sym_cell] = STATE(471),
    [sym_ignored_argument] = STATE(1488),
    [sym_assignment] = STATE(1186),
    [sym_multioutput_variable] = STATE(1488),
    [sym_function_call] = STATE(401),
    [sym_command] = STATE(1186),
    [sym__range_element] = STATE(1509),
    [sym_range] = STATE(930),
    [sym_return_statement] = STATE(1186),
    [sym_continue_statement] = STATE(1186),
    [sym_break_statement] = STATE(1186),
    [sym_if_statement] = STATE(1186),
    [sym_for_statement] = STATE(1186),
    [sym_while_statement] = STATE(1186),
    [sym_switch_statement] = STATE(1186),
    [sym_lambda] = STATE(930),
    [sym_global_operator] = STATE(1186),
    [sym_persistent_operator] = STATE(1186),
    [sym_arguments_statement] = STATE(368),
    [sym__function_definition_with_end] = STATE(1191),
    [sym_class_definition] = STATE(1186),
    [sym_try_statement] = STATE(1186),
    [sym_spmd_statement] = STATE(1186),
    [sym_number] = STATE(512),
    [sym_boolean] = STATE(397),
    [sym__keywords] = STATE(373),
    [aux_sym_function_definition_repeat1] = STATE(368),
    [ts_builtin_sym_end] = ACTIONS(205),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(221),
    [anon_sym_for] = ACTIONS(29),
    [anon_sym_parfor] = ACTIONS(31),
    [anon_sym_while] = ACTIONS(33),
    [anon_sym_switch] = ACTIONS(35),
    [anon_sym_global] = ACTIONS(37),
    [anon_sym_persistent] = ACTIONS(39),
    [anon_sym_arguments] = ACTIONS(209),
    [anon_sym_function] = ACTIONS(211),
    [anon_sym_endfunction] = ACTIONS(223),
    [anon_sym_properties] = ACTIONS(41),
    [anon_sym_get] = ACTIONS(41),
    [anon_sym_set] = ACTIONS(41),
    [anon_sym_methods] = ACTIONS(41),
    [anon_sym_events] = ACTIONS(41),
    [anon_sym_enumeration] = ACTIONS(41),
    [anon_sym_classdef] = ACTIONS(45),
    [anon_sym_try] = ACTIONS(47),
    [anon_sym_spmd] = ACTIONS(49),
    [aux_sym_number_token1] = ACTIONS(51),
    [aux_sym_number_token2] = ACTIONS(53),
    [aux_sym_number_token3] = ACTIONS(53),
    [anon_sym_true] = ACTIONS(55),
    [anon_sym_false] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(41),
  },
  [STATE(33)] = {
    [aux_sym__block] = STATE(68),
    [sym_block] = STATE(1304),
    [sym_identifier] = STATE(401),
    [sym__statement] = STATE(1186),
    [sym__expression] = STATE(930),
    [sym_parenthesis] = STATE(512),
    [sym__binary_expression] = STATE(910),
    [sym_binary_operator] = STATE(519),
    [sym_unary_operator] = STATE(528),
    [sym_indirect_access] = STATE(1361),
    [sym_field_expression] = STATE(594),
    [sym_not_operator] = STATE(549),
    [sym_metaclass_operator] = STATE(930),
    [sym_handle_operator] = STATE(930),
    [sym_comparison_operator] = STATE(498),
    [sym_boolean_operator] = STATE(498),
    [sym_postfix_operator] = STATE(512),
    [sym_string] = STATE(512),
    [sym_matrix] = STATE(512),
    [sym_cell] = STATE(471),
    [sym_ignored_argument] = STATE(1488),
    [sym_assignment] = STATE(1186),
    [sym_multioutput_variable] = STATE(1488),
    [sym_function_call] = STATE(401),
    [sym_command] = STATE(1186),
    [sym__range_element] = STATE(1509),
    [sym_range] = STATE(930),
    [sym_return_statement] = STATE(1186),
    [sym_continue_statement] = STATE(1186),
    [sym_break_statement] = STATE(1186),
    [sym_if_statement] = STATE(1186),
    [sym_for_statement] = STATE(1186),
    [sym_while_statement] = STATE(1186),
    [sym_switch_statement] = STATE(1186),
    [sym_lambda] = STATE(930),
    [sym_global_operator] = STATE(1186),
    [sym_persistent_operator] = STATE(1186),
    [sym_arguments_statement] = STATE(368),
    [sym__function_definition_with_end] = STATE(1191),
    [sym_class_definition] = STATE(1186),
    [sym_try_statement] = STATE(1186),
    [sym_spmd_statement] = STATE(1186),
    [sym_number] = STATE(512),
    [sym_boolean] = STATE(397),
    [sym__keywords] = STATE(373),
    [aux_sym_function_definition_repeat1] = STATE(368),
    [ts_builtin_sym_end] = ACTIONS(225),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(227),
    [anon_sym_for] = ACTIONS(29),
    [anon_sym_parfor] = ACTIONS(31),
    [anon_sym_while] = ACTIONS(33),
    [anon_sym_switch] = ACTIONS(35),
    [anon_sym_global] = ACTIONS(37),
    [anon_sym_persistent] = ACTIONS(39),
    [anon_sym_arguments] = ACTIONS(209),
    [anon_sym_function] = ACTIONS(211),
    [anon_sym_endfunction] = ACTIONS(229),
    [anon_sym_properties] = ACTIONS(41),
    [anon_sym_get] = ACTIONS(41),
    [anon_sym_set] = ACTIONS(41),
    [anon_sym_methods] = ACTIONS(41),
    [anon_sym_events] = ACTIONS(41),
    [anon_sym_enumeration] = ACTIONS(41),
    [anon_sym_classdef] = ACTIONS(45),
    [anon_sym_try] = ACTIONS(47),
    [anon_sym_spmd] = ACTIONS(49),
    [aux_sym_number_token1] = ACTIONS(51),
    [aux_sym_number_token2] = ACTIONS(53),
    [aux_sym_number_token3] = ACTIONS(53),
    [anon_sym_true] = ACTIONS(55),
    [anon_sym_false] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(41),
  },
  [STATE(34)] = {
    [aux_sym__block] = STATE(68),
    [sym_block] = STATE(1354),
    [sym_identifier] = STATE(401),
    [sym__statement] = STATE(1186),
    [sym__expression] = STATE(930),
    [sym_parenthesis] = STATE(512),
    [sym__binary_expression] = STATE(910),
    [sym_binary_operator] = STATE(519),
    [sym_unary_operator] = STATE(528),
    [sym_indirect_access] = STATE(1361),
    [sym_field_expression] = STATE(594),
    [sym_not_operator] = STATE(549),
    [sym_metaclass_operator] = STATE(930),
    [sym_handle_operator] = STATE(930),
    [sym_comparison_operator] = STATE(498),
    [sym_boolean_operator] = STATE(498),
    [sym_postfix_operator] = STATE(512),
    [sym_string] = STATE(512),
    [sym_matrix] = STATE(512),
    [sym_cell] = STATE(471),
    [sym_ignored_argument] = STATE(1488),
    [sym_assignment] = STATE(1186),
    [sym_multioutput_variable] = STATE(1488),
    [sym_function_call] = STATE(401),
    [sym_command] = STATE(1186),
    [sym__range_element] = STATE(1509),
    [sym_range] = STATE(930),
    [sym_return_statement] = STATE(1186),
    [sym_continue_statement] = STATE(1186),
    [sym_break_statement] = STATE(1186),
    [sym_if_statement] = STATE(1186),
    [sym_for_statement] = STATE(1186),
    [sym_while_statement] = STATE(1186),
    [sym_switch_statement] = STATE(1186),
    [sym_lambda] = STATE(930),
    [sym_global_operator] = STATE(1186),
    [sym_persistent_operator] = STATE(1186),
    [sym_arguments_statement] = STATE(42),
    [sym__function_definition_with_end] = STATE(1191),
    [sym_class_definition] = STATE(1186),
    [sym_try_statement] = STATE(1186),
    [sym_spmd_statement] = STATE(1186),
    [sym_number] = STATE(512),
    [sym_boolean] = STATE(397),
    [sym__keywords] = STATE(373),
    [aux_sym_function_definition_repeat1] = STATE(42),
    [ts_builtin_sym_end] = ACTIONS(231),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(233),
    [anon_sym_for] = ACTIONS(29),
    [anon_sym_parfor] = ACTIONS(31),
    [anon_sym_while] = ACTIONS(33),
    [anon_sym_switch] = ACTIONS(35),
    [anon_sym_global] = ACTIONS(37),
    [anon_sym_persistent] = ACTIONS(39),
    [anon_sym_arguments] = ACTIONS(209),
    [anon_sym_function] = ACTIONS(211),
    [anon_sym_endfunction] = ACTIONS(235),
    [anon_sym_properties] = ACTIONS(41),
    [anon_sym_get] = ACTIONS(41),
    [anon_sym_set] = ACTIONS(41),
    [anon_sym_methods] = ACTIONS(41),
    [anon_sym_events] = ACTIONS(41),
    [anon_sym_enumeration] = ACTIONS(41),
    [anon_sym_classdef] = ACTIONS(45),
    [anon_sym_try] = ACTIONS(47),
    [anon_sym_spmd] = ACTIONS(49),
    [aux_sym_number_token1] = ACTIONS(51),
    [aux_sym_number_token2] = ACTIONS(53),
    [aux_sym_number_token3] = ACTIONS(53),
    [anon_sym_true] = ACTIONS(55),
    [anon_sym_false] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(41),
  },
  [STATE(35)] = {
    [aux_sym__block] = STATE(68),
    [sym_block] = STATE(1217),
    [sym_identifier] = STATE(401),
    [sym__statement] = STATE(1186),
    [sym__expression] = STATE(930),
    [sym_parenthesis] = STATE(512),
    [sym__binary_expression] = STATE(910),
    [sym_binary_operator] = STATE(519),
    [sym_unary_operator] = STATE(528),
    [sym_indirect_access] = STATE(1361),
    [sym_field_expression] = STATE(594),
    [sym_not_operator] = STATE(549),
    [sym_metaclass_operator] = STATE(930),
    [sym_handle_operator] = STATE(930),
    [sym_comparison_operator] = STATE(498),
    [sym_boolean_operator] = STATE(498),
    [sym_postfix_operator] = STATE(512),
    [sym_string] = STATE(512),
    [sym_matrix] = STATE(512),
    [sym_cell] = STATE(471),
    [sym_ignored_argument] = STATE(1488),
    [sym_assignment] = STATE(1186),
    [sym_multioutput_variable] = STATE(1488),
    [sym_function_call] = STATE(401),
    [sym_command] = STATE(1186),
    [sym__range_element] = STATE(1509),
    [sym_range] = STATE(930),
    [sym_return_statement] = STATE(1186),
    [sym_continue_statement] = STATE(1186),
    [sym_break_statement] = STATE(1186),
    [sym_if_statement] = STATE(1186),
    [sym_for_statement] = STATE(1186),
    [sym_while_statement] = STATE(1186),
    [sym_switch_statement] = STATE(1186),
    [sym_lambda] = STATE(930),
    [sym_global_operator] = STATE(1186),
    [sym_persistent_operator] = STATE(1186),
    [sym_arguments_statement] = STATE(33),
    [sym__function_definition_with_end] = STATE(1191),
    [sym_class_definition] = STATE(1186),
    [sym_try_statement] = STATE(1186),
    [sym_spmd_statement] = STATE(1186),
    [sym_number] = STATE(512),
    [sym_boolean] = STATE(397),
    [sym__keywords] = STATE(373),
    [aux_sym_function_definition_repeat1] = STATE(33),
    [ts_builtin_sym_end] = ACTIONS(237),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(239),
    [anon_sym_for] = ACTIONS(29),
    [anon_sym_parfor] = ACTIONS(31),
    [anon_sym_while] = ACTIONS(33),
    [anon_sym_switch] = ACTIONS(35),
    [anon_sym_global] = ACTIONS(37),
    [anon_sym_persistent] = ACTIONS(39),
    [anon_sym_arguments] = ACTIONS(209),
    [anon_sym_function] = ACTIONS(211),
    [anon_sym_endfunction] = ACTIONS(241),
    [anon_sym_properties] = ACTIONS(41),
    [anon_sym_get] = ACTIONS(41),
    [anon_sym_set] = ACTIONS(41),
    [anon_sym_methods] = ACTIONS(41),
    [anon_sym_events] = ACTIONS(41),
    [anon_sym_enumeration] = ACTIONS(41),
    [anon_sym_classdef] = ACTIONS(45),
    [anon_sym_try] = ACTIONS(47),
    [anon_sym_spmd] = ACTIONS(49),
    [aux_sym_number_token1] = ACTIONS(51),
    [aux_sym_number_token2] = ACTIONS(53),
    [aux_sym_number_token3] = ACTIONS(53),
    [anon_sym_true] = ACTIONS(55),
    [anon_sym_false] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(41),
  },
  [STATE(36)] = {
    [aux_sym__block] = STATE(68),
    [sym_block] = STATE(1360),
    [sym_identifier] = STATE(401),
    [sym__statement] = STATE(1186),
    [sym__expression] = STATE(930),
    [sym_parenthesis] = STATE(512),
    [sym__binary_expression] = STATE(910),
    [sym_binary_operator] = STATE(519),
    [sym_unary_operator] = STATE(528),
    [sym_indirect_access] = STATE(1361),
    [sym_field_expression] = STATE(594),
    [sym_not_operator] = STATE(549),
    [sym_metaclass_operator] = STATE(930),
    [sym_handle_operator] = STATE(930),
    [sym_comparison_operator] = STATE(498),
    [sym_boolean_operator] = STATE(498),
    [sym_postfix_operator] = STATE(512),
    [sym_string] = STATE(512),
    [sym_matrix] = STATE(512),
    [sym_cell] = STATE(471),
    [sym_ignored_argument] = STATE(1488),
    [sym_assignment] = STATE(1186),
    [sym_multioutput_variable] = STATE(1488),
    [sym_function_call] = STATE(401),
    [sym_command] = STATE(1186),
    [sym__range_element] = STATE(1509),
    [sym_range] = STATE(930),
    [sym_return_statement] = STATE(1186),
    [sym_continue_statement] = STATE(1186),
    [sym_break_statement] = STATE(1186),
    [sym_if_statement] = STATE(1186),
    [sym_for_statement] = STATE(1186),
    [sym_while_statement] = STATE(1186),
    [sym_switch_statement] = STATE(1186),
    [sym_lambda] = STATE(930),
    [sym_global_operator] = STATE(1186),
    [sym_persistent_operator] = STATE(1186),
    [sym_arguments_statement] = STATE(43),
    [sym__function_definition_with_end] = STATE(1191),
    [sym_class_definition] = STATE(1186),
    [sym_try_statement] = STATE(1186),
    [sym_spmd_statement] = STATE(1186),
    [sym_number] = STATE(512),
    [sym_boolean] = STATE(397),
    [sym__keywords] = STATE(373),
    [aux_sym_function_definition_repeat1] = STATE(43),
    [ts_builtin_sym_end] = ACTIONS(215),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(243),
    [anon_sym_for] = ACTIONS(29),
    [anon_sym_parfor] = ACTIONS(31),
    [anon_sym_while] = ACTIONS(33),
    [anon_sym_switch] = ACTIONS(35),
    [anon_sym_global] = ACTIONS(37),
    [anon_sym_persistent] = ACTIONS(39),
    [anon_sym_arguments] = ACTIONS(209),
    [anon_sym_function] = ACTIONS(211),
    [anon_sym_endfunction] = ACTIONS(245),
    [anon_sym_properties] = ACTIONS(41),
    [anon_sym_get] = ACTIONS(41),
    [anon_sym_set] = ACTIONS(41),
    [anon_sym_methods] = ACTIONS(41),
    [anon_sym_events] = ACTIONS(41),
    [anon_sym_enumeration] = ACTIONS(41),
    [anon_sym_classdef] = ACTIONS(45),
    [anon_sym_try] = ACTIONS(47),
    [anon_sym_spmd] = ACTIONS(49),
    [aux_sym_number_token1] = ACTIONS(51),
    [aux_sym_number_token2] = ACTIONS(53),
    [aux_sym_number_token3] = ACTIONS(53),
    [anon_sym_true] = ACTIONS(55),
    [anon_sym_false] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(41),
  },
  [STATE(37)] = {
    [aux_sym__block] = STATE(68),
    [sym_block] = STATE(1216),
    [sym_identifier] = STATE(401),
    [sym__statement] = STATE(1186),
    [sym__expression] = STATE(930),
    [sym_parenthesis] = STATE(512),
    [sym__binary_expression] = STATE(910),
    [sym_binary_operator] = STATE(519),
    [sym_unary_operator] = STATE(528),
    [sym_indirect_access] = STATE(1361),
    [sym_field_expression] = STATE(594),
    [sym_not_operator] = STATE(549),
    [sym_metaclass_operator] = STATE(930),
    [sym_handle_operator] = STATE(930),
    [sym_comparison_operator] = STATE(498),
    [sym_boolean_operator] = STATE(498),
    [sym_postfix_operator] = STATE(512),
    [sym_string] = STATE(512),
    [sym_matrix] = STATE(512),
    [sym_cell] = STATE(471),
    [sym_ignored_argument] = STATE(1488),
    [sym_assignment] = STATE(1186),
    [sym_multioutput_variable] = STATE(1488),
    [sym_function_call] = STATE(401),
    [sym_command] = STATE(1186),
    [sym__range_element] = STATE(1509),
    [sym_range] = STATE(930),
    [sym_return_statement] = STATE(1186),
    [sym_continue_statement] = STATE(1186),
    [sym_break_statement] = STATE(1186),
    [sym_if_statement] = STATE(1186),
    [sym_for_statement] = STATE(1186),
    [sym_while_statement] = STATE(1186),
    [sym_switch_statement] = STATE(1186),
    [sym_lambda] = STATE(930),
    [sym_global_operator] = STATE(1186),
    [sym_persistent_operator] = STATE(1186),
    [sym_arguments_statement] = STATE(44),
    [sym__function_definition_with_end] = STATE(1191),
    [sym_class_definition] = STATE(1186),
    [sym_try_statement] = STATE(1186),
    [sym_spmd_statement] = STATE(1186),
    [sym_number] = STATE(512),
    [sym_boolean] = STATE(397),
    [sym__keywords] = STATE(373),
    [aux_sym_function_definition_repeat1] = STATE(44),
    [ts_builtin_sym_end] = ACTIONS(237),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(247),
    [anon_sym_for] = ACTIONS(29),
    [anon_sym_parfor] = ACTIONS(31),
    [anon_sym_while] = ACTIONS(33),
    [anon_sym_switch] = ACTIONS(35),
    [anon_sym_global] = ACTIONS(37),
    [anon_sym_persistent] = ACTIONS(39),
    [anon_sym_arguments] = ACTIONS(209),
    [anon_sym_function] = ACTIONS(211),
    [anon_sym_endfunction] = ACTIONS(249),
    [anon_sym_properties] = ACTIONS(41),
    [anon_sym_get] = ACTIONS(41),
    [anon_sym_set] = ACTIONS(41),
    [anon_sym_methods] = ACTIONS(41),
    [anon_sym_events] = ACTIONS(41),
    [anon_sym_enumeration] = ACTIONS(41),
    [anon_sym_classdef] = ACTIONS(45),
    [anon_sym_try] = ACTIONS(47),
    [anon_sym_spmd] = ACTIONS(49),
    [aux_sym_number_token1] = ACTIONS(51),
    [aux_sym_number_token2] = ACTIONS(53),
    [aux_sym_number_token3] = ACTIONS(53),
    [anon_sym_true] = ACTIONS(55),
    [anon_sym_false] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(41),
  },
  [STATE(38)] = {
    [aux_sym__block] = STATE(68),
    [sym_block] = STATE(1216),
    [sym_identifier] = STATE(401),
    [sym__statement] = STATE(1186),
    [sym__expression] = STATE(930),
    [sym_parenthesis] = STATE(512),
    [sym__binary_expression] = STATE(910),
    [sym_binary_operator] = STATE(519),
    [sym_unary_operator] = STATE(528),
    [sym_indirect_access] = STATE(1361),
    [sym_field_expression] = STATE(594),
    [sym_not_operator] = STATE(549),
    [sym_metaclass_operator] = STATE(930),
    [sym_handle_operator] = STATE(930),
    [sym_comparison_operator] = STATE(498),
    [sym_boolean_operator] = STATE(498),
    [sym_postfix_operator] = STATE(512),
    [sym_string] = STATE(512),
    [sym_matrix] = STATE(512),
    [sym_cell] = STATE(471),
    [sym_ignored_argument] = STATE(1488),
    [sym_assignment] = STATE(1186),
    [sym_multioutput_variable] = STATE(1488),
    [sym_function_call] = STATE(401),
    [sym_command] = STATE(1186),
    [sym__range_element] = STATE(1509),
    [sym_range] = STATE(930),
    [sym_return_statement] = STATE(1186),
    [sym_continue_statement] = STATE(1186),
    [sym_break_statement] = STATE(1186),
    [sym_if_statement] = STATE(1186),
    [sym_for_statement] = STATE(1186),
    [sym_while_statement] = STATE(1186),
    [sym_switch_statement] = STATE(1186),
    [sym_lambda] = STATE(930),
    [sym_global_operator] = STATE(1186),
    [sym_persistent_operator] = STATE(1186),
    [sym_arguments_statement] = STATE(368),
    [sym__function_definition_with_end] = STATE(1191),
    [sym_class_definition] = STATE(1186),
    [sym_try_statement] = STATE(1186),
    [sym_spmd_statement] = STATE(1186),
    [sym_number] = STATE(512),
    [sym_boolean] = STATE(397),
    [sym__keywords] = STATE(373),
    [aux_sym_function_definition_repeat1] = STATE(368),
    [ts_builtin_sym_end] = ACTIONS(237),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(247),
    [anon_sym_for] = ACTIONS(29),
    [anon_sym_parfor] = ACTIONS(31),
    [anon_sym_while] = ACTIONS(33),
    [anon_sym_switch] = ACTIONS(35),
    [anon_sym_global] = ACTIONS(37),
    [anon_sym_persistent] = ACTIONS(39),
    [anon_sym_arguments] = ACTIONS(209),
    [anon_sym_function] = ACTIONS(211),
    [anon_sym_endfunction] = ACTIONS(249),
    [anon_sym_properties] = ACTIONS(41),
    [anon_sym_get] = ACTIONS(41),
    [anon_sym_set] = ACTIONS(41),
    [anon_sym_methods] = ACTIONS(41),
    [anon_sym_events] = ACTIONS(41),
    [anon_sym_enumeration] = ACTIONS(41),
    [anon_sym_classdef] = ACTIONS(45),
    [anon_sym_try] = ACTIONS(47),
    [anon_sym_spmd] = ACTIONS(49),
    [aux_sym_number_token1] = ACTIONS(51),
    [aux_sym_number_token2] = ACTIONS(53),
    [aux_sym_number_token3] = ACTIONS(53),
    [anon_sym_true] = ACTIONS(55),
    [anon_sym_false] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(41),
  },
  [STATE(39)] = {
    [aux_sym__block] = STATE(68),
    [sym_block] = STATE(1217),
    [sym_identifier] = STATE(401),
    [sym__statement] = STATE(1186),
    [sym__expression] = STATE(930),
    [sym_parenthesis] = STATE(512),
    [sym__binary_expression] = STATE(910),
    [sym_binary_operator] = STATE(519),
    [sym_unary_operator] = STATE(528),
    [sym_indirect_access] = STATE(1361),
    [sym_field_expression] = STATE(594),
    [sym_not_operator] = STATE(549),
    [sym_metaclass_operator] = STATE(930),
    [sym_handle_operator] = STATE(930),
    [sym_comparison_operator] = STATE(498),
    [sym_boolean_operator] = STATE(498),
    [sym_postfix_operator] = STATE(512),
    [sym_string] = STATE(512),
    [sym_matrix] = STATE(512),
    [sym_cell] = STATE(471),
    [sym_ignored_argument] = STATE(1488),
    [sym_assignment] = STATE(1186),
    [sym_multioutput_variable] = STATE(1488),
    [sym_function_call] = STATE(401),
    [sym_command] = STATE(1186),
    [sym__range_element] = STATE(1509),
    [sym_range] = STATE(930),
    [sym_return_statement] = STATE(1186),
    [sym_continue_statement] = STATE(1186),
    [sym_break_statement] = STATE(1186),
    [sym_if_statement] = STATE(1186),
    [sym_for_statement] = STATE(1186),
    [sym_while_statement] = STATE(1186),
    [sym_switch_statement] = STATE(1186),
    [sym_lambda] = STATE(930),
    [sym_global_operator] = STATE(1186),
    [sym_persistent_operator] = STATE(1186),
    [sym_arguments_statement] = STATE(368),
    [sym__function_definition_with_end] = STATE(1191),
    [sym_class_definition] = STATE(1186),
    [sym_try_statement] = STATE(1186),
    [sym_spmd_statement] = STATE(1186),
    [sym_number] = STATE(512),
    [sym_boolean] = STATE(397),
    [sym__keywords] = STATE(373),
    [aux_sym_function_definition_repeat1] = STATE(368),
    [ts_builtin_sym_end] = ACTIONS(237),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(239),
    [anon_sym_for] = ACTIONS(29),
    [anon_sym_parfor] = ACTIONS(31),
    [anon_sym_while] = ACTIONS(33),
    [anon_sym_switch] = ACTIONS(35),
    [anon_sym_global] = ACTIONS(37),
    [anon_sym_persistent] = ACTIONS(39),
    [anon_sym_arguments] = ACTIONS(209),
    [anon_sym_function] = ACTIONS(211),
    [anon_sym_endfunction] = ACTIONS(241),
    [anon_sym_properties] = ACTIONS(41),
    [anon_sym_get] = ACTIONS(41),
    [anon_sym_set] = ACTIONS(41),
    [anon_sym_methods] = ACTIONS(41),
    [anon_sym_events] = ACTIONS(41),
    [anon_sym_enumeration] = ACTIONS(41),
    [anon_sym_classdef] = ACTIONS(45),
    [anon_sym_try] = ACTIONS(47),
    [anon_sym_spmd] = ACTIONS(49),
    [aux_sym_number_token1] = ACTIONS(51),
    [aux_sym_number_token2] = ACTIONS(53),
    [aux_sym_number_token3] = ACTIONS(53),
    [anon_sym_true] = ACTIONS(55),
    [anon_sym_false] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(41),
  },
  [STATE(40)] = {
    [aux_sym__block] = STATE(68),
    [sym_block] = STATE(1251),
    [sym_identifier] = STATE(401),
    [sym__statement] = STATE(1186),
    [sym__expression] = STATE(930),
    [sym_parenthesis] = STATE(512),
    [sym__binary_expression] = STATE(910),
    [sym_binary_operator] = STATE(519),
    [sym_unary_operator] = STATE(528),
    [sym_indirect_access] = STATE(1361),
    [sym_field_expression] = STATE(594),
    [sym_not_operator] = STATE(549),
    [sym_metaclass_operator] = STATE(930),
    [sym_handle_operator] = STATE(930),
    [sym_comparison_operator] = STATE(498),
    [sym_boolean_operator] = STATE(498),
    [sym_postfix_operator] = STATE(512),
    [sym_string] = STATE(512),
    [sym_matrix] = STATE(512),
    [sym_cell] = STATE(471),
    [sym_ignored_argument] = STATE(1488),
    [sym_assignment] = STATE(1186),
    [sym_multioutput_variable] = STATE(1488),
    [sym_function_call] = STATE(401),
    [sym_command] = STATE(1186),
    [sym__range_element] = STATE(1509),
    [sym_range] = STATE(930),
    [sym_return_statement] = STATE(1186),
    [sym_continue_statement] = STATE(1186),
    [sym_break_statement] = STATE(1186),
    [sym_if_statement] = STATE(1186),
    [sym_for_statement] = STATE(1186),
    [sym_while_statement] = STATE(1186),
    [sym_switch_statement] = STATE(1186),
    [sym_lambda] = STATE(930),
    [sym_global_operator] = STATE(1186),
    [sym_persistent_operator] = STATE(1186),
    [sym_arguments_statement] = STATE(368),
    [sym__function_definition_with_end] = STATE(1191),
    [sym_class_definition] = STATE(1186),
    [sym_try_statement] = STATE(1186),
    [sym_spmd_statement] = STATE(1186),
    [sym_number] = STATE(512),
    [sym_boolean] = STATE(397),
    [sym__keywords] = STATE(373),
    [aux_sym_function_definition_repeat1] = STATE(368),
    [ts_builtin_sym_end] = ACTIONS(251),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(253),
    [anon_sym_for] = ACTIONS(29),
    [anon_sym_parfor] = ACTIONS(31),
    [anon_sym_while] = ACTIONS(33),
    [anon_sym_switch] = ACTIONS(35),
    [anon_sym_global] = ACTIONS(37),
    [anon_sym_persistent] = ACTIONS(39),
    [anon_sym_arguments] = ACTIONS(209),
    [anon_sym_function] = ACTIONS(211),
    [anon_sym_endfunction] = ACTIONS(255),
    [anon_sym_properties] = ACTIONS(41),
    [anon_sym_get] = ACTIONS(41),
    [anon_sym_set] = ACTIONS(41),
    [anon_sym_methods] = ACTIONS(41),
    [anon_sym_events] = ACTIONS(41),
    [anon_sym_enumeration] = ACTIONS(41),
    [anon_sym_classdef] = ACTIONS(45),
    [anon_sym_try] = ACTIONS(47),
    [anon_sym_spmd] = ACTIONS(49),
    [aux_sym_number_token1] = ACTIONS(51),
    [aux_sym_number_token2] = ACTIONS(53),
    [aux_sym_number_token3] = ACTIONS(53),
    [anon_sym_true] = ACTIONS(55),
    [anon_sym_false] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(41),
  },
  [STATE(41)] = {
    [aux_sym__block] = STATE(68),
    [sym_block] = STATE(1303),
    [sym_identifier] = STATE(401),
    [sym__statement] = STATE(1186),
    [sym__expression] = STATE(930),
    [sym_parenthesis] = STATE(512),
    [sym__binary_expression] = STATE(910),
    [sym_binary_operator] = STATE(519),
    [sym_unary_operator] = STATE(528),
    [sym_indirect_access] = STATE(1361),
    [sym_field_expression] = STATE(594),
    [sym_not_operator] = STATE(549),
    [sym_metaclass_operator] = STATE(930),
    [sym_handle_operator] = STATE(930),
    [sym_comparison_operator] = STATE(498),
    [sym_boolean_operator] = STATE(498),
    [sym_postfix_operator] = STATE(512),
    [sym_string] = STATE(512),
    [sym_matrix] = STATE(512),
    [sym_cell] = STATE(471),
    [sym_ignored_argument] = STATE(1488),
    [sym_assignment] = STATE(1186),
    [sym_multioutput_variable] = STATE(1488),
    [sym_function_call] = STATE(401),
    [sym_command] = STATE(1186),
    [sym__range_element] = STATE(1509),
    [sym_range] = STATE(930),
    [sym_return_statement] = STATE(1186),
    [sym_continue_statement] = STATE(1186),
    [sym_break_statement] = STATE(1186),
    [sym_if_statement] = STATE(1186),
    [sym_for_statement] = STATE(1186),
    [sym_while_statement] = STATE(1186),
    [sym_switch_statement] = STATE(1186),
    [sym_lambda] = STATE(930),
    [sym_global_operator] = STATE(1186),
    [sym_persistent_operator] = STATE(1186),
    [sym_arguments_statement] = STATE(47),
    [sym__function_definition_with_end] = STATE(1191),
    [sym_class_definition] = STATE(1186),
    [sym_try_statement] = STATE(1186),
    [sym_spmd_statement] = STATE(1186),
    [sym_number] = STATE(512),
    [sym_boolean] = STATE(397),
    [sym__keywords] = STATE(373),
    [aux_sym_function_definition_repeat1] = STATE(47),
    [ts_builtin_sym_end] = ACTIONS(257),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(259),
    [anon_sym_for] = ACTIONS(29),
    [anon_sym_parfor] = ACTIONS(31),
    [anon_sym_while] = ACTIONS(33),
    [anon_sym_switch] = ACTIONS(35),
    [anon_sym_global] = ACTIONS(37),
    [anon_sym_persistent] = ACTIONS(39),
    [anon_sym_arguments] = ACTIONS(209),
    [anon_sym_function] = ACTIONS(211),
    [anon_sym_endfunction] = ACTIONS(261),
    [anon_sym_properties] = ACTIONS(41),
    [anon_sym_get] = ACTIONS(41),
    [anon_sym_set] = ACTIONS(41),
    [anon_sym_methods] = ACTIONS(41),
    [anon_sym_events] = ACTIONS(41),
    [anon_sym_enumeration] = ACTIONS(41),
    [anon_sym_classdef] = ACTIONS(45),
    [anon_sym_try] = ACTIONS(47),
    [anon_sym_spmd] = ACTIONS(49),
    [aux_sym_number_token1] = ACTIONS(51),
    [aux_sym_number_token2] = ACTIONS(53),
    [aux_sym_number_token3] = ACTIONS(53),
    [anon_sym_true] = ACTIONS(55),
    [anon_sym_false] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(41),
  },
  [STATE(42)] = {
    [aux_sym__block] = STATE(68),
    [sym_block] = STATE(1303),
    [sym_identifier] = STATE(401),
    [sym__statement] = STATE(1186),
    [sym__expression] = STATE(930),
    [sym_parenthesis] = STATE(512),
    [sym__binary_expression] = STATE(910),
    [sym_binary_operator] = STATE(519),
    [sym_unary_operator] = STATE(528),
    [sym_indirect_access] = STATE(1361),
    [sym_field_expression] = STATE(594),
    [sym_not_operator] = STATE(549),
    [sym_metaclass_operator] = STATE(930),
    [sym_handle_operator] = STATE(930),
    [sym_comparison_operator] = STATE(498),
    [sym_boolean_operator] = STATE(498),
    [sym_postfix_operator] = STATE(512),
    [sym_string] = STATE(512),
    [sym_matrix] = STATE(512),
    [sym_cell] = STATE(471),
    [sym_ignored_argument] = STATE(1488),
    [sym_assignment] = STATE(1186),
    [sym_multioutput_variable] = STATE(1488),
    [sym_function_call] = STATE(401),
    [sym_command] = STATE(1186),
    [sym__range_element] = STATE(1509),
    [sym_range] = STATE(930),
    [sym_return_statement] = STATE(1186),
    [sym_continue_statement] = STATE(1186),
    [sym_break_statement] = STATE(1186),
    [sym_if_statement] = STATE(1186),
    [sym_for_statement] = STATE(1186),
    [sym_while_statement] = STATE(1186),
    [sym_switch_statement] = STATE(1186),
    [sym_lambda] = STATE(930),
    [sym_global_operator] = STATE(1186),
    [sym_persistent_operator] = STATE(1186),
    [sym_arguments_statement] = STATE(368),
    [sym__function_definition_with_end] = STATE(1191),
    [sym_class_definition] = STATE(1186),
    [sym_try_statement] = STATE(1186),
    [sym_spmd_statement] = STATE(1186),
    [sym_number] = STATE(512),
    [sym_boolean] = STATE(397),
    [sym__keywords] = STATE(373),
    [aux_sym_function_definition_repeat1] = STATE(368),
    [ts_builtin_sym_end] = ACTIONS(257),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(259),
    [anon_sym_for] = ACTIONS(29),
    [anon_sym_parfor] = ACTIONS(31),
    [anon_sym_while] = ACTIONS(33),
    [anon_sym_switch] = ACTIONS(35),
    [anon_sym_global] = ACTIONS(37),
    [anon_sym_persistent] = ACTIONS(39),
    [anon_sym_arguments] = ACTIONS(209),
    [anon_sym_function] = ACTIONS(211),
    [anon_sym_endfunction] = ACTIONS(261),
    [anon_sym_properties] = ACTIONS(41),
    [anon_sym_get] = ACTIONS(41),
    [anon_sym_set] = ACTIONS(41),
    [anon_sym_methods] = ACTIONS(41),
    [anon_sym_events] = ACTIONS(41),
    [anon_sym_enumeration] = ACTIONS(41),
    [anon_sym_classdef] = ACTIONS(45),
    [anon_sym_try] = ACTIONS(47),
    [anon_sym_spmd] = ACTIONS(49),
    [aux_sym_number_token1] = ACTIONS(51),
    [aux_sym_number_token2] = ACTIONS(53),
    [aux_sym_number_token3] = ACTIONS(53),
    [anon_sym_true] = ACTIONS(55),
    [anon_sym_false] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(41),
  },
  [STATE(43)] = {
    [aux_sym__block] = STATE(68),
    [sym_block] = STATE(1228),
    [sym_identifier] = STATE(401),
    [sym__statement] = STATE(1186),
    [sym__expression] = STATE(930),
    [sym_parenthesis] = STATE(512),
    [sym__binary_expression] = STATE(910),
    [sym_binary_operator] = STATE(519),
    [sym_unary_operator] = STATE(528),
    [sym_indirect_access] = STATE(1361),
    [sym_field_expression] = STATE(594),
    [sym_not_operator] = STATE(549),
    [sym_metaclass_operator] = STATE(930),
    [sym_handle_operator] = STATE(930),
    [sym_comparison_operator] = STATE(498),
    [sym_boolean_operator] = STATE(498),
    [sym_postfix_operator] = STATE(512),
    [sym_string] = STATE(512),
    [sym_matrix] = STATE(512),
    [sym_cell] = STATE(471),
    [sym_ignored_argument] = STATE(1488),
    [sym_assignment] = STATE(1186),
    [sym_multioutput_variable] = STATE(1488),
    [sym_function_call] = STATE(401),
    [sym_command] = STATE(1186),
    [sym__range_element] = STATE(1509),
    [sym_range] = STATE(930),
    [sym_return_statement] = STATE(1186),
    [sym_continue_statement] = STATE(1186),
    [sym_break_statement] = STATE(1186),
    [sym_if_statement] = STATE(1186),
    [sym_for_statement] = STATE(1186),
    [sym_while_statement] = STATE(1186),
    [sym_switch_statement] = STATE(1186),
    [sym_lambda] = STATE(930),
    [sym_global_operator] = STATE(1186),
    [sym_persistent_operator] = STATE(1186),
    [sym_arguments_statement] = STATE(368),
    [sym__function_definition_with_end] = STATE(1191),
    [sym_class_definition] = STATE(1186),
    [sym_try_statement] = STATE(1186),
    [sym_spmd_statement] = STATE(1186),
    [sym_number] = STATE(512),
    [sym_boolean] = STATE(397),
    [sym__keywords] = STATE(373),
    [aux_sym_function_definition_repeat1] = STATE(368),
    [ts_builtin_sym_end] = ACTIONS(205),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(207),
    [anon_sym_for] = ACTIONS(29),
    [anon_sym_parfor] = ACTIONS(31),
    [anon_sym_while] = ACTIONS(33),
    [anon_sym_switch] = ACTIONS(35),
    [anon_sym_global] = ACTIONS(37),
    [anon_sym_persistent] = ACTIONS(39),
    [anon_sym_arguments] = ACTIONS(209),
    [anon_sym_function] = ACTIONS(211),
    [anon_sym_endfunction] = ACTIONS(213),
    [anon_sym_properties] = ACTIONS(41),
    [anon_sym_get] = ACTIONS(41),
    [anon_sym_set] = ACTIONS(41),
    [anon_sym_methods] = ACTIONS(41),
    [anon_sym_events] = ACTIONS(41),
    [anon_sym_enumeration] = ACTIONS(41),
    [anon_sym_classdef] = ACTIONS(45),
    [anon_sym_try] = ACTIONS(47),
    [anon_sym_spmd] = ACTIONS(49),
    [aux_sym_number_token1] = ACTIONS(51),
    [aux_sym_number_token2] = ACTIONS(53),
    [aux_sym_number_token3] = ACTIONS(53),
    [anon_sym_true] = ACTIONS(55),
    [anon_sym_false] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(41),
  },
  [STATE(44)] = {
    [aux_sym__block] = STATE(68),
    [sym_block] = STATE(1229),
    [sym_identifier] = STATE(401),
    [sym__statement] = STATE(1186),
    [sym__expression] = STATE(930),
    [sym_parenthesis] = STATE(512),
    [sym__binary_expression] = STATE(910),
    [sym_binary_operator] = STATE(519),
    [sym_unary_operator] = STATE(528),
    [sym_indirect_access] = STATE(1361),
    [sym_field_expression] = STATE(594),
    [sym_not_operator] = STATE(549),
    [sym_metaclass_operator] = STATE(930),
    [sym_handle_operator] = STATE(930),
    [sym_comparison_operator] = STATE(498),
    [sym_boolean_operator] = STATE(498),
    [sym_postfix_operator] = STATE(512),
    [sym_string] = STATE(512),
    [sym_matrix] = STATE(512),
    [sym_cell] = STATE(471),
    [sym_ignored_argument] = STATE(1488),
    [sym_assignment] = STATE(1186),
    [sym_multioutput_variable] = STATE(1488),
    [sym_function_call] = STATE(401),
    [sym_command] = STATE(1186),
    [sym__range_element] = STATE(1509),
    [sym_range] = STATE(930),
    [sym_return_statement] = STATE(1186),
    [sym_continue_statement] = STATE(1186),
    [sym_break_statement] = STATE(1186),
    [sym_if_statement] = STATE(1186),
    [sym_for_statement] = STATE(1186),
    [sym_while_statement] = STATE(1186),
    [sym_switch_statement] = STATE(1186),
    [sym_lambda] = STATE(930),
    [sym_global_operator] = STATE(1186),
    [sym_persistent_operator] = STATE(1186),
    [sym_arguments_statement] = STATE(368),
    [sym__function_definition_with_end] = STATE(1191),
    [sym_class_definition] = STATE(1186),
    [sym_try_statement] = STATE(1186),
    [sym_spmd_statement] = STATE(1186),
    [sym_number] = STATE(512),
    [sym_boolean] = STATE(397),
    [sym__keywords] = STATE(373),
    [aux_sym_function_definition_repeat1] = STATE(368),
    [ts_builtin_sym_end] = ACTIONS(225),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(263),
    [anon_sym_for] = ACTIONS(29),
    [anon_sym_parfor] = ACTIONS(31),
    [anon_sym_while] = ACTIONS(33),
    [anon_sym_switch] = ACTIONS(35),
    [anon_sym_global] = ACTIONS(37),
    [anon_sym_persistent] = ACTIONS(39),
    [anon_sym_arguments] = ACTIONS(209),
    [anon_sym_function] = ACTIONS(211),
    [anon_sym_endfunction] = ACTIONS(265),
    [anon_sym_properties] = ACTIONS(41),
    [anon_sym_get] = ACTIONS(41),
    [anon_sym_set] = ACTIONS(41),
    [anon_sym_methods] = ACTIONS(41),
    [anon_sym_events] = ACTIONS(41),
    [anon_sym_enumeration] = ACTIONS(41),
    [anon_sym_classdef] = ACTIONS(45),
    [anon_sym_try] = ACTIONS(47),
    [anon_sym_spmd] = ACTIONS(49),
    [aux_sym_number_token1] = ACTIONS(51),
    [aux_sym_number_token2] = ACTIONS(53),
    [aux_sym_number_token3] = ACTIONS(53),
    [anon_sym_true] = ACTIONS(55),
    [anon_sym_false] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(41),
  },
  [STATE(45)] = {
    [aux_sym__block] = STATE(68),
    [sym_block] = STATE(1232),
    [sym_identifier] = STATE(401),
    [sym__statement] = STATE(1186),
    [sym__expression] = STATE(930),
    [sym_parenthesis] = STATE(512),
    [sym__binary_expression] = STATE(910),
    [sym_binary_operator] = STATE(519),
    [sym_unary_operator] = STATE(528),
    [sym_indirect_access] = STATE(1361),
    [sym_field_expression] = STATE(594),
    [sym_not_operator] = STATE(549),
    [sym_metaclass_operator] = STATE(930),
    [sym_handle_operator] = STATE(930),
    [sym_comparison_operator] = STATE(498),
    [sym_boolean_operator] = STATE(498),
    [sym_postfix_operator] = STATE(512),
    [sym_string] = STATE(512),
    [sym_matrix] = STATE(512),
    [sym_cell] = STATE(471),
    [sym_ignored_argument] = STATE(1488),
    [sym_assignment] = STATE(1186),
    [sym_multioutput_variable] = STATE(1488),
    [sym_function_call] = STATE(401),
    [sym_command] = STATE(1186),
    [sym__range_element] = STATE(1509),
    [sym_range] = STATE(930),
    [sym_return_statement] = STATE(1186),
    [sym_continue_statement] = STATE(1186),
    [sym_break_statement] = STATE(1186),
    [sym_if_statement] = STATE(1186),
    [sym_for_statement] = STATE(1186),
    [sym_while_statement] = STATE(1186),
    [sym_switch_statement] = STATE(1186),
    [sym_lambda] = STATE(930),
    [sym_global_operator] = STATE(1186),
    [sym_persistent_operator] = STATE(1186),
    [sym_arguments_statement] = STATE(51),
    [sym__function_definition_with_end] = STATE(1191),
    [sym_class_definition] = STATE(1186),
    [sym_try_statement] = STATE(1186),
    [sym_spmd_statement] = STATE(1186),
    [sym_number] = STATE(512),
    [sym_boolean] = STATE(397),
    [sym__keywords] = STATE(373),
    [aux_sym_function_definition_repeat1] = STATE(51),
    [ts_builtin_sym_end] = ACTIONS(231),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(267),
    [anon_sym_for] = ACTIONS(29),
    [anon_sym_parfor] = ACTIONS(31),
    [anon_sym_while] = ACTIONS(33),
    [anon_sym_switch] = ACTIONS(35),
    [anon_sym_global] = ACTIONS(37),
    [anon_sym_persistent] = ACTIONS(39),
    [anon_sym_arguments] = ACTIONS(209),
    [anon_sym_function] = ACTIONS(211),
    [anon_sym_endfunction] = ACTIONS(269),
    [anon_sym_properties] = ACTIONS(41),
    [anon_sym_get] = ACTIONS(41),
    [anon_sym_set] = ACTIONS(41),
    [anon_sym_methods] = ACTIONS(41),
    [anon_sym_events] = ACTIONS(41),
    [anon_sym_enumeration] = ACTIONS(41),
    [anon_sym_classdef] = ACTIONS(45),
    [anon_sym_try] = ACTIONS(47),
    [anon_sym_spmd] = ACTIONS(49),
    [aux_sym_number_token1] = ACTIONS(51),
    [aux_sym_number_token2] = ACTIONS(53),
    [aux_sym_number_token3] = ACTIONS(53),
    [anon_sym_true] = ACTIONS(55),
    [anon_sym_false] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(41),
  },
  [STATE(46)] = {
    [aux_sym__block] = STATE(54),
    [sym_identifier] = STATE(401),
    [sym__statement] = STATE(1174),
    [sym__expression] = STATE(939),
    [sym_parenthesis] = STATE(512),
    [sym__binary_expression] = STATE(910),
    [sym_binary_operator] = STATE(519),
    [sym_unary_operator] = STATE(528),
    [sym_indirect_access] = STATE(1361),
    [sym_field_expression] = STATE(594),
    [sym_not_operator] = STATE(549),
    [sym_metaclass_operator] = STATE(939),
    [sym_handle_operator] = STATE(939),
    [sym_comparison_operator] = STATE(498),
    [sym_boolean_operator] = STATE(498),
    [sym_postfix_operator] = STATE(512),
    [sym_string] = STATE(512),
    [sym_matrix] = STATE(512),
    [sym_cell] = STATE(471),
    [sym_ignored_argument] = STATE(1488),
    [sym_assignment] = STATE(1174),
    [sym_multioutput_variable] = STATE(1488),
    [sym_function_call] = STATE(401),
    [sym_command] = STATE(1174),
    [sym__range_element] = STATE(1509),
    [sym_range] = STATE(939),
    [sym_return_statement] = STATE(1174),
    [sym_continue_statement] = STATE(1174),
    [sym_break_statement] = STATE(1174),
    [sym_if_statement] = STATE(1174),
    [sym_for_statement] = STATE(1174),
    [sym_while_statement] = STATE(1174),
    [sym_switch_statement] = STATE(1174),
    [sym_lambda] = STATE(939),
    [sym_global_operator] = STATE(1174),
    [sym_persistent_operator] = STATE(1174),
    [sym__function_definition_with_end] = STATE(1209),
    [sym_class_definition] = STATE(1174),
    [sym_try_statement] = STATE(1174),
    [sym_spmd_statement] = STATE(1174),
    [sym_number] = STATE(512),
    [sym_boolean] = STATE(397),
    [sym__keywords] = STATE(373),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_elseif] = ACTIONS(271),
    [anon_sym_else] = ACTIONS(273),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(271),
    [anon_sym_for] = ACTIONS(29),
    [anon_sym_parfor] = ACTIONS(31),
    [anon_sym_while] = ACTIONS(33),
    [anon_sym_case] = ACTIONS(271),
    [anon_sym_otherwise] = ACTIONS(271),
    [anon_sym_switch] = ACTIONS(35),
    [anon_sym_global] = ACTIONS(37),
    [anon_sym_persistent] = ACTIONS(39),
    [anon_sym_arguments] = ACTIONS(41),
    [anon_sym_function] = ACTIONS(211),
    [anon_sym_properties] = ACTIONS(41),
    [anon_sym_get] = ACTIONS(41),
    [anon_sym_set] = ACTIONS(41),
    [anon_sym_methods] = ACTIONS(41),
    [anon_sym_events] = ACTIONS(41),
    [anon_sym_enumeration] = ACTIONS(41),
    [anon_sym_classdef] = ACTIONS(45),
    [anon_sym_catch] = ACTIONS(271),
    [anon_sym_try] = ACTIONS(47),
    [anon_sym_spmd] = ACTIONS(49),
    [aux_sym_number_token1] = ACTIONS(51),
    [aux_sym_number_token2] = ACTIONS(53),
    [aux_sym_number_token3] = ACTIONS(53),
    [anon_sym_true] = ACTIONS(55),
    [anon_sym_false] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(41),
  },
  [STATE(47)] = {
    [aux_sym__block] = STATE(68),
    [sym_block] = STATE(1259),
    [sym_identifier] = STATE(401),
    [sym__statement] = STATE(1186),
    [sym__expression] = STATE(930),
    [sym_parenthesis] = STATE(512),
    [sym__binary_expression] = STATE(910),
    [sym_binary_operator] = STATE(519),
    [sym_unary_operator] = STATE(528),
    [sym_indirect_access] = STATE(1361),
    [sym_field_expression] = STATE(594),
    [sym_not_operator] = STATE(549),
    [sym_metaclass_operator] = STATE(930),
    [sym_handle_operator] = STATE(930),
    [sym_comparison_operator] = STATE(498),
    [sym_boolean_operator] = STATE(498),
    [sym_postfix_operator] = STATE(512),
    [sym_string] = STATE(512),
    [sym_matrix] = STATE(512),
    [sym_cell] = STATE(471),
    [sym_ignored_argument] = STATE(1488),
    [sym_assignment] = STATE(1186),
    [sym_multioutput_variable] = STATE(1488),
    [sym_function_call] = STATE(401),
    [sym_command] = STATE(1186),
    [sym__range_element] = STATE(1509),
    [sym_range] = STATE(930),
    [sym_return_statement] = STATE(1186),
    [sym_continue_statement] = STATE(1186),
    [sym_break_statement] = STATE(1186),
    [sym_if_statement] = STATE(1186),
    [sym_for_statement] = STATE(1186),
    [sym_while_statement] = STATE(1186),
    [sym_switch_statement] = STATE(1186),
    [sym_lambda] = STATE(930),
    [sym_global_operator] = STATE(1186),
    [sym_persistent_operator] = STATE(1186),
    [sym_arguments_statement] = STATE(368),
    [sym__function_definition_with_end] = STATE(1191),
    [sym_class_definition] = STATE(1186),
    [sym_try_statement] = STATE(1186),
    [sym_spmd_statement] = STATE(1186),
    [sym_number] = STATE(512),
    [sym_boolean] = STATE(397),
    [sym__keywords] = STATE(373),
    [aux_sym_function_definition_repeat1] = STATE(368),
    [ts_builtin_sym_end] = ACTIONS(275),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(277),
    [anon_sym_for] = ACTIONS(29),
    [anon_sym_parfor] = ACTIONS(31),
    [anon_sym_while] = ACTIONS(33),
    [anon_sym_switch] = ACTIONS(35),
    [anon_sym_global] = ACTIONS(37),
    [anon_sym_persistent] = ACTIONS(39),
    [anon_sym_arguments] = ACTIONS(209),
    [anon_sym_function] = ACTIONS(211),
    [anon_sym_endfunction] = ACTIONS(279),
    [anon_sym_properties] = ACTIONS(41),
    [anon_sym_get] = ACTIONS(41),
    [anon_sym_set] = ACTIONS(41),
    [anon_sym_methods] = ACTIONS(41),
    [anon_sym_events] = ACTIONS(41),
    [anon_sym_enumeration] = ACTIONS(41),
    [anon_sym_classdef] = ACTIONS(45),
    [anon_sym_try] = ACTIONS(47),
    [anon_sym_spmd] = ACTIONS(49),
    [aux_sym_number_token1] = ACTIONS(51),
    [aux_sym_number_token2] = ACTIONS(53),
    [aux_sym_number_token3] = ACTIONS(53),
    [anon_sym_true] = ACTIONS(55),
    [anon_sym_false] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(41),
  },
  [STATE(48)] = {
    [aux_sym__block] = STATE(68),
    [sym_block] = STATE(1269),
    [sym_identifier] = STATE(401),
    [sym__statement] = STATE(1186),
    [sym__expression] = STATE(930),
    [sym_parenthesis] = STATE(512),
    [sym__binary_expression] = STATE(910),
    [sym_binary_operator] = STATE(519),
    [sym_unary_operator] = STATE(528),
    [sym_indirect_access] = STATE(1361),
    [sym_field_expression] = STATE(594),
    [sym_not_operator] = STATE(549),
    [sym_metaclass_operator] = STATE(930),
    [sym_handle_operator] = STATE(930),
    [sym_comparison_operator] = STATE(498),
    [sym_boolean_operator] = STATE(498),
    [sym_postfix_operator] = STATE(512),
    [sym_string] = STATE(512),
    [sym_matrix] = STATE(512),
    [sym_cell] = STATE(471),
    [sym_ignored_argument] = STATE(1488),
    [sym_assignment] = STATE(1186),
    [sym_multioutput_variable] = STATE(1488),
    [sym_function_call] = STATE(401),
    [sym_command] = STATE(1186),
    [sym__range_element] = STATE(1509),
    [sym_range] = STATE(930),
    [sym_return_statement] = STATE(1186),
    [sym_continue_statement] = STATE(1186),
    [sym_break_statement] = STATE(1186),
    [sym_if_statement] = STATE(1186),
    [sym_for_statement] = STATE(1186),
    [sym_while_statement] = STATE(1186),
    [sym_switch_statement] = STATE(1186),
    [sym_lambda] = STATE(930),
    [sym_global_operator] = STATE(1186),
    [sym_persistent_operator] = STATE(1186),
    [sym_arguments_statement] = STATE(39),
    [sym__function_definition_with_end] = STATE(1191),
    [sym_class_definition] = STATE(1186),
    [sym_try_statement] = STATE(1186),
    [sym_spmd_statement] = STATE(1186),
    [sym_number] = STATE(512),
    [sym_boolean] = STATE(397),
    [sym__keywords] = STATE(373),
    [aux_sym_function_definition_repeat1] = STATE(39),
    [ts_builtin_sym_end] = ACTIONS(281),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(283),
    [anon_sym_for] = ACTIONS(29),
    [anon_sym_parfor] = ACTIONS(31),
    [anon_sym_while] = ACTIONS(33),
    [anon_sym_switch] = ACTIONS(35),
    [anon_sym_global] = ACTIONS(37),
    [anon_sym_persistent] = ACTIONS(39),
    [anon_sym_arguments] = ACTIONS(209),
    [anon_sym_function] = ACTIONS(211),
    [anon_sym_endfunction] = ACTIONS(285),
    [anon_sym_properties] = ACTIONS(41),
    [anon_sym_get] = ACTIONS(41),
    [anon_sym_set] = ACTIONS(41),
    [anon_sym_methods] = ACTIONS(41),
    [anon_sym_events] = ACTIONS(41),
    [anon_sym_enumeration] = ACTIONS(41),
    [anon_sym_classdef] = ACTIONS(45),
    [anon_sym_try] = ACTIONS(47),
    [anon_sym_spmd] = ACTIONS(49),
    [aux_sym_number_token1] = ACTIONS(51),
    [aux_sym_number_token2] = ACTIONS(53),
    [aux_sym_number_token3] = ACTIONS(53),
    [anon_sym_true] = ACTIONS(55),
    [anon_sym_false] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(41),
  },
  [STATE(49)] = {
    [aux_sym__block] = STATE(68),
    [sym_block] = STATE(1288),
    [sym_identifier] = STATE(401),
    [sym__statement] = STATE(1186),
    [sym__expression] = STATE(930),
    [sym_parenthesis] = STATE(512),
    [sym__binary_expression] = STATE(910),
    [sym_binary_operator] = STATE(519),
    [sym_unary_operator] = STATE(528),
    [sym_indirect_access] = STATE(1361),
    [sym_field_expression] = STATE(594),
    [sym_not_operator] = STATE(549),
    [sym_metaclass_operator] = STATE(930),
    [sym_handle_operator] = STATE(930),
    [sym_comparison_operator] = STATE(498),
    [sym_boolean_operator] = STATE(498),
    [sym_postfix_operator] = STATE(512),
    [sym_string] = STATE(512),
    [sym_matrix] = STATE(512),
    [sym_cell] = STATE(471),
    [sym_ignored_argument] = STATE(1488),
    [sym_assignment] = STATE(1186),
    [sym_multioutput_variable] = STATE(1488),
    [sym_function_call] = STATE(401),
    [sym_command] = STATE(1186),
    [sym__range_element] = STATE(1509),
    [sym_range] = STATE(930),
    [sym_return_statement] = STATE(1186),
    [sym_continue_statement] = STATE(1186),
    [sym_break_statement] = STATE(1186),
    [sym_if_statement] = STATE(1186),
    [sym_for_statement] = STATE(1186),
    [sym_while_statement] = STATE(1186),
    [sym_switch_statement] = STATE(1186),
    [sym_lambda] = STATE(930),
    [sym_global_operator] = STATE(1186),
    [sym_persistent_operator] = STATE(1186),
    [sym_arguments_statement] = STATE(368),
    [sym__function_definition_with_end] = STATE(1191),
    [sym_class_definition] = STATE(1186),
    [sym_try_statement] = STATE(1186),
    [sym_spmd_statement] = STATE(1186),
    [sym_number] = STATE(512),
    [sym_boolean] = STATE(397),
    [sym__keywords] = STATE(373),
    [aux_sym_function_definition_repeat1] = STATE(368),
    [ts_builtin_sym_end] = ACTIONS(251),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(287),
    [anon_sym_for] = ACTIONS(29),
    [anon_sym_parfor] = ACTIONS(31),
    [anon_sym_while] = ACTIONS(33),
    [anon_sym_switch] = ACTIONS(35),
    [anon_sym_global] = ACTIONS(37),
    [anon_sym_persistent] = ACTIONS(39),
    [anon_sym_arguments] = ACTIONS(209),
    [anon_sym_function] = ACTIONS(211),
    [anon_sym_endfunction] = ACTIONS(289),
    [anon_sym_properties] = ACTIONS(41),
    [anon_sym_get] = ACTIONS(41),
    [anon_sym_set] = ACTIONS(41),
    [anon_sym_methods] = ACTIONS(41),
    [anon_sym_events] = ACTIONS(41),
    [anon_sym_enumeration] = ACTIONS(41),
    [anon_sym_classdef] = ACTIONS(45),
    [anon_sym_try] = ACTIONS(47),
    [anon_sym_spmd] = ACTIONS(49),
    [aux_sym_number_token1] = ACTIONS(51),
    [aux_sym_number_token2] = ACTIONS(53),
    [aux_sym_number_token3] = ACTIONS(53),
    [anon_sym_true] = ACTIONS(55),
    [anon_sym_false] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(41),
  },
  [STATE(50)] = {
    [aux_sym__block] = STATE(68),
    [sym_block] = STATE(1294),
    [sym_identifier] = STATE(401),
    [sym__statement] = STATE(1186),
    [sym__expression] = STATE(930),
    [sym_parenthesis] = STATE(512),
    [sym__binary_expression] = STATE(910),
    [sym_binary_operator] = STATE(519),
    [sym_unary_operator] = STATE(528),
    [sym_indirect_access] = STATE(1361),
    [sym_field_expression] = STATE(594),
    [sym_not_operator] = STATE(549),
    [sym_metaclass_operator] = STATE(930),
    [sym_handle_operator] = STATE(930),
    [sym_comparison_operator] = STATE(498),
    [sym_boolean_operator] = STATE(498),
    [sym_postfix_operator] = STATE(512),
    [sym_string] = STATE(512),
    [sym_matrix] = STATE(512),
    [sym_cell] = STATE(471),
    [sym_ignored_argument] = STATE(1488),
    [sym_assignment] = STATE(1186),
    [sym_multioutput_variable] = STATE(1488),
    [sym_function_call] = STATE(401),
    [sym_command] = STATE(1186),
    [sym__range_element] = STATE(1509),
    [sym_range] = STATE(930),
    [sym_return_statement] = STATE(1186),
    [sym_continue_statement] = STATE(1186),
    [sym_break_statement] = STATE(1186),
    [sym_if_statement] = STATE(1186),
    [sym_for_statement] = STATE(1186),
    [sym_while_statement] = STATE(1186),
    [sym_switch_statement] = STATE(1186),
    [sym_lambda] = STATE(930),
    [sym_global_operator] = STATE(1186),
    [sym_persistent_operator] = STATE(1186),
    [sym_arguments_statement] = STATE(52),
    [sym__function_definition_with_end] = STATE(1191),
    [sym_class_definition] = STATE(1186),
    [sym_try_statement] = STATE(1186),
    [sym_spmd_statement] = STATE(1186),
    [sym_number] = STATE(512),
    [sym_boolean] = STATE(397),
    [sym__keywords] = STATE(373),
    [aux_sym_function_definition_repeat1] = STATE(52),
    [ts_builtin_sym_end] = ACTIONS(257),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(291),
    [anon_sym_for] = ACTIONS(29),
    [anon_sym_parfor] = ACTIONS(31),
    [anon_sym_while] = ACTIONS(33),
    [anon_sym_switch] = ACTIONS(35),
    [anon_sym_global] = ACTIONS(37),
    [anon_sym_persistent] = ACTIONS(39),
    [anon_sym_arguments] = ACTIONS(209),
    [anon_sym_function] = ACTIONS(211),
    [anon_sym_endfunction] = ACTIONS(293),
    [anon_sym_properties] = ACTIONS(41),
    [anon_sym_get] = ACTIONS(41),
    [anon_sym_set] = ACTIONS(41),
    [anon_sym_methods] = ACTIONS(41),
    [anon_sym_events] = ACTIONS(41),
    [anon_sym_enumeration] = ACTIONS(41),
    [anon_sym_classdef] = ACTIONS(45),
    [anon_sym_try] = ACTIONS(47),
    [anon_sym_spmd] = ACTIONS(49),
    [aux_sym_number_token1] = ACTIONS(51),
    [aux_sym_number_token2] = ACTIONS(53),
    [aux_sym_number_token3] = ACTIONS(53),
    [anon_sym_true] = ACTIONS(55),
    [anon_sym_false] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(41),
  },
  [STATE(51)] = {
    [aux_sym__block] = STATE(68),
    [sym_block] = STATE(1294),
    [sym_identifier] = STATE(401),
    [sym__statement] = STATE(1186),
    [sym__expression] = STATE(930),
    [sym_parenthesis] = STATE(512),
    [sym__binary_expression] = STATE(910),
    [sym_binary_operator] = STATE(519),
    [sym_unary_operator] = STATE(528),
    [sym_indirect_access] = STATE(1361),
    [sym_field_expression] = STATE(594),
    [sym_not_operator] = STATE(549),
    [sym_metaclass_operator] = STATE(930),
    [sym_handle_operator] = STATE(930),
    [sym_comparison_operator] = STATE(498),
    [sym_boolean_operator] = STATE(498),
    [sym_postfix_operator] = STATE(512),
    [sym_string] = STATE(512),
    [sym_matrix] = STATE(512),
    [sym_cell] = STATE(471),
    [sym_ignored_argument] = STATE(1488),
    [sym_assignment] = STATE(1186),
    [sym_multioutput_variable] = STATE(1488),
    [sym_function_call] = STATE(401),
    [sym_command] = STATE(1186),
    [sym__range_element] = STATE(1509),
    [sym_range] = STATE(930),
    [sym_return_statement] = STATE(1186),
    [sym_continue_statement] = STATE(1186),
    [sym_break_statement] = STATE(1186),
    [sym_if_statement] = STATE(1186),
    [sym_for_statement] = STATE(1186),
    [sym_while_statement] = STATE(1186),
    [sym_switch_statement] = STATE(1186),
    [sym_lambda] = STATE(930),
    [sym_global_operator] = STATE(1186),
    [sym_persistent_operator] = STATE(1186),
    [sym_arguments_statement] = STATE(368),
    [sym__function_definition_with_end] = STATE(1191),
    [sym_class_definition] = STATE(1186),
    [sym_try_statement] = STATE(1186),
    [sym_spmd_statement] = STATE(1186),
    [sym_number] = STATE(512),
    [sym_boolean] = STATE(397),
    [sym__keywords] = STATE(373),
    [aux_sym_function_definition_repeat1] = STATE(368),
    [ts_builtin_sym_end] = ACTIONS(257),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(291),
    [anon_sym_for] = ACTIONS(29),
    [anon_sym_parfor] = ACTIONS(31),
    [anon_sym_while] = ACTIONS(33),
    [anon_sym_switch] = ACTIONS(35),
    [anon_sym_global] = ACTIONS(37),
    [anon_sym_persistent] = ACTIONS(39),
    [anon_sym_arguments] = ACTIONS(209),
    [anon_sym_function] = ACTIONS(211),
    [anon_sym_endfunction] = ACTIONS(293),
    [anon_sym_properties] = ACTIONS(41),
    [anon_sym_get] = ACTIONS(41),
    [anon_sym_set] = ACTIONS(41),
    [anon_sym_methods] = ACTIONS(41),
    [anon_sym_events] = ACTIONS(41),
    [anon_sym_enumeration] = ACTIONS(41),
    [anon_sym_classdef] = ACTIONS(45),
    [anon_sym_try] = ACTIONS(47),
    [anon_sym_spmd] = ACTIONS(49),
    [aux_sym_number_token1] = ACTIONS(51),
    [aux_sym_number_token2] = ACTIONS(53),
    [aux_sym_number_token3] = ACTIONS(53),
    [anon_sym_true] = ACTIONS(55),
    [anon_sym_false] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(41),
  },
  [STATE(52)] = {
    [aux_sym__block] = STATE(68),
    [sym_block] = STATE(1350),
    [sym_identifier] = STATE(401),
    [sym__statement] = STATE(1186),
    [sym__expression] = STATE(930),
    [sym_parenthesis] = STATE(512),
    [sym__binary_expression] = STATE(910),
    [sym_binary_operator] = STATE(519),
    [sym_unary_operator] = STATE(528),
    [sym_indirect_access] = STATE(1361),
    [sym_field_expression] = STATE(594),
    [sym_not_operator] = STATE(549),
    [sym_metaclass_operator] = STATE(930),
    [sym_handle_operator] = STATE(930),
    [sym_comparison_operator] = STATE(498),
    [sym_boolean_operator] = STATE(498),
    [sym_postfix_operator] = STATE(512),
    [sym_string] = STATE(512),
    [sym_matrix] = STATE(512),
    [sym_cell] = STATE(471),
    [sym_ignored_argument] = STATE(1488),
    [sym_assignment] = STATE(1186),
    [sym_multioutput_variable] = STATE(1488),
    [sym_function_call] = STATE(401),
    [sym_command] = STATE(1186),
    [sym__range_element] = STATE(1509),
    [sym_range] = STATE(930),
    [sym_return_statement] = STATE(1186),
    [sym_continue_statement] = STATE(1186),
    [sym_break_statement] = STATE(1186),
    [sym_if_statement] = STATE(1186),
    [sym_for_statement] = STATE(1186),
    [sym_while_statement] = STATE(1186),
    [sym_switch_statement] = STATE(1186),
    [sym_lambda] = STATE(930),
    [sym_global_operator] = STATE(1186),
    [sym_persistent_operator] = STATE(1186),
    [sym_arguments_statement] = STATE(368),
    [sym__function_definition_with_end] = STATE(1191),
    [sym_class_definition] = STATE(1186),
    [sym_try_statement] = STATE(1186),
    [sym_spmd_statement] = STATE(1186),
    [sym_number] = STATE(512),
    [sym_boolean] = STATE(397),
    [sym__keywords] = STATE(373),
    [aux_sym_function_definition_repeat1] = STATE(368),
    [ts_builtin_sym_end] = ACTIONS(275),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(295),
    [anon_sym_for] = ACTIONS(29),
    [anon_sym_parfor] = ACTIONS(31),
    [anon_sym_while] = ACTIONS(33),
    [anon_sym_switch] = ACTIONS(35),
    [anon_sym_global] = ACTIONS(37),
    [anon_sym_persistent] = ACTIONS(39),
    [anon_sym_arguments] = ACTIONS(209),
    [anon_sym_function] = ACTIONS(211),
    [anon_sym_endfunction] = ACTIONS(297),
    [anon_sym_properties] = ACTIONS(41),
    [anon_sym_get] = ACTIONS(41),
    [anon_sym_set] = ACTIONS(41),
    [anon_sym_methods] = ACTIONS(41),
    [anon_sym_events] = ACTIONS(41),
    [anon_sym_enumeration] = ACTIONS(41),
    [anon_sym_classdef] = ACTIONS(45),
    [anon_sym_try] = ACTIONS(47),
    [anon_sym_spmd] = ACTIONS(49),
    [aux_sym_number_token1] = ACTIONS(51),
    [aux_sym_number_token2] = ACTIONS(53),
    [aux_sym_number_token3] = ACTIONS(53),
    [anon_sym_true] = ACTIONS(55),
    [anon_sym_false] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(41),
  },
  [STATE(53)] = {
    [aux_sym__block] = STATE(68),
    [sym_block] = STATE(1346),
    [sym_identifier] = STATE(401),
    [sym__statement] = STATE(1186),
    [sym__expression] = STATE(930),
    [sym_parenthesis] = STATE(512),
    [sym__binary_expression] = STATE(910),
    [sym_binary_operator] = STATE(519),
    [sym_unary_operator] = STATE(528),
    [sym_indirect_access] = STATE(1361),
    [sym_field_expression] = STATE(594),
    [sym_not_operator] = STATE(549),
    [sym_metaclass_operator] = STATE(930),
    [sym_handle_operator] = STATE(930),
    [sym_comparison_operator] = STATE(498),
    [sym_boolean_operator] = STATE(498),
    [sym_postfix_operator] = STATE(512),
    [sym_string] = STATE(512),
    [sym_matrix] = STATE(512),
    [sym_cell] = STATE(471),
    [sym_ignored_argument] = STATE(1488),
    [sym_assignment] = STATE(1186),
    [sym_multioutput_variable] = STATE(1488),
    [sym_function_call] = STATE(401),
    [sym_command] = STATE(1186),
    [sym__range_element] = STATE(1509),
    [sym_range] = STATE(930),
    [sym_return_statement] = STATE(1186),
    [sym_continue_statement] = STATE(1186),
    [sym_break_statement] = STATE(1186),
    [sym_if_statement] = STATE(1186),
    [sym_for_statement] = STATE(1186),
    [sym_while_statement] = STATE(1186),
    [sym_switch_statement] = STATE(1186),
    [sym_lambda] = STATE(930),
    [sym_global_operator] = STATE(1186),
    [sym_persistent_operator] = STATE(1186),
    [sym_arguments_statement] = STATE(38),
    [sym__function_definition_with_end] = STATE(1191),
    [sym_class_definition] = STATE(1186),
    [sym_try_statement] = STATE(1186),
    [sym_spmd_statement] = STATE(1186),
    [sym_number] = STATE(512),
    [sym_boolean] = STATE(397),
    [sym__keywords] = STATE(373),
    [aux_sym_function_definition_repeat1] = STATE(38),
    [ts_builtin_sym_end] = ACTIONS(281),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(299),
    [anon_sym_for] = ACTIONS(29),
    [anon_sym_parfor] = ACTIONS(31),
    [anon_sym_while] = ACTIONS(33),
    [anon_sym_switch] = ACTIONS(35),
    [anon_sym_global] = ACTIONS(37),
    [anon_sym_persistent] = ACTIONS(39),
    [anon_sym_arguments] = ACTIONS(209),
    [anon_sym_function] = ACTIONS(211),
    [anon_sym_endfunction] = ACTIONS(301),
    [anon_sym_properties] = ACTIONS(41),
    [anon_sym_get] = ACTIONS(41),
    [anon_sym_set] = ACTIONS(41),
    [anon_sym_methods] = ACTIONS(41),
    [anon_sym_events] = ACTIONS(41),
    [anon_sym_enumeration] = ACTIONS(41),
    [anon_sym_classdef] = ACTIONS(45),
    [anon_sym_try] = ACTIONS(47),
    [anon_sym_spmd] = ACTIONS(49),
    [aux_sym_number_token1] = ACTIONS(51),
    [aux_sym_number_token2] = ACTIONS(53),
    [aux_sym_number_token3] = ACTIONS(53),
    [anon_sym_true] = ACTIONS(55),
    [anon_sym_false] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(41),
  },
  [STATE(54)] = {
    [aux_sym__block] = STATE(54),
    [sym_identifier] = STATE(401),
    [sym__statement] = STATE(1174),
    [sym__expression] = STATE(939),
    [sym_parenthesis] = STATE(512),
    [sym__binary_expression] = STATE(910),
    [sym_binary_operator] = STATE(519),
    [sym_unary_operator] = STATE(528),
    [sym_indirect_access] = STATE(1361),
    [sym_field_expression] = STATE(594),
    [sym_not_operator] = STATE(549),
    [sym_metaclass_operator] = STATE(939),
    [sym_handle_operator] = STATE(939),
    [sym_comparison_operator] = STATE(498),
    [sym_boolean_operator] = STATE(498),
    [sym_postfix_operator] = STATE(512),
    [sym_string] = STATE(512),
    [sym_matrix] = STATE(512),
    [sym_cell] = STATE(471),
    [sym_ignored_argument] = STATE(1488),
    [sym_assignment] = STATE(1174),
    [sym_multioutput_variable] = STATE(1488),
    [sym_function_call] = STATE(401),
    [sym_command] = STATE(1174),
    [sym__range_element] = STATE(1509),
    [sym_range] = STATE(939),
    [sym_return_statement] = STATE(1174),
    [sym_continue_statement] = STATE(1174),
    [sym_break_statement] = STATE(1174),
    [sym_if_statement] = STATE(1174),
    [sym_for_statement] = STATE(1174),
    [sym_while_statement] = STATE(1174),
    [sym_switch_statement] = STATE(1174),
    [sym_lambda] = STATE(939),
    [sym_global_operator] = STATE(1174),
    [sym_persistent_operator] = STATE(1174),
    [sym__function_definition_with_end] = STATE(1209),
    [sym_class_definition] = STATE(1174),
    [sym_try_statement] = STATE(1174),
    [sym_spmd_statement] = STATE(1174),
    [sym_number] = STATE(512),
    [sym_boolean] = STATE(397),
    [sym__keywords] = STATE(373),
    [anon_sym_LPAREN] = ACTIONS(303),
    [anon_sym_PLUS] = ACTIONS(306),
    [anon_sym_DASH] = ACTIONS(306),
    [anon_sym_TILDE] = ACTIONS(309),
    [anon_sym_QMARK] = ACTIONS(312),
    [anon_sym_AT] = ACTIONS(315),
    [anon_sym_LBRACK] = ACTIONS(318),
    [anon_sym_LBRACE] = ACTIONS(321),
    [anon_sym_return] = ACTIONS(324),
    [anon_sym_continue] = ACTIONS(327),
    [anon_sym_break] = ACTIONS(330),
    [anon_sym_elseif] = ACTIONS(333),
    [anon_sym_else] = ACTIONS(335),
    [anon_sym_if] = ACTIONS(337),
    [anon_sym_end] = ACTIONS(333),
    [anon_sym_for] = ACTIONS(340),
    [anon_sym_parfor] = ACTIONS(343),
    [anon_sym_while] = ACTIONS(346),
    [anon_sym_case] = ACTIONS(333),
    [anon_sym_otherwise] = ACTIONS(333),
    [anon_sym_switch] = ACTIONS(349),
    [anon_sym_global] = ACTIONS(352),
    [anon_sym_persistent] = ACTIONS(355),
    [anon_sym_arguments] = ACTIONS(358),
    [anon_sym_function] = ACTIONS(361),
    [anon_sym_properties] = ACTIONS(358),
    [anon_sym_get] = ACTIONS(358),
    [anon_sym_set] = ACTIONS(358),
    [anon_sym_methods] = ACTIONS(358),
    [anon_sym_events] = ACTIONS(358),
    [anon_sym_enumeration] = ACTIONS(358),
    [anon_sym_classdef] = ACTIONS(364),
    [anon_sym_catch] = ACTIONS(333),
    [anon_sym_try] = ACTIONS(367),
    [anon_sym_spmd] = ACTIONS(370),
    [aux_sym_number_token1] = ACTIONS(373),
    [aux_sym_number_token2] = ACTIONS(376),
    [aux_sym_number_token3] = ACTIONS(376),
    [anon_sym_true] = ACTIONS(379),
    [anon_sym_false] = ACTIONS(379),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(382),
    [sym__single_quote_string_start] = ACTIONS(385),
    [sym__double_quote_string_start] = ACTIONS(388),
    [sym__multioutput_variable_start] = ACTIONS(391),
    [sym__external_identifier] = ACTIONS(358),
  },
  [STATE(55)] = {
    [aux_sym__block] = STATE(70),
    [sym_block] = STATE(1440),
    [sym_identifier] = STATE(401),
    [sym__statement] = STATE(1186),
    [sym__expression] = STATE(930),
    [sym_parenthesis] = STATE(512),
    [sym__binary_expression] = STATE(910),
    [sym_binary_operator] = STATE(519),
    [sym_unary_operator] = STATE(528),
    [sym_indirect_access] = STATE(1361),
    [sym_field_expression] = STATE(594),
    [sym_not_operator] = STATE(549),
    [sym_metaclass_operator] = STATE(930),
    [sym_handle_operator] = STATE(930),
    [sym_comparison_operator] = STATE(498),
    [sym_boolean_operator] = STATE(498),
    [sym_postfix_operator] = STATE(512),
    [sym_string] = STATE(512),
    [sym_matrix] = STATE(512),
    [sym_cell] = STATE(471),
    [sym_ignored_argument] = STATE(1488),
    [sym_assignment] = STATE(1186),
    [sym_multioutput_variable] = STATE(1488),
    [sym_function_call] = STATE(401),
    [sym_command] = STATE(1186),
    [sym__range_element] = STATE(1509),
    [sym_range] = STATE(930),
    [sym_return_statement] = STATE(1186),
    [sym_continue_statement] = STATE(1186),
    [sym_break_statement] = STATE(1186),
    [sym_if_statement] = STATE(1186),
    [sym_for_statement] = STATE(1186),
    [sym_while_statement] = STATE(1186),
    [sym_switch_statement] = STATE(1186),
    [sym_lambda] = STATE(930),
    [sym_global_operator] = STATE(1186),
    [sym_persistent_operator] = STATE(1186),
    [sym_arguments_statement] = STATE(60),
    [sym__function_definition_with_end] = STATE(1191),
    [sym_class_definition] = STATE(1186),
    [sym_try_statement] = STATE(1186),
    [sym_spmd_statement] = STATE(1186),
    [sym_number] = STATE(512),
    [sym_boolean] = STATE(397),
    [sym__keywords] = STATE(373),
    [aux_sym_function_definition_repeat1] = STATE(60),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(394),
    [anon_sym_for] = ACTIONS(29),
    [anon_sym_parfor] = ACTIONS(31),
    [anon_sym_while] = ACTIONS(33),
    [anon_sym_switch] = ACTIONS(35),
    [anon_sym_global] = ACTIONS(37),
    [anon_sym_persistent] = ACTIONS(39),
    [anon_sym_arguments] = ACTIONS(209),
    [anon_sym_function] = ACTIONS(211),
    [anon_sym_endfunction] = ACTIONS(396),
    [anon_sym_properties] = ACTIONS(41),
    [anon_sym_get] = ACTIONS(41),
    [anon_sym_set] = ACTIONS(41),
    [anon_sym_methods] = ACTIONS(41),
    [anon_sym_events] = ACTIONS(41),
    [anon_sym_enumeration] = ACTIONS(41),
    [anon_sym_classdef] = ACTIONS(45),
    [anon_sym_try] = ACTIONS(47),
    [anon_sym_spmd] = ACTIONS(49),
    [aux_sym_number_token1] = ACTIONS(51),
    [aux_sym_number_token2] = ACTIONS(53),
    [aux_sym_number_token3] = ACTIONS(53),
    [anon_sym_true] = ACTIONS(55),
    [anon_sym_false] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(41),
  },
  [STATE(56)] = {
    [aux_sym__block] = STATE(70),
    [sym_block] = STATE(1446),
    [sym_identifier] = STATE(401),
    [sym__statement] = STATE(1186),
    [sym__expression] = STATE(930),
    [sym_parenthesis] = STATE(512),
    [sym__binary_expression] = STATE(910),
    [sym_binary_operator] = STATE(519),
    [sym_unary_operator] = STATE(528),
    [sym_indirect_access] = STATE(1361),
    [sym_field_expression] = STATE(594),
    [sym_not_operator] = STATE(549),
    [sym_metaclass_operator] = STATE(930),
    [sym_handle_operator] = STATE(930),
    [sym_comparison_operator] = STATE(498),
    [sym_boolean_operator] = STATE(498),
    [sym_postfix_operator] = STATE(512),
    [sym_string] = STATE(512),
    [sym_matrix] = STATE(512),
    [sym_cell] = STATE(471),
    [sym_ignored_argument] = STATE(1488),
    [sym_assignment] = STATE(1186),
    [sym_multioutput_variable] = STATE(1488),
    [sym_function_call] = STATE(401),
    [sym_command] = STATE(1186),
    [sym__range_element] = STATE(1509),
    [sym_range] = STATE(930),
    [sym_return_statement] = STATE(1186),
    [sym_continue_statement] = STATE(1186),
    [sym_break_statement] = STATE(1186),
    [sym_if_statement] = STATE(1186),
    [sym_for_statement] = STATE(1186),
    [sym_while_statement] = STATE(1186),
    [sym_switch_statement] = STATE(1186),
    [sym_lambda] = STATE(930),
    [sym_global_operator] = STATE(1186),
    [sym_persistent_operator] = STATE(1186),
    [sym_arguments_statement] = STATE(368),
    [sym__function_definition_with_end] = STATE(1191),
    [sym_class_definition] = STATE(1186),
    [sym_try_statement] = STATE(1186),
    [sym_spmd_statement] = STATE(1186),
    [sym_number] = STATE(512),
    [sym_boolean] = STATE(397),
    [sym__keywords] = STATE(373),
    [aux_sym_function_definition_repeat1] = STATE(368),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(398),
    [anon_sym_for] = ACTIONS(29),
    [anon_sym_parfor] = ACTIONS(31),
    [anon_sym_while] = ACTIONS(33),
    [anon_sym_switch] = ACTIONS(35),
    [anon_sym_global] = ACTIONS(37),
    [anon_sym_persistent] = ACTIONS(39),
    [anon_sym_arguments] = ACTIONS(209),
    [anon_sym_function] = ACTIONS(211),
    [anon_sym_endfunction] = ACTIONS(400),
    [anon_sym_properties] = ACTIONS(41),
    [anon_sym_get] = ACTIONS(41),
    [anon_sym_set] = ACTIONS(41),
    [anon_sym_methods] = ACTIONS(41),
    [anon_sym_events] = ACTIONS(41),
    [anon_sym_enumeration] = ACTIONS(41),
    [anon_sym_classdef] = ACTIONS(45),
    [anon_sym_try] = ACTIONS(47),
    [anon_sym_spmd] = ACTIONS(49),
    [aux_sym_number_token1] = ACTIONS(51),
    [aux_sym_number_token2] = ACTIONS(53),
    [aux_sym_number_token3] = ACTIONS(53),
    [anon_sym_true] = ACTIONS(55),
    [anon_sym_false] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(41),
  },
  [STATE(57)] = {
    [aux_sym__block] = STATE(70),
    [sym_block] = STATE(1428),
    [sym_identifier] = STATE(401),
    [sym__statement] = STATE(1186),
    [sym__expression] = STATE(930),
    [sym_parenthesis] = STATE(512),
    [sym__binary_expression] = STATE(910),
    [sym_binary_operator] = STATE(519),
    [sym_unary_operator] = STATE(528),
    [sym_indirect_access] = STATE(1361),
    [sym_field_expression] = STATE(594),
    [sym_not_operator] = STATE(549),
    [sym_metaclass_operator] = STATE(930),
    [sym_handle_operator] = STATE(930),
    [sym_comparison_operator] = STATE(498),
    [sym_boolean_operator] = STATE(498),
    [sym_postfix_operator] = STATE(512),
    [sym_string] = STATE(512),
    [sym_matrix] = STATE(512),
    [sym_cell] = STATE(471),
    [sym_ignored_argument] = STATE(1488),
    [sym_assignment] = STATE(1186),
    [sym_multioutput_variable] = STATE(1488),
    [sym_function_call] = STATE(401),
    [sym_command] = STATE(1186),
    [sym__range_element] = STATE(1509),
    [sym_range] = STATE(930),
    [sym_return_statement] = STATE(1186),
    [sym_continue_statement] = STATE(1186),
    [sym_break_statement] = STATE(1186),
    [sym_if_statement] = STATE(1186),
    [sym_for_statement] = STATE(1186),
    [sym_while_statement] = STATE(1186),
    [sym_switch_statement] = STATE(1186),
    [sym_lambda] = STATE(930),
    [sym_global_operator] = STATE(1186),
    [sym_persistent_operator] = STATE(1186),
    [sym_arguments_statement] = STATE(368),
    [sym__function_definition_with_end] = STATE(1191),
    [sym_class_definition] = STATE(1186),
    [sym_try_statement] = STATE(1186),
    [sym_spmd_statement] = STATE(1186),
    [sym_number] = STATE(512),
    [sym_boolean] = STATE(397),
    [sym__keywords] = STATE(373),
    [aux_sym_function_definition_repeat1] = STATE(368),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(402),
    [anon_sym_for] = ACTIONS(29),
    [anon_sym_parfor] = ACTIONS(31),
    [anon_sym_while] = ACTIONS(33),
    [anon_sym_switch] = ACTIONS(35),
    [anon_sym_global] = ACTIONS(37),
    [anon_sym_persistent] = ACTIONS(39),
    [anon_sym_arguments] = ACTIONS(209),
    [anon_sym_function] = ACTIONS(211),
    [anon_sym_endfunction] = ACTIONS(404),
    [anon_sym_properties] = ACTIONS(41),
    [anon_sym_get] = ACTIONS(41),
    [anon_sym_set] = ACTIONS(41),
    [anon_sym_methods] = ACTIONS(41),
    [anon_sym_events] = ACTIONS(41),
    [anon_sym_enumeration] = ACTIONS(41),
    [anon_sym_classdef] = ACTIONS(45),
    [anon_sym_try] = ACTIONS(47),
    [anon_sym_spmd] = ACTIONS(49),
    [aux_sym_number_token1] = ACTIONS(51),
    [aux_sym_number_token2] = ACTIONS(53),
    [aux_sym_number_token3] = ACTIONS(53),
    [anon_sym_true] = ACTIONS(55),
    [anon_sym_false] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(41),
  },
  [STATE(58)] = {
    [aux_sym__block] = STATE(70),
    [sym_block] = STATE(1420),
    [sym_identifier] = STATE(401),
    [sym__statement] = STATE(1186),
    [sym__expression] = STATE(930),
    [sym_parenthesis] = STATE(512),
    [sym__binary_expression] = STATE(910),
    [sym_binary_operator] = STATE(519),
    [sym_unary_operator] = STATE(528),
    [sym_indirect_access] = STATE(1361),
    [sym_field_expression] = STATE(594),
    [sym_not_operator] = STATE(549),
    [sym_metaclass_operator] = STATE(930),
    [sym_handle_operator] = STATE(930),
    [sym_comparison_operator] = STATE(498),
    [sym_boolean_operator] = STATE(498),
    [sym_postfix_operator] = STATE(512),
    [sym_string] = STATE(512),
    [sym_matrix] = STATE(512),
    [sym_cell] = STATE(471),
    [sym_ignored_argument] = STATE(1488),
    [sym_assignment] = STATE(1186),
    [sym_multioutput_variable] = STATE(1488),
    [sym_function_call] = STATE(401),
    [sym_command] = STATE(1186),
    [sym__range_element] = STATE(1509),
    [sym_range] = STATE(930),
    [sym_return_statement] = STATE(1186),
    [sym_continue_statement] = STATE(1186),
    [sym_break_statement] = STATE(1186),
    [sym_if_statement] = STATE(1186),
    [sym_for_statement] = STATE(1186),
    [sym_while_statement] = STATE(1186),
    [sym_switch_statement] = STATE(1186),
    [sym_lambda] = STATE(930),
    [sym_global_operator] = STATE(1186),
    [sym_persistent_operator] = STATE(1186),
    [sym_arguments_statement] = STATE(63),
    [sym__function_definition_with_end] = STATE(1191),
    [sym_class_definition] = STATE(1186),
    [sym_try_statement] = STATE(1186),
    [sym_spmd_statement] = STATE(1186),
    [sym_number] = STATE(512),
    [sym_boolean] = STATE(397),
    [sym__keywords] = STATE(373),
    [aux_sym_function_definition_repeat1] = STATE(63),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(406),
    [anon_sym_for] = ACTIONS(29),
    [anon_sym_parfor] = ACTIONS(31),
    [anon_sym_while] = ACTIONS(33),
    [anon_sym_switch] = ACTIONS(35),
    [anon_sym_global] = ACTIONS(37),
    [anon_sym_persistent] = ACTIONS(39),
    [anon_sym_arguments] = ACTIONS(209),
    [anon_sym_function] = ACTIONS(211),
    [anon_sym_endfunction] = ACTIONS(408),
    [anon_sym_properties] = ACTIONS(41),
    [anon_sym_get] = ACTIONS(41),
    [anon_sym_set] = ACTIONS(41),
    [anon_sym_methods] = ACTIONS(41),
    [anon_sym_events] = ACTIONS(41),
    [anon_sym_enumeration] = ACTIONS(41),
    [anon_sym_classdef] = ACTIONS(45),
    [anon_sym_try] = ACTIONS(47),
    [anon_sym_spmd] = ACTIONS(49),
    [aux_sym_number_token1] = ACTIONS(51),
    [aux_sym_number_token2] = ACTIONS(53),
    [aux_sym_number_token3] = ACTIONS(53),
    [anon_sym_true] = ACTIONS(55),
    [anon_sym_false] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(41),
  },
  [STATE(59)] = {
    [aux_sym__block] = STATE(70),
    [sym_block] = STATE(1420),
    [sym_identifier] = STATE(401),
    [sym__statement] = STATE(1186),
    [sym__expression] = STATE(930),
    [sym_parenthesis] = STATE(512),
    [sym__binary_expression] = STATE(910),
    [sym_binary_operator] = STATE(519),
    [sym_unary_operator] = STATE(528),
    [sym_indirect_access] = STATE(1361),
    [sym_field_expression] = STATE(594),
    [sym_not_operator] = STATE(549),
    [sym_metaclass_operator] = STATE(930),
    [sym_handle_operator] = STATE(930),
    [sym_comparison_operator] = STATE(498),
    [sym_boolean_operator] = STATE(498),
    [sym_postfix_operator] = STATE(512),
    [sym_string] = STATE(512),
    [sym_matrix] = STATE(512),
    [sym_cell] = STATE(471),
    [sym_ignored_argument] = STATE(1488),
    [sym_assignment] = STATE(1186),
    [sym_multioutput_variable] = STATE(1488),
    [sym_function_call] = STATE(401),
    [sym_command] = STATE(1186),
    [sym__range_element] = STATE(1509),
    [sym_range] = STATE(930),
    [sym_return_statement] = STATE(1186),
    [sym_continue_statement] = STATE(1186),
    [sym_break_statement] = STATE(1186),
    [sym_if_statement] = STATE(1186),
    [sym_for_statement] = STATE(1186),
    [sym_while_statement] = STATE(1186),
    [sym_switch_statement] = STATE(1186),
    [sym_lambda] = STATE(930),
    [sym_global_operator] = STATE(1186),
    [sym_persistent_operator] = STATE(1186),
    [sym_arguments_statement] = STATE(368),
    [sym__function_definition_with_end] = STATE(1191),
    [sym_class_definition] = STATE(1186),
    [sym_try_statement] = STATE(1186),
    [sym_spmd_statement] = STATE(1186),
    [sym_number] = STATE(512),
    [sym_boolean] = STATE(397),
    [sym__keywords] = STATE(373),
    [aux_sym_function_definition_repeat1] = STATE(368),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(406),
    [anon_sym_for] = ACTIONS(29),
    [anon_sym_parfor] = ACTIONS(31),
    [anon_sym_while] = ACTIONS(33),
    [anon_sym_switch] = ACTIONS(35),
    [anon_sym_global] = ACTIONS(37),
    [anon_sym_persistent] = ACTIONS(39),
    [anon_sym_arguments] = ACTIONS(209),
    [anon_sym_function] = ACTIONS(211),
    [anon_sym_endfunction] = ACTIONS(408),
    [anon_sym_properties] = ACTIONS(41),
    [anon_sym_get] = ACTIONS(41),
    [anon_sym_set] = ACTIONS(41),
    [anon_sym_methods] = ACTIONS(41),
    [anon_sym_events] = ACTIONS(41),
    [anon_sym_enumeration] = ACTIONS(41),
    [anon_sym_classdef] = ACTIONS(45),
    [anon_sym_try] = ACTIONS(47),
    [anon_sym_spmd] = ACTIONS(49),
    [aux_sym_number_token1] = ACTIONS(51),
    [aux_sym_number_token2] = ACTIONS(53),
    [aux_sym_number_token3] = ACTIONS(53),
    [anon_sym_true] = ACTIONS(55),
    [anon_sym_false] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(41),
  },
  [STATE(60)] = {
    [aux_sym__block] = STATE(70),
    [sym_block] = STATE(1429),
    [sym_identifier] = STATE(401),
    [sym__statement] = STATE(1186),
    [sym__expression] = STATE(930),
    [sym_parenthesis] = STATE(512),
    [sym__binary_expression] = STATE(910),
    [sym_binary_operator] = STATE(519),
    [sym_unary_operator] = STATE(528),
    [sym_indirect_access] = STATE(1361),
    [sym_field_expression] = STATE(594),
    [sym_not_operator] = STATE(549),
    [sym_metaclass_operator] = STATE(930),
    [sym_handle_operator] = STATE(930),
    [sym_comparison_operator] = STATE(498),
    [sym_boolean_operator] = STATE(498),
    [sym_postfix_operator] = STATE(512),
    [sym_string] = STATE(512),
    [sym_matrix] = STATE(512),
    [sym_cell] = STATE(471),
    [sym_ignored_argument] = STATE(1488),
    [sym_assignment] = STATE(1186),
    [sym_multioutput_variable] = STATE(1488),
    [sym_function_call] = STATE(401),
    [sym_command] = STATE(1186),
    [sym__range_element] = STATE(1509),
    [sym_range] = STATE(930),
    [sym_return_statement] = STATE(1186),
    [sym_continue_statement] = STATE(1186),
    [sym_break_statement] = STATE(1186),
    [sym_if_statement] = STATE(1186),
    [sym_for_statement] = STATE(1186),
    [sym_while_statement] = STATE(1186),
    [sym_switch_statement] = STATE(1186),
    [sym_lambda] = STATE(930),
    [sym_global_operator] = STATE(1186),
    [sym_persistent_operator] = STATE(1186),
    [sym_arguments_statement] = STATE(368),
    [sym__function_definition_with_end] = STATE(1191),
    [sym_class_definition] = STATE(1186),
    [sym_try_statement] = STATE(1186),
    [sym_spmd_statement] = STATE(1186),
    [sym_number] = STATE(512),
    [sym_boolean] = STATE(397),
    [sym__keywords] = STATE(373),
    [aux_sym_function_definition_repeat1] = STATE(368),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(410),
    [anon_sym_for] = ACTIONS(29),
    [anon_sym_parfor] = ACTIONS(31),
    [anon_sym_while] = ACTIONS(33),
    [anon_sym_switch] = ACTIONS(35),
    [anon_sym_global] = ACTIONS(37),
    [anon_sym_persistent] = ACTIONS(39),
    [anon_sym_arguments] = ACTIONS(209),
    [anon_sym_function] = ACTIONS(211),
    [anon_sym_endfunction] = ACTIONS(412),
    [anon_sym_properties] = ACTIONS(41),
    [anon_sym_get] = ACTIONS(41),
    [anon_sym_set] = ACTIONS(41),
    [anon_sym_methods] = ACTIONS(41),
    [anon_sym_events] = ACTIONS(41),
    [anon_sym_enumeration] = ACTIONS(41),
    [anon_sym_classdef] = ACTIONS(45),
    [anon_sym_try] = ACTIONS(47),
    [anon_sym_spmd] = ACTIONS(49),
    [aux_sym_number_token1] = ACTIONS(51),
    [aux_sym_number_token2] = ACTIONS(53),
    [aux_sym_number_token3] = ACTIONS(53),
    [anon_sym_true] = ACTIONS(55),
    [anon_sym_false] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(41),
  },
  [STATE(61)] = {
    [aux_sym__block] = STATE(70),
    [sym_block] = STATE(1441),
    [sym_identifier] = STATE(401),
    [sym__statement] = STATE(1186),
    [sym__expression] = STATE(930),
    [sym_parenthesis] = STATE(512),
    [sym__binary_expression] = STATE(910),
    [sym_binary_operator] = STATE(519),
    [sym_unary_operator] = STATE(528),
    [sym_indirect_access] = STATE(1361),
    [sym_field_expression] = STATE(594),
    [sym_not_operator] = STATE(549),
    [sym_metaclass_operator] = STATE(930),
    [sym_handle_operator] = STATE(930),
    [sym_comparison_operator] = STATE(498),
    [sym_boolean_operator] = STATE(498),
    [sym_postfix_operator] = STATE(512),
    [sym_string] = STATE(512),
    [sym_matrix] = STATE(512),
    [sym_cell] = STATE(471),
    [sym_ignored_argument] = STATE(1488),
    [sym_assignment] = STATE(1186),
    [sym_multioutput_variable] = STATE(1488),
    [sym_function_call] = STATE(401),
    [sym_command] = STATE(1186),
    [sym__range_element] = STATE(1509),
    [sym_range] = STATE(930),
    [sym_return_statement] = STATE(1186),
    [sym_continue_statement] = STATE(1186),
    [sym_break_statement] = STATE(1186),
    [sym_if_statement] = STATE(1186),
    [sym_for_statement] = STATE(1186),
    [sym_while_statement] = STATE(1186),
    [sym_switch_statement] = STATE(1186),
    [sym_lambda] = STATE(930),
    [sym_global_operator] = STATE(1186),
    [sym_persistent_operator] = STATE(1186),
    [sym_arguments_statement] = STATE(59),
    [sym__function_definition_with_end] = STATE(1191),
    [sym_class_definition] = STATE(1186),
    [sym_try_statement] = STATE(1186),
    [sym_spmd_statement] = STATE(1186),
    [sym_number] = STATE(512),
    [sym_boolean] = STATE(397),
    [sym__keywords] = STATE(373),
    [aux_sym_function_definition_repeat1] = STATE(59),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(414),
    [anon_sym_for] = ACTIONS(29),
    [anon_sym_parfor] = ACTIONS(31),
    [anon_sym_while] = ACTIONS(33),
    [anon_sym_switch] = ACTIONS(35),
    [anon_sym_global] = ACTIONS(37),
    [anon_sym_persistent] = ACTIONS(39),
    [anon_sym_arguments] = ACTIONS(209),
    [anon_sym_function] = ACTIONS(211),
    [anon_sym_endfunction] = ACTIONS(416),
    [anon_sym_properties] = ACTIONS(41),
    [anon_sym_get] = ACTIONS(41),
    [anon_sym_set] = ACTIONS(41),
    [anon_sym_methods] = ACTIONS(41),
    [anon_sym_events] = ACTIONS(41),
    [anon_sym_enumeration] = ACTIONS(41),
    [anon_sym_classdef] = ACTIONS(45),
    [anon_sym_try] = ACTIONS(47),
    [anon_sym_spmd] = ACTIONS(49),
    [aux_sym_number_token1] = ACTIONS(51),
    [aux_sym_number_token2] = ACTIONS(53),
    [aux_sym_number_token3] = ACTIONS(53),
    [anon_sym_true] = ACTIONS(55),
    [anon_sym_false] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(41),
  },
  [STATE(62)] = {
    [aux_sym__block] = STATE(70),
    [sym_block] = STATE(1422),
    [sym_identifier] = STATE(401),
    [sym__statement] = STATE(1186),
    [sym__expression] = STATE(930),
    [sym_parenthesis] = STATE(512),
    [sym__binary_expression] = STATE(910),
    [sym_binary_operator] = STATE(519),
    [sym_unary_operator] = STATE(528),
    [sym_indirect_access] = STATE(1361),
    [sym_field_expression] = STATE(594),
    [sym_not_operator] = STATE(549),
    [sym_metaclass_operator] = STATE(930),
    [sym_handle_operator] = STATE(930),
    [sym_comparison_operator] = STATE(498),
    [sym_boolean_operator] = STATE(498),
    [sym_postfix_operator] = STATE(512),
    [sym_string] = STATE(512),
    [sym_matrix] = STATE(512),
    [sym_cell] = STATE(471),
    [sym_ignored_argument] = STATE(1488),
    [sym_assignment] = STATE(1186),
    [sym_multioutput_variable] = STATE(1488),
    [sym_function_call] = STATE(401),
    [sym_command] = STATE(1186),
    [sym__range_element] = STATE(1509),
    [sym_range] = STATE(930),
    [sym_return_statement] = STATE(1186),
    [sym_continue_statement] = STATE(1186),
    [sym_break_statement] = STATE(1186),
    [sym_if_statement] = STATE(1186),
    [sym_for_statement] = STATE(1186),
    [sym_while_statement] = STATE(1186),
    [sym_switch_statement] = STATE(1186),
    [sym_lambda] = STATE(930),
    [sym_global_operator] = STATE(1186),
    [sym_persistent_operator] = STATE(1186),
    [sym_arguments_statement] = STATE(64),
    [sym__function_definition_with_end] = STATE(1191),
    [sym_class_definition] = STATE(1186),
    [sym_try_statement] = STATE(1186),
    [sym_spmd_statement] = STATE(1186),
    [sym_number] = STATE(512),
    [sym_boolean] = STATE(397),
    [sym__keywords] = STATE(373),
    [aux_sym_function_definition_repeat1] = STATE(64),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(418),
    [anon_sym_for] = ACTIONS(29),
    [anon_sym_parfor] = ACTIONS(31),
    [anon_sym_while] = ACTIONS(33),
    [anon_sym_switch] = ACTIONS(35),
    [anon_sym_global] = ACTIONS(37),
    [anon_sym_persistent] = ACTIONS(39),
    [anon_sym_arguments] = ACTIONS(209),
    [anon_sym_function] = ACTIONS(211),
    [anon_sym_endfunction] = ACTIONS(420),
    [anon_sym_properties] = ACTIONS(41),
    [anon_sym_get] = ACTIONS(41),
    [anon_sym_set] = ACTIONS(41),
    [anon_sym_methods] = ACTIONS(41),
    [anon_sym_events] = ACTIONS(41),
    [anon_sym_enumeration] = ACTIONS(41),
    [anon_sym_classdef] = ACTIONS(45),
    [anon_sym_try] = ACTIONS(47),
    [anon_sym_spmd] = ACTIONS(49),
    [aux_sym_number_token1] = ACTIONS(51),
    [aux_sym_number_token2] = ACTIONS(53),
    [aux_sym_number_token3] = ACTIONS(53),
    [anon_sym_true] = ACTIONS(55),
    [anon_sym_false] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(41),
  },
  [STATE(63)] = {
    [aux_sym__block] = STATE(70),
    [sym_block] = STATE(1430),
    [sym_identifier] = STATE(401),
    [sym__statement] = STATE(1186),
    [sym__expression] = STATE(930),
    [sym_parenthesis] = STATE(512),
    [sym__binary_expression] = STATE(910),
    [sym_binary_operator] = STATE(519),
    [sym_unary_operator] = STATE(528),
    [sym_indirect_access] = STATE(1361),
    [sym_field_expression] = STATE(594),
    [sym_not_operator] = STATE(549),
    [sym_metaclass_operator] = STATE(930),
    [sym_handle_operator] = STATE(930),
    [sym_comparison_operator] = STATE(498),
    [sym_boolean_operator] = STATE(498),
    [sym_postfix_operator] = STATE(512),
    [sym_string] = STATE(512),
    [sym_matrix] = STATE(512),
    [sym_cell] = STATE(471),
    [sym_ignored_argument] = STATE(1488),
    [sym_assignment] = STATE(1186),
    [sym_multioutput_variable] = STATE(1488),
    [sym_function_call] = STATE(401),
    [sym_command] = STATE(1186),
    [sym__range_element] = STATE(1509),
    [sym_range] = STATE(930),
    [sym_return_statement] = STATE(1186),
    [sym_continue_statement] = STATE(1186),
    [sym_break_statement] = STATE(1186),
    [sym_if_statement] = STATE(1186),
    [sym_for_statement] = STATE(1186),
    [sym_while_statement] = STATE(1186),
    [sym_switch_statement] = STATE(1186),
    [sym_lambda] = STATE(930),
    [sym_global_operator] = STATE(1186),
    [sym_persistent_operator] = STATE(1186),
    [sym_arguments_statement] = STATE(368),
    [sym__function_definition_with_end] = STATE(1191),
    [sym_class_definition] = STATE(1186),
    [sym_try_statement] = STATE(1186),
    [sym_spmd_statement] = STATE(1186),
    [sym_number] = STATE(512),
    [sym_boolean] = STATE(397),
    [sym__keywords] = STATE(373),
    [aux_sym_function_definition_repeat1] = STATE(368),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(422),
    [anon_sym_for] = ACTIONS(29),
    [anon_sym_parfor] = ACTIONS(31),
    [anon_sym_while] = ACTIONS(33),
    [anon_sym_switch] = ACTIONS(35),
    [anon_sym_global] = ACTIONS(37),
    [anon_sym_persistent] = ACTIONS(39),
    [anon_sym_arguments] = ACTIONS(209),
    [anon_sym_function] = ACTIONS(211),
    [anon_sym_endfunction] = ACTIONS(424),
    [anon_sym_properties] = ACTIONS(41),
    [anon_sym_get] = ACTIONS(41),
    [anon_sym_set] = ACTIONS(41),
    [anon_sym_methods] = ACTIONS(41),
    [anon_sym_events] = ACTIONS(41),
    [anon_sym_enumeration] = ACTIONS(41),
    [anon_sym_classdef] = ACTIONS(45),
    [anon_sym_try] = ACTIONS(47),
    [anon_sym_spmd] = ACTIONS(49),
    [aux_sym_number_token1] = ACTIONS(51),
    [aux_sym_number_token2] = ACTIONS(53),
    [aux_sym_number_token3] = ACTIONS(53),
    [anon_sym_true] = ACTIONS(55),
    [anon_sym_false] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(41),
  },
  [STATE(64)] = {
    [aux_sym__block] = STATE(70),
    [sym_block] = STATE(1440),
    [sym_identifier] = STATE(401),
    [sym__statement] = STATE(1186),
    [sym__expression] = STATE(930),
    [sym_parenthesis] = STATE(512),
    [sym__binary_expression] = STATE(910),
    [sym_binary_operator] = STATE(519),
    [sym_unary_operator] = STATE(528),
    [sym_indirect_access] = STATE(1361),
    [sym_field_expression] = STATE(594),
    [sym_not_operator] = STATE(549),
    [sym_metaclass_operator] = STATE(930),
    [sym_handle_operator] = STATE(930),
    [sym_comparison_operator] = STATE(498),
    [sym_boolean_operator] = STATE(498),
    [sym_postfix_operator] = STATE(512),
    [sym_string] = STATE(512),
    [sym_matrix] = STATE(512),
    [sym_cell] = STATE(471),
    [sym_ignored_argument] = STATE(1488),
    [sym_assignment] = STATE(1186),
    [sym_multioutput_variable] = STATE(1488),
    [sym_function_call] = STATE(401),
    [sym_command] = STATE(1186),
    [sym__range_element] = STATE(1509),
    [sym_range] = STATE(930),
    [sym_return_statement] = STATE(1186),
    [sym_continue_statement] = STATE(1186),
    [sym_break_statement] = STATE(1186),
    [sym_if_statement] = STATE(1186),
    [sym_for_statement] = STATE(1186),
    [sym_while_statement] = STATE(1186),
    [sym_switch_statement] = STATE(1186),
    [sym_lambda] = STATE(930),
    [sym_global_operator] = STATE(1186),
    [sym_persistent_operator] = STATE(1186),
    [sym_arguments_statement] = STATE(368),
    [sym__function_definition_with_end] = STATE(1191),
    [sym_class_definition] = STATE(1186),
    [sym_try_statement] = STATE(1186),
    [sym_spmd_statement] = STATE(1186),
    [sym_number] = STATE(512),
    [sym_boolean] = STATE(397),
    [sym__keywords] = STATE(373),
    [aux_sym_function_definition_repeat1] = STATE(368),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(394),
    [anon_sym_for] = ACTIONS(29),
    [anon_sym_parfor] = ACTIONS(31),
    [anon_sym_while] = ACTIONS(33),
    [anon_sym_switch] = ACTIONS(35),
    [anon_sym_global] = ACTIONS(37),
    [anon_sym_persistent] = ACTIONS(39),
    [anon_sym_arguments] = ACTIONS(209),
    [anon_sym_function] = ACTIONS(211),
    [anon_sym_endfunction] = ACTIONS(396),
    [anon_sym_properties] = ACTIONS(41),
    [anon_sym_get] = ACTIONS(41),
    [anon_sym_set] = ACTIONS(41),
    [anon_sym_methods] = ACTIONS(41),
    [anon_sym_events] = ACTIONS(41),
    [anon_sym_enumeration] = ACTIONS(41),
    [anon_sym_classdef] = ACTIONS(45),
    [anon_sym_try] = ACTIONS(47),
    [anon_sym_spmd] = ACTIONS(49),
    [aux_sym_number_token1] = ACTIONS(51),
    [aux_sym_number_token2] = ACTIONS(53),
    [aux_sym_number_token3] = ACTIONS(53),
    [anon_sym_true] = ACTIONS(55),
    [anon_sym_false] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(41),
  },
  [STATE(65)] = {
    [aux_sym__block] = STATE(70),
    [sym_block] = STATE(1447),
    [sym_identifier] = STATE(401),
    [sym__statement] = STATE(1186),
    [sym__expression] = STATE(930),
    [sym_parenthesis] = STATE(512),
    [sym__binary_expression] = STATE(910),
    [sym_binary_operator] = STATE(519),
    [sym_unary_operator] = STATE(528),
    [sym_indirect_access] = STATE(1361),
    [sym_field_expression] = STATE(594),
    [sym_not_operator] = STATE(549),
    [sym_metaclass_operator] = STATE(930),
    [sym_handle_operator] = STATE(930),
    [sym_comparison_operator] = STATE(498),
    [sym_boolean_operator] = STATE(498),
    [sym_postfix_operator] = STATE(512),
    [sym_string] = STATE(512),
    [sym_matrix] = STATE(512),
    [sym_cell] = STATE(471),
    [sym_ignored_argument] = STATE(1488),
    [sym_assignment] = STATE(1186),
    [sym_multioutput_variable] = STATE(1488),
    [sym_function_call] = STATE(401),
    [sym_command] = STATE(1186),
    [sym__range_element] = STATE(1509),
    [sym_range] = STATE(930),
    [sym_return_statement] = STATE(1186),
    [sym_continue_statement] = STATE(1186),
    [sym_break_statement] = STATE(1186),
    [sym_if_statement] = STATE(1186),
    [sym_for_statement] = STATE(1186),
    [sym_while_statement] = STATE(1186),
    [sym_switch_statement] = STATE(1186),
    [sym_lambda] = STATE(930),
    [sym_global_operator] = STATE(1186),
    [sym_persistent_operator] = STATE(1186),
    [sym_arguments_statement] = STATE(56),
    [sym__function_definition_with_end] = STATE(1191),
    [sym_class_definition] = STATE(1186),
    [sym_try_statement] = STATE(1186),
    [sym_spmd_statement] = STATE(1186),
    [sym_number] = STATE(512),
    [sym_boolean] = STATE(397),
    [sym__keywords] = STATE(373),
    [aux_sym_function_definition_repeat1] = STATE(56),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(426),
    [anon_sym_for] = ACTIONS(29),
    [anon_sym_parfor] = ACTIONS(31),
    [anon_sym_while] = ACTIONS(33),
    [anon_sym_switch] = ACTIONS(35),
    [anon_sym_global] = ACTIONS(37),
    [anon_sym_persistent] = ACTIONS(39),
    [anon_sym_arguments] = ACTIONS(209),
    [anon_sym_function] = ACTIONS(211),
    [anon_sym_endfunction] = ACTIONS(428),
    [anon_sym_properties] = ACTIONS(41),
    [anon_sym_get] = ACTIONS(41),
    [anon_sym_set] = ACTIONS(41),
    [anon_sym_methods] = ACTIONS(41),
    [anon_sym_events] = ACTIONS(41),
    [anon_sym_enumeration] = ACTIONS(41),
    [anon_sym_classdef] = ACTIONS(45),
    [anon_sym_try] = ACTIONS(47),
    [anon_sym_spmd] = ACTIONS(49),
    [aux_sym_number_token1] = ACTIONS(51),
    [aux_sym_number_token2] = ACTIONS(53),
    [aux_sym_number_token3] = ACTIONS(53),
    [anon_sym_true] = ACTIONS(55),
    [anon_sym_false] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(41),
  },
  [STATE(66)] = {
    [aux_sym__block] = STATE(70),
    [sym_block] = STATE(1446),
    [sym_identifier] = STATE(401),
    [sym__statement] = STATE(1186),
    [sym__expression] = STATE(930),
    [sym_parenthesis] = STATE(512),
    [sym__binary_expression] = STATE(910),
    [sym_binary_operator] = STATE(519),
    [sym_unary_operator] = STATE(528),
    [sym_indirect_access] = STATE(1361),
    [sym_field_expression] = STATE(594),
    [sym_not_operator] = STATE(549),
    [sym_metaclass_operator] = STATE(930),
    [sym_handle_operator] = STATE(930),
    [sym_comparison_operator] = STATE(498),
    [sym_boolean_operator] = STATE(498),
    [sym_postfix_operator] = STATE(512),
    [sym_string] = STATE(512),
    [sym_matrix] = STATE(512),
    [sym_cell] = STATE(471),
    [sym_ignored_argument] = STATE(1488),
    [sym_assignment] = STATE(1186),
    [sym_multioutput_variable] = STATE(1488),
    [sym_function_call] = STATE(401),
    [sym_command] = STATE(1186),
    [sym__range_element] = STATE(1509),
    [sym_range] = STATE(930),
    [sym_return_statement] = STATE(1186),
    [sym_continue_statement] = STATE(1186),
    [sym_break_statement] = STATE(1186),
    [sym_if_statement] = STATE(1186),
    [sym_for_statement] = STATE(1186),
    [sym_while_statement] = STATE(1186),
    [sym_switch_statement] = STATE(1186),
    [sym_lambda] = STATE(930),
    [sym_global_operator] = STATE(1186),
    [sym_persistent_operator] = STATE(1186),
    [sym_arguments_statement] = STATE(57),
    [sym__function_definition_with_end] = STATE(1191),
    [sym_class_definition] = STATE(1186),
    [sym_try_statement] = STATE(1186),
    [sym_spmd_statement] = STATE(1186),
    [sym_number] = STATE(512),
    [sym_boolean] = STATE(397),
    [sym__keywords] = STATE(373),
    [aux_sym_function_definition_repeat1] = STATE(57),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(398),
    [anon_sym_for] = ACTIONS(29),
    [anon_sym_parfor] = ACTIONS(31),
    [anon_sym_while] = ACTIONS(33),
    [anon_sym_switch] = ACTIONS(35),
    [anon_sym_global] = ACTIONS(37),
    [anon_sym_persistent] = ACTIONS(39),
    [anon_sym_arguments] = ACTIONS(209),
    [anon_sym_function] = ACTIONS(211),
    [anon_sym_endfunction] = ACTIONS(400),
    [anon_sym_properties] = ACTIONS(41),
    [anon_sym_get] = ACTIONS(41),
    [anon_sym_set] = ACTIONS(41),
    [anon_sym_methods] = ACTIONS(41),
    [anon_sym_events] = ACTIONS(41),
    [anon_sym_enumeration] = ACTIONS(41),
    [anon_sym_classdef] = ACTIONS(45),
    [anon_sym_try] = ACTIONS(47),
    [anon_sym_spmd] = ACTIONS(49),
    [aux_sym_number_token1] = ACTIONS(51),
    [aux_sym_number_token2] = ACTIONS(53),
    [aux_sym_number_token3] = ACTIONS(53),
    [anon_sym_true] = ACTIONS(55),
    [anon_sym_false] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(41),
  },
  [STATE(67)] = {
    [aux_sym__block] = STATE(71),
    [sym_identifier] = STATE(401),
    [sym__statement] = STATE(1167),
    [sym__expression] = STATE(938),
    [sym_parenthesis] = STATE(512),
    [sym__binary_expression] = STATE(910),
    [sym_binary_operator] = STATE(519),
    [sym_unary_operator] = STATE(528),
    [sym_indirect_access] = STATE(1361),
    [sym_field_expression] = STATE(594),
    [sym_not_operator] = STATE(549),
    [sym_metaclass_operator] = STATE(938),
    [sym_handle_operator] = STATE(938),
    [sym_comparison_operator] = STATE(498),
    [sym_boolean_operator] = STATE(498),
    [sym_postfix_operator] = STATE(512),
    [sym_string] = STATE(512),
    [sym_matrix] = STATE(512),
    [sym_cell] = STATE(471),
    [sym_ignored_argument] = STATE(1488),
    [sym_assignment] = STATE(1167),
    [sym_multioutput_variable] = STATE(1488),
    [sym_function_call] = STATE(401),
    [sym_command] = STATE(1167),
    [sym__range_element] = STATE(1509),
    [sym_range] = STATE(938),
    [sym_return_statement] = STATE(1167),
    [sym_continue_statement] = STATE(1167),
    [sym_break_statement] = STATE(1167),
    [sym_if_statement] = STATE(1167),
    [sym_for_statement] = STATE(1167),
    [sym_while_statement] = STATE(1167),
    [sym_switch_statement] = STATE(1167),
    [sym_lambda] = STATE(938),
    [sym_global_operator] = STATE(1167),
    [sym_persistent_operator] = STATE(1167),
    [sym_function_definition] = STATE(1324),
    [sym__function_definition_with_end] = STATE(1201),
    [sym_class_definition] = STATE(1167),
    [sym_try_statement] = STATE(1167),
    [sym_spmd_statement] = STATE(1167),
    [sym_number] = STATE(512),
    [sym_boolean] = STATE(397),
    [sym__keywords] = STATE(373),
    [aux_sym_source_file_repeat1] = STATE(1324),
    [ts_builtin_sym_end] = ACTIONS(430),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_for] = ACTIONS(29),
    [anon_sym_parfor] = ACTIONS(31),
    [anon_sym_while] = ACTIONS(33),
    [anon_sym_switch] = ACTIONS(35),
    [anon_sym_global] = ACTIONS(37),
    [anon_sym_persistent] = ACTIONS(39),
    [anon_sym_arguments] = ACTIONS(41),
    [anon_sym_function] = ACTIONS(43),
    [anon_sym_properties] = ACTIONS(41),
    [anon_sym_get] = ACTIONS(41),
    [anon_sym_set] = ACTIONS(41),
    [anon_sym_methods] = ACTIONS(41),
    [anon_sym_events] = ACTIONS(41),
    [anon_sym_enumeration] = ACTIONS(41),
    [anon_sym_classdef] = ACTIONS(45),
    [anon_sym_try] = ACTIONS(47),
    [anon_sym_spmd] = ACTIONS(49),
    [aux_sym_number_token1] = ACTIONS(51),
    [aux_sym_number_token2] = ACTIONS(53),
    [aux_sym_number_token3] = ACTIONS(53),
    [anon_sym_true] = ACTIONS(55),
    [anon_sym_false] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(41),
  },
  [STATE(68)] = {
    [aux_sym__block] = STATE(69),
    [sym_identifier] = STATE(401),
    [sym__statement] = STATE(1186),
    [sym__expression] = STATE(930),
    [sym_parenthesis] = STATE(512),
    [sym__binary_expression] = STATE(910),
    [sym_binary_operator] = STATE(519),
    [sym_unary_operator] = STATE(528),
    [sym_indirect_access] = STATE(1361),
    [sym_field_expression] = STATE(594),
    [sym_not_operator] = STATE(549),
    [sym_metaclass_operator] = STATE(930),
    [sym_handle_operator] = STATE(930),
    [sym_comparison_operator] = STATE(498),
    [sym_boolean_operator] = STATE(498),
    [sym_postfix_operator] = STATE(512),
    [sym_string] = STATE(512),
    [sym_matrix] = STATE(512),
    [sym_cell] = STATE(471),
    [sym_ignored_argument] = STATE(1488),
    [sym_assignment] = STATE(1186),
    [sym_multioutput_variable] = STATE(1488),
    [sym_function_call] = STATE(401),
    [sym_command] = STATE(1186),
    [sym__range_element] = STATE(1509),
    [sym_range] = STATE(930),
    [sym_return_statement] = STATE(1186),
    [sym_continue_statement] = STATE(1186),
    [sym_break_statement] = STATE(1186),
    [sym_if_statement] = STATE(1186),
    [sym_for_statement] = STATE(1186),
    [sym_while_statement] = STATE(1186),
    [sym_switch_statement] = STATE(1186),
    [sym_lambda] = STATE(930),
    [sym_global_operator] = STATE(1186),
    [sym_persistent_operator] = STATE(1186),
    [sym__function_definition_with_end] = STATE(1191),
    [sym_class_definition] = STATE(1186),
    [sym_try_statement] = STATE(1186),
    [sym_spmd_statement] = STATE(1186),
    [sym_number] = STATE(512),
    [sym_boolean] = STATE(397),
    [sym__keywords] = STATE(373),
    [ts_builtin_sym_end] = ACTIONS(271),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(273),
    [anon_sym_for] = ACTIONS(29),
    [anon_sym_parfor] = ACTIONS(31),
    [anon_sym_while] = ACTIONS(33),
    [anon_sym_switch] = ACTIONS(35),
    [anon_sym_global] = ACTIONS(37),
    [anon_sym_persistent] = ACTIONS(39),
    [anon_sym_arguments] = ACTIONS(41),
    [anon_sym_function] = ACTIONS(432),
    [anon_sym_endfunction] = ACTIONS(271),
    [anon_sym_properties] = ACTIONS(41),
    [anon_sym_get] = ACTIONS(41),
    [anon_sym_set] = ACTIONS(41),
    [anon_sym_methods] = ACTIONS(41),
    [anon_sym_events] = ACTIONS(41),
    [anon_sym_enumeration] = ACTIONS(41),
    [anon_sym_classdef] = ACTIONS(45),
    [anon_sym_try] = ACTIONS(47),
    [anon_sym_spmd] = ACTIONS(49),
    [aux_sym_number_token1] = ACTIONS(51),
    [aux_sym_number_token2] = ACTIONS(53),
    [aux_sym_number_token3] = ACTIONS(53),
    [anon_sym_true] = ACTIONS(55),
    [anon_sym_false] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(41),
  },
  [STATE(69)] = {
    [aux_sym__block] = STATE(69),
    [sym_identifier] = STATE(401),
    [sym__statement] = STATE(1186),
    [sym__expression] = STATE(930),
    [sym_parenthesis] = STATE(512),
    [sym__binary_expression] = STATE(910),
    [sym_binary_operator] = STATE(519),
    [sym_unary_operator] = STATE(528),
    [sym_indirect_access] = STATE(1361),
    [sym_field_expression] = STATE(594),
    [sym_not_operator] = STATE(549),
    [sym_metaclass_operator] = STATE(930),
    [sym_handle_operator] = STATE(930),
    [sym_comparison_operator] = STATE(498),
    [sym_boolean_operator] = STATE(498),
    [sym_postfix_operator] = STATE(512),
    [sym_string] = STATE(512),
    [sym_matrix] = STATE(512),
    [sym_cell] = STATE(471),
    [sym_ignored_argument] = STATE(1488),
    [sym_assignment] = STATE(1186),
    [sym_multioutput_variable] = STATE(1488),
    [sym_function_call] = STATE(401),
    [sym_command] = STATE(1186),
    [sym__range_element] = STATE(1509),
    [sym_range] = STATE(930),
    [sym_return_statement] = STATE(1186),
    [sym_continue_statement] = STATE(1186),
    [sym_break_statement] = STATE(1186),
    [sym_if_statement] = STATE(1186),
    [sym_for_statement] = STATE(1186),
    [sym_while_statement] = STATE(1186),
    [sym_switch_statement] = STATE(1186),
    [sym_lambda] = STATE(930),
    [sym_global_operator] = STATE(1186),
    [sym_persistent_operator] = STATE(1186),
    [sym__function_definition_with_end] = STATE(1191),
    [sym_class_definition] = STATE(1186),
    [sym_try_statement] = STATE(1186),
    [sym_spmd_statement] = STATE(1186),
    [sym_number] = STATE(512),
    [sym_boolean] = STATE(397),
    [sym__keywords] = STATE(373),
    [ts_builtin_sym_end] = ACTIONS(333),
    [anon_sym_LPAREN] = ACTIONS(303),
    [anon_sym_PLUS] = ACTIONS(306),
    [anon_sym_DASH] = ACTIONS(306),
    [anon_sym_TILDE] = ACTIONS(309),
    [anon_sym_QMARK] = ACTIONS(312),
    [anon_sym_AT] = ACTIONS(315),
    [anon_sym_LBRACK] = ACTIONS(318),
    [anon_sym_LBRACE] = ACTIONS(321),
    [anon_sym_return] = ACTIONS(324),
    [anon_sym_continue] = ACTIONS(327),
    [anon_sym_break] = ACTIONS(330),
    [anon_sym_if] = ACTIONS(337),
    [anon_sym_end] = ACTIONS(335),
    [anon_sym_for] = ACTIONS(340),
    [anon_sym_parfor] = ACTIONS(343),
    [anon_sym_while] = ACTIONS(346),
    [anon_sym_switch] = ACTIONS(349),
    [anon_sym_global] = ACTIONS(352),
    [anon_sym_persistent] = ACTIONS(355),
    [anon_sym_arguments] = ACTIONS(358),
    [anon_sym_function] = ACTIONS(361),
    [anon_sym_endfunction] = ACTIONS(333),
    [anon_sym_properties] = ACTIONS(358),
    [anon_sym_get] = ACTIONS(358),
    [anon_sym_set] = ACTIONS(358),
    [anon_sym_methods] = ACTIONS(358),
    [anon_sym_events] = ACTIONS(358),
    [anon_sym_enumeration] = ACTIONS(358),
    [anon_sym_classdef] = ACTIONS(364),
    [anon_sym_try] = ACTIONS(367),
    [anon_sym_spmd] = ACTIONS(370),
    [aux_sym_number_token1] = ACTIONS(373),
    [aux_sym_number_token2] = ACTIONS(376),
    [aux_sym_number_token3] = ACTIONS(376),
    [anon_sym_true] = ACTIONS(379),
    [anon_sym_false] = ACTIONS(379),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(382),
    [sym__single_quote_string_start] = ACTIONS(385),
    [sym__double_quote_string_start] = ACTIONS(388),
    [sym__multioutput_variable_start] = ACTIONS(391),
    [sym__external_identifier] = ACTIONS(358),
  },
  [STATE(70)] = {
    [aux_sym__block] = STATE(69),
    [sym_identifier] = STATE(401),
    [sym__statement] = STATE(1186),
    [sym__expression] = STATE(930),
    [sym_parenthesis] = STATE(512),
    [sym__binary_expression] = STATE(910),
    [sym_binary_operator] = STATE(519),
    [sym_unary_operator] = STATE(528),
    [sym_indirect_access] = STATE(1361),
    [sym_field_expression] = STATE(594),
    [sym_not_operator] = STATE(549),
    [sym_metaclass_operator] = STATE(930),
    [sym_handle_operator] = STATE(930),
    [sym_comparison_operator] = STATE(498),
    [sym_boolean_operator] = STATE(498),
    [sym_postfix_operator] = STATE(512),
    [sym_string] = STATE(512),
    [sym_matrix] = STATE(512),
    [sym_cell] = STATE(471),
    [sym_ignored_argument] = STATE(1488),
    [sym_assignment] = STATE(1186),
    [sym_multioutput_variable] = STATE(1488),
    [sym_function_call] = STATE(401),
    [sym_command] = STATE(1186),
    [sym__range_element] = STATE(1509),
    [sym_range] = STATE(930),
    [sym_return_statement] = STATE(1186),
    [sym_continue_statement] = STATE(1186),
    [sym_break_statement] = STATE(1186),
    [sym_if_statement] = STATE(1186),
    [sym_for_statement] = STATE(1186),
    [sym_while_statement] = STATE(1186),
    [sym_switch_statement] = STATE(1186),
    [sym_lambda] = STATE(930),
    [sym_global_operator] = STATE(1186),
    [sym_persistent_operator] = STATE(1186),
    [sym__function_definition_with_end] = STATE(1191),
    [sym_class_definition] = STATE(1186),
    [sym_try_statement] = STATE(1186),
    [sym_spmd_statement] = STATE(1186),
    [sym_number] = STATE(512),
    [sym_boolean] = STATE(397),
    [sym__keywords] = STATE(373),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(273),
    [anon_sym_for] = ACTIONS(29),
    [anon_sym_parfor] = ACTIONS(31),
    [anon_sym_while] = ACTIONS(33),
    [anon_sym_switch] = ACTIONS(35),
    [anon_sym_global] = ACTIONS(37),
    [anon_sym_persistent] = ACTIONS(39),
    [anon_sym_arguments] = ACTIONS(41),
    [anon_sym_function] = ACTIONS(211),
    [anon_sym_endfunction] = ACTIONS(271),
    [anon_sym_properties] = ACTIONS(41),
    [anon_sym_get] = ACTIONS(41),
    [anon_sym_set] = ACTIONS(41),
    [anon_sym_methods] = ACTIONS(41),
    [anon_sym_events] = ACTIONS(41),
    [anon_sym_enumeration] = ACTIONS(41),
    [anon_sym_classdef] = ACTIONS(45),
    [anon_sym_try] = ACTIONS(47),
    [anon_sym_spmd] = ACTIONS(49),
    [aux_sym_number_token1] = ACTIONS(51),
    [aux_sym_number_token2] = ACTIONS(53),
    [aux_sym_number_token3] = ACTIONS(53),
    [anon_sym_true] = ACTIONS(55),
    [anon_sym_false] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(41),
  },
  [STATE(71)] = {
    [aux_sym__block] = STATE(71),
    [sym_identifier] = STATE(401),
    [sym__statement] = STATE(1167),
    [sym__expression] = STATE(938),
    [sym_parenthesis] = STATE(512),
    [sym__binary_expression] = STATE(910),
    [sym_binary_operator] = STATE(519),
    [sym_unary_operator] = STATE(528),
    [sym_indirect_access] = STATE(1361),
    [sym_field_expression] = STATE(594),
    [sym_not_operator] = STATE(549),
    [sym_metaclass_operator] = STATE(938),
    [sym_handle_operator] = STATE(938),
    [sym_comparison_operator] = STATE(498),
    [sym_boolean_operator] = STATE(498),
    [sym_postfix_operator] = STATE(512),
    [sym_string] = STATE(512),
    [sym_matrix] = STATE(512),
    [sym_cell] = STATE(471),
    [sym_ignored_argument] = STATE(1488),
    [sym_assignment] = STATE(1167),
    [sym_multioutput_variable] = STATE(1488),
    [sym_function_call] = STATE(401),
    [sym_command] = STATE(1167),
    [sym__range_element] = STATE(1509),
    [sym_range] = STATE(938),
    [sym_return_statement] = STATE(1167),
    [sym_continue_statement] = STATE(1167),
    [sym_break_statement] = STATE(1167),
    [sym_if_statement] = STATE(1167),
    [sym_for_statement] = STATE(1167),
    [sym_while_statement] = STATE(1167),
    [sym_switch_statement] = STATE(1167),
    [sym_lambda] = STATE(938),
    [sym_global_operator] = STATE(1167),
    [sym_persistent_operator] = STATE(1167),
    [sym__function_definition_with_end] = STATE(1201),
    [sym_class_definition] = STATE(1167),
    [sym_try_statement] = STATE(1167),
    [sym_spmd_statement] = STATE(1167),
    [sym_number] = STATE(512),
    [sym_boolean] = STATE(397),
    [sym__keywords] = STATE(373),
    [ts_builtin_sym_end] = ACTIONS(333),
    [anon_sym_LPAREN] = ACTIONS(303),
    [anon_sym_PLUS] = ACTIONS(306),
    [anon_sym_DASH] = ACTIONS(306),
    [anon_sym_TILDE] = ACTIONS(309),
    [anon_sym_QMARK] = ACTIONS(312),
    [anon_sym_AT] = ACTIONS(315),
    [anon_sym_LBRACK] = ACTIONS(318),
    [anon_sym_LBRACE] = ACTIONS(321),
    [anon_sym_return] = ACTIONS(324),
    [anon_sym_continue] = ACTIONS(327),
    [anon_sym_break] = ACTIONS(330),
    [anon_sym_if] = ACTIONS(337),
    [anon_sym_for] = ACTIONS(340),
    [anon_sym_parfor] = ACTIONS(343),
    [anon_sym_while] = ACTIONS(346),
    [anon_sym_switch] = ACTIONS(349),
    [anon_sym_global] = ACTIONS(352),
    [anon_sym_persistent] = ACTIONS(355),
    [anon_sym_arguments] = ACTIONS(358),
    [anon_sym_function] = ACTIONS(361),
    [anon_sym_properties] = ACTIONS(358),
    [anon_sym_get] = ACTIONS(358),
    [anon_sym_set] = ACTIONS(358),
    [anon_sym_methods] = ACTIONS(358),
    [anon_sym_events] = ACTIONS(358),
    [anon_sym_enumeration] = ACTIONS(358),
    [anon_sym_classdef] = ACTIONS(364),
    [anon_sym_try] = ACTIONS(367),
    [anon_sym_spmd] = ACTIONS(370),
    [aux_sym_number_token1] = ACTIONS(373),
    [aux_sym_number_token2] = ACTIONS(376),
    [aux_sym_number_token3] = ACTIONS(376),
    [anon_sym_true] = ACTIONS(379),
    [anon_sym_false] = ACTIONS(379),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(382),
    [sym__single_quote_string_start] = ACTIONS(385),
    [sym__double_quote_string_start] = ACTIONS(388),
    [sym__multioutput_variable_start] = ACTIONS(391),
    [sym__external_identifier] = ACTIONS(358),
  },
  [STATE(72)] = {
    [sym__args] = STATE(99),
    [aux_sym_field_expression_repeat1] = STATE(84),
    [anon_sym_SEMI] = ACTIONS(435),
    [anon_sym_COMMA] = ACTIONS(435),
    [anon_sym_LPAREN] = ACTIONS(437),
    [anon_sym_PLUS] = ACTIONS(435),
    [anon_sym_DOT_PLUS] = ACTIONS(435),
    [anon_sym_DASH] = ACTIONS(435),
    [anon_sym_DOT_DASH] = ACTIONS(435),
    [anon_sym_STAR] = ACTIONS(435),
    [anon_sym_DOT_STAR] = ACTIONS(435),
    [anon_sym_SLASH] = ACTIONS(435),
    [anon_sym_DOT_SLASH] = ACTIONS(435),
    [anon_sym_BSLASH] = ACTIONS(435),
    [anon_sym_DOT_BSLASH] = ACTIONS(435),
    [anon_sym_CARET] = ACTIONS(435),
    [anon_sym_DOT_CARET] = ACTIONS(435),
    [anon_sym_PIPE] = ACTIONS(435),
    [anon_sym_AMP] = ACTIONS(435),
    [anon_sym_DOT] = ACTIONS(439),
    [anon_sym_TILDE] = ACTIONS(435),
    [anon_sym_QMARK] = ACTIONS(435),
    [anon_sym_AT] = ACTIONS(441),
    [anon_sym_LT] = ACTIONS(435),
    [anon_sym_LT_EQ] = ACTIONS(435),
    [anon_sym_EQ_EQ] = ACTIONS(435),
    [anon_sym_TILDE_EQ] = ACTIONS(435),
    [anon_sym_GT_EQ] = ACTIONS(435),
    [anon_sym_GT] = ACTIONS(435),
    [anon_sym_AMP_AMP] = ACTIONS(435),
    [anon_sym_PIPE_PIPE] = ACTIONS(435),
    [anon_sym_DOT_SQUOTE] = ACTIONS(443),
    [anon_sym_SQUOTE] = ACTIONS(443),
    [anon_sym_LBRACK] = ACTIONS(435),
    [anon_sym_LF] = ACTIONS(435),
    [anon_sym_LBRACE] = ACTIONS(445),
    [anon_sym_COLON] = ACTIONS(435),
    [anon_sym_return] = ACTIONS(435),
    [anon_sym_continue] = ACTIONS(435),
    [anon_sym_break] = ACTIONS(435),
    [anon_sym_elseif] = ACTIONS(435),
    [anon_sym_else] = ACTIONS(435),
    [anon_sym_if] = ACTIONS(435),
    [anon_sym_end] = ACTIONS(435),
    [anon_sym_for] = ACTIONS(435),
    [anon_sym_parfor] = ACTIONS(435),
    [anon_sym_while] = ACTIONS(435),
    [anon_sym_switch] = ACTIONS(435),
    [anon_sym_global] = ACTIONS(435),
    [anon_sym_persistent] = ACTIONS(435),
    [anon_sym_arguments] = ACTIONS(435),
    [anon_sym_function] = ACTIONS(435),
    [anon_sym_properties] = ACTIONS(435),
    [anon_sym_get] = ACTIONS(435),
    [anon_sym_set] = ACTIONS(435),
    [anon_sym_methods] = ACTIONS(435),
    [anon_sym_events] = ACTIONS(435),
    [anon_sym_enumeration] = ACTIONS(435),
    [anon_sym_classdef] = ACTIONS(435),
    [anon_sym_try] = ACTIONS(435),
    [anon_sym_spmd] = ACTIONS(435),
    [aux_sym_number_token1] = ACTIONS(435),
    [aux_sym_number_token2] = ACTIONS(435),
    [aux_sym_number_token3] = ACTIONS(435),
    [anon_sym_true] = ACTIONS(435),
    [anon_sym_false] = ACTIONS(435),
    [anon_sym_CR] = ACTIONS(435),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(447),
    [sym__single_quote_string_start] = ACTIONS(447),
    [sym__double_quote_string_start] = ACTIONS(447),
    [sym__multioutput_variable_start] = ACTIONS(447),
    [sym__external_identifier] = ACTIONS(447),
  },
  [STATE(73)] = {
    [sym__args] = STATE(99),
    [aux_sym_field_expression_repeat1] = STATE(84),
    [anon_sym_SEMI] = ACTIONS(449),
    [anon_sym_COMMA] = ACTIONS(449),
    [anon_sym_LPAREN] = ACTIONS(437),
    [anon_sym_PLUS] = ACTIONS(451),
    [anon_sym_DOT_PLUS] = ACTIONS(451),
    [anon_sym_DASH] = ACTIONS(451),
    [anon_sym_DOT_DASH] = ACTIONS(451),
    [anon_sym_STAR] = ACTIONS(451),
    [anon_sym_DOT_STAR] = ACTIONS(451),
    [anon_sym_SLASH] = ACTIONS(451),
    [anon_sym_DOT_SLASH] = ACTIONS(451),
    [anon_sym_BSLASH] = ACTIONS(451),
    [anon_sym_DOT_BSLASH] = ACTIONS(451),
    [anon_sym_CARET] = ACTIONS(451),
    [anon_sym_DOT_CARET] = ACTIONS(451),
    [anon_sym_PIPE] = ACTIONS(451),
    [anon_sym_AMP] = ACTIONS(451),
    [anon_sym_DOT] = ACTIONS(439),
    [anon_sym_TILDE] = ACTIONS(449),
    [anon_sym_QMARK] = ACTIONS(449),
    [anon_sym_AT] = ACTIONS(441),
    [anon_sym_LT] = ACTIONS(449),
    [anon_sym_LT_EQ] = ACTIONS(449),
    [anon_sym_EQ_EQ] = ACTIONS(449),
    [anon_sym_TILDE_EQ] = ACTIONS(449),
    [anon_sym_GT_EQ] = ACTIONS(449),
    [anon_sym_GT] = ACTIONS(449),
    [anon_sym_AMP_AMP] = ACTIONS(449),
    [anon_sym_PIPE_PIPE] = ACTIONS(449),
    [anon_sym_DOT_SQUOTE] = ACTIONS(443),
    [anon_sym_SQUOTE] = ACTIONS(443),
    [anon_sym_LBRACK] = ACTIONS(449),
    [anon_sym_LF] = ACTIONS(449),
    [anon_sym_LBRACE] = ACTIONS(445),
    [anon_sym_COLON] = ACTIONS(453),
    [anon_sym_return] = ACTIONS(449),
    [anon_sym_continue] = ACTIONS(449),
    [anon_sym_break] = ACTIONS(449),
    [anon_sym_elseif] = ACTIONS(449),
    [anon_sym_else] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(449),
    [anon_sym_end] = ACTIONS(449),
    [anon_sym_for] = ACTIONS(449),
    [anon_sym_parfor] = ACTIONS(449),
    [anon_sym_while] = ACTIONS(449),
    [anon_sym_switch] = ACTIONS(449),
    [anon_sym_global] = ACTIONS(449),
    [anon_sym_persistent] = ACTIONS(449),
    [anon_sym_arguments] = ACTIONS(449),
    [anon_sym_function] = ACTIONS(449),
    [anon_sym_properties] = ACTIONS(449),
    [anon_sym_get] = ACTIONS(449),
    [anon_sym_set] = ACTIONS(449),
    [anon_sym_methods] = ACTIONS(449),
    [anon_sym_events] = ACTIONS(449),
    [anon_sym_enumeration] = ACTIONS(449),
    [anon_sym_classdef] = ACTIONS(449),
    [anon_sym_try] = ACTIONS(449),
    [anon_sym_spmd] = ACTIONS(449),
    [aux_sym_number_token1] = ACTIONS(449),
    [aux_sym_number_token2] = ACTIONS(449),
    [aux_sym_number_token3] = ACTIONS(449),
    [anon_sym_true] = ACTIONS(449),
    [anon_sym_false] = ACTIONS(449),
    [anon_sym_CR] = ACTIONS(449),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(456),
    [sym__single_quote_string_start] = ACTIONS(456),
    [sym__double_quote_string_start] = ACTIONS(456),
    [sym__multioutput_variable_start] = ACTIONS(456),
    [sym__external_identifier] = ACTIONS(456),
  },
  [STATE(74)] = {
    [sym__args] = STATE(99),
    [aux_sym_field_expression_repeat1] = STATE(84),
    [anon_sym_SEMI] = ACTIONS(449),
    [anon_sym_COMMA] = ACTIONS(449),
    [anon_sym_LPAREN] = ACTIONS(437),
    [anon_sym_PLUS] = ACTIONS(451),
    [anon_sym_DOT_PLUS] = ACTIONS(451),
    [anon_sym_DASH] = ACTIONS(451),
    [anon_sym_DOT_DASH] = ACTIONS(451),
    [anon_sym_STAR] = ACTIONS(451),
    [anon_sym_DOT_STAR] = ACTIONS(451),
    [anon_sym_SLASH] = ACTIONS(451),
    [anon_sym_DOT_SLASH] = ACTIONS(451),
    [anon_sym_BSLASH] = ACTIONS(451),
    [anon_sym_DOT_BSLASH] = ACTIONS(451),
    [anon_sym_CARET] = ACTIONS(451),
    [anon_sym_DOT_CARET] = ACTIONS(451),
    [anon_sym_PIPE] = ACTIONS(451),
    [anon_sym_AMP] = ACTIONS(451),
    [anon_sym_DOT] = ACTIONS(439),
    [anon_sym_TILDE] = ACTIONS(449),
    [anon_sym_QMARK] = ACTIONS(449),
    [anon_sym_AT] = ACTIONS(441),
    [anon_sym_LT] = ACTIONS(449),
    [anon_sym_LT_EQ] = ACTIONS(449),
    [anon_sym_EQ_EQ] = ACTIONS(449),
    [anon_sym_TILDE_EQ] = ACTIONS(449),
    [anon_sym_GT_EQ] = ACTIONS(449),
    [anon_sym_GT] = ACTIONS(449),
    [anon_sym_AMP_AMP] = ACTIONS(449),
    [anon_sym_PIPE_PIPE] = ACTIONS(449),
    [anon_sym_DOT_SQUOTE] = ACTIONS(443),
    [anon_sym_SQUOTE] = ACTIONS(443),
    [anon_sym_LBRACK] = ACTIONS(449),
    [anon_sym_LF] = ACTIONS(449),
    [anon_sym_LBRACE] = ACTIONS(445),
    [anon_sym_COLON] = ACTIONS(458),
    [anon_sym_return] = ACTIONS(449),
    [anon_sym_continue] = ACTIONS(449),
    [anon_sym_break] = ACTIONS(449),
    [anon_sym_elseif] = ACTIONS(449),
    [anon_sym_else] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(449),
    [anon_sym_end] = ACTIONS(449),
    [anon_sym_for] = ACTIONS(449),
    [anon_sym_parfor] = ACTIONS(449),
    [anon_sym_while] = ACTIONS(449),
    [anon_sym_switch] = ACTIONS(449),
    [anon_sym_global] = ACTIONS(449),
    [anon_sym_persistent] = ACTIONS(449),
    [anon_sym_arguments] = ACTIONS(449),
    [anon_sym_function] = ACTIONS(449),
    [anon_sym_properties] = ACTIONS(449),
    [anon_sym_get] = ACTIONS(449),
    [anon_sym_set] = ACTIONS(449),
    [anon_sym_methods] = ACTIONS(449),
    [anon_sym_events] = ACTIONS(449),
    [anon_sym_enumeration] = ACTIONS(449),
    [anon_sym_classdef] = ACTIONS(449),
    [anon_sym_try] = ACTIONS(449),
    [anon_sym_spmd] = ACTIONS(449),
    [aux_sym_number_token1] = ACTIONS(449),
    [aux_sym_number_token2] = ACTIONS(449),
    [aux_sym_number_token3] = ACTIONS(449),
    [anon_sym_true] = ACTIONS(449),
    [anon_sym_false] = ACTIONS(449),
    [anon_sym_CR] = ACTIONS(449),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(456),
    [sym__single_quote_string_start] = ACTIONS(456),
    [sym__double_quote_string_start] = ACTIONS(456),
    [sym__multioutput_variable_start] = ACTIONS(456),
    [sym__external_identifier] = ACTIONS(456),
  },
  [STATE(75)] = {
    [sym__args] = STATE(99),
    [aux_sym_field_expression_repeat1] = STATE(84),
    [anon_sym_SEMI] = ACTIONS(451),
    [anon_sym_COMMA] = ACTIONS(451),
    [anon_sym_LPAREN] = ACTIONS(437),
    [anon_sym_PLUS] = ACTIONS(451),
    [anon_sym_DOT_PLUS] = ACTIONS(451),
    [anon_sym_DASH] = ACTIONS(451),
    [anon_sym_DOT_DASH] = ACTIONS(451),
    [anon_sym_STAR] = ACTIONS(451),
    [anon_sym_DOT_STAR] = ACTIONS(451),
    [anon_sym_SLASH] = ACTIONS(451),
    [anon_sym_DOT_SLASH] = ACTIONS(451),
    [anon_sym_BSLASH] = ACTIONS(451),
    [anon_sym_DOT_BSLASH] = ACTIONS(451),
    [anon_sym_CARET] = ACTIONS(451),
    [anon_sym_DOT_CARET] = ACTIONS(451),
    [anon_sym_PIPE] = ACTIONS(451),
    [anon_sym_AMP] = ACTIONS(451),
    [anon_sym_DOT] = ACTIONS(439),
    [anon_sym_TILDE] = ACTIONS(451),
    [anon_sym_QMARK] = ACTIONS(451),
    [anon_sym_AT] = ACTIONS(441),
    [anon_sym_LT] = ACTIONS(451),
    [anon_sym_LT_EQ] = ACTIONS(451),
    [anon_sym_EQ_EQ] = ACTIONS(451),
    [anon_sym_TILDE_EQ] = ACTIONS(451),
    [anon_sym_GT_EQ] = ACTIONS(451),
    [anon_sym_GT] = ACTIONS(451),
    [anon_sym_AMP_AMP] = ACTIONS(451),
    [anon_sym_PIPE_PIPE] = ACTIONS(451),
    [anon_sym_DOT_SQUOTE] = ACTIONS(443),
    [anon_sym_SQUOTE] = ACTIONS(443),
    [anon_sym_LBRACK] = ACTIONS(451),
    [anon_sym_LF] = ACTIONS(451),
    [anon_sym_LBRACE] = ACTIONS(445),
    [anon_sym_COLON] = ACTIONS(451),
    [anon_sym_return] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(451),
    [anon_sym_break] = ACTIONS(451),
    [anon_sym_elseif] = ACTIONS(451),
    [anon_sym_else] = ACTIONS(451),
    [anon_sym_if] = ACTIONS(451),
    [anon_sym_end] = ACTIONS(451),
    [anon_sym_for] = ACTIONS(451),
    [anon_sym_parfor] = ACTIONS(451),
    [anon_sym_while] = ACTIONS(451),
    [anon_sym_switch] = ACTIONS(451),
    [anon_sym_global] = ACTIONS(451),
    [anon_sym_persistent] = ACTIONS(451),
    [anon_sym_arguments] = ACTIONS(451),
    [anon_sym_function] = ACTIONS(451),
    [anon_sym_properties] = ACTIONS(451),
    [anon_sym_get] = ACTIONS(451),
    [anon_sym_set] = ACTIONS(451),
    [anon_sym_methods] = ACTIONS(451),
    [anon_sym_events] = ACTIONS(451),
    [anon_sym_enumeration] = ACTIONS(451),
    [anon_sym_classdef] = ACTIONS(451),
    [anon_sym_try] = ACTIONS(451),
    [anon_sym_spmd] = ACTIONS(451),
    [aux_sym_number_token1] = ACTIONS(451),
    [aux_sym_number_token2] = ACTIONS(451),
    [aux_sym_number_token3] = ACTIONS(451),
    [anon_sym_true] = ACTIONS(451),
    [anon_sym_false] = ACTIONS(451),
    [anon_sym_CR] = ACTIONS(451),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(460),
    [sym__single_quote_string_start] = ACTIONS(460),
    [sym__double_quote_string_start] = ACTIONS(460),
    [sym__multioutput_variable_start] = ACTIONS(460),
    [sym__external_identifier] = ACTIONS(460),
  },
  [STATE(76)] = {
    [sym__args] = STATE(99),
    [aux_sym_field_expression_repeat1] = STATE(84),
    [anon_sym_SEMI] = ACTIONS(458),
    [anon_sym_COMMA] = ACTIONS(458),
    [anon_sym_LPAREN] = ACTIONS(437),
    [anon_sym_PLUS] = ACTIONS(451),
    [anon_sym_DOT_PLUS] = ACTIONS(451),
    [anon_sym_DASH] = ACTIONS(451),
    [anon_sym_DOT_DASH] = ACTIONS(451),
    [anon_sym_STAR] = ACTIONS(451),
    [anon_sym_DOT_STAR] = ACTIONS(451),
    [anon_sym_SLASH] = ACTIONS(451),
    [anon_sym_DOT_SLASH] = ACTIONS(451),
    [anon_sym_BSLASH] = ACTIONS(451),
    [anon_sym_DOT_BSLASH] = ACTIONS(451),
    [anon_sym_CARET] = ACTIONS(451),
    [anon_sym_DOT_CARET] = ACTIONS(451),
    [anon_sym_PIPE] = ACTIONS(451),
    [anon_sym_AMP] = ACTIONS(451),
    [anon_sym_DOT] = ACTIONS(439),
    [anon_sym_TILDE] = ACTIONS(458),
    [anon_sym_QMARK] = ACTIONS(458),
    [anon_sym_AT] = ACTIONS(441),
    [anon_sym_LT] = ACTIONS(453),
    [anon_sym_LT_EQ] = ACTIONS(453),
    [anon_sym_EQ_EQ] = ACTIONS(453),
    [anon_sym_TILDE_EQ] = ACTIONS(453),
    [anon_sym_GT_EQ] = ACTIONS(453),
    [anon_sym_GT] = ACTIONS(453),
    [anon_sym_AMP_AMP] = ACTIONS(453),
    [anon_sym_PIPE_PIPE] = ACTIONS(453),
    [anon_sym_DOT_SQUOTE] = ACTIONS(443),
    [anon_sym_SQUOTE] = ACTIONS(443),
    [anon_sym_LBRACK] = ACTIONS(458),
    [anon_sym_LF] = ACTIONS(458),
    [anon_sym_LBRACE] = ACTIONS(445),
    [anon_sym_COLON] = ACTIONS(458),
    [anon_sym_return] = ACTIONS(458),
    [anon_sym_continue] = ACTIONS(458),
    [anon_sym_break] = ACTIONS(458),
    [anon_sym_elseif] = ACTIONS(458),
    [anon_sym_else] = ACTIONS(458),
    [anon_sym_if] = ACTIONS(458),
    [anon_sym_end] = ACTIONS(458),
    [anon_sym_for] = ACTIONS(458),
    [anon_sym_parfor] = ACTIONS(458),
    [anon_sym_while] = ACTIONS(458),
    [anon_sym_switch] = ACTIONS(458),
    [anon_sym_global] = ACTIONS(458),
    [anon_sym_persistent] = ACTIONS(458),
    [anon_sym_arguments] = ACTIONS(458),
    [anon_sym_function] = ACTIONS(458),
    [anon_sym_properties] = ACTIONS(458),
    [anon_sym_get] = ACTIONS(458),
    [anon_sym_set] = ACTIONS(458),
    [anon_sym_methods] = ACTIONS(458),
    [anon_sym_events] = ACTIONS(458),
    [anon_sym_enumeration] = ACTIONS(458),
    [anon_sym_classdef] = ACTIONS(458),
    [anon_sym_try] = ACTIONS(458),
    [anon_sym_spmd] = ACTIONS(458),
    [aux_sym_number_token1] = ACTIONS(458),
    [aux_sym_number_token2] = ACTIONS(458),
    [aux_sym_number_token3] = ACTIONS(458),
    [anon_sym_true] = ACTIONS(458),
    [anon_sym_false] = ACTIONS(458),
    [anon_sym_CR] = ACTIONS(458),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(462),
    [sym__single_quote_string_start] = ACTIONS(462),
    [sym__double_quote_string_start] = ACTIONS(462),
    [sym__multioutput_variable_start] = ACTIONS(462),
    [sym__external_identifier] = ACTIONS(462),
  },
  [STATE(77)] = {
    [aux_sym_metaclass_operator_repeat1] = STATE(80),
    [anon_sym_SEMI] = ACTIONS(464),
    [anon_sym_COMMA] = ACTIONS(464),
    [anon_sym_LPAREN] = ACTIONS(464),
    [anon_sym_PLUS] = ACTIONS(464),
    [anon_sym_DOT_PLUS] = ACTIONS(464),
    [anon_sym_DASH] = ACTIONS(464),
    [anon_sym_DOT_DASH] = ACTIONS(464),
    [anon_sym_STAR] = ACTIONS(464),
    [anon_sym_DOT_STAR] = ACTIONS(464),
    [anon_sym_SLASH] = ACTIONS(464),
    [anon_sym_DOT_SLASH] = ACTIONS(464),
    [anon_sym_BSLASH] = ACTIONS(464),
    [anon_sym_DOT_BSLASH] = ACTIONS(464),
    [anon_sym_CARET] = ACTIONS(464),
    [anon_sym_DOT_CARET] = ACTIONS(464),
    [anon_sym_PIPE] = ACTIONS(464),
    [anon_sym_AMP] = ACTIONS(464),
    [anon_sym_DOT] = ACTIONS(466),
    [anon_sym_TILDE] = ACTIONS(464),
    [anon_sym_QMARK] = ACTIONS(464),
    [anon_sym_AT] = ACTIONS(464),
    [anon_sym_LT] = ACTIONS(464),
    [anon_sym_LT_EQ] = ACTIONS(464),
    [anon_sym_EQ_EQ] = ACTIONS(464),
    [anon_sym_TILDE_EQ] = ACTIONS(464),
    [anon_sym_GT_EQ] = ACTIONS(464),
    [anon_sym_GT] = ACTIONS(464),
    [anon_sym_AMP_AMP] = ACTIONS(464),
    [anon_sym_PIPE_PIPE] = ACTIONS(464),
    [anon_sym_DOT_SQUOTE] = ACTIONS(464),
    [anon_sym_SQUOTE] = ACTIONS(464),
    [anon_sym_LBRACK] = ACTIONS(464),
    [anon_sym_LF] = ACTIONS(464),
    [anon_sym_LBRACE] = ACTIONS(464),
    [anon_sym_COLON] = ACTIONS(464),
    [anon_sym_return] = ACTIONS(464),
    [anon_sym_continue] = ACTIONS(464),
    [anon_sym_break] = ACTIONS(464),
    [anon_sym_elseif] = ACTIONS(464),
    [anon_sym_else] = ACTIONS(464),
    [anon_sym_if] = ACTIONS(464),
    [anon_sym_end] = ACTIONS(464),
    [anon_sym_for] = ACTIONS(464),
    [anon_sym_parfor] = ACTIONS(464),
    [anon_sym_while] = ACTIONS(464),
    [anon_sym_switch] = ACTIONS(464),
    [anon_sym_global] = ACTIONS(464),
    [anon_sym_persistent] = ACTIONS(464),
    [anon_sym_arguments] = ACTIONS(464),
    [anon_sym_function] = ACTIONS(464),
    [anon_sym_properties] = ACTIONS(464),
    [anon_sym_get] = ACTIONS(464),
    [anon_sym_set] = ACTIONS(464),
    [anon_sym_methods] = ACTIONS(464),
    [anon_sym_events] = ACTIONS(464),
    [anon_sym_enumeration] = ACTIONS(464),
    [anon_sym_classdef] = ACTIONS(464),
    [anon_sym_try] = ACTIONS(464),
    [anon_sym_spmd] = ACTIONS(464),
    [aux_sym_number_token1] = ACTIONS(464),
    [aux_sym_number_token2] = ACTIONS(464),
    [aux_sym_number_token3] = ACTIONS(464),
    [anon_sym_true] = ACTIONS(464),
    [anon_sym_false] = ACTIONS(464),
    [anon_sym_CR] = ACTIONS(464),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(468),
    [sym__single_quote_string_start] = ACTIONS(468),
    [sym__double_quote_string_start] = ACTIONS(468),
    [sym__multioutput_variable_start] = ACTIONS(468),
    [sym__external_identifier] = ACTIONS(468),
  },
  [STATE(78)] = {
    [sym__args] = STATE(99),
    [anon_sym_SEMI] = ACTIONS(470),
    [anon_sym_COMMA] = ACTIONS(470),
    [anon_sym_LPAREN] = ACTIONS(437),
    [anon_sym_PLUS] = ACTIONS(470),
    [anon_sym_DOT_PLUS] = ACTIONS(470),
    [anon_sym_DASH] = ACTIONS(470),
    [anon_sym_DOT_DASH] = ACTIONS(470),
    [anon_sym_STAR] = ACTIONS(470),
    [anon_sym_DOT_STAR] = ACTIONS(470),
    [anon_sym_SLASH] = ACTIONS(470),
    [anon_sym_DOT_SLASH] = ACTIONS(470),
    [anon_sym_BSLASH] = ACTIONS(470),
    [anon_sym_DOT_BSLASH] = ACTIONS(470),
    [anon_sym_CARET] = ACTIONS(470),
    [anon_sym_DOT_CARET] = ACTIONS(470),
    [anon_sym_PIPE] = ACTIONS(470),
    [anon_sym_AMP] = ACTIONS(470),
    [anon_sym_DOT] = ACTIONS(470),
    [anon_sym_TILDE] = ACTIONS(470),
    [anon_sym_QMARK] = ACTIONS(470),
    [anon_sym_AT] = ACTIONS(441),
    [anon_sym_LT] = ACTIONS(470),
    [anon_sym_LT_EQ] = ACTIONS(470),
    [anon_sym_EQ_EQ] = ACTIONS(470),
    [anon_sym_TILDE_EQ] = ACTIONS(470),
    [anon_sym_GT_EQ] = ACTIONS(470),
    [anon_sym_GT] = ACTIONS(470),
    [anon_sym_AMP_AMP] = ACTIONS(470),
    [anon_sym_PIPE_PIPE] = ACTIONS(470),
    [anon_sym_DOT_SQUOTE] = ACTIONS(470),
    [anon_sym_SQUOTE] = ACTIONS(470),
    [anon_sym_LBRACK] = ACTIONS(470),
    [anon_sym_LF] = ACTIONS(470),
    [anon_sym_LBRACE] = ACTIONS(445),
    [anon_sym_COLON] = ACTIONS(470),
    [anon_sym_return] = ACTIONS(470),
    [anon_sym_continue] = ACTIONS(470),
    [anon_sym_break] = ACTIONS(470),
    [anon_sym_elseif] = ACTIONS(470),
    [anon_sym_else] = ACTIONS(470),
    [anon_sym_if] = ACTIONS(470),
    [anon_sym_end] = ACTIONS(470),
    [anon_sym_for] = ACTIONS(470),
    [anon_sym_parfor] = ACTIONS(470),
    [anon_sym_while] = ACTIONS(470),
    [anon_sym_switch] = ACTIONS(470),
    [anon_sym_global] = ACTIONS(470),
    [anon_sym_persistent] = ACTIONS(470),
    [anon_sym_arguments] = ACTIONS(470),
    [anon_sym_function] = ACTIONS(470),
    [anon_sym_properties] = ACTIONS(470),
    [anon_sym_get] = ACTIONS(470),
    [anon_sym_set] = ACTIONS(470),
    [anon_sym_methods] = ACTIONS(470),
    [anon_sym_events] = ACTIONS(470),
    [anon_sym_enumeration] = ACTIONS(470),
    [anon_sym_classdef] = ACTIONS(470),
    [anon_sym_try] = ACTIONS(470),
    [anon_sym_spmd] = ACTIONS(470),
    [aux_sym_number_token1] = ACTIONS(470),
    [aux_sym_number_token2] = ACTIONS(470),
    [aux_sym_number_token3] = ACTIONS(470),
    [anon_sym_true] = ACTIONS(470),
    [anon_sym_false] = ACTIONS(470),
    [anon_sym_CR] = ACTIONS(470),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(472),
    [sym__single_quote_string_start] = ACTIONS(472),
    [sym__double_quote_string_start] = ACTIONS(472),
    [sym__multioutput_variable_start] = ACTIONS(472),
    [sym__external_identifier] = ACTIONS(472),
  },
  [STATE(79)] = {
    [aux_sym_field_expression_repeat1] = STATE(79),
    [anon_sym_SEMI] = ACTIONS(474),
    [anon_sym_COMMA] = ACTIONS(474),
    [anon_sym_LPAREN] = ACTIONS(474),
    [anon_sym_PLUS] = ACTIONS(474),
    [anon_sym_DOT_PLUS] = ACTIONS(474),
    [anon_sym_DASH] = ACTIONS(474),
    [anon_sym_DOT_DASH] = ACTIONS(474),
    [anon_sym_STAR] = ACTIONS(474),
    [anon_sym_DOT_STAR] = ACTIONS(474),
    [anon_sym_SLASH] = ACTIONS(474),
    [anon_sym_DOT_SLASH] = ACTIONS(474),
    [anon_sym_BSLASH] = ACTIONS(474),
    [anon_sym_DOT_BSLASH] = ACTIONS(474),
    [anon_sym_CARET] = ACTIONS(474),
    [anon_sym_DOT_CARET] = ACTIONS(474),
    [anon_sym_PIPE] = ACTIONS(474),
    [anon_sym_AMP] = ACTIONS(474),
    [anon_sym_DOT] = ACTIONS(476),
    [anon_sym_TILDE] = ACTIONS(474),
    [anon_sym_QMARK] = ACTIONS(474),
    [anon_sym_AT] = ACTIONS(474),
    [anon_sym_LT] = ACTIONS(474),
    [anon_sym_LT_EQ] = ACTIONS(474),
    [anon_sym_EQ_EQ] = ACTIONS(474),
    [anon_sym_TILDE_EQ] = ACTIONS(474),
    [anon_sym_GT_EQ] = ACTIONS(474),
    [anon_sym_GT] = ACTIONS(474),
    [anon_sym_AMP_AMP] = ACTIONS(474),
    [anon_sym_PIPE_PIPE] = ACTIONS(474),
    [anon_sym_DOT_SQUOTE] = ACTIONS(474),
    [anon_sym_SQUOTE] = ACTIONS(474),
    [anon_sym_LBRACK] = ACTIONS(474),
    [anon_sym_LF] = ACTIONS(474),
    [anon_sym_LBRACE] = ACTIONS(474),
    [anon_sym_COLON] = ACTIONS(474),
    [anon_sym_return] = ACTIONS(474),
    [anon_sym_continue] = ACTIONS(474),
    [anon_sym_break] = ACTIONS(474),
    [anon_sym_elseif] = ACTIONS(474),
    [anon_sym_else] = ACTIONS(474),
    [anon_sym_if] = ACTIONS(474),
    [anon_sym_end] = ACTIONS(474),
    [anon_sym_for] = ACTIONS(474),
    [anon_sym_parfor] = ACTIONS(474),
    [anon_sym_while] = ACTIONS(474),
    [anon_sym_switch] = ACTIONS(474),
    [anon_sym_global] = ACTIONS(474),
    [anon_sym_persistent] = ACTIONS(474),
    [anon_sym_arguments] = ACTIONS(474),
    [anon_sym_function] = ACTIONS(474),
    [anon_sym_properties] = ACTIONS(474),
    [anon_sym_get] = ACTIONS(474),
    [anon_sym_set] = ACTIONS(474),
    [anon_sym_methods] = ACTIONS(474),
    [anon_sym_events] = ACTIONS(474),
    [anon_sym_enumeration] = ACTIONS(474),
    [anon_sym_classdef] = ACTIONS(474),
    [anon_sym_try] = ACTIONS(474),
    [anon_sym_spmd] = ACTIONS(474),
    [aux_sym_number_token1] = ACTIONS(474),
    [aux_sym_number_token2] = ACTIONS(474),
    [aux_sym_number_token3] = ACTIONS(474),
    [anon_sym_true] = ACTIONS(474),
    [anon_sym_false] = ACTIONS(474),
    [anon_sym_CR] = ACTIONS(474),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(479),
    [sym__single_quote_string_start] = ACTIONS(479),
    [sym__double_quote_string_start] = ACTIONS(479),
    [sym__multioutput_variable_start] = ACTIONS(479),
    [sym__external_identifier] = ACTIONS(479),
  },
  [STATE(80)] = {
    [aux_sym_metaclass_operator_repeat1] = STATE(83),
    [anon_sym_SEMI] = ACTIONS(481),
    [anon_sym_COMMA] = ACTIONS(481),
    [anon_sym_LPAREN] = ACTIONS(481),
    [anon_sym_PLUS] = ACTIONS(481),
    [anon_sym_DOT_PLUS] = ACTIONS(481),
    [anon_sym_DASH] = ACTIONS(481),
    [anon_sym_DOT_DASH] = ACTIONS(481),
    [anon_sym_STAR] = ACTIONS(481),
    [anon_sym_DOT_STAR] = ACTIONS(481),
    [anon_sym_SLASH] = ACTIONS(481),
    [anon_sym_DOT_SLASH] = ACTIONS(481),
    [anon_sym_BSLASH] = ACTIONS(481),
    [anon_sym_DOT_BSLASH] = ACTIONS(481),
    [anon_sym_CARET] = ACTIONS(481),
    [anon_sym_DOT_CARET] = ACTIONS(481),
    [anon_sym_PIPE] = ACTIONS(481),
    [anon_sym_AMP] = ACTIONS(481),
    [anon_sym_DOT] = ACTIONS(466),
    [anon_sym_TILDE] = ACTIONS(481),
    [anon_sym_QMARK] = ACTIONS(481),
    [anon_sym_AT] = ACTIONS(481),
    [anon_sym_LT] = ACTIONS(481),
    [anon_sym_LT_EQ] = ACTIONS(481),
    [anon_sym_EQ_EQ] = ACTIONS(481),
    [anon_sym_TILDE_EQ] = ACTIONS(481),
    [anon_sym_GT_EQ] = ACTIONS(481),
    [anon_sym_GT] = ACTIONS(481),
    [anon_sym_AMP_AMP] = ACTIONS(481),
    [anon_sym_PIPE_PIPE] = ACTIONS(481),
    [anon_sym_DOT_SQUOTE] = ACTIONS(481),
    [anon_sym_SQUOTE] = ACTIONS(481),
    [anon_sym_LBRACK] = ACTIONS(481),
    [anon_sym_LF] = ACTIONS(481),
    [anon_sym_LBRACE] = ACTIONS(481),
    [anon_sym_COLON] = ACTIONS(481),
    [anon_sym_return] = ACTIONS(481),
    [anon_sym_continue] = ACTIONS(481),
    [anon_sym_break] = ACTIONS(481),
    [anon_sym_elseif] = ACTIONS(481),
    [anon_sym_else] = ACTIONS(481),
    [anon_sym_if] = ACTIONS(481),
    [anon_sym_end] = ACTIONS(481),
    [anon_sym_for] = ACTIONS(481),
    [anon_sym_parfor] = ACTIONS(481),
    [anon_sym_while] = ACTIONS(481),
    [anon_sym_switch] = ACTIONS(481),
    [anon_sym_global] = ACTIONS(481),
    [anon_sym_persistent] = ACTIONS(481),
    [anon_sym_arguments] = ACTIONS(481),
    [anon_sym_function] = ACTIONS(481),
    [anon_sym_properties] = ACTIONS(481),
    [anon_sym_get] = ACTIONS(481),
    [anon_sym_set] = ACTIONS(481),
    [anon_sym_methods] = ACTIONS(481),
    [anon_sym_events] = ACTIONS(481),
    [anon_sym_enumeration] = ACTIONS(481),
    [anon_sym_classdef] = ACTIONS(481),
    [anon_sym_try] = ACTIONS(481),
    [anon_sym_spmd] = ACTIONS(481),
    [aux_sym_number_token1] = ACTIONS(481),
    [aux_sym_number_token2] = ACTIONS(481),
    [aux_sym_number_token3] = ACTIONS(481),
    [anon_sym_true] = ACTIONS(481),
    [anon_sym_false] = ACTIONS(481),
    [anon_sym_CR] = ACTIONS(481),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(483),
    [sym__single_quote_string_start] = ACTIONS(483),
    [sym__double_quote_string_start] = ACTIONS(483),
    [sym__multioutput_variable_start] = ACTIONS(483),
    [sym__external_identifier] = ACTIONS(483),
  },
  [STATE(81)] = {
    [aux_sym_metaclass_operator_repeat1] = STATE(83),
    [anon_sym_SEMI] = ACTIONS(485),
    [anon_sym_COMMA] = ACTIONS(485),
    [anon_sym_LPAREN] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(485),
    [anon_sym_DOT_PLUS] = ACTIONS(485),
    [anon_sym_DASH] = ACTIONS(485),
    [anon_sym_DOT_DASH] = ACTIONS(485),
    [anon_sym_STAR] = ACTIONS(485),
    [anon_sym_DOT_STAR] = ACTIONS(485),
    [anon_sym_SLASH] = ACTIONS(485),
    [anon_sym_DOT_SLASH] = ACTIONS(485),
    [anon_sym_BSLASH] = ACTIONS(485),
    [anon_sym_DOT_BSLASH] = ACTIONS(485),
    [anon_sym_CARET] = ACTIONS(485),
    [anon_sym_DOT_CARET] = ACTIONS(485),
    [anon_sym_PIPE] = ACTIONS(485),
    [anon_sym_AMP] = ACTIONS(485),
    [anon_sym_DOT] = ACTIONS(466),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_QMARK] = ACTIONS(485),
    [anon_sym_AT] = ACTIONS(485),
    [anon_sym_LT] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_TILDE_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_GT] = ACTIONS(485),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_DOT_SQUOTE] = ACTIONS(485),
    [anon_sym_SQUOTE] = ACTIONS(485),
    [anon_sym_LBRACK] = ACTIONS(485),
    [anon_sym_LF] = ACTIONS(485),
    [anon_sym_LBRACE] = ACTIONS(485),
    [anon_sym_COLON] = ACTIONS(485),
    [anon_sym_return] = ACTIONS(485),
    [anon_sym_continue] = ACTIONS(485),
    [anon_sym_break] = ACTIONS(485),
    [anon_sym_elseif] = ACTIONS(485),
    [anon_sym_else] = ACTIONS(485),
    [anon_sym_if] = ACTIONS(485),
    [anon_sym_end] = ACTIONS(485),
    [anon_sym_for] = ACTIONS(485),
    [anon_sym_parfor] = ACTIONS(485),
    [anon_sym_while] = ACTIONS(485),
    [anon_sym_switch] = ACTIONS(485),
    [anon_sym_global] = ACTIONS(485),
    [anon_sym_persistent] = ACTIONS(485),
    [anon_sym_arguments] = ACTIONS(485),
    [anon_sym_function] = ACTIONS(485),
    [anon_sym_properties] = ACTIONS(485),
    [anon_sym_get] = ACTIONS(485),
    [anon_sym_set] = ACTIONS(485),
    [anon_sym_methods] = ACTIONS(485),
    [anon_sym_events] = ACTIONS(485),
    [anon_sym_enumeration] = ACTIONS(485),
    [anon_sym_classdef] = ACTIONS(485),
    [anon_sym_try] = ACTIONS(485),
    [anon_sym_spmd] = ACTIONS(485),
    [aux_sym_number_token1] = ACTIONS(485),
    [aux_sym_number_token2] = ACTIONS(485),
    [aux_sym_number_token3] = ACTIONS(485),
    [anon_sym_true] = ACTIONS(485),
    [anon_sym_false] = ACTIONS(485),
    [anon_sym_CR] = ACTIONS(485),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(487),
    [sym__single_quote_string_start] = ACTIONS(487),
    [sym__double_quote_string_start] = ACTIONS(487),
    [sym__multioutput_variable_start] = ACTIONS(487),
    [sym__external_identifier] = ACTIONS(487),
  },
  [STATE(82)] = {
    [aux_sym_metaclass_operator_repeat1] = STATE(81),
    [anon_sym_SEMI] = ACTIONS(489),
    [anon_sym_COMMA] = ACTIONS(489),
    [anon_sym_LPAREN] = ACTIONS(489),
    [anon_sym_PLUS] = ACTIONS(489),
    [anon_sym_DOT_PLUS] = ACTIONS(489),
    [anon_sym_DASH] = ACTIONS(489),
    [anon_sym_DOT_DASH] = ACTIONS(489),
    [anon_sym_STAR] = ACTIONS(489),
    [anon_sym_DOT_STAR] = ACTIONS(489),
    [anon_sym_SLASH] = ACTIONS(489),
    [anon_sym_DOT_SLASH] = ACTIONS(489),
    [anon_sym_BSLASH] = ACTIONS(489),
    [anon_sym_DOT_BSLASH] = ACTIONS(489),
    [anon_sym_CARET] = ACTIONS(489),
    [anon_sym_DOT_CARET] = ACTIONS(489),
    [anon_sym_PIPE] = ACTIONS(489),
    [anon_sym_AMP] = ACTIONS(489),
    [anon_sym_DOT] = ACTIONS(466),
    [anon_sym_TILDE] = ACTIONS(489),
    [anon_sym_QMARK] = ACTIONS(489),
    [anon_sym_AT] = ACTIONS(489),
    [anon_sym_LT] = ACTIONS(489),
    [anon_sym_LT_EQ] = ACTIONS(489),
    [anon_sym_EQ_EQ] = ACTIONS(489),
    [anon_sym_TILDE_EQ] = ACTIONS(489),
    [anon_sym_GT_EQ] = ACTIONS(489),
    [anon_sym_GT] = ACTIONS(489),
    [anon_sym_AMP_AMP] = ACTIONS(489),
    [anon_sym_PIPE_PIPE] = ACTIONS(489),
    [anon_sym_DOT_SQUOTE] = ACTIONS(489),
    [anon_sym_SQUOTE] = ACTIONS(489),
    [anon_sym_LBRACK] = ACTIONS(489),
    [anon_sym_LF] = ACTIONS(489),
    [anon_sym_LBRACE] = ACTIONS(489),
    [anon_sym_COLON] = ACTIONS(489),
    [anon_sym_return] = ACTIONS(489),
    [anon_sym_continue] = ACTIONS(489),
    [anon_sym_break] = ACTIONS(489),
    [anon_sym_elseif] = ACTIONS(489),
    [anon_sym_else] = ACTIONS(489),
    [anon_sym_if] = ACTIONS(489),
    [anon_sym_end] = ACTIONS(489),
    [anon_sym_for] = ACTIONS(489),
    [anon_sym_parfor] = ACTIONS(489),
    [anon_sym_while] = ACTIONS(489),
    [anon_sym_switch] = ACTIONS(489),
    [anon_sym_global] = ACTIONS(489),
    [anon_sym_persistent] = ACTIONS(489),
    [anon_sym_arguments] = ACTIONS(489),
    [anon_sym_function] = ACTIONS(489),
    [anon_sym_properties] = ACTIONS(489),
    [anon_sym_get] = ACTIONS(489),
    [anon_sym_set] = ACTIONS(489),
    [anon_sym_methods] = ACTIONS(489),
    [anon_sym_events] = ACTIONS(489),
    [anon_sym_enumeration] = ACTIONS(489),
    [anon_sym_classdef] = ACTIONS(489),
    [anon_sym_try] = ACTIONS(489),
    [anon_sym_spmd] = ACTIONS(489),
    [aux_sym_number_token1] = ACTIONS(489),
    [aux_sym_number_token2] = ACTIONS(489),
    [aux_sym_number_token3] = ACTIONS(489),
    [anon_sym_true] = ACTIONS(489),
    [anon_sym_false] = ACTIONS(489),
    [anon_sym_CR] = ACTIONS(489),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(491),
    [sym__single_quote_string_start] = ACTIONS(491),
    [sym__double_quote_string_start] = ACTIONS(491),
    [sym__multioutput_variable_start] = ACTIONS(491),
    [sym__external_identifier] = ACTIONS(491),
  },
  [STATE(83)] = {
    [aux_sym_metaclass_operator_repeat1] = STATE(83),
    [anon_sym_SEMI] = ACTIONS(493),
    [anon_sym_COMMA] = ACTIONS(493),
    [anon_sym_LPAREN] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(493),
    [anon_sym_DOT_PLUS] = ACTIONS(493),
    [anon_sym_DASH] = ACTIONS(493),
    [anon_sym_DOT_DASH] = ACTIONS(493),
    [anon_sym_STAR] = ACTIONS(493),
    [anon_sym_DOT_STAR] = ACTIONS(493),
    [anon_sym_SLASH] = ACTIONS(493),
    [anon_sym_DOT_SLASH] = ACTIONS(493),
    [anon_sym_BSLASH] = ACTIONS(493),
    [anon_sym_DOT_BSLASH] = ACTIONS(493),
    [anon_sym_CARET] = ACTIONS(493),
    [anon_sym_DOT_CARET] = ACTIONS(493),
    [anon_sym_PIPE] = ACTIONS(493),
    [anon_sym_AMP] = ACTIONS(493),
    [anon_sym_DOT] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(493),
    [anon_sym_QMARK] = ACTIONS(493),
    [anon_sym_AT] = ACTIONS(493),
    [anon_sym_LT] = ACTIONS(493),
    [anon_sym_LT_EQ] = ACTIONS(493),
    [anon_sym_EQ_EQ] = ACTIONS(493),
    [anon_sym_TILDE_EQ] = ACTIONS(493),
    [anon_sym_GT_EQ] = ACTIONS(493),
    [anon_sym_GT] = ACTIONS(493),
    [anon_sym_AMP_AMP] = ACTIONS(493),
    [anon_sym_PIPE_PIPE] = ACTIONS(493),
    [anon_sym_DOT_SQUOTE] = ACTIONS(493),
    [anon_sym_SQUOTE] = ACTIONS(493),
    [anon_sym_LBRACK] = ACTIONS(493),
    [anon_sym_LF] = ACTIONS(493),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_COLON] = ACTIONS(493),
    [anon_sym_return] = ACTIONS(493),
    [anon_sym_continue] = ACTIONS(493),
    [anon_sym_break] = ACTIONS(493),
    [anon_sym_elseif] = ACTIONS(493),
    [anon_sym_else] = ACTIONS(493),
    [anon_sym_if] = ACTIONS(493),
    [anon_sym_end] = ACTIONS(493),
    [anon_sym_for] = ACTIONS(493),
    [anon_sym_parfor] = ACTIONS(493),
    [anon_sym_while] = ACTIONS(493),
    [anon_sym_switch] = ACTIONS(493),
    [anon_sym_global] = ACTIONS(493),
    [anon_sym_persistent] = ACTIONS(493),
    [anon_sym_arguments] = ACTIONS(493),
    [anon_sym_function] = ACTIONS(493),
    [anon_sym_properties] = ACTIONS(493),
    [anon_sym_get] = ACTIONS(493),
    [anon_sym_set] = ACTIONS(493),
    [anon_sym_methods] = ACTIONS(493),
    [anon_sym_events] = ACTIONS(493),
    [anon_sym_enumeration] = ACTIONS(493),
    [anon_sym_classdef] = ACTIONS(493),
    [anon_sym_try] = ACTIONS(493),
    [anon_sym_spmd] = ACTIONS(493),
    [aux_sym_number_token1] = ACTIONS(493),
    [aux_sym_number_token2] = ACTIONS(493),
    [aux_sym_number_token3] = ACTIONS(493),
    [anon_sym_true] = ACTIONS(493),
    [anon_sym_false] = ACTIONS(493),
    [anon_sym_CR] = ACTIONS(493),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(498),
    [sym__single_quote_string_start] = ACTIONS(498),
    [sym__double_quote_string_start] = ACTIONS(498),
    [sym__multioutput_variable_start] = ACTIONS(498),
    [sym__external_identifier] = ACTIONS(498),
  },
  [STATE(84)] = {
    [aux_sym_field_expression_repeat1] = STATE(79),
    [anon_sym_SEMI] = ACTIONS(500),
    [anon_sym_COMMA] = ACTIONS(500),
    [anon_sym_LPAREN] = ACTIONS(500),
    [anon_sym_PLUS] = ACTIONS(500),
    [anon_sym_DOT_PLUS] = ACTIONS(500),
    [anon_sym_DASH] = ACTIONS(500),
    [anon_sym_DOT_DASH] = ACTIONS(500),
    [anon_sym_STAR] = ACTIONS(500),
    [anon_sym_DOT_STAR] = ACTIONS(500),
    [anon_sym_SLASH] = ACTIONS(500),
    [anon_sym_DOT_SLASH] = ACTIONS(500),
    [anon_sym_BSLASH] = ACTIONS(500),
    [anon_sym_DOT_BSLASH] = ACTIONS(500),
    [anon_sym_CARET] = ACTIONS(500),
    [anon_sym_DOT_CARET] = ACTIONS(500),
    [anon_sym_PIPE] = ACTIONS(500),
    [anon_sym_AMP] = ACTIONS(500),
    [anon_sym_DOT] = ACTIONS(439),
    [anon_sym_TILDE] = ACTIONS(500),
    [anon_sym_QMARK] = ACTIONS(500),
    [anon_sym_AT] = ACTIONS(500),
    [anon_sym_LT] = ACTIONS(500),
    [anon_sym_LT_EQ] = ACTIONS(500),
    [anon_sym_EQ_EQ] = ACTIONS(500),
    [anon_sym_TILDE_EQ] = ACTIONS(500),
    [anon_sym_GT_EQ] = ACTIONS(500),
    [anon_sym_GT] = ACTIONS(500),
    [anon_sym_AMP_AMP] = ACTIONS(500),
    [anon_sym_PIPE_PIPE] = ACTIONS(500),
    [anon_sym_DOT_SQUOTE] = ACTIONS(500),
    [anon_sym_SQUOTE] = ACTIONS(500),
    [anon_sym_LBRACK] = ACTIONS(500),
    [anon_sym_LF] = ACTIONS(500),
    [anon_sym_LBRACE] = ACTIONS(500),
    [anon_sym_COLON] = ACTIONS(500),
    [anon_sym_return] = ACTIONS(500),
    [anon_sym_continue] = ACTIONS(500),
    [anon_sym_break] = ACTIONS(500),
    [anon_sym_elseif] = ACTIONS(500),
    [anon_sym_else] = ACTIONS(500),
    [anon_sym_if] = ACTIONS(500),
    [anon_sym_end] = ACTIONS(500),
    [anon_sym_for] = ACTIONS(500),
    [anon_sym_parfor] = ACTIONS(500),
    [anon_sym_while] = ACTIONS(500),
    [anon_sym_switch] = ACTIONS(500),
    [anon_sym_global] = ACTIONS(500),
    [anon_sym_persistent] = ACTIONS(500),
    [anon_sym_arguments] = ACTIONS(500),
    [anon_sym_function] = ACTIONS(500),
    [anon_sym_properties] = ACTIONS(500),
    [anon_sym_get] = ACTIONS(500),
    [anon_sym_set] = ACTIONS(500),
    [anon_sym_methods] = ACTIONS(500),
    [anon_sym_events] = ACTIONS(500),
    [anon_sym_enumeration] = ACTIONS(500),
    [anon_sym_classdef] = ACTIONS(500),
    [anon_sym_try] = ACTIONS(500),
    [anon_sym_spmd] = ACTIONS(500),
    [aux_sym_number_token1] = ACTIONS(500),
    [aux_sym_number_token2] = ACTIONS(500),
    [aux_sym_number_token3] = ACTIONS(500),
    [anon_sym_true] = ACTIONS(500),
    [anon_sym_false] = ACTIONS(500),
    [anon_sym_CR] = ACTIONS(500),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(502),
    [sym__single_quote_string_start] = ACTIONS(502),
    [sym__double_quote_string_start] = ACTIONS(502),
    [sym__multioutput_variable_start] = ACTIONS(502),
    [sym__external_identifier] = ACTIONS(502),
  },
  [STATE(85)] = {
    [anon_sym_SEMI] = ACTIONS(504),
    [anon_sym_COMMA] = ACTIONS(504),
    [anon_sym_LPAREN] = ACTIONS(504),
    [anon_sym_PLUS] = ACTIONS(504),
    [anon_sym_DOT_PLUS] = ACTIONS(504),
    [anon_sym_DASH] = ACTIONS(504),
    [anon_sym_DOT_DASH] = ACTIONS(504),
    [anon_sym_STAR] = ACTIONS(504),
    [anon_sym_DOT_STAR] = ACTIONS(504),
    [anon_sym_SLASH] = ACTIONS(504),
    [anon_sym_DOT_SLASH] = ACTIONS(504),
    [anon_sym_BSLASH] = ACTIONS(504),
    [anon_sym_DOT_BSLASH] = ACTIONS(504),
    [anon_sym_CARET] = ACTIONS(504),
    [anon_sym_DOT_CARET] = ACTIONS(504),
    [anon_sym_PIPE] = ACTIONS(504),
    [anon_sym_AMP] = ACTIONS(504),
    [anon_sym_DOT] = ACTIONS(504),
    [anon_sym_TILDE] = ACTIONS(504),
    [anon_sym_QMARK] = ACTIONS(504),
    [anon_sym_AT] = ACTIONS(504),
    [anon_sym_LT] = ACTIONS(504),
    [anon_sym_LT_EQ] = ACTIONS(504),
    [anon_sym_EQ_EQ] = ACTIONS(504),
    [anon_sym_TILDE_EQ] = ACTIONS(504),
    [anon_sym_GT_EQ] = ACTIONS(504),
    [anon_sym_GT] = ACTIONS(504),
    [anon_sym_AMP_AMP] = ACTIONS(504),
    [anon_sym_PIPE_PIPE] = ACTIONS(504),
    [anon_sym_DOT_SQUOTE] = ACTIONS(504),
    [anon_sym_SQUOTE] = ACTIONS(504),
    [anon_sym_LBRACK] = ACTIONS(504),
    [anon_sym_LF] = ACTIONS(504),
    [anon_sym_LBRACE] = ACTIONS(504),
    [anon_sym_COLON] = ACTIONS(504),
    [anon_sym_return] = ACTIONS(504),
    [anon_sym_continue] = ACTIONS(504),
    [anon_sym_break] = ACTIONS(504),
    [anon_sym_elseif] = ACTIONS(504),
    [anon_sym_else] = ACTIONS(504),
    [anon_sym_if] = ACTIONS(504),
    [anon_sym_end] = ACTIONS(504),
    [anon_sym_for] = ACTIONS(504),
    [anon_sym_parfor] = ACTIONS(504),
    [anon_sym_while] = ACTIONS(504),
    [anon_sym_switch] = ACTIONS(504),
    [anon_sym_global] = ACTIONS(504),
    [anon_sym_persistent] = ACTIONS(504),
    [anon_sym_arguments] = ACTIONS(504),
    [anon_sym_function] = ACTIONS(504),
    [anon_sym_properties] = ACTIONS(504),
    [anon_sym_get] = ACTIONS(504),
    [anon_sym_set] = ACTIONS(504),
    [anon_sym_methods] = ACTIONS(504),
    [anon_sym_events] = ACTIONS(504),
    [anon_sym_enumeration] = ACTIONS(504),
    [anon_sym_classdef] = ACTIONS(504),
    [anon_sym_try] = ACTIONS(504),
    [anon_sym_spmd] = ACTIONS(504),
    [aux_sym_number_token1] = ACTIONS(504),
    [aux_sym_number_token2] = ACTIONS(504),
    [aux_sym_number_token3] = ACTIONS(504),
    [anon_sym_true] = ACTIONS(504),
    [anon_sym_false] = ACTIONS(504),
    [anon_sym_CR] = ACTIONS(504),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(506),
    [sym__single_quote_string_start] = ACTIONS(506),
    [sym__double_quote_string_start] = ACTIONS(506),
    [sym__multioutput_variable_start] = ACTIONS(506),
    [sym__external_identifier] = ACTIONS(506),
  },
  [STATE(86)] = {
    [anon_sym_SEMI] = ACTIONS(508),
    [anon_sym_COMMA] = ACTIONS(508),
    [anon_sym_LPAREN] = ACTIONS(508),
    [anon_sym_PLUS] = ACTIONS(508),
    [anon_sym_DOT_PLUS] = ACTIONS(508),
    [anon_sym_DASH] = ACTIONS(508),
    [anon_sym_DOT_DASH] = ACTIONS(508),
    [anon_sym_STAR] = ACTIONS(508),
    [anon_sym_DOT_STAR] = ACTIONS(508),
    [anon_sym_SLASH] = ACTIONS(508),
    [anon_sym_DOT_SLASH] = ACTIONS(508),
    [anon_sym_BSLASH] = ACTIONS(508),
    [anon_sym_DOT_BSLASH] = ACTIONS(508),
    [anon_sym_CARET] = ACTIONS(508),
    [anon_sym_DOT_CARET] = ACTIONS(508),
    [anon_sym_PIPE] = ACTIONS(508),
    [anon_sym_AMP] = ACTIONS(508),
    [anon_sym_DOT] = ACTIONS(508),
    [anon_sym_TILDE] = ACTIONS(508),
    [anon_sym_QMARK] = ACTIONS(508),
    [anon_sym_AT] = ACTIONS(508),
    [anon_sym_LT] = ACTIONS(508),
    [anon_sym_LT_EQ] = ACTIONS(508),
    [anon_sym_EQ_EQ] = ACTIONS(508),
    [anon_sym_TILDE_EQ] = ACTIONS(508),
    [anon_sym_GT_EQ] = ACTIONS(508),
    [anon_sym_GT] = ACTIONS(508),
    [anon_sym_AMP_AMP] = ACTIONS(508),
    [anon_sym_PIPE_PIPE] = ACTIONS(508),
    [anon_sym_DOT_SQUOTE] = ACTIONS(508),
    [anon_sym_SQUOTE] = ACTIONS(508),
    [anon_sym_LBRACK] = ACTIONS(508),
    [anon_sym_LF] = ACTIONS(508),
    [anon_sym_LBRACE] = ACTIONS(508),
    [anon_sym_COLON] = ACTIONS(508),
    [anon_sym_return] = ACTIONS(508),
    [anon_sym_continue] = ACTIONS(508),
    [anon_sym_break] = ACTIONS(508),
    [anon_sym_elseif] = ACTIONS(508),
    [anon_sym_else] = ACTIONS(508),
    [anon_sym_if] = ACTIONS(508),
    [anon_sym_end] = ACTIONS(508),
    [anon_sym_for] = ACTIONS(508),
    [anon_sym_parfor] = ACTIONS(508),
    [anon_sym_while] = ACTIONS(508),
    [anon_sym_switch] = ACTIONS(508),
    [anon_sym_global] = ACTIONS(508),
    [anon_sym_persistent] = ACTIONS(508),
    [anon_sym_arguments] = ACTIONS(508),
    [anon_sym_function] = ACTIONS(508),
    [anon_sym_properties] = ACTIONS(508),
    [anon_sym_get] = ACTIONS(508),
    [anon_sym_set] = ACTIONS(508),
    [anon_sym_methods] = ACTIONS(508),
    [anon_sym_events] = ACTIONS(508),
    [anon_sym_enumeration] = ACTIONS(508),
    [anon_sym_classdef] = ACTIONS(508),
    [anon_sym_try] = ACTIONS(508),
    [anon_sym_spmd] = ACTIONS(508),
    [aux_sym_number_token1] = ACTIONS(508),
    [aux_sym_number_token2] = ACTIONS(508),
    [aux_sym_number_token3] = ACTIONS(508),
    [anon_sym_true] = ACTIONS(508),
    [anon_sym_false] = ACTIONS(508),
    [anon_sym_CR] = ACTIONS(508),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(510),
    [sym__single_quote_string_start] = ACTIONS(510),
    [sym__double_quote_string_start] = ACTIONS(510),
    [sym__multioutput_variable_start] = ACTIONS(510),
    [sym__external_identifier] = ACTIONS(510),
  },
  [STATE(87)] = {
    [anon_sym_SEMI] = ACTIONS(512),
    [anon_sym_COMMA] = ACTIONS(512),
    [anon_sym_LPAREN] = ACTIONS(512),
    [anon_sym_PLUS] = ACTIONS(512),
    [anon_sym_DOT_PLUS] = ACTIONS(512),
    [anon_sym_DASH] = ACTIONS(512),
    [anon_sym_DOT_DASH] = ACTIONS(512),
    [anon_sym_STAR] = ACTIONS(512),
    [anon_sym_DOT_STAR] = ACTIONS(512),
    [anon_sym_SLASH] = ACTIONS(512),
    [anon_sym_DOT_SLASH] = ACTIONS(512),
    [anon_sym_BSLASH] = ACTIONS(512),
    [anon_sym_DOT_BSLASH] = ACTIONS(512),
    [anon_sym_CARET] = ACTIONS(512),
    [anon_sym_DOT_CARET] = ACTIONS(512),
    [anon_sym_PIPE] = ACTIONS(512),
    [anon_sym_AMP] = ACTIONS(512),
    [anon_sym_DOT] = ACTIONS(512),
    [anon_sym_TILDE] = ACTIONS(512),
    [anon_sym_QMARK] = ACTIONS(512),
    [anon_sym_AT] = ACTIONS(512),
    [anon_sym_LT] = ACTIONS(512),
    [anon_sym_LT_EQ] = ACTIONS(512),
    [anon_sym_EQ_EQ] = ACTIONS(512),
    [anon_sym_TILDE_EQ] = ACTIONS(512),
    [anon_sym_GT_EQ] = ACTIONS(512),
    [anon_sym_GT] = ACTIONS(512),
    [anon_sym_AMP_AMP] = ACTIONS(512),
    [anon_sym_PIPE_PIPE] = ACTIONS(512),
    [anon_sym_DOT_SQUOTE] = ACTIONS(512),
    [anon_sym_SQUOTE] = ACTIONS(512),
    [anon_sym_LBRACK] = ACTIONS(512),
    [anon_sym_LF] = ACTIONS(512),
    [anon_sym_LBRACE] = ACTIONS(512),
    [anon_sym_COLON] = ACTIONS(512),
    [anon_sym_return] = ACTIONS(512),
    [anon_sym_continue] = ACTIONS(512),
    [anon_sym_break] = ACTIONS(512),
    [anon_sym_elseif] = ACTIONS(512),
    [anon_sym_else] = ACTIONS(512),
    [anon_sym_if] = ACTIONS(512),
    [anon_sym_end] = ACTIONS(512),
    [anon_sym_for] = ACTIONS(512),
    [anon_sym_parfor] = ACTIONS(512),
    [anon_sym_while] = ACTIONS(512),
    [anon_sym_switch] = ACTIONS(512),
    [anon_sym_global] = ACTIONS(512),
    [anon_sym_persistent] = ACTIONS(512),
    [anon_sym_arguments] = ACTIONS(512),
    [anon_sym_function] = ACTIONS(512),
    [anon_sym_properties] = ACTIONS(512),
    [anon_sym_get] = ACTIONS(512),
    [anon_sym_set] = ACTIONS(512),
    [anon_sym_methods] = ACTIONS(512),
    [anon_sym_events] = ACTIONS(512),
    [anon_sym_enumeration] = ACTIONS(512),
    [anon_sym_classdef] = ACTIONS(512),
    [anon_sym_try] = ACTIONS(512),
    [anon_sym_spmd] = ACTIONS(512),
    [aux_sym_number_token1] = ACTIONS(512),
    [aux_sym_number_token2] = ACTIONS(512),
    [aux_sym_number_token3] = ACTIONS(512),
    [anon_sym_true] = ACTIONS(512),
    [anon_sym_false] = ACTIONS(512),
    [anon_sym_CR] = ACTIONS(512),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(514),
    [sym__single_quote_string_start] = ACTIONS(514),
    [sym__double_quote_string_start] = ACTIONS(514),
    [sym__multioutput_variable_start] = ACTIONS(514),
    [sym__external_identifier] = ACTIONS(514),
  },
  [STATE(88)] = {
    [anon_sym_SEMI] = ACTIONS(508),
    [anon_sym_COMMA] = ACTIONS(508),
    [anon_sym_LPAREN] = ACTIONS(508),
    [anon_sym_PLUS] = ACTIONS(508),
    [anon_sym_DOT_PLUS] = ACTIONS(508),
    [anon_sym_DASH] = ACTIONS(508),
    [anon_sym_DOT_DASH] = ACTIONS(508),
    [anon_sym_STAR] = ACTIONS(508),
    [anon_sym_DOT_STAR] = ACTIONS(508),
    [anon_sym_SLASH] = ACTIONS(508),
    [anon_sym_DOT_SLASH] = ACTIONS(508),
    [anon_sym_BSLASH] = ACTIONS(508),
    [anon_sym_DOT_BSLASH] = ACTIONS(508),
    [anon_sym_CARET] = ACTIONS(508),
    [anon_sym_DOT_CARET] = ACTIONS(508),
    [anon_sym_PIPE] = ACTIONS(508),
    [anon_sym_AMP] = ACTIONS(508),
    [anon_sym_DOT] = ACTIONS(508),
    [anon_sym_TILDE] = ACTIONS(508),
    [anon_sym_QMARK] = ACTIONS(508),
    [anon_sym_AT] = ACTIONS(508),
    [anon_sym_LT] = ACTIONS(508),
    [anon_sym_LT_EQ] = ACTIONS(508),
    [anon_sym_EQ_EQ] = ACTIONS(508),
    [anon_sym_TILDE_EQ] = ACTIONS(508),
    [anon_sym_GT_EQ] = ACTIONS(508),
    [anon_sym_GT] = ACTIONS(508),
    [anon_sym_AMP_AMP] = ACTIONS(508),
    [anon_sym_PIPE_PIPE] = ACTIONS(508),
    [anon_sym_DOT_SQUOTE] = ACTIONS(508),
    [anon_sym_SQUOTE] = ACTIONS(508),
    [anon_sym_LBRACK] = ACTIONS(508),
    [anon_sym_LF] = ACTIONS(508),
    [anon_sym_LBRACE] = ACTIONS(508),
    [anon_sym_COLON] = ACTIONS(508),
    [anon_sym_return] = ACTIONS(508),
    [anon_sym_continue] = ACTIONS(508),
    [anon_sym_break] = ACTIONS(508),
    [anon_sym_elseif] = ACTIONS(508),
    [anon_sym_else] = ACTIONS(508),
    [anon_sym_if] = ACTIONS(508),
    [anon_sym_end] = ACTIONS(508),
    [anon_sym_for] = ACTIONS(508),
    [anon_sym_parfor] = ACTIONS(508),
    [anon_sym_while] = ACTIONS(508),
    [anon_sym_switch] = ACTIONS(508),
    [anon_sym_global] = ACTIONS(508),
    [anon_sym_persistent] = ACTIONS(508),
    [anon_sym_arguments] = ACTIONS(508),
    [anon_sym_function] = ACTIONS(508),
    [anon_sym_properties] = ACTIONS(508),
    [anon_sym_get] = ACTIONS(508),
    [anon_sym_set] = ACTIONS(508),
    [anon_sym_methods] = ACTIONS(508),
    [anon_sym_events] = ACTIONS(508),
    [anon_sym_enumeration] = ACTIONS(508),
    [anon_sym_classdef] = ACTIONS(508),
    [anon_sym_try] = ACTIONS(508),
    [anon_sym_spmd] = ACTIONS(508),
    [aux_sym_number_token1] = ACTIONS(508),
    [aux_sym_number_token2] = ACTIONS(508),
    [aux_sym_number_token3] = ACTIONS(508),
    [anon_sym_true] = ACTIONS(508),
    [anon_sym_false] = ACTIONS(508),
    [anon_sym_CR] = ACTIONS(508),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(510),
    [sym__single_quote_string_start] = ACTIONS(510),
    [sym__double_quote_string_start] = ACTIONS(510),
    [sym__multioutput_variable_start] = ACTIONS(510),
    [sym__external_identifier] = ACTIONS(510),
  },
  [STATE(89)] = {
    [anon_sym_SEMI] = ACTIONS(470),
    [anon_sym_COMMA] = ACTIONS(470),
    [anon_sym_LPAREN] = ACTIONS(470),
    [anon_sym_PLUS] = ACTIONS(470),
    [anon_sym_DOT_PLUS] = ACTIONS(470),
    [anon_sym_DASH] = ACTIONS(470),
    [anon_sym_DOT_DASH] = ACTIONS(470),
    [anon_sym_STAR] = ACTIONS(470),
    [anon_sym_DOT_STAR] = ACTIONS(470),
    [anon_sym_SLASH] = ACTIONS(470),
    [anon_sym_DOT_SLASH] = ACTIONS(470),
    [anon_sym_BSLASH] = ACTIONS(470),
    [anon_sym_DOT_BSLASH] = ACTIONS(470),
    [anon_sym_CARET] = ACTIONS(470),
    [anon_sym_DOT_CARET] = ACTIONS(470),
    [anon_sym_PIPE] = ACTIONS(470),
    [anon_sym_AMP] = ACTIONS(470),
    [anon_sym_DOT] = ACTIONS(470),
    [anon_sym_TILDE] = ACTIONS(470),
    [anon_sym_QMARK] = ACTIONS(470),
    [anon_sym_AT] = ACTIONS(470),
    [anon_sym_LT] = ACTIONS(470),
    [anon_sym_LT_EQ] = ACTIONS(470),
    [anon_sym_EQ_EQ] = ACTIONS(470),
    [anon_sym_TILDE_EQ] = ACTIONS(470),
    [anon_sym_GT_EQ] = ACTIONS(470),
    [anon_sym_GT] = ACTIONS(470),
    [anon_sym_AMP_AMP] = ACTIONS(470),
    [anon_sym_PIPE_PIPE] = ACTIONS(470),
    [anon_sym_DOT_SQUOTE] = ACTIONS(470),
    [anon_sym_SQUOTE] = ACTIONS(470),
    [anon_sym_LBRACK] = ACTIONS(470),
    [anon_sym_LF] = ACTIONS(470),
    [anon_sym_LBRACE] = ACTIONS(470),
    [anon_sym_COLON] = ACTIONS(470),
    [anon_sym_return] = ACTIONS(470),
    [anon_sym_continue] = ACTIONS(470),
    [anon_sym_break] = ACTIONS(470),
    [anon_sym_elseif] = ACTIONS(470),
    [anon_sym_else] = ACTIONS(470),
    [anon_sym_if] = ACTIONS(470),
    [anon_sym_end] = ACTIONS(470),
    [anon_sym_for] = ACTIONS(470),
    [anon_sym_parfor] = ACTIONS(470),
    [anon_sym_while] = ACTIONS(470),
    [anon_sym_switch] = ACTIONS(470),
    [anon_sym_global] = ACTIONS(470),
    [anon_sym_persistent] = ACTIONS(470),
    [anon_sym_arguments] = ACTIONS(470),
    [anon_sym_function] = ACTIONS(470),
    [anon_sym_properties] = ACTIONS(470),
    [anon_sym_get] = ACTIONS(470),
    [anon_sym_set] = ACTIONS(470),
    [anon_sym_methods] = ACTIONS(470),
    [anon_sym_events] = ACTIONS(470),
    [anon_sym_enumeration] = ACTIONS(470),
    [anon_sym_classdef] = ACTIONS(470),
    [anon_sym_try] = ACTIONS(470),
    [anon_sym_spmd] = ACTIONS(470),
    [aux_sym_number_token1] = ACTIONS(470),
    [aux_sym_number_token2] = ACTIONS(470),
    [aux_sym_number_token3] = ACTIONS(470),
    [anon_sym_true] = ACTIONS(470),
    [anon_sym_false] = ACTIONS(470),
    [anon_sym_CR] = ACTIONS(470),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(472),
    [sym__single_quote_string_start] = ACTIONS(472),
    [sym__double_quote_string_start] = ACTIONS(472),
    [sym__multioutput_variable_start] = ACTIONS(472),
    [sym__external_identifier] = ACTIONS(472),
  },
  [STATE(90)] = {
    [anon_sym_SEMI] = ACTIONS(516),
    [anon_sym_COMMA] = ACTIONS(516),
    [anon_sym_LPAREN] = ACTIONS(516),
    [anon_sym_PLUS] = ACTIONS(516),
    [anon_sym_DOT_PLUS] = ACTIONS(516),
    [anon_sym_DASH] = ACTIONS(516),
    [anon_sym_DOT_DASH] = ACTIONS(516),
    [anon_sym_STAR] = ACTIONS(516),
    [anon_sym_DOT_STAR] = ACTIONS(516),
    [anon_sym_SLASH] = ACTIONS(516),
    [anon_sym_DOT_SLASH] = ACTIONS(516),
    [anon_sym_BSLASH] = ACTIONS(516),
    [anon_sym_DOT_BSLASH] = ACTIONS(516),
    [anon_sym_CARET] = ACTIONS(516),
    [anon_sym_DOT_CARET] = ACTIONS(516),
    [anon_sym_PIPE] = ACTIONS(516),
    [anon_sym_AMP] = ACTIONS(516),
    [anon_sym_DOT] = ACTIONS(516),
    [anon_sym_TILDE] = ACTIONS(516),
    [anon_sym_QMARK] = ACTIONS(516),
    [anon_sym_AT] = ACTIONS(516),
    [anon_sym_LT] = ACTIONS(516),
    [anon_sym_LT_EQ] = ACTIONS(516),
    [anon_sym_EQ_EQ] = ACTIONS(516),
    [anon_sym_TILDE_EQ] = ACTIONS(516),
    [anon_sym_GT_EQ] = ACTIONS(516),
    [anon_sym_GT] = ACTIONS(516),
    [anon_sym_AMP_AMP] = ACTIONS(516),
    [anon_sym_PIPE_PIPE] = ACTIONS(516),
    [anon_sym_DOT_SQUOTE] = ACTIONS(516),
    [anon_sym_SQUOTE] = ACTIONS(516),
    [anon_sym_LBRACK] = ACTIONS(516),
    [anon_sym_LF] = ACTIONS(516),
    [anon_sym_LBRACE] = ACTIONS(516),
    [anon_sym_COLON] = ACTIONS(516),
    [anon_sym_return] = ACTIONS(516),
    [anon_sym_continue] = ACTIONS(516),
    [anon_sym_break] = ACTIONS(516),
    [anon_sym_elseif] = ACTIONS(516),
    [anon_sym_else] = ACTIONS(516),
    [anon_sym_if] = ACTIONS(516),
    [anon_sym_end] = ACTIONS(516),
    [anon_sym_for] = ACTIONS(516),
    [anon_sym_parfor] = ACTIONS(516),
    [anon_sym_while] = ACTIONS(516),
    [anon_sym_switch] = ACTIONS(516),
    [anon_sym_global] = ACTIONS(516),
    [anon_sym_persistent] = ACTIONS(516),
    [anon_sym_arguments] = ACTIONS(516),
    [anon_sym_function] = ACTIONS(516),
    [anon_sym_properties] = ACTIONS(516),
    [anon_sym_get] = ACTIONS(516),
    [anon_sym_set] = ACTIONS(516),
    [anon_sym_methods] = ACTIONS(516),
    [anon_sym_events] = ACTIONS(516),
    [anon_sym_enumeration] = ACTIONS(516),
    [anon_sym_classdef] = ACTIONS(516),
    [anon_sym_try] = ACTIONS(516),
    [anon_sym_spmd] = ACTIONS(516),
    [aux_sym_number_token1] = ACTIONS(516),
    [aux_sym_number_token2] = ACTIONS(516),
    [aux_sym_number_token3] = ACTIONS(516),
    [anon_sym_true] = ACTIONS(516),
    [anon_sym_false] = ACTIONS(516),
    [anon_sym_CR] = ACTIONS(516),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(518),
    [sym__single_quote_string_start] = ACTIONS(518),
    [sym__double_quote_string_start] = ACTIONS(518),
    [sym__multioutput_variable_start] = ACTIONS(518),
    [sym__external_identifier] = ACTIONS(518),
  },
  [STATE(91)] = {
    [anon_sym_SEMI] = ACTIONS(520),
    [anon_sym_COMMA] = ACTIONS(520),
    [anon_sym_LPAREN] = ACTIONS(520),
    [anon_sym_PLUS] = ACTIONS(520),
    [anon_sym_DOT_PLUS] = ACTIONS(520),
    [anon_sym_DASH] = ACTIONS(520),
    [anon_sym_DOT_DASH] = ACTIONS(520),
    [anon_sym_STAR] = ACTIONS(520),
    [anon_sym_DOT_STAR] = ACTIONS(520),
    [anon_sym_SLASH] = ACTIONS(520),
    [anon_sym_DOT_SLASH] = ACTIONS(520),
    [anon_sym_BSLASH] = ACTIONS(520),
    [anon_sym_DOT_BSLASH] = ACTIONS(520),
    [anon_sym_CARET] = ACTIONS(520),
    [anon_sym_DOT_CARET] = ACTIONS(520),
    [anon_sym_PIPE] = ACTIONS(520),
    [anon_sym_AMP] = ACTIONS(520),
    [anon_sym_DOT] = ACTIONS(520),
    [anon_sym_TILDE] = ACTIONS(520),
    [anon_sym_QMARK] = ACTIONS(520),
    [anon_sym_AT] = ACTIONS(520),
    [anon_sym_LT] = ACTIONS(520),
    [anon_sym_LT_EQ] = ACTIONS(520),
    [anon_sym_EQ_EQ] = ACTIONS(520),
    [anon_sym_TILDE_EQ] = ACTIONS(520),
    [anon_sym_GT_EQ] = ACTIONS(520),
    [anon_sym_GT] = ACTIONS(520),
    [anon_sym_AMP_AMP] = ACTIONS(520),
    [anon_sym_PIPE_PIPE] = ACTIONS(520),
    [anon_sym_DOT_SQUOTE] = ACTIONS(520),
    [anon_sym_SQUOTE] = ACTIONS(520),
    [anon_sym_LBRACK] = ACTIONS(520),
    [anon_sym_LF] = ACTIONS(520),
    [anon_sym_LBRACE] = ACTIONS(520),
    [anon_sym_COLON] = ACTIONS(520),
    [anon_sym_return] = ACTIONS(520),
    [anon_sym_continue] = ACTIONS(520),
    [anon_sym_break] = ACTIONS(520),
    [anon_sym_elseif] = ACTIONS(520),
    [anon_sym_else] = ACTIONS(520),
    [anon_sym_if] = ACTIONS(520),
    [anon_sym_end] = ACTIONS(520),
    [anon_sym_for] = ACTIONS(520),
    [anon_sym_parfor] = ACTIONS(520),
    [anon_sym_while] = ACTIONS(520),
    [anon_sym_switch] = ACTIONS(520),
    [anon_sym_global] = ACTIONS(520),
    [anon_sym_persistent] = ACTIONS(520),
    [anon_sym_arguments] = ACTIONS(520),
    [anon_sym_function] = ACTIONS(520),
    [anon_sym_properties] = ACTIONS(520),
    [anon_sym_get] = ACTIONS(520),
    [anon_sym_set] = ACTIONS(520),
    [anon_sym_methods] = ACTIONS(520),
    [anon_sym_events] = ACTIONS(520),
    [anon_sym_enumeration] = ACTIONS(520),
    [anon_sym_classdef] = ACTIONS(520),
    [anon_sym_try] = ACTIONS(520),
    [anon_sym_spmd] = ACTIONS(520),
    [aux_sym_number_token1] = ACTIONS(520),
    [aux_sym_number_token2] = ACTIONS(520),
    [aux_sym_number_token3] = ACTIONS(520),
    [anon_sym_true] = ACTIONS(520),
    [anon_sym_false] = ACTIONS(520),
    [anon_sym_CR] = ACTIONS(520),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(522),
    [sym__single_quote_string_start] = ACTIONS(522),
    [sym__double_quote_string_start] = ACTIONS(522),
    [sym__multioutput_variable_start] = ACTIONS(522),
    [sym__external_identifier] = ACTIONS(522),
  },
  [STATE(92)] = {
    [anon_sym_SEMI] = ACTIONS(524),
    [anon_sym_COMMA] = ACTIONS(524),
    [anon_sym_LPAREN] = ACTIONS(524),
    [anon_sym_PLUS] = ACTIONS(524),
    [anon_sym_DOT_PLUS] = ACTIONS(524),
    [anon_sym_DASH] = ACTIONS(524),
    [anon_sym_DOT_DASH] = ACTIONS(524),
    [anon_sym_STAR] = ACTIONS(524),
    [anon_sym_DOT_STAR] = ACTIONS(524),
    [anon_sym_SLASH] = ACTIONS(524),
    [anon_sym_DOT_SLASH] = ACTIONS(524),
    [anon_sym_BSLASH] = ACTIONS(524),
    [anon_sym_DOT_BSLASH] = ACTIONS(524),
    [anon_sym_CARET] = ACTIONS(524),
    [anon_sym_DOT_CARET] = ACTIONS(524),
    [anon_sym_PIPE] = ACTIONS(524),
    [anon_sym_AMP] = ACTIONS(524),
    [anon_sym_DOT] = ACTIONS(524),
    [anon_sym_TILDE] = ACTIONS(524),
    [anon_sym_QMARK] = ACTIONS(524),
    [anon_sym_AT] = ACTIONS(524),
    [anon_sym_LT] = ACTIONS(524),
    [anon_sym_LT_EQ] = ACTIONS(524),
    [anon_sym_EQ_EQ] = ACTIONS(524),
    [anon_sym_TILDE_EQ] = ACTIONS(524),
    [anon_sym_GT_EQ] = ACTIONS(524),
    [anon_sym_GT] = ACTIONS(524),
    [anon_sym_AMP_AMP] = ACTIONS(524),
    [anon_sym_PIPE_PIPE] = ACTIONS(524),
    [anon_sym_DOT_SQUOTE] = ACTIONS(524),
    [anon_sym_SQUOTE] = ACTIONS(524),
    [anon_sym_LBRACK] = ACTIONS(524),
    [anon_sym_LF] = ACTIONS(524),
    [anon_sym_LBRACE] = ACTIONS(524),
    [anon_sym_COLON] = ACTIONS(524),
    [anon_sym_return] = ACTIONS(524),
    [anon_sym_continue] = ACTIONS(524),
    [anon_sym_break] = ACTIONS(524),
    [anon_sym_elseif] = ACTIONS(524),
    [anon_sym_else] = ACTIONS(524),
    [anon_sym_if] = ACTIONS(524),
    [anon_sym_end] = ACTIONS(524),
    [anon_sym_for] = ACTIONS(524),
    [anon_sym_parfor] = ACTIONS(524),
    [anon_sym_while] = ACTIONS(524),
    [anon_sym_switch] = ACTIONS(524),
    [anon_sym_global] = ACTIONS(524),
    [anon_sym_persistent] = ACTIONS(524),
    [anon_sym_arguments] = ACTIONS(524),
    [anon_sym_function] = ACTIONS(524),
    [anon_sym_properties] = ACTIONS(524),
    [anon_sym_get] = ACTIONS(524),
    [anon_sym_set] = ACTIONS(524),
    [anon_sym_methods] = ACTIONS(524),
    [anon_sym_events] = ACTIONS(524),
    [anon_sym_enumeration] = ACTIONS(524),
    [anon_sym_classdef] = ACTIONS(524),
    [anon_sym_try] = ACTIONS(524),
    [anon_sym_spmd] = ACTIONS(524),
    [aux_sym_number_token1] = ACTIONS(524),
    [aux_sym_number_token2] = ACTIONS(524),
    [aux_sym_number_token3] = ACTIONS(524),
    [anon_sym_true] = ACTIONS(524),
    [anon_sym_false] = ACTIONS(524),
    [anon_sym_CR] = ACTIONS(524),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(526),
    [sym__single_quote_string_start] = ACTIONS(526),
    [sym__double_quote_string_start] = ACTIONS(526),
    [sym__multioutput_variable_start] = ACTIONS(526),
    [sym__external_identifier] = ACTIONS(526),
  },
  [STATE(93)] = {
    [anon_sym_SEMI] = ACTIONS(528),
    [anon_sym_COMMA] = ACTIONS(528),
    [anon_sym_LPAREN] = ACTIONS(528),
    [anon_sym_PLUS] = ACTIONS(528),
    [anon_sym_DOT_PLUS] = ACTIONS(528),
    [anon_sym_DASH] = ACTIONS(528),
    [anon_sym_DOT_DASH] = ACTIONS(528),
    [anon_sym_STAR] = ACTIONS(528),
    [anon_sym_DOT_STAR] = ACTIONS(528),
    [anon_sym_SLASH] = ACTIONS(528),
    [anon_sym_DOT_SLASH] = ACTIONS(528),
    [anon_sym_BSLASH] = ACTIONS(528),
    [anon_sym_DOT_BSLASH] = ACTIONS(528),
    [anon_sym_CARET] = ACTIONS(528),
    [anon_sym_DOT_CARET] = ACTIONS(528),
    [anon_sym_PIPE] = ACTIONS(528),
    [anon_sym_AMP] = ACTIONS(528),
    [anon_sym_DOT] = ACTIONS(528),
    [anon_sym_TILDE] = ACTIONS(528),
    [anon_sym_QMARK] = ACTIONS(528),
    [anon_sym_AT] = ACTIONS(528),
    [anon_sym_LT] = ACTIONS(528),
    [anon_sym_LT_EQ] = ACTIONS(528),
    [anon_sym_EQ_EQ] = ACTIONS(528),
    [anon_sym_TILDE_EQ] = ACTIONS(528),
    [anon_sym_GT_EQ] = ACTIONS(528),
    [anon_sym_GT] = ACTIONS(528),
    [anon_sym_AMP_AMP] = ACTIONS(528),
    [anon_sym_PIPE_PIPE] = ACTIONS(528),
    [anon_sym_DOT_SQUOTE] = ACTIONS(528),
    [anon_sym_SQUOTE] = ACTIONS(528),
    [anon_sym_LBRACK] = ACTIONS(528),
    [anon_sym_LF] = ACTIONS(528),
    [anon_sym_LBRACE] = ACTIONS(528),
    [anon_sym_COLON] = ACTIONS(528),
    [anon_sym_return] = ACTIONS(528),
    [anon_sym_continue] = ACTIONS(528),
    [anon_sym_break] = ACTIONS(528),
    [anon_sym_elseif] = ACTIONS(528),
    [anon_sym_else] = ACTIONS(528),
    [anon_sym_if] = ACTIONS(528),
    [anon_sym_end] = ACTIONS(528),
    [anon_sym_for] = ACTIONS(528),
    [anon_sym_parfor] = ACTIONS(528),
    [anon_sym_while] = ACTIONS(528),
    [anon_sym_switch] = ACTIONS(528),
    [anon_sym_global] = ACTIONS(528),
    [anon_sym_persistent] = ACTIONS(528),
    [anon_sym_arguments] = ACTIONS(528),
    [anon_sym_function] = ACTIONS(528),
    [anon_sym_properties] = ACTIONS(528),
    [anon_sym_get] = ACTIONS(528),
    [anon_sym_set] = ACTIONS(528),
    [anon_sym_methods] = ACTIONS(528),
    [anon_sym_events] = ACTIONS(528),
    [anon_sym_enumeration] = ACTIONS(528),
    [anon_sym_classdef] = ACTIONS(528),
    [anon_sym_try] = ACTIONS(528),
    [anon_sym_spmd] = ACTIONS(528),
    [aux_sym_number_token1] = ACTIONS(528),
    [aux_sym_number_token2] = ACTIONS(528),
    [aux_sym_number_token3] = ACTIONS(528),
    [anon_sym_true] = ACTIONS(528),
    [anon_sym_false] = ACTIONS(528),
    [anon_sym_CR] = ACTIONS(528),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(530),
    [sym__single_quote_string_start] = ACTIONS(530),
    [sym__double_quote_string_start] = ACTIONS(530),
    [sym__multioutput_variable_start] = ACTIONS(530),
    [sym__external_identifier] = ACTIONS(530),
  },
  [STATE(94)] = {
    [sym__args] = STATE(101),
    [anon_sym_SEMI] = ACTIONS(435),
    [anon_sym_COMMA] = ACTIONS(435),
    [anon_sym_LPAREN] = ACTIONS(437),
    [anon_sym_PLUS] = ACTIONS(435),
    [anon_sym_DOT_PLUS] = ACTIONS(435),
    [anon_sym_DASH] = ACTIONS(435),
    [anon_sym_DOT_DASH] = ACTIONS(435),
    [anon_sym_STAR] = ACTIONS(435),
    [anon_sym_DOT_STAR] = ACTIONS(435),
    [anon_sym_SLASH] = ACTIONS(435),
    [anon_sym_DOT_SLASH] = ACTIONS(435),
    [anon_sym_BSLASH] = ACTIONS(435),
    [anon_sym_DOT_BSLASH] = ACTIONS(435),
    [anon_sym_CARET] = ACTIONS(435),
    [anon_sym_DOT_CARET] = ACTIONS(435),
    [anon_sym_PIPE] = ACTIONS(435),
    [anon_sym_AMP] = ACTIONS(435),
    [anon_sym_TILDE] = ACTIONS(435),
    [anon_sym_QMARK] = ACTIONS(435),
    [anon_sym_AT] = ACTIONS(532),
    [anon_sym_LT] = ACTIONS(435),
    [anon_sym_LT_EQ] = ACTIONS(435),
    [anon_sym_EQ_EQ] = ACTIONS(435),
    [anon_sym_TILDE_EQ] = ACTIONS(435),
    [anon_sym_GT_EQ] = ACTIONS(435),
    [anon_sym_GT] = ACTIONS(435),
    [anon_sym_AMP_AMP] = ACTIONS(435),
    [anon_sym_PIPE_PIPE] = ACTIONS(435),
    [anon_sym_DOT_SQUOTE] = ACTIONS(443),
    [anon_sym_SQUOTE] = ACTIONS(443),
    [anon_sym_LBRACK] = ACTIONS(435),
    [anon_sym_LF] = ACTIONS(435),
    [anon_sym_LBRACE] = ACTIONS(445),
    [anon_sym_COLON] = ACTIONS(435),
    [anon_sym_return] = ACTIONS(435),
    [anon_sym_continue] = ACTIONS(435),
    [anon_sym_break] = ACTIONS(435),
    [anon_sym_elseif] = ACTIONS(435),
    [anon_sym_else] = ACTIONS(435),
    [anon_sym_if] = ACTIONS(435),
    [anon_sym_end] = ACTIONS(435),
    [anon_sym_for] = ACTIONS(435),
    [anon_sym_parfor] = ACTIONS(435),
    [anon_sym_while] = ACTIONS(435),
    [anon_sym_switch] = ACTIONS(435),
    [anon_sym_global] = ACTIONS(435),
    [anon_sym_persistent] = ACTIONS(435),
    [anon_sym_arguments] = ACTIONS(435),
    [anon_sym_function] = ACTIONS(435),
    [anon_sym_properties] = ACTIONS(435),
    [anon_sym_get] = ACTIONS(435),
    [anon_sym_set] = ACTIONS(435),
    [anon_sym_methods] = ACTIONS(435),
    [anon_sym_events] = ACTIONS(435),
    [anon_sym_enumeration] = ACTIONS(435),
    [anon_sym_classdef] = ACTIONS(435),
    [anon_sym_try] = ACTIONS(435),
    [anon_sym_spmd] = ACTIONS(435),
    [aux_sym_number_token1] = ACTIONS(435),
    [aux_sym_number_token2] = ACTIONS(435),
    [aux_sym_number_token3] = ACTIONS(435),
    [anon_sym_true] = ACTIONS(435),
    [anon_sym_false] = ACTIONS(435),
    [anon_sym_CR] = ACTIONS(435),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(447),
    [sym__single_quote_string_start] = ACTIONS(447),
    [sym__double_quote_string_start] = ACTIONS(447),
    [sym__multioutput_variable_start] = ACTIONS(447),
    [sym__external_identifier] = ACTIONS(447),
  },
  [STATE(95)] = {
    [sym__args] = STATE(101),
    [anon_sym_SEMI] = ACTIONS(449),
    [anon_sym_COMMA] = ACTIONS(449),
    [anon_sym_LPAREN] = ACTIONS(437),
    [anon_sym_PLUS] = ACTIONS(451),
    [anon_sym_DOT_PLUS] = ACTIONS(451),
    [anon_sym_DASH] = ACTIONS(451),
    [anon_sym_DOT_DASH] = ACTIONS(451),
    [anon_sym_STAR] = ACTIONS(451),
    [anon_sym_DOT_STAR] = ACTIONS(451),
    [anon_sym_SLASH] = ACTIONS(451),
    [anon_sym_DOT_SLASH] = ACTIONS(451),
    [anon_sym_BSLASH] = ACTIONS(451),
    [anon_sym_DOT_BSLASH] = ACTIONS(451),
    [anon_sym_CARET] = ACTIONS(451),
    [anon_sym_DOT_CARET] = ACTIONS(451),
    [anon_sym_PIPE] = ACTIONS(451),
    [anon_sym_AMP] = ACTIONS(451),
    [anon_sym_TILDE] = ACTIONS(449),
    [anon_sym_QMARK] = ACTIONS(449),
    [anon_sym_AT] = ACTIONS(532),
    [anon_sym_LT] = ACTIONS(449),
    [anon_sym_LT_EQ] = ACTIONS(449),
    [anon_sym_EQ_EQ] = ACTIONS(449),
    [anon_sym_TILDE_EQ] = ACTIONS(449),
    [anon_sym_GT_EQ] = ACTIONS(449),
    [anon_sym_GT] = ACTIONS(449),
    [anon_sym_AMP_AMP] = ACTIONS(449),
    [anon_sym_PIPE_PIPE] = ACTIONS(449),
    [anon_sym_DOT_SQUOTE] = ACTIONS(443),
    [anon_sym_SQUOTE] = ACTIONS(443),
    [anon_sym_LBRACK] = ACTIONS(449),
    [anon_sym_LF] = ACTIONS(449),
    [anon_sym_LBRACE] = ACTIONS(445),
    [anon_sym_COLON] = ACTIONS(458),
    [anon_sym_return] = ACTIONS(449),
    [anon_sym_continue] = ACTIONS(449),
    [anon_sym_break] = ACTIONS(449),
    [anon_sym_elseif] = ACTIONS(449),
    [anon_sym_else] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(449),
    [anon_sym_end] = ACTIONS(449),
    [anon_sym_for] = ACTIONS(449),
    [anon_sym_parfor] = ACTIONS(449),
    [anon_sym_while] = ACTIONS(449),
    [anon_sym_switch] = ACTIONS(449),
    [anon_sym_global] = ACTIONS(449),
    [anon_sym_persistent] = ACTIONS(449),
    [anon_sym_arguments] = ACTIONS(449),
    [anon_sym_function] = ACTIONS(449),
    [anon_sym_properties] = ACTIONS(449),
    [anon_sym_get] = ACTIONS(449),
    [anon_sym_set] = ACTIONS(449),
    [anon_sym_methods] = ACTIONS(449),
    [anon_sym_events] = ACTIONS(449),
    [anon_sym_enumeration] = ACTIONS(449),
    [anon_sym_classdef] = ACTIONS(449),
    [anon_sym_try] = ACTIONS(449),
    [anon_sym_spmd] = ACTIONS(449),
    [aux_sym_number_token1] = ACTIONS(449),
    [aux_sym_number_token2] = ACTIONS(449),
    [aux_sym_number_token3] = ACTIONS(449),
    [anon_sym_true] = ACTIONS(449),
    [anon_sym_false] = ACTIONS(449),
    [anon_sym_CR] = ACTIONS(449),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(456),
    [sym__single_quote_string_start] = ACTIONS(456),
    [sym__double_quote_string_start] = ACTIONS(456),
    [sym__multioutput_variable_start] = ACTIONS(456),
    [sym__external_identifier] = ACTIONS(456),
  },
  [STATE(96)] = {
    [sym__args] = STATE(101),
    [anon_sym_SEMI] = ACTIONS(449),
    [anon_sym_COMMA] = ACTIONS(449),
    [anon_sym_LPAREN] = ACTIONS(437),
    [anon_sym_PLUS] = ACTIONS(451),
    [anon_sym_DOT_PLUS] = ACTIONS(451),
    [anon_sym_DASH] = ACTIONS(451),
    [anon_sym_DOT_DASH] = ACTIONS(451),
    [anon_sym_STAR] = ACTIONS(451),
    [anon_sym_DOT_STAR] = ACTIONS(451),
    [anon_sym_SLASH] = ACTIONS(451),
    [anon_sym_DOT_SLASH] = ACTIONS(451),
    [anon_sym_BSLASH] = ACTIONS(451),
    [anon_sym_DOT_BSLASH] = ACTIONS(451),
    [anon_sym_CARET] = ACTIONS(451),
    [anon_sym_DOT_CARET] = ACTIONS(451),
    [anon_sym_PIPE] = ACTIONS(451),
    [anon_sym_AMP] = ACTIONS(451),
    [anon_sym_TILDE] = ACTIONS(449),
    [anon_sym_QMARK] = ACTIONS(449),
    [anon_sym_AT] = ACTIONS(532),
    [anon_sym_LT] = ACTIONS(449),
    [anon_sym_LT_EQ] = ACTIONS(449),
    [anon_sym_EQ_EQ] = ACTIONS(449),
    [anon_sym_TILDE_EQ] = ACTIONS(449),
    [anon_sym_GT_EQ] = ACTIONS(449),
    [anon_sym_GT] = ACTIONS(449),
    [anon_sym_AMP_AMP] = ACTIONS(449),
    [anon_sym_PIPE_PIPE] = ACTIONS(449),
    [anon_sym_DOT_SQUOTE] = ACTIONS(443),
    [anon_sym_SQUOTE] = ACTIONS(443),
    [anon_sym_LBRACK] = ACTIONS(449),
    [anon_sym_LF] = ACTIONS(449),
    [anon_sym_LBRACE] = ACTIONS(445),
    [anon_sym_COLON] = ACTIONS(453),
    [anon_sym_return] = ACTIONS(449),
    [anon_sym_continue] = ACTIONS(449),
    [anon_sym_break] = ACTIONS(449),
    [anon_sym_elseif] = ACTIONS(449),
    [anon_sym_else] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(449),
    [anon_sym_end] = ACTIONS(449),
    [anon_sym_for] = ACTIONS(449),
    [anon_sym_parfor] = ACTIONS(449),
    [anon_sym_while] = ACTIONS(449),
    [anon_sym_switch] = ACTIONS(449),
    [anon_sym_global] = ACTIONS(449),
    [anon_sym_persistent] = ACTIONS(449),
    [anon_sym_arguments] = ACTIONS(449),
    [anon_sym_function] = ACTIONS(449),
    [anon_sym_properties] = ACTIONS(449),
    [anon_sym_get] = ACTIONS(449),
    [anon_sym_set] = ACTIONS(449),
    [anon_sym_methods] = ACTIONS(449),
    [anon_sym_events] = ACTIONS(449),
    [anon_sym_enumeration] = ACTIONS(449),
    [anon_sym_classdef] = ACTIONS(449),
    [anon_sym_try] = ACTIONS(449),
    [anon_sym_spmd] = ACTIONS(449),
    [aux_sym_number_token1] = ACTIONS(449),
    [aux_sym_number_token2] = ACTIONS(449),
    [aux_sym_number_token3] = ACTIONS(449),
    [anon_sym_true] = ACTIONS(449),
    [anon_sym_false] = ACTIONS(449),
    [anon_sym_CR] = ACTIONS(449),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(456),
    [sym__single_quote_string_start] = ACTIONS(456),
    [sym__double_quote_string_start] = ACTIONS(456),
    [sym__multioutput_variable_start] = ACTIONS(456),
    [sym__external_identifier] = ACTIONS(456),
  },
  [STATE(97)] = {
    [anon_sym_SEMI] = ACTIONS(493),
    [anon_sym_COMMA] = ACTIONS(493),
    [anon_sym_LPAREN] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(493),
    [anon_sym_DOT_PLUS] = ACTIONS(493),
    [anon_sym_DASH] = ACTIONS(493),
    [anon_sym_DOT_DASH] = ACTIONS(493),
    [anon_sym_STAR] = ACTIONS(493),
    [anon_sym_DOT_STAR] = ACTIONS(493),
    [anon_sym_SLASH] = ACTIONS(493),
    [anon_sym_DOT_SLASH] = ACTIONS(493),
    [anon_sym_BSLASH] = ACTIONS(493),
    [anon_sym_DOT_BSLASH] = ACTIONS(493),
    [anon_sym_CARET] = ACTIONS(493),
    [anon_sym_DOT_CARET] = ACTIONS(493),
    [anon_sym_PIPE] = ACTIONS(493),
    [anon_sym_AMP] = ACTIONS(493),
    [anon_sym_DOT] = ACTIONS(493),
    [anon_sym_TILDE] = ACTIONS(493),
    [anon_sym_QMARK] = ACTIONS(493),
    [anon_sym_AT] = ACTIONS(493),
    [anon_sym_LT] = ACTIONS(493),
    [anon_sym_LT_EQ] = ACTIONS(493),
    [anon_sym_EQ_EQ] = ACTIONS(493),
    [anon_sym_TILDE_EQ] = ACTIONS(493),
    [anon_sym_GT_EQ] = ACTIONS(493),
    [anon_sym_GT] = ACTIONS(493),
    [anon_sym_AMP_AMP] = ACTIONS(493),
    [anon_sym_PIPE_PIPE] = ACTIONS(493),
    [anon_sym_DOT_SQUOTE] = ACTIONS(493),
    [anon_sym_SQUOTE] = ACTIONS(493),
    [anon_sym_LBRACK] = ACTIONS(493),
    [anon_sym_LF] = ACTIONS(493),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_COLON] = ACTIONS(493),
    [anon_sym_return] = ACTIONS(493),
    [anon_sym_continue] = ACTIONS(493),
    [anon_sym_break] = ACTIONS(493),
    [anon_sym_elseif] = ACTIONS(493),
    [anon_sym_else] = ACTIONS(493),
    [anon_sym_if] = ACTIONS(493),
    [anon_sym_end] = ACTIONS(493),
    [anon_sym_for] = ACTIONS(493),
    [anon_sym_parfor] = ACTIONS(493),
    [anon_sym_while] = ACTIONS(493),
    [anon_sym_switch] = ACTIONS(493),
    [anon_sym_global] = ACTIONS(493),
    [anon_sym_persistent] = ACTIONS(493),
    [anon_sym_arguments] = ACTIONS(493),
    [anon_sym_function] = ACTIONS(493),
    [anon_sym_properties] = ACTIONS(493),
    [anon_sym_get] = ACTIONS(493),
    [anon_sym_set] = ACTIONS(493),
    [anon_sym_methods] = ACTIONS(493),
    [anon_sym_events] = ACTIONS(493),
    [anon_sym_enumeration] = ACTIONS(493),
    [anon_sym_classdef] = ACTIONS(493),
    [anon_sym_try] = ACTIONS(493),
    [anon_sym_spmd] = ACTIONS(493),
    [aux_sym_number_token1] = ACTIONS(493),
    [aux_sym_number_token2] = ACTIONS(493),
    [aux_sym_number_token3] = ACTIONS(493),
    [anon_sym_true] = ACTIONS(493),
    [anon_sym_false] = ACTIONS(493),
    [anon_sym_CR] = ACTIONS(493),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(498),
    [sym__single_quote_string_start] = ACTIONS(498),
    [sym__double_quote_string_start] = ACTIONS(498),
    [sym__multioutput_variable_start] = ACTIONS(498),
    [sym__external_identifier] = ACTIONS(498),
  },
  [STATE(98)] = {
    [sym__args] = STATE(101),
    [anon_sym_SEMI] = ACTIONS(451),
    [anon_sym_COMMA] = ACTIONS(451),
    [anon_sym_LPAREN] = ACTIONS(437),
    [anon_sym_PLUS] = ACTIONS(451),
    [anon_sym_DOT_PLUS] = ACTIONS(451),
    [anon_sym_DASH] = ACTIONS(451),
    [anon_sym_DOT_DASH] = ACTIONS(451),
    [anon_sym_STAR] = ACTIONS(451),
    [anon_sym_DOT_STAR] = ACTIONS(451),
    [anon_sym_SLASH] = ACTIONS(451),
    [anon_sym_DOT_SLASH] = ACTIONS(451),
    [anon_sym_BSLASH] = ACTIONS(451),
    [anon_sym_DOT_BSLASH] = ACTIONS(451),
    [anon_sym_CARET] = ACTIONS(451),
    [anon_sym_DOT_CARET] = ACTIONS(451),
    [anon_sym_PIPE] = ACTIONS(451),
    [anon_sym_AMP] = ACTIONS(451),
    [anon_sym_TILDE] = ACTIONS(451),
    [anon_sym_QMARK] = ACTIONS(451),
    [anon_sym_AT] = ACTIONS(532),
    [anon_sym_LT] = ACTIONS(451),
    [anon_sym_LT_EQ] = ACTIONS(451),
    [anon_sym_EQ_EQ] = ACTIONS(451),
    [anon_sym_TILDE_EQ] = ACTIONS(451),
    [anon_sym_GT_EQ] = ACTIONS(451),
    [anon_sym_GT] = ACTIONS(451),
    [anon_sym_AMP_AMP] = ACTIONS(451),
    [anon_sym_PIPE_PIPE] = ACTIONS(451),
    [anon_sym_DOT_SQUOTE] = ACTIONS(443),
    [anon_sym_SQUOTE] = ACTIONS(443),
    [anon_sym_LBRACK] = ACTIONS(451),
    [anon_sym_LF] = ACTIONS(451),
    [anon_sym_LBRACE] = ACTIONS(445),
    [anon_sym_COLON] = ACTIONS(451),
    [anon_sym_return] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(451),
    [anon_sym_break] = ACTIONS(451),
    [anon_sym_elseif] = ACTIONS(451),
    [anon_sym_else] = ACTIONS(451),
    [anon_sym_if] = ACTIONS(451),
    [anon_sym_end] = ACTIONS(451),
    [anon_sym_for] = ACTIONS(451),
    [anon_sym_parfor] = ACTIONS(451),
    [anon_sym_while] = ACTIONS(451),
    [anon_sym_switch] = ACTIONS(451),
    [anon_sym_global] = ACTIONS(451),
    [anon_sym_persistent] = ACTIONS(451),
    [anon_sym_arguments] = ACTIONS(451),
    [anon_sym_function] = ACTIONS(451),
    [anon_sym_properties] = ACTIONS(451),
    [anon_sym_get] = ACTIONS(451),
    [anon_sym_set] = ACTIONS(451),
    [anon_sym_methods] = ACTIONS(451),
    [anon_sym_events] = ACTIONS(451),
    [anon_sym_enumeration] = ACTIONS(451),
    [anon_sym_classdef] = ACTIONS(451),
    [anon_sym_try] = ACTIONS(451),
    [anon_sym_spmd] = ACTIONS(451),
    [aux_sym_number_token1] = ACTIONS(451),
    [aux_sym_number_token2] = ACTIONS(451),
    [aux_sym_number_token3] = ACTIONS(451),
    [anon_sym_true] = ACTIONS(451),
    [anon_sym_false] = ACTIONS(451),
    [anon_sym_CR] = ACTIONS(451),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(460),
    [sym__single_quote_string_start] = ACTIONS(460),
    [sym__double_quote_string_start] = ACTIONS(460),
    [sym__multioutput_variable_start] = ACTIONS(460),
    [sym__external_identifier] = ACTIONS(460),
  },
  [STATE(99)] = {
    [anon_sym_SEMI] = ACTIONS(534),
    [anon_sym_COMMA] = ACTIONS(534),
    [anon_sym_LPAREN] = ACTIONS(534),
    [anon_sym_PLUS] = ACTIONS(534),
    [anon_sym_DOT_PLUS] = ACTIONS(534),
    [anon_sym_DASH] = ACTIONS(534),
    [anon_sym_DOT_DASH] = ACTIONS(534),
    [anon_sym_STAR] = ACTIONS(534),
    [anon_sym_DOT_STAR] = ACTIONS(534),
    [anon_sym_SLASH] = ACTIONS(534),
    [anon_sym_DOT_SLASH] = ACTIONS(534),
    [anon_sym_BSLASH] = ACTIONS(534),
    [anon_sym_DOT_BSLASH] = ACTIONS(534),
    [anon_sym_CARET] = ACTIONS(534),
    [anon_sym_DOT_CARET] = ACTIONS(534),
    [anon_sym_PIPE] = ACTIONS(534),
    [anon_sym_AMP] = ACTIONS(534),
    [anon_sym_DOT] = ACTIONS(534),
    [anon_sym_TILDE] = ACTIONS(534),
    [anon_sym_QMARK] = ACTIONS(534),
    [anon_sym_AT] = ACTIONS(534),
    [anon_sym_LT] = ACTIONS(534),
    [anon_sym_LT_EQ] = ACTIONS(534),
    [anon_sym_EQ_EQ] = ACTIONS(534),
    [anon_sym_TILDE_EQ] = ACTIONS(534),
    [anon_sym_GT_EQ] = ACTIONS(534),
    [anon_sym_GT] = ACTIONS(534),
    [anon_sym_AMP_AMP] = ACTIONS(534),
    [anon_sym_PIPE_PIPE] = ACTIONS(534),
    [anon_sym_DOT_SQUOTE] = ACTIONS(534),
    [anon_sym_SQUOTE] = ACTIONS(534),
    [anon_sym_LBRACK] = ACTIONS(534),
    [anon_sym_LF] = ACTIONS(534),
    [anon_sym_LBRACE] = ACTIONS(534),
    [anon_sym_COLON] = ACTIONS(534),
    [anon_sym_return] = ACTIONS(534),
    [anon_sym_continue] = ACTIONS(534),
    [anon_sym_break] = ACTIONS(534),
    [anon_sym_elseif] = ACTIONS(534),
    [anon_sym_else] = ACTIONS(534),
    [anon_sym_if] = ACTIONS(534),
    [anon_sym_end] = ACTIONS(534),
    [anon_sym_for] = ACTIONS(534),
    [anon_sym_parfor] = ACTIONS(534),
    [anon_sym_while] = ACTIONS(534),
    [anon_sym_switch] = ACTIONS(534),
    [anon_sym_global] = ACTIONS(534),
    [anon_sym_persistent] = ACTIONS(534),
    [anon_sym_arguments] = ACTIONS(534),
    [anon_sym_function] = ACTIONS(534),
    [anon_sym_properties] = ACTIONS(534),
    [anon_sym_get] = ACTIONS(534),
    [anon_sym_set] = ACTIONS(534),
    [anon_sym_methods] = ACTIONS(534),
    [anon_sym_events] = ACTIONS(534),
    [anon_sym_enumeration] = ACTIONS(534),
    [anon_sym_classdef] = ACTIONS(534),
    [anon_sym_try] = ACTIONS(534),
    [anon_sym_spmd] = ACTIONS(534),
    [aux_sym_number_token1] = ACTIONS(534),
    [aux_sym_number_token2] = ACTIONS(534),
    [aux_sym_number_token3] = ACTIONS(534),
    [anon_sym_true] = ACTIONS(534),
    [anon_sym_false] = ACTIONS(534),
    [anon_sym_CR] = ACTIONS(534),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(536),
    [sym__single_quote_string_start] = ACTIONS(536),
    [sym__double_quote_string_start] = ACTIONS(536),
    [sym__multioutput_variable_start] = ACTIONS(536),
    [sym__external_identifier] = ACTIONS(536),
  },
  [STATE(100)] = {
    [sym__args] = STATE(101),
    [anon_sym_SEMI] = ACTIONS(458),
    [anon_sym_COMMA] = ACTIONS(458),
    [anon_sym_LPAREN] = ACTIONS(437),
    [anon_sym_PLUS] = ACTIONS(451),
    [anon_sym_DOT_PLUS] = ACTIONS(451),
    [anon_sym_DASH] = ACTIONS(451),
    [anon_sym_DOT_DASH] = ACTIONS(451),
    [anon_sym_STAR] = ACTIONS(451),
    [anon_sym_DOT_STAR] = ACTIONS(451),
    [anon_sym_SLASH] = ACTIONS(451),
    [anon_sym_DOT_SLASH] = ACTIONS(451),
    [anon_sym_BSLASH] = ACTIONS(451),
    [anon_sym_DOT_BSLASH] = ACTIONS(451),
    [anon_sym_CARET] = ACTIONS(451),
    [anon_sym_DOT_CARET] = ACTIONS(451),
    [anon_sym_PIPE] = ACTIONS(451),
    [anon_sym_AMP] = ACTIONS(451),
    [anon_sym_TILDE] = ACTIONS(458),
    [anon_sym_QMARK] = ACTIONS(458),
    [anon_sym_AT] = ACTIONS(532),
    [anon_sym_LT] = ACTIONS(453),
    [anon_sym_LT_EQ] = ACTIONS(453),
    [anon_sym_EQ_EQ] = ACTIONS(453),
    [anon_sym_TILDE_EQ] = ACTIONS(453),
    [anon_sym_GT_EQ] = ACTIONS(453),
    [anon_sym_GT] = ACTIONS(453),
    [anon_sym_AMP_AMP] = ACTIONS(453),
    [anon_sym_PIPE_PIPE] = ACTIONS(453),
    [anon_sym_DOT_SQUOTE] = ACTIONS(443),
    [anon_sym_SQUOTE] = ACTIONS(443),
    [anon_sym_LBRACK] = ACTIONS(458),
    [anon_sym_LF] = ACTIONS(458),
    [anon_sym_LBRACE] = ACTIONS(445),
    [anon_sym_COLON] = ACTIONS(458),
    [anon_sym_return] = ACTIONS(458),
    [anon_sym_continue] = ACTIONS(458),
    [anon_sym_break] = ACTIONS(458),
    [anon_sym_elseif] = ACTIONS(458),
    [anon_sym_else] = ACTIONS(458),
    [anon_sym_if] = ACTIONS(458),
    [anon_sym_end] = ACTIONS(458),
    [anon_sym_for] = ACTIONS(458),
    [anon_sym_parfor] = ACTIONS(458),
    [anon_sym_while] = ACTIONS(458),
    [anon_sym_switch] = ACTIONS(458),
    [anon_sym_global] = ACTIONS(458),
    [anon_sym_persistent] = ACTIONS(458),
    [anon_sym_arguments] = ACTIONS(458),
    [anon_sym_function] = ACTIONS(458),
    [anon_sym_properties] = ACTIONS(458),
    [anon_sym_get] = ACTIONS(458),
    [anon_sym_set] = ACTIONS(458),
    [anon_sym_methods] = ACTIONS(458),
    [anon_sym_events] = ACTIONS(458),
    [anon_sym_enumeration] = ACTIONS(458),
    [anon_sym_classdef] = ACTIONS(458),
    [anon_sym_try] = ACTIONS(458),
    [anon_sym_spmd] = ACTIONS(458),
    [aux_sym_number_token1] = ACTIONS(458),
    [aux_sym_number_token2] = ACTIONS(458),
    [aux_sym_number_token3] = ACTIONS(458),
    [anon_sym_true] = ACTIONS(458),
    [anon_sym_false] = ACTIONS(458),
    [anon_sym_CR] = ACTIONS(458),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(462),
    [sym__single_quote_string_start] = ACTIONS(462),
    [sym__double_quote_string_start] = ACTIONS(462),
    [sym__multioutput_variable_start] = ACTIONS(462),
    [sym__external_identifier] = ACTIONS(462),
  },
  [STATE(101)] = {
    [anon_sym_SEMI] = ACTIONS(538),
    [anon_sym_COMMA] = ACTIONS(538),
    [anon_sym_LPAREN] = ACTIONS(538),
    [anon_sym_PLUS] = ACTIONS(538),
    [anon_sym_DOT_PLUS] = ACTIONS(538),
    [anon_sym_DASH] = ACTIONS(538),
    [anon_sym_DOT_DASH] = ACTIONS(538),
    [anon_sym_STAR] = ACTIONS(538),
    [anon_sym_DOT_STAR] = ACTIONS(538),
    [anon_sym_SLASH] = ACTIONS(538),
    [anon_sym_DOT_SLASH] = ACTIONS(538),
    [anon_sym_BSLASH] = ACTIONS(538),
    [anon_sym_DOT_BSLASH] = ACTIONS(538),
    [anon_sym_CARET] = ACTIONS(538),
    [anon_sym_DOT_CARET] = ACTIONS(538),
    [anon_sym_PIPE] = ACTIONS(538),
    [anon_sym_AMP] = ACTIONS(538),
    [anon_sym_DOT] = ACTIONS(538),
    [anon_sym_TILDE] = ACTIONS(538),
    [anon_sym_QMARK] = ACTIONS(538),
    [anon_sym_AT] = ACTIONS(538),
    [anon_sym_LT] = ACTIONS(538),
    [anon_sym_LT_EQ] = ACTIONS(538),
    [anon_sym_EQ_EQ] = ACTIONS(538),
    [anon_sym_TILDE_EQ] = ACTIONS(538),
    [anon_sym_GT_EQ] = ACTIONS(538),
    [anon_sym_GT] = ACTIONS(538),
    [anon_sym_AMP_AMP] = ACTIONS(538),
    [anon_sym_PIPE_PIPE] = ACTIONS(538),
    [anon_sym_DOT_SQUOTE] = ACTIONS(538),
    [anon_sym_SQUOTE] = ACTIONS(538),
    [anon_sym_LBRACK] = ACTIONS(538),
    [anon_sym_LF] = ACTIONS(538),
    [anon_sym_LBRACE] = ACTIONS(538),
    [anon_sym_COLON] = ACTIONS(538),
    [anon_sym_return] = ACTIONS(538),
    [anon_sym_continue] = ACTIONS(538),
    [anon_sym_break] = ACTIONS(538),
    [anon_sym_elseif] = ACTIONS(538),
    [anon_sym_else] = ACTIONS(538),
    [anon_sym_if] = ACTIONS(538),
    [anon_sym_end] = ACTIONS(538),
    [anon_sym_for] = ACTIONS(538),
    [anon_sym_parfor] = ACTIONS(538),
    [anon_sym_while] = ACTIONS(538),
    [anon_sym_switch] = ACTIONS(538),
    [anon_sym_global] = ACTIONS(538),
    [anon_sym_persistent] = ACTIONS(538),
    [anon_sym_arguments] = ACTIONS(538),
    [anon_sym_function] = ACTIONS(538),
    [anon_sym_properties] = ACTIONS(538),
    [anon_sym_get] = ACTIONS(538),
    [anon_sym_set] = ACTIONS(538),
    [anon_sym_methods] = ACTIONS(538),
    [anon_sym_events] = ACTIONS(538),
    [anon_sym_enumeration] = ACTIONS(538),
    [anon_sym_classdef] = ACTIONS(538),
    [anon_sym_try] = ACTIONS(538),
    [anon_sym_spmd] = ACTIONS(538),
    [aux_sym_number_token1] = ACTIONS(538),
    [aux_sym_number_token2] = ACTIONS(538),
    [aux_sym_number_token3] = ACTIONS(538),
    [anon_sym_true] = ACTIONS(538),
    [anon_sym_false] = ACTIONS(538),
    [anon_sym_CR] = ACTIONS(538),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(540),
    [sym__single_quote_string_start] = ACTIONS(540),
    [sym__double_quote_string_start] = ACTIONS(540),
    [sym__multioutput_variable_start] = ACTIONS(540),
    [sym__external_identifier] = ACTIONS(540),
  },
  [STATE(102)] = {
    [anon_sym_SEMI] = ACTIONS(542),
    [anon_sym_COMMA] = ACTIONS(542),
    [anon_sym_LPAREN] = ACTIONS(542),
    [anon_sym_PLUS] = ACTIONS(542),
    [anon_sym_DOT_PLUS] = ACTIONS(542),
    [anon_sym_DASH] = ACTIONS(542),
    [anon_sym_DOT_DASH] = ACTIONS(542),
    [anon_sym_STAR] = ACTIONS(542),
    [anon_sym_DOT_STAR] = ACTIONS(542),
    [anon_sym_SLASH] = ACTIONS(542),
    [anon_sym_DOT_SLASH] = ACTIONS(542),
    [anon_sym_BSLASH] = ACTIONS(542),
    [anon_sym_DOT_BSLASH] = ACTIONS(542),
    [anon_sym_CARET] = ACTIONS(542),
    [anon_sym_DOT_CARET] = ACTIONS(542),
    [anon_sym_PIPE] = ACTIONS(542),
    [anon_sym_AMP] = ACTIONS(542),
    [anon_sym_TILDE] = ACTIONS(542),
    [anon_sym_QMARK] = ACTIONS(542),
    [anon_sym_AT] = ACTIONS(542),
    [anon_sym_LT] = ACTIONS(542),
    [anon_sym_LT_EQ] = ACTIONS(542),
    [anon_sym_EQ_EQ] = ACTIONS(542),
    [anon_sym_TILDE_EQ] = ACTIONS(542),
    [anon_sym_GT_EQ] = ACTIONS(542),
    [anon_sym_GT] = ACTIONS(542),
    [anon_sym_AMP_AMP] = ACTIONS(542),
    [anon_sym_PIPE_PIPE] = ACTIONS(542),
    [anon_sym_DOT_SQUOTE] = ACTIONS(542),
    [anon_sym_SQUOTE] = ACTIONS(542),
    [anon_sym_LBRACK] = ACTIONS(542),
    [anon_sym_LF] = ACTIONS(542),
    [anon_sym_LBRACE] = ACTIONS(542),
    [anon_sym_COLON] = ACTIONS(542),
    [anon_sym_return] = ACTIONS(542),
    [anon_sym_continue] = ACTIONS(542),
    [anon_sym_break] = ACTIONS(542),
    [anon_sym_elseif] = ACTIONS(542),
    [anon_sym_else] = ACTIONS(542),
    [anon_sym_if] = ACTIONS(542),
    [anon_sym_end] = ACTIONS(542),
    [anon_sym_for] = ACTIONS(542),
    [anon_sym_parfor] = ACTIONS(542),
    [anon_sym_while] = ACTIONS(542),
    [anon_sym_switch] = ACTIONS(542),
    [anon_sym_global] = ACTIONS(542),
    [anon_sym_persistent] = ACTIONS(542),
    [anon_sym_arguments] = ACTIONS(542),
    [anon_sym_function] = ACTIONS(542),
    [anon_sym_properties] = ACTIONS(542),
    [anon_sym_get] = ACTIONS(542),
    [anon_sym_set] = ACTIONS(542),
    [anon_sym_methods] = ACTIONS(542),
    [anon_sym_events] = ACTIONS(542),
    [anon_sym_enumeration] = ACTIONS(542),
    [anon_sym_classdef] = ACTIONS(542),
    [anon_sym_try] = ACTIONS(542),
    [anon_sym_spmd] = ACTIONS(542),
    [aux_sym_number_token1] = ACTIONS(542),
    [aux_sym_number_token2] = ACTIONS(542),
    [aux_sym_number_token3] = ACTIONS(542),
    [anon_sym_true] = ACTIONS(542),
    [anon_sym_false] = ACTIONS(542),
    [anon_sym_CR] = ACTIONS(542),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(544),
    [sym__single_quote_string_start] = ACTIONS(544),
    [sym__double_quote_string_start] = ACTIONS(544),
    [sym__multioutput_variable_start] = ACTIONS(544),
    [sym__external_identifier] = ACTIONS(544),
  },
  [STATE(103)] = {
    [anon_sym_SEMI] = ACTIONS(546),
    [anon_sym_COMMA] = ACTIONS(546),
    [anon_sym_LPAREN] = ACTIONS(546),
    [anon_sym_PLUS] = ACTIONS(546),
    [anon_sym_DOT_PLUS] = ACTIONS(546),
    [anon_sym_DASH] = ACTIONS(546),
    [anon_sym_DOT_DASH] = ACTIONS(546),
    [anon_sym_STAR] = ACTIONS(546),
    [anon_sym_DOT_STAR] = ACTIONS(546),
    [anon_sym_SLASH] = ACTIONS(546),
    [anon_sym_DOT_SLASH] = ACTIONS(546),
    [anon_sym_BSLASH] = ACTIONS(546),
    [anon_sym_DOT_BSLASH] = ACTIONS(546),
    [anon_sym_CARET] = ACTIONS(546),
    [anon_sym_DOT_CARET] = ACTIONS(546),
    [anon_sym_PIPE] = ACTIONS(546),
    [anon_sym_AMP] = ACTIONS(546),
    [anon_sym_TILDE] = ACTIONS(546),
    [anon_sym_QMARK] = ACTIONS(546),
    [anon_sym_AT] = ACTIONS(546),
    [anon_sym_LT] = ACTIONS(546),
    [anon_sym_LT_EQ] = ACTIONS(546),
    [anon_sym_EQ_EQ] = ACTIONS(546),
    [anon_sym_TILDE_EQ] = ACTIONS(546),
    [anon_sym_GT_EQ] = ACTIONS(546),
    [anon_sym_GT] = ACTIONS(546),
    [anon_sym_AMP_AMP] = ACTIONS(546),
    [anon_sym_PIPE_PIPE] = ACTIONS(546),
    [anon_sym_DOT_SQUOTE] = ACTIONS(546),
    [anon_sym_SQUOTE] = ACTIONS(546),
    [anon_sym_LBRACK] = ACTIONS(546),
    [anon_sym_LF] = ACTIONS(546),
    [anon_sym_LBRACE] = ACTIONS(546),
    [anon_sym_COLON] = ACTIONS(546),
    [anon_sym_return] = ACTIONS(546),
    [anon_sym_continue] = ACTIONS(546),
    [anon_sym_break] = ACTIONS(546),
    [anon_sym_elseif] = ACTIONS(546),
    [anon_sym_else] = ACTIONS(546),
    [anon_sym_if] = ACTIONS(546),
    [anon_sym_end] = ACTIONS(546),
    [anon_sym_for] = ACTIONS(546),
    [anon_sym_parfor] = ACTIONS(546),
    [anon_sym_while] = ACTIONS(546),
    [anon_sym_switch] = ACTIONS(546),
    [anon_sym_global] = ACTIONS(546),
    [anon_sym_persistent] = ACTIONS(546),
    [anon_sym_arguments] = ACTIONS(546),
    [anon_sym_function] = ACTIONS(546),
    [anon_sym_properties] = ACTIONS(546),
    [anon_sym_get] = ACTIONS(546),
    [anon_sym_set] = ACTIONS(546),
    [anon_sym_methods] = ACTIONS(546),
    [anon_sym_events] = ACTIONS(546),
    [anon_sym_enumeration] = ACTIONS(546),
    [anon_sym_classdef] = ACTIONS(546),
    [anon_sym_try] = ACTIONS(546),
    [anon_sym_spmd] = ACTIONS(546),
    [aux_sym_number_token1] = ACTIONS(546),
    [aux_sym_number_token2] = ACTIONS(546),
    [aux_sym_number_token3] = ACTIONS(546),
    [anon_sym_true] = ACTIONS(546),
    [anon_sym_false] = ACTIONS(546),
    [anon_sym_CR] = ACTIONS(546),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(548),
    [sym__single_quote_string_start] = ACTIONS(548),
    [sym__double_quote_string_start] = ACTIONS(548),
    [sym__multioutput_variable_start] = ACTIONS(548),
    [sym__external_identifier] = ACTIONS(548),
  },
  [STATE(104)] = {
    [anon_sym_SEMI] = ACTIONS(550),
    [anon_sym_COMMA] = ACTIONS(550),
    [anon_sym_LPAREN] = ACTIONS(550),
    [anon_sym_PLUS] = ACTIONS(550),
    [anon_sym_DOT_PLUS] = ACTIONS(550),
    [anon_sym_DASH] = ACTIONS(550),
    [anon_sym_DOT_DASH] = ACTIONS(550),
    [anon_sym_STAR] = ACTIONS(550),
    [anon_sym_DOT_STAR] = ACTIONS(550),
    [anon_sym_SLASH] = ACTIONS(550),
    [anon_sym_DOT_SLASH] = ACTIONS(550),
    [anon_sym_BSLASH] = ACTIONS(550),
    [anon_sym_DOT_BSLASH] = ACTIONS(550),
    [anon_sym_CARET] = ACTIONS(550),
    [anon_sym_DOT_CARET] = ACTIONS(550),
    [anon_sym_PIPE] = ACTIONS(550),
    [anon_sym_AMP] = ACTIONS(550),
    [anon_sym_TILDE] = ACTIONS(550),
    [anon_sym_QMARK] = ACTIONS(550),
    [anon_sym_AT] = ACTIONS(550),
    [anon_sym_LT] = ACTIONS(550),
    [anon_sym_LT_EQ] = ACTIONS(550),
    [anon_sym_EQ_EQ] = ACTIONS(550),
    [anon_sym_TILDE_EQ] = ACTIONS(550),
    [anon_sym_GT_EQ] = ACTIONS(550),
    [anon_sym_GT] = ACTIONS(550),
    [anon_sym_AMP_AMP] = ACTIONS(550),
    [anon_sym_PIPE_PIPE] = ACTIONS(550),
    [anon_sym_DOT_SQUOTE] = ACTIONS(550),
    [anon_sym_SQUOTE] = ACTIONS(550),
    [anon_sym_LBRACK] = ACTIONS(550),
    [anon_sym_LF] = ACTIONS(550),
    [anon_sym_LBRACE] = ACTIONS(550),
    [anon_sym_COLON] = ACTIONS(550),
    [anon_sym_return] = ACTIONS(550),
    [anon_sym_continue] = ACTIONS(550),
    [anon_sym_break] = ACTIONS(550),
    [anon_sym_elseif] = ACTIONS(550),
    [anon_sym_else] = ACTIONS(550),
    [anon_sym_if] = ACTIONS(550),
    [anon_sym_end] = ACTIONS(550),
    [anon_sym_for] = ACTIONS(550),
    [anon_sym_parfor] = ACTIONS(550),
    [anon_sym_while] = ACTIONS(550),
    [anon_sym_switch] = ACTIONS(550),
    [anon_sym_global] = ACTIONS(550),
    [anon_sym_persistent] = ACTIONS(550),
    [anon_sym_arguments] = ACTIONS(550),
    [anon_sym_function] = ACTIONS(550),
    [anon_sym_properties] = ACTIONS(550),
    [anon_sym_get] = ACTIONS(550),
    [anon_sym_set] = ACTIONS(550),
    [anon_sym_methods] = ACTIONS(550),
    [anon_sym_events] = ACTIONS(550),
    [anon_sym_enumeration] = ACTIONS(550),
    [anon_sym_classdef] = ACTIONS(550),
    [anon_sym_try] = ACTIONS(550),
    [anon_sym_spmd] = ACTIONS(550),
    [aux_sym_number_token1] = ACTIONS(550),
    [aux_sym_number_token2] = ACTIONS(550),
    [aux_sym_number_token3] = ACTIONS(550),
    [anon_sym_true] = ACTIONS(550),
    [anon_sym_false] = ACTIONS(550),
    [anon_sym_CR] = ACTIONS(550),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(552),
    [sym__single_quote_string_start] = ACTIONS(552),
    [sym__double_quote_string_start] = ACTIONS(552),
    [sym__multioutput_variable_start] = ACTIONS(552),
    [sym__external_identifier] = ACTIONS(552),
  },
  [STATE(105)] = {
    [anon_sym_SEMI] = ACTIONS(449),
    [anon_sym_COMMA] = ACTIONS(449),
    [anon_sym_LPAREN] = ACTIONS(449),
    [anon_sym_PLUS] = ACTIONS(451),
    [anon_sym_DOT_PLUS] = ACTIONS(451),
    [anon_sym_DASH] = ACTIONS(451),
    [anon_sym_DOT_DASH] = ACTIONS(451),
    [anon_sym_STAR] = ACTIONS(451),
    [anon_sym_DOT_STAR] = ACTIONS(451),
    [anon_sym_SLASH] = ACTIONS(451),
    [anon_sym_DOT_SLASH] = ACTIONS(451),
    [anon_sym_BSLASH] = ACTIONS(451),
    [anon_sym_DOT_BSLASH] = ACTIONS(451),
    [anon_sym_CARET] = ACTIONS(451),
    [anon_sym_DOT_CARET] = ACTIONS(451),
    [anon_sym_PIPE] = ACTIONS(451),
    [anon_sym_AMP] = ACTIONS(451),
    [anon_sym_TILDE] = ACTIONS(449),
    [anon_sym_QMARK] = ACTIONS(449),
    [anon_sym_AT] = ACTIONS(449),
    [anon_sym_LT] = ACTIONS(449),
    [anon_sym_LT_EQ] = ACTIONS(449),
    [anon_sym_EQ_EQ] = ACTIONS(449),
    [anon_sym_TILDE_EQ] = ACTIONS(449),
    [anon_sym_GT_EQ] = ACTIONS(449),
    [anon_sym_GT] = ACTIONS(449),
    [anon_sym_AMP_AMP] = ACTIONS(449),
    [anon_sym_PIPE_PIPE] = ACTIONS(449),
    [anon_sym_DOT_SQUOTE] = ACTIONS(443),
    [anon_sym_SQUOTE] = ACTIONS(443),
    [anon_sym_LBRACK] = ACTIONS(449),
    [anon_sym_LF] = ACTIONS(449),
    [anon_sym_LBRACE] = ACTIONS(449),
    [anon_sym_COLON] = ACTIONS(554),
    [anon_sym_return] = ACTIONS(449),
    [anon_sym_continue] = ACTIONS(449),
    [anon_sym_break] = ACTIONS(449),
    [anon_sym_elseif] = ACTIONS(449),
    [anon_sym_else] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(449),
    [anon_sym_end] = ACTIONS(449),
    [anon_sym_for] = ACTIONS(449),
    [anon_sym_parfor] = ACTIONS(449),
    [anon_sym_while] = ACTIONS(449),
    [anon_sym_switch] = ACTIONS(449),
    [anon_sym_global] = ACTIONS(449),
    [anon_sym_persistent] = ACTIONS(449),
    [anon_sym_arguments] = ACTIONS(449),
    [anon_sym_function] = ACTIONS(449),
    [anon_sym_properties] = ACTIONS(449),
    [anon_sym_get] = ACTIONS(449),
    [anon_sym_set] = ACTIONS(449),
    [anon_sym_methods] = ACTIONS(449),
    [anon_sym_events] = ACTIONS(449),
    [anon_sym_enumeration] = ACTIONS(449),
    [anon_sym_classdef] = ACTIONS(449),
    [anon_sym_try] = ACTIONS(449),
    [anon_sym_spmd] = ACTIONS(449),
    [aux_sym_number_token1] = ACTIONS(449),
    [aux_sym_number_token2] = ACTIONS(449),
    [aux_sym_number_token3] = ACTIONS(449),
    [anon_sym_true] = ACTIONS(449),
    [anon_sym_false] = ACTIONS(449),
    [anon_sym_CR] = ACTIONS(449),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(456),
    [sym__single_quote_string_start] = ACTIONS(456),
    [sym__double_quote_string_start] = ACTIONS(456),
    [sym__multioutput_variable_start] = ACTIONS(456),
    [sym__external_identifier] = ACTIONS(456),
  },
  [STATE(106)] = {
    [anon_sym_SEMI] = ACTIONS(449),
    [anon_sym_COMMA] = ACTIONS(449),
    [anon_sym_LPAREN] = ACTIONS(449),
    [anon_sym_PLUS] = ACTIONS(451),
    [anon_sym_DOT_PLUS] = ACTIONS(451),
    [anon_sym_DASH] = ACTIONS(451),
    [anon_sym_DOT_DASH] = ACTIONS(451),
    [anon_sym_STAR] = ACTIONS(451),
    [anon_sym_DOT_STAR] = ACTIONS(451),
    [anon_sym_SLASH] = ACTIONS(451),
    [anon_sym_DOT_SLASH] = ACTIONS(451),
    [anon_sym_BSLASH] = ACTIONS(451),
    [anon_sym_DOT_BSLASH] = ACTIONS(451),
    [anon_sym_CARET] = ACTIONS(451),
    [anon_sym_DOT_CARET] = ACTIONS(451),
    [anon_sym_PIPE] = ACTIONS(451),
    [anon_sym_AMP] = ACTIONS(451),
    [anon_sym_TILDE] = ACTIONS(449),
    [anon_sym_QMARK] = ACTIONS(449),
    [anon_sym_AT] = ACTIONS(449),
    [anon_sym_LT] = ACTIONS(449),
    [anon_sym_LT_EQ] = ACTIONS(449),
    [anon_sym_EQ_EQ] = ACTIONS(449),
    [anon_sym_TILDE_EQ] = ACTIONS(449),
    [anon_sym_GT_EQ] = ACTIONS(449),
    [anon_sym_GT] = ACTIONS(449),
    [anon_sym_AMP_AMP] = ACTIONS(449),
    [anon_sym_PIPE_PIPE] = ACTIONS(449),
    [anon_sym_DOT_SQUOTE] = ACTIONS(449),
    [anon_sym_SQUOTE] = ACTIONS(449),
    [anon_sym_LBRACK] = ACTIONS(449),
    [anon_sym_LF] = ACTIONS(449),
    [anon_sym_LBRACE] = ACTIONS(449),
    [anon_sym_COLON] = ACTIONS(449),
    [anon_sym_return] = ACTIONS(449),
    [anon_sym_continue] = ACTIONS(449),
    [anon_sym_break] = ACTIONS(449),
    [anon_sym_elseif] = ACTIONS(449),
    [anon_sym_else] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(449),
    [anon_sym_end] = ACTIONS(449),
    [anon_sym_for] = ACTIONS(449),
    [anon_sym_parfor] = ACTIONS(449),
    [anon_sym_while] = ACTIONS(449),
    [anon_sym_switch] = ACTIONS(449),
    [anon_sym_global] = ACTIONS(449),
    [anon_sym_persistent] = ACTIONS(449),
    [anon_sym_arguments] = ACTIONS(449),
    [anon_sym_function] = ACTIONS(449),
    [anon_sym_properties] = ACTIONS(449),
    [anon_sym_get] = ACTIONS(449),
    [anon_sym_set] = ACTIONS(449),
    [anon_sym_methods] = ACTIONS(449),
    [anon_sym_events] = ACTIONS(449),
    [anon_sym_enumeration] = ACTIONS(449),
    [anon_sym_classdef] = ACTIONS(449),
    [anon_sym_try] = ACTIONS(449),
    [anon_sym_spmd] = ACTIONS(449),
    [aux_sym_number_token1] = ACTIONS(449),
    [aux_sym_number_token2] = ACTIONS(449),
    [aux_sym_number_token3] = ACTIONS(449),
    [anon_sym_true] = ACTIONS(449),
    [anon_sym_false] = ACTIONS(449),
    [anon_sym_CR] = ACTIONS(449),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(456),
    [sym__single_quote_string_start] = ACTIONS(456),
    [sym__double_quote_string_start] = ACTIONS(456),
    [sym__multioutput_variable_start] = ACTIONS(456),
    [sym__external_identifier] = ACTIONS(456),
  },
  [STATE(107)] = {
    [anon_sym_SEMI] = ACTIONS(449),
    [anon_sym_COMMA] = ACTIONS(449),
    [anon_sym_LPAREN] = ACTIONS(449),
    [anon_sym_PLUS] = ACTIONS(451),
    [anon_sym_DOT_PLUS] = ACTIONS(451),
    [anon_sym_DASH] = ACTIONS(451),
    [anon_sym_DOT_DASH] = ACTIONS(451),
    [anon_sym_STAR] = ACTIONS(451),
    [anon_sym_DOT_STAR] = ACTIONS(451),
    [anon_sym_SLASH] = ACTIONS(451),
    [anon_sym_DOT_SLASH] = ACTIONS(451),
    [anon_sym_BSLASH] = ACTIONS(451),
    [anon_sym_DOT_BSLASH] = ACTIONS(451),
    [anon_sym_CARET] = ACTIONS(451),
    [anon_sym_DOT_CARET] = ACTIONS(451),
    [anon_sym_PIPE] = ACTIONS(451),
    [anon_sym_AMP] = ACTIONS(451),
    [anon_sym_TILDE] = ACTIONS(449),
    [anon_sym_QMARK] = ACTIONS(449),
    [anon_sym_AT] = ACTIONS(449),
    [anon_sym_LT] = ACTIONS(449),
    [anon_sym_LT_EQ] = ACTIONS(449),
    [anon_sym_EQ_EQ] = ACTIONS(449),
    [anon_sym_TILDE_EQ] = ACTIONS(449),
    [anon_sym_GT_EQ] = ACTIONS(449),
    [anon_sym_GT] = ACTIONS(449),
    [anon_sym_AMP_AMP] = ACTIONS(449),
    [anon_sym_PIPE_PIPE] = ACTIONS(449),
    [anon_sym_DOT_SQUOTE] = ACTIONS(443),
    [anon_sym_SQUOTE] = ACTIONS(443),
    [anon_sym_LBRACK] = ACTIONS(449),
    [anon_sym_LF] = ACTIONS(449),
    [anon_sym_LBRACE] = ACTIONS(449),
    [anon_sym_COLON] = ACTIONS(449),
    [anon_sym_return] = ACTIONS(449),
    [anon_sym_continue] = ACTIONS(449),
    [anon_sym_break] = ACTIONS(449),
    [anon_sym_elseif] = ACTIONS(449),
    [anon_sym_else] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(449),
    [anon_sym_end] = ACTIONS(449),
    [anon_sym_for] = ACTIONS(449),
    [anon_sym_parfor] = ACTIONS(449),
    [anon_sym_while] = ACTIONS(449),
    [anon_sym_switch] = ACTIONS(449),
    [anon_sym_global] = ACTIONS(449),
    [anon_sym_persistent] = ACTIONS(449),
    [anon_sym_arguments] = ACTIONS(449),
    [anon_sym_function] = ACTIONS(449),
    [anon_sym_properties] = ACTIONS(449),
    [anon_sym_get] = ACTIONS(449),
    [anon_sym_set] = ACTIONS(449),
    [anon_sym_methods] = ACTIONS(449),
    [anon_sym_events] = ACTIONS(449),
    [anon_sym_enumeration] = ACTIONS(449),
    [anon_sym_classdef] = ACTIONS(449),
    [anon_sym_try] = ACTIONS(449),
    [anon_sym_spmd] = ACTIONS(449),
    [aux_sym_number_token1] = ACTIONS(449),
    [aux_sym_number_token2] = ACTIONS(449),
    [aux_sym_number_token3] = ACTIONS(449),
    [anon_sym_true] = ACTIONS(449),
    [anon_sym_false] = ACTIONS(449),
    [anon_sym_CR] = ACTIONS(449),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(456),
    [sym__single_quote_string_start] = ACTIONS(456),
    [sym__double_quote_string_start] = ACTIONS(456),
    [sym__multioutput_variable_start] = ACTIONS(456),
    [sym__external_identifier] = ACTIONS(456),
  },
  [STATE(108)] = {
    [anon_sym_SEMI] = ACTIONS(556),
    [anon_sym_COMMA] = ACTIONS(556),
    [anon_sym_LPAREN] = ACTIONS(556),
    [anon_sym_PLUS] = ACTIONS(556),
    [anon_sym_DOT_PLUS] = ACTIONS(556),
    [anon_sym_DASH] = ACTIONS(556),
    [anon_sym_DOT_DASH] = ACTIONS(556),
    [anon_sym_STAR] = ACTIONS(556),
    [anon_sym_DOT_STAR] = ACTIONS(556),
    [anon_sym_SLASH] = ACTIONS(556),
    [anon_sym_DOT_SLASH] = ACTIONS(556),
    [anon_sym_BSLASH] = ACTIONS(556),
    [anon_sym_DOT_BSLASH] = ACTIONS(556),
    [anon_sym_CARET] = ACTIONS(556),
    [anon_sym_DOT_CARET] = ACTIONS(556),
    [anon_sym_PIPE] = ACTIONS(556),
    [anon_sym_AMP] = ACTIONS(556),
    [anon_sym_TILDE] = ACTIONS(556),
    [anon_sym_QMARK] = ACTIONS(556),
    [anon_sym_AT] = ACTIONS(556),
    [anon_sym_LT] = ACTIONS(556),
    [anon_sym_LT_EQ] = ACTIONS(556),
    [anon_sym_EQ_EQ] = ACTIONS(556),
    [anon_sym_TILDE_EQ] = ACTIONS(556),
    [anon_sym_GT_EQ] = ACTIONS(556),
    [anon_sym_GT] = ACTIONS(556),
    [anon_sym_AMP_AMP] = ACTIONS(556),
    [anon_sym_PIPE_PIPE] = ACTIONS(556),
    [anon_sym_DOT_SQUOTE] = ACTIONS(556),
    [anon_sym_SQUOTE] = ACTIONS(556),
    [anon_sym_LBRACK] = ACTIONS(556),
    [anon_sym_LF] = ACTIONS(556),
    [anon_sym_LBRACE] = ACTIONS(556),
    [anon_sym_COLON] = ACTIONS(556),
    [anon_sym_return] = ACTIONS(556),
    [anon_sym_continue] = ACTIONS(556),
    [anon_sym_break] = ACTIONS(556),
    [anon_sym_elseif] = ACTIONS(556),
    [anon_sym_else] = ACTIONS(556),
    [anon_sym_if] = ACTIONS(556),
    [anon_sym_end] = ACTIONS(556),
    [anon_sym_for] = ACTIONS(556),
    [anon_sym_parfor] = ACTIONS(556),
    [anon_sym_while] = ACTIONS(556),
    [anon_sym_switch] = ACTIONS(556),
    [anon_sym_global] = ACTIONS(556),
    [anon_sym_persistent] = ACTIONS(556),
    [anon_sym_arguments] = ACTIONS(556),
    [anon_sym_function] = ACTIONS(556),
    [anon_sym_properties] = ACTIONS(556),
    [anon_sym_get] = ACTIONS(556),
    [anon_sym_set] = ACTIONS(556),
    [anon_sym_methods] = ACTIONS(556),
    [anon_sym_events] = ACTIONS(556),
    [anon_sym_enumeration] = ACTIONS(556),
    [anon_sym_classdef] = ACTIONS(556),
    [anon_sym_try] = ACTIONS(556),
    [anon_sym_spmd] = ACTIONS(556),
    [aux_sym_number_token1] = ACTIONS(556),
    [aux_sym_number_token2] = ACTIONS(556),
    [aux_sym_number_token3] = ACTIONS(556),
    [anon_sym_true] = ACTIONS(556),
    [anon_sym_false] = ACTIONS(556),
    [anon_sym_CR] = ACTIONS(556),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(558),
    [sym__single_quote_string_start] = ACTIONS(558),
    [sym__double_quote_string_start] = ACTIONS(558),
    [sym__multioutput_variable_start] = ACTIONS(558),
    [sym__external_identifier] = ACTIONS(558),
  },
  [STATE(109)] = {
    [anon_sym_SEMI] = ACTIONS(435),
    [anon_sym_COMMA] = ACTIONS(435),
    [anon_sym_LPAREN] = ACTIONS(435),
    [anon_sym_PLUS] = ACTIONS(435),
    [anon_sym_DOT_PLUS] = ACTIONS(435),
    [anon_sym_DASH] = ACTIONS(435),
    [anon_sym_DOT_DASH] = ACTIONS(435),
    [anon_sym_STAR] = ACTIONS(435),
    [anon_sym_DOT_STAR] = ACTIONS(435),
    [anon_sym_SLASH] = ACTIONS(435),
    [anon_sym_DOT_SLASH] = ACTIONS(435),
    [anon_sym_BSLASH] = ACTIONS(435),
    [anon_sym_DOT_BSLASH] = ACTIONS(435),
    [anon_sym_CARET] = ACTIONS(435),
    [anon_sym_DOT_CARET] = ACTIONS(435),
    [anon_sym_PIPE] = ACTIONS(435),
    [anon_sym_AMP] = ACTIONS(435),
    [anon_sym_TILDE] = ACTIONS(435),
    [anon_sym_QMARK] = ACTIONS(435),
    [anon_sym_AT] = ACTIONS(435),
    [anon_sym_LT] = ACTIONS(435),
    [anon_sym_LT_EQ] = ACTIONS(435),
    [anon_sym_EQ_EQ] = ACTIONS(435),
    [anon_sym_TILDE_EQ] = ACTIONS(435),
    [anon_sym_GT_EQ] = ACTIONS(435),
    [anon_sym_GT] = ACTIONS(435),
    [anon_sym_AMP_AMP] = ACTIONS(435),
    [anon_sym_PIPE_PIPE] = ACTIONS(435),
    [anon_sym_DOT_SQUOTE] = ACTIONS(443),
    [anon_sym_SQUOTE] = ACTIONS(443),
    [anon_sym_LBRACK] = ACTIONS(435),
    [anon_sym_LF] = ACTIONS(435),
    [anon_sym_LBRACE] = ACTIONS(435),
    [anon_sym_COLON] = ACTIONS(435),
    [anon_sym_return] = ACTIONS(435),
    [anon_sym_continue] = ACTIONS(435),
    [anon_sym_break] = ACTIONS(435),
    [anon_sym_elseif] = ACTIONS(435),
    [anon_sym_else] = ACTIONS(435),
    [anon_sym_if] = ACTIONS(435),
    [anon_sym_end] = ACTIONS(435),
    [anon_sym_for] = ACTIONS(435),
    [anon_sym_parfor] = ACTIONS(435),
    [anon_sym_while] = ACTIONS(435),
    [anon_sym_switch] = ACTIONS(435),
    [anon_sym_global] = ACTIONS(435),
    [anon_sym_persistent] = ACTIONS(435),
    [anon_sym_arguments] = ACTIONS(435),
    [anon_sym_function] = ACTIONS(435),
    [anon_sym_properties] = ACTIONS(435),
    [anon_sym_get] = ACTIONS(435),
    [anon_sym_set] = ACTIONS(435),
    [anon_sym_methods] = ACTIONS(435),
    [anon_sym_events] = ACTIONS(435),
    [anon_sym_enumeration] = ACTIONS(435),
    [anon_sym_classdef] = ACTIONS(435),
    [anon_sym_try] = ACTIONS(435),
    [anon_sym_spmd] = ACTIONS(435),
    [aux_sym_number_token1] = ACTIONS(435),
    [aux_sym_number_token2] = ACTIONS(435),
    [aux_sym_number_token3] = ACTIONS(435),
    [anon_sym_true] = ACTIONS(435),
    [anon_sym_false] = ACTIONS(435),
    [anon_sym_CR] = ACTIONS(435),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(447),
    [sym__single_quote_string_start] = ACTIONS(447),
    [sym__double_quote_string_start] = ACTIONS(447),
    [sym__multioutput_variable_start] = ACTIONS(447),
    [sym__external_identifier] = ACTIONS(447),
  },
  [STATE(110)] = {
    [anon_sym_SEMI] = ACTIONS(435),
    [anon_sym_COMMA] = ACTIONS(435),
    [anon_sym_LPAREN] = ACTIONS(435),
    [anon_sym_PLUS] = ACTIONS(435),
    [anon_sym_DOT_PLUS] = ACTIONS(435),
    [anon_sym_DASH] = ACTIONS(435),
    [anon_sym_DOT_DASH] = ACTIONS(435),
    [anon_sym_STAR] = ACTIONS(435),
    [anon_sym_DOT_STAR] = ACTIONS(435),
    [anon_sym_SLASH] = ACTIONS(435),
    [anon_sym_DOT_SLASH] = ACTIONS(435),
    [anon_sym_BSLASH] = ACTIONS(435),
    [anon_sym_DOT_BSLASH] = ACTIONS(435),
    [anon_sym_CARET] = ACTIONS(435),
    [anon_sym_DOT_CARET] = ACTIONS(435),
    [anon_sym_PIPE] = ACTIONS(435),
    [anon_sym_AMP] = ACTIONS(435),
    [anon_sym_TILDE] = ACTIONS(435),
    [anon_sym_QMARK] = ACTIONS(435),
    [anon_sym_AT] = ACTIONS(435),
    [anon_sym_LT] = ACTIONS(435),
    [anon_sym_LT_EQ] = ACTIONS(435),
    [anon_sym_EQ_EQ] = ACTIONS(435),
    [anon_sym_TILDE_EQ] = ACTIONS(435),
    [anon_sym_GT_EQ] = ACTIONS(435),
    [anon_sym_GT] = ACTIONS(435),
    [anon_sym_AMP_AMP] = ACTIONS(435),
    [anon_sym_PIPE_PIPE] = ACTIONS(435),
    [anon_sym_DOT_SQUOTE] = ACTIONS(443),
    [anon_sym_SQUOTE] = ACTIONS(443),
    [anon_sym_LBRACK] = ACTIONS(435),
    [anon_sym_LF] = ACTIONS(435),
    [anon_sym_LBRACE] = ACTIONS(435),
    [anon_sym_COLON] = ACTIONS(435),
    [anon_sym_return] = ACTIONS(435),
    [anon_sym_continue] = ACTIONS(435),
    [anon_sym_break] = ACTIONS(435),
    [anon_sym_elseif] = ACTIONS(435),
    [anon_sym_else] = ACTIONS(435),
    [anon_sym_if] = ACTIONS(435),
    [anon_sym_end] = ACTIONS(435),
    [anon_sym_for] = ACTIONS(435),
    [anon_sym_parfor] = ACTIONS(435),
    [anon_sym_while] = ACTIONS(435),
    [anon_sym_switch] = ACTIONS(435),
    [anon_sym_global] = ACTIONS(435),
    [anon_sym_persistent] = ACTIONS(435),
    [anon_sym_arguments] = ACTIONS(435),
    [anon_sym_function] = ACTIONS(435),
    [anon_sym_properties] = ACTIONS(435),
    [anon_sym_get] = ACTIONS(435),
    [anon_sym_set] = ACTIONS(435),
    [anon_sym_methods] = ACTIONS(435),
    [anon_sym_events] = ACTIONS(435),
    [anon_sym_enumeration] = ACTIONS(435),
    [anon_sym_classdef] = ACTIONS(435),
    [anon_sym_try] = ACTIONS(435),
    [anon_sym_spmd] = ACTIONS(435),
    [aux_sym_number_token1] = ACTIONS(435),
    [aux_sym_number_token2] = ACTIONS(435),
    [aux_sym_number_token3] = ACTIONS(435),
    [anon_sym_true] = ACTIONS(435),
    [anon_sym_false] = ACTIONS(435),
    [anon_sym_CR] = ACTIONS(435),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(447),
    [sym__single_quote_string_start] = ACTIONS(447),
    [sym__double_quote_string_start] = ACTIONS(447),
    [sym__multioutput_variable_start] = ACTIONS(447),
    [sym__external_identifier] = ACTIONS(447),
  },
  [STATE(111)] = {
    [anon_sym_SEMI] = ACTIONS(435),
    [anon_sym_COMMA] = ACTIONS(435),
    [anon_sym_LPAREN] = ACTIONS(435),
    [anon_sym_PLUS] = ACTIONS(435),
    [anon_sym_DOT_PLUS] = ACTIONS(435),
    [anon_sym_DASH] = ACTIONS(435),
    [anon_sym_DOT_DASH] = ACTIONS(435),
    [anon_sym_STAR] = ACTIONS(435),
    [anon_sym_DOT_STAR] = ACTIONS(435),
    [anon_sym_SLASH] = ACTIONS(435),
    [anon_sym_DOT_SLASH] = ACTIONS(435),
    [anon_sym_BSLASH] = ACTIONS(435),
    [anon_sym_DOT_BSLASH] = ACTIONS(435),
    [anon_sym_CARET] = ACTIONS(435),
    [anon_sym_DOT_CARET] = ACTIONS(435),
    [anon_sym_PIPE] = ACTIONS(435),
    [anon_sym_AMP] = ACTIONS(435),
    [anon_sym_TILDE] = ACTIONS(435),
    [anon_sym_QMARK] = ACTIONS(435),
    [anon_sym_AT] = ACTIONS(435),
    [anon_sym_LT] = ACTIONS(435),
    [anon_sym_LT_EQ] = ACTIONS(435),
    [anon_sym_EQ_EQ] = ACTIONS(435),
    [anon_sym_TILDE_EQ] = ACTIONS(435),
    [anon_sym_GT_EQ] = ACTIONS(435),
    [anon_sym_GT] = ACTIONS(435),
    [anon_sym_AMP_AMP] = ACTIONS(435),
    [anon_sym_PIPE_PIPE] = ACTIONS(435),
    [anon_sym_DOT_SQUOTE] = ACTIONS(435),
    [anon_sym_SQUOTE] = ACTIONS(435),
    [anon_sym_LBRACK] = ACTIONS(435),
    [anon_sym_LF] = ACTIONS(435),
    [anon_sym_LBRACE] = ACTIONS(435),
    [anon_sym_COLON] = ACTIONS(435),
    [anon_sym_return] = ACTIONS(435),
    [anon_sym_continue] = ACTIONS(435),
    [anon_sym_break] = ACTIONS(435),
    [anon_sym_elseif] = ACTIONS(435),
    [anon_sym_else] = ACTIONS(435),
    [anon_sym_if] = ACTIONS(435),
    [anon_sym_end] = ACTIONS(435),
    [anon_sym_for] = ACTIONS(435),
    [anon_sym_parfor] = ACTIONS(435),
    [anon_sym_while] = ACTIONS(435),
    [anon_sym_switch] = ACTIONS(435),
    [anon_sym_global] = ACTIONS(435),
    [anon_sym_persistent] = ACTIONS(435),
    [anon_sym_arguments] = ACTIONS(435),
    [anon_sym_function] = ACTIONS(435),
    [anon_sym_properties] = ACTIONS(435),
    [anon_sym_get] = ACTIONS(435),
    [anon_sym_set] = ACTIONS(435),
    [anon_sym_methods] = ACTIONS(435),
    [anon_sym_events] = ACTIONS(435),
    [anon_sym_enumeration] = ACTIONS(435),
    [anon_sym_classdef] = ACTIONS(435),
    [anon_sym_try] = ACTIONS(435),
    [anon_sym_spmd] = ACTIONS(435),
    [aux_sym_number_token1] = ACTIONS(435),
    [aux_sym_number_token2] = ACTIONS(435),
    [aux_sym_number_token3] = ACTIONS(435),
    [anon_sym_true] = ACTIONS(435),
    [anon_sym_false] = ACTIONS(435),
    [anon_sym_CR] = ACTIONS(435),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(447),
    [sym__single_quote_string_start] = ACTIONS(447),
    [sym__double_quote_string_start] = ACTIONS(447),
    [sym__multioutput_variable_start] = ACTIONS(447),
    [sym__external_identifier] = ACTIONS(447),
  },
  [STATE(112)] = {
    [anon_sym_SEMI] = ACTIONS(435),
    [anon_sym_COMMA] = ACTIONS(435),
    [anon_sym_LPAREN] = ACTIONS(435),
    [anon_sym_PLUS] = ACTIONS(435),
    [anon_sym_DOT_PLUS] = ACTIONS(435),
    [anon_sym_DASH] = ACTIONS(435),
    [anon_sym_DOT_DASH] = ACTIONS(435),
    [anon_sym_STAR] = ACTIONS(435),
    [anon_sym_DOT_STAR] = ACTIONS(435),
    [anon_sym_SLASH] = ACTIONS(435),
    [anon_sym_DOT_SLASH] = ACTIONS(435),
    [anon_sym_BSLASH] = ACTIONS(435),
    [anon_sym_DOT_BSLASH] = ACTIONS(435),
    [anon_sym_CARET] = ACTIONS(435),
    [anon_sym_DOT_CARET] = ACTIONS(435),
    [anon_sym_PIPE] = ACTIONS(435),
    [anon_sym_AMP] = ACTIONS(435),
    [anon_sym_TILDE] = ACTIONS(435),
    [anon_sym_QMARK] = ACTIONS(435),
    [anon_sym_AT] = ACTIONS(435),
    [anon_sym_LT] = ACTIONS(435),
    [anon_sym_LT_EQ] = ACTIONS(435),
    [anon_sym_EQ_EQ] = ACTIONS(435),
    [anon_sym_TILDE_EQ] = ACTIONS(435),
    [anon_sym_GT_EQ] = ACTIONS(435),
    [anon_sym_GT] = ACTIONS(435),
    [anon_sym_AMP_AMP] = ACTIONS(435),
    [anon_sym_PIPE_PIPE] = ACTIONS(435),
    [anon_sym_DOT_SQUOTE] = ACTIONS(443),
    [anon_sym_SQUOTE] = ACTIONS(443),
    [anon_sym_LBRACK] = ACTIONS(435),
    [anon_sym_LF] = ACTIONS(435),
    [anon_sym_LBRACE] = ACTIONS(435),
    [anon_sym_COLON] = ACTIONS(435),
    [anon_sym_return] = ACTIONS(435),
    [anon_sym_continue] = ACTIONS(435),
    [anon_sym_break] = ACTIONS(435),
    [anon_sym_elseif] = ACTIONS(435),
    [anon_sym_else] = ACTIONS(435),
    [anon_sym_if] = ACTIONS(435),
    [anon_sym_end] = ACTIONS(435),
    [anon_sym_for] = ACTIONS(435),
    [anon_sym_parfor] = ACTIONS(435),
    [anon_sym_while] = ACTIONS(435),
    [anon_sym_switch] = ACTIONS(435),
    [anon_sym_global] = ACTIONS(435),
    [anon_sym_persistent] = ACTIONS(435),
    [anon_sym_arguments] = ACTIONS(435),
    [anon_sym_function] = ACTIONS(435),
    [anon_sym_properties] = ACTIONS(435),
    [anon_sym_get] = ACTIONS(435),
    [anon_sym_set] = ACTIONS(435),
    [anon_sym_methods] = ACTIONS(435),
    [anon_sym_events] = ACTIONS(435),
    [anon_sym_enumeration] = ACTIONS(435),
    [anon_sym_classdef] = ACTIONS(435),
    [anon_sym_try] = ACTIONS(435),
    [anon_sym_spmd] = ACTIONS(435),
    [aux_sym_number_token1] = ACTIONS(435),
    [aux_sym_number_token2] = ACTIONS(435),
    [aux_sym_number_token3] = ACTIONS(435),
    [anon_sym_true] = ACTIONS(435),
    [anon_sym_false] = ACTIONS(435),
    [anon_sym_CR] = ACTIONS(435),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(447),
    [sym__single_quote_string_start] = ACTIONS(447),
    [sym__double_quote_string_start] = ACTIONS(447),
    [sym__multioutput_variable_start] = ACTIONS(447),
    [sym__external_identifier] = ACTIONS(447),
  },
  [STATE(113)] = {
    [anon_sym_SEMI] = ACTIONS(560),
    [anon_sym_COMMA] = ACTIONS(560),
    [anon_sym_LPAREN] = ACTIONS(560),
    [anon_sym_PLUS] = ACTIONS(560),
    [anon_sym_DOT_PLUS] = ACTIONS(560),
    [anon_sym_DASH] = ACTIONS(560),
    [anon_sym_DOT_DASH] = ACTIONS(560),
    [anon_sym_STAR] = ACTIONS(560),
    [anon_sym_DOT_STAR] = ACTIONS(560),
    [anon_sym_SLASH] = ACTIONS(560),
    [anon_sym_DOT_SLASH] = ACTIONS(560),
    [anon_sym_BSLASH] = ACTIONS(560),
    [anon_sym_DOT_BSLASH] = ACTIONS(560),
    [anon_sym_CARET] = ACTIONS(560),
    [anon_sym_DOT_CARET] = ACTIONS(560),
    [anon_sym_PIPE] = ACTIONS(560),
    [anon_sym_AMP] = ACTIONS(560),
    [anon_sym_TILDE] = ACTIONS(560),
    [anon_sym_QMARK] = ACTIONS(560),
    [anon_sym_AT] = ACTIONS(560),
    [anon_sym_LT] = ACTIONS(562),
    [anon_sym_LT_EQ] = ACTIONS(562),
    [anon_sym_EQ_EQ] = ACTIONS(562),
    [anon_sym_TILDE_EQ] = ACTIONS(562),
    [anon_sym_GT_EQ] = ACTIONS(562),
    [anon_sym_GT] = ACTIONS(562),
    [anon_sym_AMP_AMP] = ACTIONS(560),
    [anon_sym_PIPE_PIPE] = ACTIONS(560),
    [anon_sym_DOT_SQUOTE] = ACTIONS(560),
    [anon_sym_SQUOTE] = ACTIONS(560),
    [anon_sym_LBRACK] = ACTIONS(560),
    [anon_sym_LF] = ACTIONS(560),
    [anon_sym_LBRACE] = ACTIONS(560),
    [anon_sym_COLON] = ACTIONS(560),
    [anon_sym_return] = ACTIONS(560),
    [anon_sym_continue] = ACTIONS(560),
    [anon_sym_break] = ACTIONS(560),
    [anon_sym_elseif] = ACTIONS(560),
    [anon_sym_else] = ACTIONS(560),
    [anon_sym_if] = ACTIONS(560),
    [anon_sym_end] = ACTIONS(560),
    [anon_sym_for] = ACTIONS(560),
    [anon_sym_parfor] = ACTIONS(560),
    [anon_sym_while] = ACTIONS(560),
    [anon_sym_switch] = ACTIONS(560),
    [anon_sym_global] = ACTIONS(560),
    [anon_sym_persistent] = ACTIONS(560),
    [anon_sym_arguments] = ACTIONS(560),
    [anon_sym_function] = ACTIONS(560),
    [anon_sym_properties] = ACTIONS(560),
    [anon_sym_get] = ACTIONS(560),
    [anon_sym_set] = ACTIONS(560),
    [anon_sym_methods] = ACTIONS(560),
    [anon_sym_events] = ACTIONS(560),
    [anon_sym_enumeration] = ACTIONS(560),
    [anon_sym_classdef] = ACTIONS(560),
    [anon_sym_try] = ACTIONS(560),
    [anon_sym_spmd] = ACTIONS(560),
    [aux_sym_number_token1] = ACTIONS(560),
    [aux_sym_number_token2] = ACTIONS(560),
    [aux_sym_number_token3] = ACTIONS(560),
    [anon_sym_true] = ACTIONS(560),
    [anon_sym_false] = ACTIONS(560),
    [anon_sym_CR] = ACTIONS(560),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(564),
    [sym__single_quote_string_start] = ACTIONS(564),
    [sym__double_quote_string_start] = ACTIONS(564),
    [sym__multioutput_variable_start] = ACTIONS(564),
    [sym__external_identifier] = ACTIONS(564),
  },
  [STATE(114)] = {
    [anon_sym_SEMI] = ACTIONS(566),
    [anon_sym_COMMA] = ACTIONS(566),
    [anon_sym_LPAREN] = ACTIONS(566),
    [anon_sym_PLUS] = ACTIONS(566),
    [anon_sym_DOT_PLUS] = ACTIONS(566),
    [anon_sym_DASH] = ACTIONS(566),
    [anon_sym_DOT_DASH] = ACTIONS(566),
    [anon_sym_STAR] = ACTIONS(566),
    [anon_sym_DOT_STAR] = ACTIONS(566),
    [anon_sym_SLASH] = ACTIONS(566),
    [anon_sym_DOT_SLASH] = ACTIONS(566),
    [anon_sym_BSLASH] = ACTIONS(566),
    [anon_sym_DOT_BSLASH] = ACTIONS(566),
    [anon_sym_CARET] = ACTIONS(566),
    [anon_sym_DOT_CARET] = ACTIONS(566),
    [anon_sym_PIPE] = ACTIONS(566),
    [anon_sym_AMP] = ACTIONS(566),
    [anon_sym_TILDE] = ACTIONS(566),
    [anon_sym_QMARK] = ACTIONS(566),
    [anon_sym_AT] = ACTIONS(566),
    [anon_sym_LT] = ACTIONS(566),
    [anon_sym_LT_EQ] = ACTIONS(566),
    [anon_sym_EQ_EQ] = ACTIONS(566),
    [anon_sym_TILDE_EQ] = ACTIONS(566),
    [anon_sym_GT_EQ] = ACTIONS(566),
    [anon_sym_GT] = ACTIONS(566),
    [anon_sym_AMP_AMP] = ACTIONS(566),
    [anon_sym_PIPE_PIPE] = ACTIONS(566),
    [anon_sym_DOT_SQUOTE] = ACTIONS(566),
    [anon_sym_SQUOTE] = ACTIONS(566),
    [anon_sym_LBRACK] = ACTIONS(566),
    [anon_sym_LF] = ACTIONS(566),
    [anon_sym_LBRACE] = ACTIONS(566),
    [anon_sym_COLON] = ACTIONS(566),
    [anon_sym_return] = ACTIONS(566),
    [anon_sym_continue] = ACTIONS(566),
    [anon_sym_break] = ACTIONS(566),
    [anon_sym_elseif] = ACTIONS(566),
    [anon_sym_else] = ACTIONS(566),
    [anon_sym_if] = ACTIONS(566),
    [anon_sym_end] = ACTIONS(566),
    [anon_sym_for] = ACTIONS(566),
    [anon_sym_parfor] = ACTIONS(566),
    [anon_sym_while] = ACTIONS(566),
    [anon_sym_switch] = ACTIONS(566),
    [anon_sym_global] = ACTIONS(566),
    [anon_sym_persistent] = ACTIONS(566),
    [anon_sym_arguments] = ACTIONS(566),
    [anon_sym_function] = ACTIONS(566),
    [anon_sym_properties] = ACTIONS(566),
    [anon_sym_get] = ACTIONS(566),
    [anon_sym_set] = ACTIONS(566),
    [anon_sym_methods] = ACTIONS(566),
    [anon_sym_events] = ACTIONS(566),
    [anon_sym_enumeration] = ACTIONS(566),
    [anon_sym_classdef] = ACTIONS(566),
    [anon_sym_try] = ACTIONS(566),
    [anon_sym_spmd] = ACTIONS(566),
    [aux_sym_number_token1] = ACTIONS(566),
    [aux_sym_number_token2] = ACTIONS(566),
    [aux_sym_number_token3] = ACTIONS(566),
    [anon_sym_true] = ACTIONS(566),
    [anon_sym_false] = ACTIONS(566),
    [anon_sym_CR] = ACTIONS(566),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(568),
    [sym__single_quote_string_start] = ACTIONS(568),
    [sym__double_quote_string_start] = ACTIONS(568),
    [sym__multioutput_variable_start] = ACTIONS(568),
    [sym__external_identifier] = ACTIONS(568),
  },
  [STATE(115)] = {
    [anon_sym_SEMI] = ACTIONS(570),
    [anon_sym_COMMA] = ACTIONS(570),
    [anon_sym_LPAREN] = ACTIONS(570),
    [anon_sym_PLUS] = ACTIONS(570),
    [anon_sym_DOT_PLUS] = ACTIONS(570),
    [anon_sym_DASH] = ACTIONS(570),
    [anon_sym_DOT_DASH] = ACTIONS(570),
    [anon_sym_STAR] = ACTIONS(570),
    [anon_sym_DOT_STAR] = ACTIONS(570),
    [anon_sym_SLASH] = ACTIONS(570),
    [anon_sym_DOT_SLASH] = ACTIONS(570),
    [anon_sym_BSLASH] = ACTIONS(570),
    [anon_sym_DOT_BSLASH] = ACTIONS(570),
    [anon_sym_CARET] = ACTIONS(570),
    [anon_sym_DOT_CARET] = ACTIONS(570),
    [anon_sym_PIPE] = ACTIONS(570),
    [anon_sym_AMP] = ACTIONS(570),
    [anon_sym_TILDE] = ACTIONS(570),
    [anon_sym_QMARK] = ACTIONS(570),
    [anon_sym_AT] = ACTIONS(570),
    [anon_sym_LT] = ACTIONS(570),
    [anon_sym_LT_EQ] = ACTIONS(570),
    [anon_sym_EQ_EQ] = ACTIONS(570),
    [anon_sym_TILDE_EQ] = ACTIONS(570),
    [anon_sym_GT_EQ] = ACTIONS(570),
    [anon_sym_GT] = ACTIONS(570),
    [anon_sym_AMP_AMP] = ACTIONS(570),
    [anon_sym_PIPE_PIPE] = ACTIONS(570),
    [anon_sym_DOT_SQUOTE] = ACTIONS(570),
    [anon_sym_SQUOTE] = ACTIONS(570),
    [anon_sym_LBRACK] = ACTIONS(570),
    [anon_sym_LF] = ACTIONS(570),
    [anon_sym_LBRACE] = ACTIONS(570),
    [anon_sym_COLON] = ACTIONS(570),
    [anon_sym_return] = ACTIONS(570),
    [anon_sym_continue] = ACTIONS(570),
    [anon_sym_break] = ACTIONS(570),
    [anon_sym_elseif] = ACTIONS(570),
    [anon_sym_else] = ACTIONS(570),
    [anon_sym_if] = ACTIONS(570),
    [anon_sym_end] = ACTIONS(570),
    [anon_sym_for] = ACTIONS(570),
    [anon_sym_parfor] = ACTIONS(570),
    [anon_sym_while] = ACTIONS(570),
    [anon_sym_switch] = ACTIONS(570),
    [anon_sym_global] = ACTIONS(570),
    [anon_sym_persistent] = ACTIONS(570),
    [anon_sym_arguments] = ACTIONS(570),
    [anon_sym_function] = ACTIONS(570),
    [anon_sym_properties] = ACTIONS(570),
    [anon_sym_get] = ACTIONS(570),
    [anon_sym_set] = ACTIONS(570),
    [anon_sym_methods] = ACTIONS(570),
    [anon_sym_events] = ACTIONS(570),
    [anon_sym_enumeration] = ACTIONS(570),
    [anon_sym_classdef] = ACTIONS(570),
    [anon_sym_try] = ACTIONS(570),
    [anon_sym_spmd] = ACTIONS(570),
    [aux_sym_number_token1] = ACTIONS(570),
    [aux_sym_number_token2] = ACTIONS(570),
    [aux_sym_number_token3] = ACTIONS(570),
    [anon_sym_true] = ACTIONS(570),
    [anon_sym_false] = ACTIONS(570),
    [anon_sym_CR] = ACTIONS(570),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(572),
    [sym__single_quote_string_start] = ACTIONS(572),
    [sym__double_quote_string_start] = ACTIONS(572),
    [sym__multioutput_variable_start] = ACTIONS(572),
    [sym__external_identifier] = ACTIONS(572),
  },
  [STATE(116)] = {
    [anon_sym_SEMI] = ACTIONS(574),
    [anon_sym_COMMA] = ACTIONS(574),
    [anon_sym_LPAREN] = ACTIONS(574),
    [anon_sym_PLUS] = ACTIONS(574),
    [anon_sym_DOT_PLUS] = ACTIONS(574),
    [anon_sym_DASH] = ACTIONS(574),
    [anon_sym_DOT_DASH] = ACTIONS(574),
    [anon_sym_STAR] = ACTIONS(574),
    [anon_sym_DOT_STAR] = ACTIONS(574),
    [anon_sym_SLASH] = ACTIONS(574),
    [anon_sym_DOT_SLASH] = ACTIONS(574),
    [anon_sym_BSLASH] = ACTIONS(574),
    [anon_sym_DOT_BSLASH] = ACTIONS(574),
    [anon_sym_CARET] = ACTIONS(574),
    [anon_sym_DOT_CARET] = ACTIONS(574),
    [anon_sym_PIPE] = ACTIONS(574),
    [anon_sym_AMP] = ACTIONS(574),
    [anon_sym_TILDE] = ACTIONS(574),
    [anon_sym_QMARK] = ACTIONS(574),
    [anon_sym_AT] = ACTIONS(574),
    [anon_sym_LT] = ACTIONS(574),
    [anon_sym_LT_EQ] = ACTIONS(574),
    [anon_sym_EQ_EQ] = ACTIONS(574),
    [anon_sym_TILDE_EQ] = ACTIONS(574),
    [anon_sym_GT_EQ] = ACTIONS(574),
    [anon_sym_GT] = ACTIONS(574),
    [anon_sym_AMP_AMP] = ACTIONS(574),
    [anon_sym_PIPE_PIPE] = ACTIONS(574),
    [anon_sym_DOT_SQUOTE] = ACTIONS(574),
    [anon_sym_SQUOTE] = ACTIONS(574),
    [anon_sym_LBRACK] = ACTIONS(574),
    [anon_sym_LF] = ACTIONS(574),
    [anon_sym_LBRACE] = ACTIONS(574),
    [anon_sym_COLON] = ACTIONS(574),
    [anon_sym_return] = ACTIONS(574),
    [anon_sym_continue] = ACTIONS(574),
    [anon_sym_break] = ACTIONS(574),
    [anon_sym_elseif] = ACTIONS(574),
    [anon_sym_else] = ACTIONS(574),
    [anon_sym_if] = ACTIONS(574),
    [anon_sym_end] = ACTIONS(574),
    [anon_sym_for] = ACTIONS(574),
    [anon_sym_parfor] = ACTIONS(574),
    [anon_sym_while] = ACTIONS(574),
    [anon_sym_switch] = ACTIONS(574),
    [anon_sym_global] = ACTIONS(574),
    [anon_sym_persistent] = ACTIONS(574),
    [anon_sym_arguments] = ACTIONS(574),
    [anon_sym_function] = ACTIONS(574),
    [anon_sym_properties] = ACTIONS(574),
    [anon_sym_get] = ACTIONS(574),
    [anon_sym_set] = ACTIONS(574),
    [anon_sym_methods] = ACTIONS(574),
    [anon_sym_events] = ACTIONS(574),
    [anon_sym_enumeration] = ACTIONS(574),
    [anon_sym_classdef] = ACTIONS(574),
    [anon_sym_try] = ACTIONS(574),
    [anon_sym_spmd] = ACTIONS(574),
    [aux_sym_number_token1] = ACTIONS(574),
    [aux_sym_number_token2] = ACTIONS(574),
    [aux_sym_number_token3] = ACTIONS(574),
    [anon_sym_true] = ACTIONS(574),
    [anon_sym_false] = ACTIONS(574),
    [anon_sym_CR] = ACTIONS(574),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(576),
    [sym__single_quote_string_start] = ACTIONS(576),
    [sym__double_quote_string_start] = ACTIONS(576),
    [sym__multioutput_variable_start] = ACTIONS(576),
    [sym__external_identifier] = ACTIONS(576),
  },
  [STATE(117)] = {
    [anon_sym_SEMI] = ACTIONS(71),
    [anon_sym_COMMA] = ACTIONS(71),
    [anon_sym_LPAREN] = ACTIONS(71),
    [anon_sym_PLUS] = ACTIONS(71),
    [anon_sym_DOT_PLUS] = ACTIONS(71),
    [anon_sym_DASH] = ACTIONS(71),
    [anon_sym_DOT_DASH] = ACTIONS(71),
    [anon_sym_STAR] = ACTIONS(71),
    [anon_sym_DOT_STAR] = ACTIONS(71),
    [anon_sym_SLASH] = ACTIONS(71),
    [anon_sym_DOT_SLASH] = ACTIONS(71),
    [anon_sym_BSLASH] = ACTIONS(71),
    [anon_sym_DOT_BSLASH] = ACTIONS(71),
    [anon_sym_CARET] = ACTIONS(71),
    [anon_sym_DOT_CARET] = ACTIONS(71),
    [anon_sym_PIPE] = ACTIONS(71),
    [anon_sym_AMP] = ACTIONS(71),
    [anon_sym_TILDE] = ACTIONS(71),
    [anon_sym_QMARK] = ACTIONS(71),
    [anon_sym_AT] = ACTIONS(71),
    [anon_sym_LT] = ACTIONS(71),
    [anon_sym_LT_EQ] = ACTIONS(71),
    [anon_sym_EQ_EQ] = ACTIONS(71),
    [anon_sym_TILDE_EQ] = ACTIONS(71),
    [anon_sym_GT_EQ] = ACTIONS(71),
    [anon_sym_GT] = ACTIONS(71),
    [anon_sym_AMP_AMP] = ACTIONS(71),
    [anon_sym_PIPE_PIPE] = ACTIONS(71),
    [anon_sym_DOT_SQUOTE] = ACTIONS(71),
    [anon_sym_SQUOTE] = ACTIONS(71),
    [anon_sym_LBRACK] = ACTIONS(71),
    [anon_sym_LF] = ACTIONS(71),
    [anon_sym_LBRACE] = ACTIONS(71),
    [anon_sym_COLON] = ACTIONS(71),
    [anon_sym_return] = ACTIONS(71),
    [anon_sym_continue] = ACTIONS(71),
    [anon_sym_break] = ACTIONS(71),
    [anon_sym_elseif] = ACTIONS(71),
    [anon_sym_else] = ACTIONS(71),
    [anon_sym_if] = ACTIONS(71),
    [anon_sym_end] = ACTIONS(71),
    [anon_sym_for] = ACTIONS(71),
    [anon_sym_parfor] = ACTIONS(71),
    [anon_sym_while] = ACTIONS(71),
    [anon_sym_switch] = ACTIONS(71),
    [anon_sym_global] = ACTIONS(71),
    [anon_sym_persistent] = ACTIONS(71),
    [anon_sym_arguments] = ACTIONS(71),
    [anon_sym_function] = ACTIONS(71),
    [anon_sym_properties] = ACTIONS(71),
    [anon_sym_get] = ACTIONS(71),
    [anon_sym_set] = ACTIONS(71),
    [anon_sym_methods] = ACTIONS(71),
    [anon_sym_events] = ACTIONS(71),
    [anon_sym_enumeration] = ACTIONS(71),
    [anon_sym_classdef] = ACTIONS(71),
    [anon_sym_try] = ACTIONS(71),
    [anon_sym_spmd] = ACTIONS(71),
    [aux_sym_number_token1] = ACTIONS(71),
    [aux_sym_number_token2] = ACTIONS(71),
    [aux_sym_number_token3] = ACTIONS(71),
    [anon_sym_true] = ACTIONS(71),
    [anon_sym_false] = ACTIONS(71),
    [anon_sym_CR] = ACTIONS(71),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(578),
    [sym__single_quote_string_start] = ACTIONS(578),
    [sym__double_quote_string_start] = ACTIONS(578),
    [sym__multioutput_variable_start] = ACTIONS(578),
    [sym__external_identifier] = ACTIONS(578),
  },
  [STATE(118)] = {
    [anon_sym_SEMI] = ACTIONS(580),
    [anon_sym_COMMA] = ACTIONS(580),
    [anon_sym_LPAREN] = ACTIONS(580),
    [anon_sym_PLUS] = ACTIONS(580),
    [anon_sym_DOT_PLUS] = ACTIONS(580),
    [anon_sym_DASH] = ACTIONS(580),
    [anon_sym_DOT_DASH] = ACTIONS(580),
    [anon_sym_STAR] = ACTIONS(580),
    [anon_sym_DOT_STAR] = ACTIONS(580),
    [anon_sym_SLASH] = ACTIONS(580),
    [anon_sym_DOT_SLASH] = ACTIONS(580),
    [anon_sym_BSLASH] = ACTIONS(580),
    [anon_sym_DOT_BSLASH] = ACTIONS(580),
    [anon_sym_CARET] = ACTIONS(580),
    [anon_sym_DOT_CARET] = ACTIONS(580),
    [anon_sym_PIPE] = ACTIONS(580),
    [anon_sym_AMP] = ACTIONS(580),
    [anon_sym_TILDE] = ACTIONS(580),
    [anon_sym_QMARK] = ACTIONS(580),
    [anon_sym_AT] = ACTIONS(580),
    [anon_sym_LT] = ACTIONS(580),
    [anon_sym_LT_EQ] = ACTIONS(580),
    [anon_sym_EQ_EQ] = ACTIONS(580),
    [anon_sym_TILDE_EQ] = ACTIONS(580),
    [anon_sym_GT_EQ] = ACTIONS(580),
    [anon_sym_GT] = ACTIONS(580),
    [anon_sym_AMP_AMP] = ACTIONS(580),
    [anon_sym_PIPE_PIPE] = ACTIONS(580),
    [anon_sym_DOT_SQUOTE] = ACTIONS(580),
    [anon_sym_SQUOTE] = ACTIONS(580),
    [anon_sym_LBRACK] = ACTIONS(580),
    [anon_sym_LF] = ACTIONS(580),
    [anon_sym_LBRACE] = ACTIONS(580),
    [anon_sym_COLON] = ACTIONS(580),
    [anon_sym_return] = ACTIONS(580),
    [anon_sym_continue] = ACTIONS(580),
    [anon_sym_break] = ACTIONS(580),
    [anon_sym_elseif] = ACTIONS(580),
    [anon_sym_else] = ACTIONS(580),
    [anon_sym_if] = ACTIONS(580),
    [anon_sym_end] = ACTIONS(580),
    [anon_sym_for] = ACTIONS(580),
    [anon_sym_parfor] = ACTIONS(580),
    [anon_sym_while] = ACTIONS(580),
    [anon_sym_switch] = ACTIONS(580),
    [anon_sym_global] = ACTIONS(580),
    [anon_sym_persistent] = ACTIONS(580),
    [anon_sym_arguments] = ACTIONS(580),
    [anon_sym_function] = ACTIONS(580),
    [anon_sym_properties] = ACTIONS(580),
    [anon_sym_get] = ACTIONS(580),
    [anon_sym_set] = ACTIONS(580),
    [anon_sym_methods] = ACTIONS(580),
    [anon_sym_events] = ACTIONS(580),
    [anon_sym_enumeration] = ACTIONS(580),
    [anon_sym_classdef] = ACTIONS(580),
    [anon_sym_try] = ACTIONS(580),
    [anon_sym_spmd] = ACTIONS(580),
    [aux_sym_number_token1] = ACTIONS(580),
    [aux_sym_number_token2] = ACTIONS(580),
    [aux_sym_number_token3] = ACTIONS(580),
    [anon_sym_true] = ACTIONS(580),
    [anon_sym_false] = ACTIONS(580),
    [anon_sym_CR] = ACTIONS(580),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(582),
    [sym__single_quote_string_start] = ACTIONS(582),
    [sym__double_quote_string_start] = ACTIONS(582),
    [sym__multioutput_variable_start] = ACTIONS(582),
    [sym__external_identifier] = ACTIONS(582),
  },
  [STATE(119)] = {
    [anon_sym_SEMI] = ACTIONS(584),
    [anon_sym_COMMA] = ACTIONS(584),
    [anon_sym_LPAREN] = ACTIONS(584),
    [anon_sym_PLUS] = ACTIONS(584),
    [anon_sym_DOT_PLUS] = ACTIONS(584),
    [anon_sym_DASH] = ACTIONS(584),
    [anon_sym_DOT_DASH] = ACTIONS(584),
    [anon_sym_STAR] = ACTIONS(584),
    [anon_sym_DOT_STAR] = ACTIONS(584),
    [anon_sym_SLASH] = ACTIONS(584),
    [anon_sym_DOT_SLASH] = ACTIONS(584),
    [anon_sym_BSLASH] = ACTIONS(584),
    [anon_sym_DOT_BSLASH] = ACTIONS(584),
    [anon_sym_CARET] = ACTIONS(584),
    [anon_sym_DOT_CARET] = ACTIONS(584),
    [anon_sym_PIPE] = ACTIONS(584),
    [anon_sym_AMP] = ACTIONS(584),
    [anon_sym_TILDE] = ACTIONS(584),
    [anon_sym_QMARK] = ACTIONS(584),
    [anon_sym_AT] = ACTIONS(584),
    [anon_sym_LT] = ACTIONS(584),
    [anon_sym_LT_EQ] = ACTIONS(584),
    [anon_sym_EQ_EQ] = ACTIONS(584),
    [anon_sym_TILDE_EQ] = ACTIONS(584),
    [anon_sym_GT_EQ] = ACTIONS(584),
    [anon_sym_GT] = ACTIONS(584),
    [anon_sym_AMP_AMP] = ACTIONS(584),
    [anon_sym_PIPE_PIPE] = ACTIONS(584),
    [anon_sym_DOT_SQUOTE] = ACTIONS(584),
    [anon_sym_SQUOTE] = ACTIONS(584),
    [anon_sym_LBRACK] = ACTIONS(584),
    [anon_sym_LF] = ACTIONS(584),
    [anon_sym_LBRACE] = ACTIONS(584),
    [anon_sym_COLON] = ACTIONS(584),
    [anon_sym_return] = ACTIONS(584),
    [anon_sym_continue] = ACTIONS(584),
    [anon_sym_break] = ACTIONS(584),
    [anon_sym_elseif] = ACTIONS(584),
    [anon_sym_else] = ACTIONS(584),
    [anon_sym_if] = ACTIONS(584),
    [anon_sym_end] = ACTIONS(584),
    [anon_sym_for] = ACTIONS(584),
    [anon_sym_parfor] = ACTIONS(584),
    [anon_sym_while] = ACTIONS(584),
    [anon_sym_switch] = ACTIONS(584),
    [anon_sym_global] = ACTIONS(584),
    [anon_sym_persistent] = ACTIONS(584),
    [anon_sym_arguments] = ACTIONS(584),
    [anon_sym_function] = ACTIONS(584),
    [anon_sym_properties] = ACTIONS(584),
    [anon_sym_get] = ACTIONS(584),
    [anon_sym_set] = ACTIONS(584),
    [anon_sym_methods] = ACTIONS(584),
    [anon_sym_events] = ACTIONS(584),
    [anon_sym_enumeration] = ACTIONS(584),
    [anon_sym_classdef] = ACTIONS(584),
    [anon_sym_try] = ACTIONS(584),
    [anon_sym_spmd] = ACTIONS(584),
    [aux_sym_number_token1] = ACTIONS(584),
    [aux_sym_number_token2] = ACTIONS(584),
    [aux_sym_number_token3] = ACTIONS(584),
    [anon_sym_true] = ACTIONS(584),
    [anon_sym_false] = ACTIONS(584),
    [anon_sym_CR] = ACTIONS(584),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(586),
    [sym__single_quote_string_start] = ACTIONS(586),
    [sym__double_quote_string_start] = ACTIONS(586),
    [sym__multioutput_variable_start] = ACTIONS(586),
    [sym__external_identifier] = ACTIONS(586),
  },
  [STATE(120)] = {
    [anon_sym_SEMI] = ACTIONS(588),
    [anon_sym_COMMA] = ACTIONS(588),
    [anon_sym_LPAREN] = ACTIONS(588),
    [anon_sym_PLUS] = ACTIONS(588),
    [anon_sym_DOT_PLUS] = ACTIONS(588),
    [anon_sym_DASH] = ACTIONS(588),
    [anon_sym_DOT_DASH] = ACTIONS(588),
    [anon_sym_STAR] = ACTIONS(588),
    [anon_sym_DOT_STAR] = ACTIONS(588),
    [anon_sym_SLASH] = ACTIONS(588),
    [anon_sym_DOT_SLASH] = ACTIONS(588),
    [anon_sym_BSLASH] = ACTIONS(588),
    [anon_sym_DOT_BSLASH] = ACTIONS(588),
    [anon_sym_CARET] = ACTIONS(588),
    [anon_sym_DOT_CARET] = ACTIONS(588),
    [anon_sym_PIPE] = ACTIONS(588),
    [anon_sym_AMP] = ACTIONS(588),
    [anon_sym_TILDE] = ACTIONS(588),
    [anon_sym_QMARK] = ACTIONS(588),
    [anon_sym_AT] = ACTIONS(588),
    [anon_sym_LT] = ACTIONS(588),
    [anon_sym_LT_EQ] = ACTIONS(588),
    [anon_sym_EQ_EQ] = ACTIONS(588),
    [anon_sym_TILDE_EQ] = ACTIONS(588),
    [anon_sym_GT_EQ] = ACTIONS(588),
    [anon_sym_GT] = ACTIONS(588),
    [anon_sym_AMP_AMP] = ACTIONS(588),
    [anon_sym_PIPE_PIPE] = ACTIONS(588),
    [anon_sym_DOT_SQUOTE] = ACTIONS(588),
    [anon_sym_SQUOTE] = ACTIONS(588),
    [anon_sym_LBRACK] = ACTIONS(588),
    [anon_sym_LF] = ACTIONS(588),
    [anon_sym_LBRACE] = ACTIONS(588),
    [anon_sym_COLON] = ACTIONS(588),
    [anon_sym_return] = ACTIONS(588),
    [anon_sym_continue] = ACTIONS(588),
    [anon_sym_break] = ACTIONS(588),
    [anon_sym_elseif] = ACTIONS(588),
    [anon_sym_else] = ACTIONS(588),
    [anon_sym_if] = ACTIONS(588),
    [anon_sym_end] = ACTIONS(588),
    [anon_sym_for] = ACTIONS(588),
    [anon_sym_parfor] = ACTIONS(588),
    [anon_sym_while] = ACTIONS(588),
    [anon_sym_switch] = ACTIONS(588),
    [anon_sym_global] = ACTIONS(588),
    [anon_sym_persistent] = ACTIONS(588),
    [anon_sym_arguments] = ACTIONS(588),
    [anon_sym_function] = ACTIONS(588),
    [anon_sym_properties] = ACTIONS(588),
    [anon_sym_get] = ACTIONS(588),
    [anon_sym_set] = ACTIONS(588),
    [anon_sym_methods] = ACTIONS(588),
    [anon_sym_events] = ACTIONS(588),
    [anon_sym_enumeration] = ACTIONS(588),
    [anon_sym_classdef] = ACTIONS(588),
    [anon_sym_try] = ACTIONS(588),
    [anon_sym_spmd] = ACTIONS(588),
    [aux_sym_number_token1] = ACTIONS(588),
    [aux_sym_number_token2] = ACTIONS(588),
    [aux_sym_number_token3] = ACTIONS(588),
    [anon_sym_true] = ACTIONS(588),
    [anon_sym_false] = ACTIONS(588),
    [anon_sym_CR] = ACTIONS(588),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(590),
    [sym__single_quote_string_start] = ACTIONS(590),
    [sym__double_quote_string_start] = ACTIONS(590),
    [sym__multioutput_variable_start] = ACTIONS(590),
    [sym__external_identifier] = ACTIONS(590),
  },
  [STATE(121)] = {
    [anon_sym_SEMI] = ACTIONS(592),
    [anon_sym_COMMA] = ACTIONS(592),
    [anon_sym_LPAREN] = ACTIONS(592),
    [anon_sym_PLUS] = ACTIONS(592),
    [anon_sym_DOT_PLUS] = ACTIONS(592),
    [anon_sym_DASH] = ACTIONS(592),
    [anon_sym_DOT_DASH] = ACTIONS(592),
    [anon_sym_STAR] = ACTIONS(594),
    [anon_sym_DOT_STAR] = ACTIONS(594),
    [anon_sym_SLASH] = ACTIONS(594),
    [anon_sym_DOT_SLASH] = ACTIONS(594),
    [anon_sym_BSLASH] = ACTIONS(594),
    [anon_sym_DOT_BSLASH] = ACTIONS(594),
    [anon_sym_CARET] = ACTIONS(596),
    [anon_sym_DOT_CARET] = ACTIONS(596),
    [anon_sym_PIPE] = ACTIONS(592),
    [anon_sym_AMP] = ACTIONS(592),
    [anon_sym_TILDE] = ACTIONS(592),
    [anon_sym_QMARK] = ACTIONS(592),
    [anon_sym_AT] = ACTIONS(592),
    [anon_sym_LT] = ACTIONS(592),
    [anon_sym_LT_EQ] = ACTIONS(592),
    [anon_sym_EQ_EQ] = ACTIONS(592),
    [anon_sym_TILDE_EQ] = ACTIONS(592),
    [anon_sym_GT_EQ] = ACTIONS(592),
    [anon_sym_GT] = ACTIONS(592),
    [anon_sym_AMP_AMP] = ACTIONS(592),
    [anon_sym_PIPE_PIPE] = ACTIONS(592),
    [anon_sym_DOT_SQUOTE] = ACTIONS(592),
    [anon_sym_SQUOTE] = ACTIONS(592),
    [anon_sym_LBRACK] = ACTIONS(592),
    [anon_sym_LF] = ACTIONS(592),
    [anon_sym_LBRACE] = ACTIONS(592),
    [anon_sym_COLON] = ACTIONS(592),
    [anon_sym_return] = ACTIONS(592),
    [anon_sym_continue] = ACTIONS(592),
    [anon_sym_break] = ACTIONS(592),
    [anon_sym_elseif] = ACTIONS(592),
    [anon_sym_else] = ACTIONS(592),
    [anon_sym_if] = ACTIONS(592),
    [anon_sym_end] = ACTIONS(592),
    [anon_sym_for] = ACTIONS(592),
    [anon_sym_parfor] = ACTIONS(592),
    [anon_sym_while] = ACTIONS(592),
    [anon_sym_switch] = ACTIONS(592),
    [anon_sym_global] = ACTIONS(592),
    [anon_sym_persistent] = ACTIONS(592),
    [anon_sym_arguments] = ACTIONS(592),
    [anon_sym_function] = ACTIONS(592),
    [anon_sym_properties] = ACTIONS(592),
    [anon_sym_get] = ACTIONS(592),
    [anon_sym_set] = ACTIONS(592),
    [anon_sym_methods] = ACTIONS(592),
    [anon_sym_events] = ACTIONS(592),
    [anon_sym_enumeration] = ACTIONS(592),
    [anon_sym_classdef] = ACTIONS(592),
    [anon_sym_try] = ACTIONS(592),
    [anon_sym_spmd] = ACTIONS(592),
    [aux_sym_number_token1] = ACTIONS(592),
    [aux_sym_number_token2] = ACTIONS(592),
    [aux_sym_number_token3] = ACTIONS(592),
    [anon_sym_true] = ACTIONS(592),
    [anon_sym_false] = ACTIONS(592),
    [anon_sym_CR] = ACTIONS(592),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(598),
    [sym__single_quote_string_start] = ACTIONS(598),
    [sym__double_quote_string_start] = ACTIONS(598),
    [sym__multioutput_variable_start] = ACTIONS(598),
    [sym__external_identifier] = ACTIONS(598),
  },
  [STATE(122)] = {
    [anon_sym_SEMI] = ACTIONS(592),
    [anon_sym_COMMA] = ACTIONS(592),
    [anon_sym_LPAREN] = ACTIONS(592),
    [anon_sym_PLUS] = ACTIONS(592),
    [anon_sym_DOT_PLUS] = ACTIONS(592),
    [anon_sym_DASH] = ACTIONS(592),
    [anon_sym_DOT_DASH] = ACTIONS(592),
    [anon_sym_STAR] = ACTIONS(592),
    [anon_sym_DOT_STAR] = ACTIONS(592),
    [anon_sym_SLASH] = ACTIONS(592),
    [anon_sym_DOT_SLASH] = ACTIONS(592),
    [anon_sym_BSLASH] = ACTIONS(592),
    [anon_sym_DOT_BSLASH] = ACTIONS(592),
    [anon_sym_CARET] = ACTIONS(596),
    [anon_sym_DOT_CARET] = ACTIONS(596),
    [anon_sym_PIPE] = ACTIONS(592),
    [anon_sym_AMP] = ACTIONS(592),
    [anon_sym_TILDE] = ACTIONS(592),
    [anon_sym_QMARK] = ACTIONS(592),
    [anon_sym_AT] = ACTIONS(592),
    [anon_sym_LT] = ACTIONS(592),
    [anon_sym_LT_EQ] = ACTIONS(592),
    [anon_sym_EQ_EQ] = ACTIONS(592),
    [anon_sym_TILDE_EQ] = ACTIONS(592),
    [anon_sym_GT_EQ] = ACTIONS(592),
    [anon_sym_GT] = ACTIONS(592),
    [anon_sym_AMP_AMP] = ACTIONS(592),
    [anon_sym_PIPE_PIPE] = ACTIONS(592),
    [anon_sym_DOT_SQUOTE] = ACTIONS(592),
    [anon_sym_SQUOTE] = ACTIONS(592),
    [anon_sym_LBRACK] = ACTIONS(592),
    [anon_sym_LF] = ACTIONS(592),
    [anon_sym_LBRACE] = ACTIONS(592),
    [anon_sym_COLON] = ACTIONS(592),
    [anon_sym_return] = ACTIONS(592),
    [anon_sym_continue] = ACTIONS(592),
    [anon_sym_break] = ACTIONS(592),
    [anon_sym_elseif] = ACTIONS(592),
    [anon_sym_else] = ACTIONS(592),
    [anon_sym_if] = ACTIONS(592),
    [anon_sym_end] = ACTIONS(592),
    [anon_sym_for] = ACTIONS(592),
    [anon_sym_parfor] = ACTIONS(592),
    [anon_sym_while] = ACTIONS(592),
    [anon_sym_switch] = ACTIONS(592),
    [anon_sym_global] = ACTIONS(592),
    [anon_sym_persistent] = ACTIONS(592),
    [anon_sym_arguments] = ACTIONS(592),
    [anon_sym_function] = ACTIONS(592),
    [anon_sym_properties] = ACTIONS(592),
    [anon_sym_get] = ACTIONS(592),
    [anon_sym_set] = ACTIONS(592),
    [anon_sym_methods] = ACTIONS(592),
    [anon_sym_events] = ACTIONS(592),
    [anon_sym_enumeration] = ACTIONS(592),
    [anon_sym_classdef] = ACTIONS(592),
    [anon_sym_try] = ACTIONS(592),
    [anon_sym_spmd] = ACTIONS(592),
    [aux_sym_number_token1] = ACTIONS(592),
    [aux_sym_number_token2] = ACTIONS(592),
    [aux_sym_number_token3] = ACTIONS(592),
    [anon_sym_true] = ACTIONS(592),
    [anon_sym_false] = ACTIONS(592),
    [anon_sym_CR] = ACTIONS(592),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(598),
    [sym__single_quote_string_start] = ACTIONS(598),
    [sym__double_quote_string_start] = ACTIONS(598),
    [sym__multioutput_variable_start] = ACTIONS(598),
    [sym__external_identifier] = ACTIONS(598),
  },
  [STATE(123)] = {
    [anon_sym_SEMI] = ACTIONS(592),
    [anon_sym_COMMA] = ACTIONS(592),
    [anon_sym_LPAREN] = ACTIONS(592),
    [anon_sym_PLUS] = ACTIONS(592),
    [anon_sym_DOT_PLUS] = ACTIONS(592),
    [anon_sym_DASH] = ACTIONS(592),
    [anon_sym_DOT_DASH] = ACTIONS(592),
    [anon_sym_STAR] = ACTIONS(592),
    [anon_sym_DOT_STAR] = ACTIONS(592),
    [anon_sym_SLASH] = ACTIONS(592),
    [anon_sym_DOT_SLASH] = ACTIONS(592),
    [anon_sym_BSLASH] = ACTIONS(592),
    [anon_sym_DOT_BSLASH] = ACTIONS(592),
    [anon_sym_CARET] = ACTIONS(596),
    [anon_sym_DOT_CARET] = ACTIONS(596),
    [anon_sym_PIPE] = ACTIONS(592),
    [anon_sym_AMP] = ACTIONS(592),
    [anon_sym_TILDE] = ACTIONS(592),
    [anon_sym_QMARK] = ACTIONS(592),
    [anon_sym_AT] = ACTIONS(592),
    [anon_sym_LT] = ACTIONS(592),
    [anon_sym_LT_EQ] = ACTIONS(592),
    [anon_sym_EQ_EQ] = ACTIONS(592),
    [anon_sym_TILDE_EQ] = ACTIONS(592),
    [anon_sym_GT_EQ] = ACTIONS(592),
    [anon_sym_GT] = ACTIONS(592),
    [anon_sym_AMP_AMP] = ACTIONS(592),
    [anon_sym_PIPE_PIPE] = ACTIONS(592),
    [anon_sym_DOT_SQUOTE] = ACTIONS(592),
    [anon_sym_SQUOTE] = ACTIONS(592),
    [anon_sym_LBRACK] = ACTIONS(592),
    [anon_sym_LF] = ACTIONS(592),
    [anon_sym_LBRACE] = ACTIONS(592),
    [anon_sym_COLON] = ACTIONS(592),
    [anon_sym_return] = ACTIONS(592),
    [anon_sym_continue] = ACTIONS(592),
    [anon_sym_break] = ACTIONS(592),
    [anon_sym_elseif] = ACTIONS(592),
    [anon_sym_else] = ACTIONS(592),
    [anon_sym_if] = ACTIONS(592),
    [anon_sym_end] = ACTIONS(592),
    [anon_sym_for] = ACTIONS(592),
    [anon_sym_parfor] = ACTIONS(592),
    [anon_sym_while] = ACTIONS(592),
    [anon_sym_switch] = ACTIONS(592),
    [anon_sym_global] = ACTIONS(592),
    [anon_sym_persistent] = ACTIONS(592),
    [anon_sym_arguments] = ACTIONS(592),
    [anon_sym_function] = ACTIONS(592),
    [anon_sym_properties] = ACTIONS(592),
    [anon_sym_get] = ACTIONS(592),
    [anon_sym_set] = ACTIONS(592),
    [anon_sym_methods] = ACTIONS(592),
    [anon_sym_events] = ACTIONS(592),
    [anon_sym_enumeration] = ACTIONS(592),
    [anon_sym_classdef] = ACTIONS(592),
    [anon_sym_try] = ACTIONS(592),
    [anon_sym_spmd] = ACTIONS(592),
    [aux_sym_number_token1] = ACTIONS(592),
    [aux_sym_number_token2] = ACTIONS(592),
    [aux_sym_number_token3] = ACTIONS(592),
    [anon_sym_true] = ACTIONS(592),
    [anon_sym_false] = ACTIONS(592),
    [anon_sym_CR] = ACTIONS(592),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(598),
    [sym__single_quote_string_start] = ACTIONS(598),
    [sym__double_quote_string_start] = ACTIONS(598),
    [sym__multioutput_variable_start] = ACTIONS(598),
    [sym__external_identifier] = ACTIONS(598),
  },
  [STATE(124)] = {
    [anon_sym_SEMI] = ACTIONS(600),
    [anon_sym_COMMA] = ACTIONS(600),
    [anon_sym_LPAREN] = ACTIONS(600),
    [anon_sym_PLUS] = ACTIONS(600),
    [anon_sym_DOT_PLUS] = ACTIONS(600),
    [anon_sym_DASH] = ACTIONS(600),
    [anon_sym_DOT_DASH] = ACTIONS(600),
    [anon_sym_STAR] = ACTIONS(600),
    [anon_sym_DOT_STAR] = ACTIONS(600),
    [anon_sym_SLASH] = ACTIONS(600),
    [anon_sym_DOT_SLASH] = ACTIONS(600),
    [anon_sym_BSLASH] = ACTIONS(600),
    [anon_sym_DOT_BSLASH] = ACTIONS(600),
    [anon_sym_CARET] = ACTIONS(600),
    [anon_sym_DOT_CARET] = ACTIONS(600),
    [anon_sym_PIPE] = ACTIONS(600),
    [anon_sym_AMP] = ACTIONS(600),
    [anon_sym_TILDE] = ACTIONS(600),
    [anon_sym_QMARK] = ACTIONS(600),
    [anon_sym_AT] = ACTIONS(600),
    [anon_sym_LT] = ACTIONS(562),
    [anon_sym_LT_EQ] = ACTIONS(562),
    [anon_sym_EQ_EQ] = ACTIONS(562),
    [anon_sym_TILDE_EQ] = ACTIONS(562),
    [anon_sym_GT_EQ] = ACTIONS(562),
    [anon_sym_GT] = ACTIONS(562),
    [anon_sym_AMP_AMP] = ACTIONS(602),
    [anon_sym_PIPE_PIPE] = ACTIONS(604),
    [anon_sym_DOT_SQUOTE] = ACTIONS(600),
    [anon_sym_SQUOTE] = ACTIONS(600),
    [anon_sym_LBRACK] = ACTIONS(600),
    [anon_sym_LF] = ACTIONS(600),
    [anon_sym_LBRACE] = ACTIONS(600),
    [anon_sym_COLON] = ACTIONS(600),
    [anon_sym_return] = ACTIONS(600),
    [anon_sym_continue] = ACTIONS(600),
    [anon_sym_break] = ACTIONS(600),
    [anon_sym_elseif] = ACTIONS(600),
    [anon_sym_else] = ACTIONS(600),
    [anon_sym_if] = ACTIONS(600),
    [anon_sym_end] = ACTIONS(600),
    [anon_sym_for] = ACTIONS(600),
    [anon_sym_parfor] = ACTIONS(600),
    [anon_sym_while] = ACTIONS(600),
    [anon_sym_switch] = ACTIONS(600),
    [anon_sym_global] = ACTIONS(600),
    [anon_sym_persistent] = ACTIONS(600),
    [anon_sym_arguments] = ACTIONS(600),
    [anon_sym_function] = ACTIONS(600),
    [anon_sym_properties] = ACTIONS(600),
    [anon_sym_get] = ACTIONS(600),
    [anon_sym_set] = ACTIONS(600),
    [anon_sym_methods] = ACTIONS(600),
    [anon_sym_events] = ACTIONS(600),
    [anon_sym_enumeration] = ACTIONS(600),
    [anon_sym_classdef] = ACTIONS(600),
    [anon_sym_try] = ACTIONS(600),
    [anon_sym_spmd] = ACTIONS(600),
    [aux_sym_number_token1] = ACTIONS(600),
    [aux_sym_number_token2] = ACTIONS(600),
    [aux_sym_number_token3] = ACTIONS(600),
    [anon_sym_true] = ACTIONS(600),
    [anon_sym_false] = ACTIONS(600),
    [anon_sym_CR] = ACTIONS(600),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(606),
    [sym__single_quote_string_start] = ACTIONS(606),
    [sym__double_quote_string_start] = ACTIONS(606),
    [sym__multioutput_variable_start] = ACTIONS(606),
    [sym__external_identifier] = ACTIONS(606),
  },
  [STATE(125)] = {
    [anon_sym_SEMI] = ACTIONS(592),
    [anon_sym_COMMA] = ACTIONS(592),
    [anon_sym_LPAREN] = ACTIONS(592),
    [anon_sym_PLUS] = ACTIONS(608),
    [anon_sym_DOT_PLUS] = ACTIONS(608),
    [anon_sym_DASH] = ACTIONS(608),
    [anon_sym_DOT_DASH] = ACTIONS(608),
    [anon_sym_STAR] = ACTIONS(594),
    [anon_sym_DOT_STAR] = ACTIONS(594),
    [anon_sym_SLASH] = ACTIONS(594),
    [anon_sym_DOT_SLASH] = ACTIONS(594),
    [anon_sym_BSLASH] = ACTIONS(594),
    [anon_sym_DOT_BSLASH] = ACTIONS(594),
    [anon_sym_CARET] = ACTIONS(596),
    [anon_sym_DOT_CARET] = ACTIONS(596),
    [anon_sym_PIPE] = ACTIONS(592),
    [anon_sym_AMP] = ACTIONS(592),
    [anon_sym_TILDE] = ACTIONS(592),
    [anon_sym_QMARK] = ACTIONS(592),
    [anon_sym_AT] = ACTIONS(592),
    [anon_sym_LT] = ACTIONS(592),
    [anon_sym_LT_EQ] = ACTIONS(592),
    [anon_sym_EQ_EQ] = ACTIONS(592),
    [anon_sym_TILDE_EQ] = ACTIONS(592),
    [anon_sym_GT_EQ] = ACTIONS(592),
    [anon_sym_GT] = ACTIONS(592),
    [anon_sym_AMP_AMP] = ACTIONS(592),
    [anon_sym_PIPE_PIPE] = ACTIONS(592),
    [anon_sym_DOT_SQUOTE] = ACTIONS(592),
    [anon_sym_SQUOTE] = ACTIONS(592),
    [anon_sym_LBRACK] = ACTIONS(592),
    [anon_sym_LF] = ACTIONS(592),
    [anon_sym_LBRACE] = ACTIONS(592),
    [anon_sym_COLON] = ACTIONS(592),
    [anon_sym_return] = ACTIONS(592),
    [anon_sym_continue] = ACTIONS(592),
    [anon_sym_break] = ACTIONS(592),
    [anon_sym_elseif] = ACTIONS(592),
    [anon_sym_else] = ACTIONS(592),
    [anon_sym_if] = ACTIONS(592),
    [anon_sym_end] = ACTIONS(592),
    [anon_sym_for] = ACTIONS(592),
    [anon_sym_parfor] = ACTIONS(592),
    [anon_sym_while] = ACTIONS(592),
    [anon_sym_switch] = ACTIONS(592),
    [anon_sym_global] = ACTIONS(592),
    [anon_sym_persistent] = ACTIONS(592),
    [anon_sym_arguments] = ACTIONS(592),
    [anon_sym_function] = ACTIONS(592),
    [anon_sym_properties] = ACTIONS(592),
    [anon_sym_get] = ACTIONS(592),
    [anon_sym_set] = ACTIONS(592),
    [anon_sym_methods] = ACTIONS(592),
    [anon_sym_events] = ACTIONS(592),
    [anon_sym_enumeration] = ACTIONS(592),
    [anon_sym_classdef] = ACTIONS(592),
    [anon_sym_try] = ACTIONS(592),
    [anon_sym_spmd] = ACTIONS(592),
    [aux_sym_number_token1] = ACTIONS(592),
    [aux_sym_number_token2] = ACTIONS(592),
    [aux_sym_number_token3] = ACTIONS(592),
    [anon_sym_true] = ACTIONS(592),
    [anon_sym_false] = ACTIONS(592),
    [anon_sym_CR] = ACTIONS(592),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(598),
    [sym__single_quote_string_start] = ACTIONS(598),
    [sym__double_quote_string_start] = ACTIONS(598),
    [sym__multioutput_variable_start] = ACTIONS(598),
    [sym__external_identifier] = ACTIONS(598),
  },
  [STATE(126)] = {
    [anon_sym_SEMI] = ACTIONS(610),
    [anon_sym_COMMA] = ACTIONS(610),
    [anon_sym_LPAREN] = ACTIONS(610),
    [anon_sym_PLUS] = ACTIONS(610),
    [anon_sym_DOT_PLUS] = ACTIONS(610),
    [anon_sym_DASH] = ACTIONS(610),
    [anon_sym_DOT_DASH] = ACTIONS(610),
    [anon_sym_STAR] = ACTIONS(610),
    [anon_sym_DOT_STAR] = ACTIONS(610),
    [anon_sym_SLASH] = ACTIONS(610),
    [anon_sym_DOT_SLASH] = ACTIONS(610),
    [anon_sym_BSLASH] = ACTIONS(610),
    [anon_sym_DOT_BSLASH] = ACTIONS(610),
    [anon_sym_CARET] = ACTIONS(610),
    [anon_sym_DOT_CARET] = ACTIONS(610),
    [anon_sym_PIPE] = ACTIONS(610),
    [anon_sym_AMP] = ACTIONS(610),
    [anon_sym_TILDE] = ACTIONS(610),
    [anon_sym_QMARK] = ACTIONS(610),
    [anon_sym_AT] = ACTIONS(610),
    [anon_sym_LT] = ACTIONS(610),
    [anon_sym_LT_EQ] = ACTIONS(610),
    [anon_sym_EQ_EQ] = ACTIONS(610),
    [anon_sym_TILDE_EQ] = ACTIONS(610),
    [anon_sym_GT_EQ] = ACTIONS(610),
    [anon_sym_GT] = ACTIONS(610),
    [anon_sym_AMP_AMP] = ACTIONS(610),
    [anon_sym_PIPE_PIPE] = ACTIONS(610),
    [anon_sym_DOT_SQUOTE] = ACTIONS(610),
    [anon_sym_SQUOTE] = ACTIONS(610),
    [anon_sym_LBRACK] = ACTIONS(610),
    [anon_sym_LF] = ACTIONS(610),
    [anon_sym_LBRACE] = ACTIONS(610),
    [anon_sym_COLON] = ACTIONS(612),
    [anon_sym_return] = ACTIONS(610),
    [anon_sym_continue] = ACTIONS(610),
    [anon_sym_break] = ACTIONS(610),
    [anon_sym_elseif] = ACTIONS(610),
    [anon_sym_else] = ACTIONS(610),
    [anon_sym_if] = ACTIONS(610),
    [anon_sym_end] = ACTIONS(610),
    [anon_sym_for] = ACTIONS(610),
    [anon_sym_parfor] = ACTIONS(610),
    [anon_sym_while] = ACTIONS(610),
    [anon_sym_switch] = ACTIONS(610),
    [anon_sym_global] = ACTIONS(610),
    [anon_sym_persistent] = ACTIONS(610),
    [anon_sym_arguments] = ACTIONS(610),
    [anon_sym_function] = ACTIONS(610),
    [anon_sym_properties] = ACTIONS(610),
    [anon_sym_get] = ACTIONS(610),
    [anon_sym_set] = ACTIONS(610),
    [anon_sym_methods] = ACTIONS(610),
    [anon_sym_events] = ACTIONS(610),
    [anon_sym_enumeration] = ACTIONS(610),
    [anon_sym_classdef] = ACTIONS(610),
    [anon_sym_try] = ACTIONS(610),
    [anon_sym_spmd] = ACTIONS(610),
    [aux_sym_number_token1] = ACTIONS(610),
    [aux_sym_number_token2] = ACTIONS(610),
    [aux_sym_number_token3] = ACTIONS(610),
    [anon_sym_true] = ACTIONS(610),
    [anon_sym_false] = ACTIONS(610),
    [anon_sym_CR] = ACTIONS(610),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(614),
    [sym__single_quote_string_start] = ACTIONS(614),
    [sym__double_quote_string_start] = ACTIONS(614),
    [sym__multioutput_variable_start] = ACTIONS(614),
    [sym__external_identifier] = ACTIONS(614),
  },
  [STATE(127)] = {
    [anon_sym_SEMI] = ACTIONS(616),
    [anon_sym_COMMA] = ACTIONS(616),
    [anon_sym_LPAREN] = ACTIONS(616),
    [anon_sym_PLUS] = ACTIONS(616),
    [anon_sym_DOT_PLUS] = ACTIONS(616),
    [anon_sym_DASH] = ACTIONS(616),
    [anon_sym_DOT_DASH] = ACTIONS(616),
    [anon_sym_STAR] = ACTIONS(616),
    [anon_sym_DOT_STAR] = ACTIONS(616),
    [anon_sym_SLASH] = ACTIONS(616),
    [anon_sym_DOT_SLASH] = ACTIONS(616),
    [anon_sym_BSLASH] = ACTIONS(616),
    [anon_sym_DOT_BSLASH] = ACTIONS(616),
    [anon_sym_CARET] = ACTIONS(616),
    [anon_sym_DOT_CARET] = ACTIONS(616),
    [anon_sym_PIPE] = ACTIONS(616),
    [anon_sym_AMP] = ACTIONS(616),
    [anon_sym_TILDE] = ACTIONS(616),
    [anon_sym_QMARK] = ACTIONS(616),
    [anon_sym_AT] = ACTIONS(616),
    [anon_sym_LT] = ACTIONS(616),
    [anon_sym_LT_EQ] = ACTIONS(616),
    [anon_sym_EQ_EQ] = ACTIONS(616),
    [anon_sym_TILDE_EQ] = ACTIONS(616),
    [anon_sym_GT_EQ] = ACTIONS(616),
    [anon_sym_GT] = ACTIONS(616),
    [anon_sym_AMP_AMP] = ACTIONS(616),
    [anon_sym_PIPE_PIPE] = ACTIONS(616),
    [anon_sym_DOT_SQUOTE] = ACTIONS(616),
    [anon_sym_SQUOTE] = ACTIONS(616),
    [anon_sym_LBRACK] = ACTIONS(616),
    [anon_sym_LF] = ACTIONS(616),
    [anon_sym_LBRACE] = ACTIONS(616),
    [anon_sym_COLON] = ACTIONS(616),
    [anon_sym_return] = ACTIONS(616),
    [anon_sym_continue] = ACTIONS(616),
    [anon_sym_break] = ACTIONS(616),
    [anon_sym_elseif] = ACTIONS(616),
    [anon_sym_else] = ACTIONS(616),
    [anon_sym_if] = ACTIONS(616),
    [anon_sym_end] = ACTIONS(616),
    [anon_sym_for] = ACTIONS(616),
    [anon_sym_parfor] = ACTIONS(616),
    [anon_sym_while] = ACTIONS(616),
    [anon_sym_switch] = ACTIONS(616),
    [anon_sym_global] = ACTIONS(616),
    [anon_sym_persistent] = ACTIONS(616),
    [anon_sym_arguments] = ACTIONS(616),
    [anon_sym_function] = ACTIONS(616),
    [anon_sym_properties] = ACTIONS(616),
    [anon_sym_get] = ACTIONS(616),
    [anon_sym_set] = ACTIONS(616),
    [anon_sym_methods] = ACTIONS(616),
    [anon_sym_events] = ACTIONS(616),
    [anon_sym_enumeration] = ACTIONS(616),
    [anon_sym_classdef] = ACTIONS(616),
    [anon_sym_try] = ACTIONS(616),
    [anon_sym_spmd] = ACTIONS(616),
    [aux_sym_number_token1] = ACTIONS(616),
    [aux_sym_number_token2] = ACTIONS(616),
    [aux_sym_number_token3] = ACTIONS(616),
    [anon_sym_true] = ACTIONS(616),
    [anon_sym_false] = ACTIONS(616),
    [anon_sym_CR] = ACTIONS(616),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(618),
    [sym__single_quote_string_start] = ACTIONS(618),
    [sym__double_quote_string_start] = ACTIONS(618),
    [sym__multioutput_variable_start] = ACTIONS(618),
    [sym__external_identifier] = ACTIONS(618),
  },
  [STATE(128)] = {
    [anon_sym_SEMI] = ACTIONS(620),
    [anon_sym_COMMA] = ACTIONS(620),
    [anon_sym_LPAREN] = ACTIONS(620),
    [anon_sym_PLUS] = ACTIONS(620),
    [anon_sym_DOT_PLUS] = ACTIONS(620),
    [anon_sym_DASH] = ACTIONS(620),
    [anon_sym_DOT_DASH] = ACTIONS(620),
    [anon_sym_STAR] = ACTIONS(620),
    [anon_sym_DOT_STAR] = ACTIONS(620),
    [anon_sym_SLASH] = ACTIONS(620),
    [anon_sym_DOT_SLASH] = ACTIONS(620),
    [anon_sym_BSLASH] = ACTIONS(620),
    [anon_sym_DOT_BSLASH] = ACTIONS(620),
    [anon_sym_CARET] = ACTIONS(620),
    [anon_sym_DOT_CARET] = ACTIONS(620),
    [anon_sym_PIPE] = ACTIONS(620),
    [anon_sym_AMP] = ACTIONS(620),
    [anon_sym_TILDE] = ACTIONS(620),
    [anon_sym_QMARK] = ACTIONS(620),
    [anon_sym_AT] = ACTIONS(620),
    [anon_sym_LT] = ACTIONS(620),
    [anon_sym_LT_EQ] = ACTIONS(620),
    [anon_sym_EQ_EQ] = ACTIONS(620),
    [anon_sym_TILDE_EQ] = ACTIONS(620),
    [anon_sym_GT_EQ] = ACTIONS(620),
    [anon_sym_GT] = ACTIONS(620),
    [anon_sym_AMP_AMP] = ACTIONS(620),
    [anon_sym_PIPE_PIPE] = ACTIONS(620),
    [anon_sym_DOT_SQUOTE] = ACTIONS(620),
    [anon_sym_SQUOTE] = ACTIONS(620),
    [anon_sym_LBRACK] = ACTIONS(620),
    [anon_sym_LF] = ACTIONS(620),
    [anon_sym_LBRACE] = ACTIONS(620),
    [anon_sym_COLON] = ACTIONS(620),
    [anon_sym_return] = ACTIONS(620),
    [anon_sym_continue] = ACTIONS(620),
    [anon_sym_break] = ACTIONS(620),
    [anon_sym_elseif] = ACTIONS(620),
    [anon_sym_else] = ACTIONS(620),
    [anon_sym_if] = ACTIONS(620),
    [anon_sym_end] = ACTIONS(620),
    [anon_sym_for] = ACTIONS(620),
    [anon_sym_parfor] = ACTIONS(620),
    [anon_sym_while] = ACTIONS(620),
    [anon_sym_switch] = ACTIONS(620),
    [anon_sym_global] = ACTIONS(620),
    [anon_sym_persistent] = ACTIONS(620),
    [anon_sym_arguments] = ACTIONS(620),
    [anon_sym_function] = ACTIONS(620),
    [anon_sym_properties] = ACTIONS(620),
    [anon_sym_get] = ACTIONS(620),
    [anon_sym_set] = ACTIONS(620),
    [anon_sym_methods] = ACTIONS(620),
    [anon_sym_events] = ACTIONS(620),
    [anon_sym_enumeration] = ACTIONS(620),
    [anon_sym_classdef] = ACTIONS(620),
    [anon_sym_try] = ACTIONS(620),
    [anon_sym_spmd] = ACTIONS(620),
    [aux_sym_number_token1] = ACTIONS(620),
    [aux_sym_number_token2] = ACTIONS(620),
    [aux_sym_number_token3] = ACTIONS(620),
    [anon_sym_true] = ACTIONS(620),
    [anon_sym_false] = ACTIONS(620),
    [anon_sym_CR] = ACTIONS(620),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(622),
    [sym__single_quote_string_start] = ACTIONS(622),
    [sym__double_quote_string_start] = ACTIONS(622),
    [sym__multioutput_variable_start] = ACTIONS(622),
    [sym__external_identifier] = ACTIONS(622),
  },
  [STATE(129)] = {
    [anon_sym_SEMI] = ACTIONS(624),
    [anon_sym_COMMA] = ACTIONS(624),
    [anon_sym_LPAREN] = ACTIONS(624),
    [anon_sym_PLUS] = ACTIONS(624),
    [anon_sym_DOT_PLUS] = ACTIONS(624),
    [anon_sym_DASH] = ACTIONS(624),
    [anon_sym_DOT_DASH] = ACTIONS(624),
    [anon_sym_STAR] = ACTIONS(624),
    [anon_sym_DOT_STAR] = ACTIONS(624),
    [anon_sym_SLASH] = ACTIONS(624),
    [anon_sym_DOT_SLASH] = ACTIONS(624),
    [anon_sym_BSLASH] = ACTIONS(624),
    [anon_sym_DOT_BSLASH] = ACTIONS(624),
    [anon_sym_CARET] = ACTIONS(624),
    [anon_sym_DOT_CARET] = ACTIONS(624),
    [anon_sym_PIPE] = ACTIONS(624),
    [anon_sym_AMP] = ACTIONS(624),
    [anon_sym_TILDE] = ACTIONS(624),
    [anon_sym_QMARK] = ACTIONS(624),
    [anon_sym_AT] = ACTIONS(624),
    [anon_sym_LT] = ACTIONS(624),
    [anon_sym_LT_EQ] = ACTIONS(624),
    [anon_sym_EQ_EQ] = ACTIONS(624),
    [anon_sym_TILDE_EQ] = ACTIONS(624),
    [anon_sym_GT_EQ] = ACTIONS(624),
    [anon_sym_GT] = ACTIONS(624),
    [anon_sym_AMP_AMP] = ACTIONS(624),
    [anon_sym_PIPE_PIPE] = ACTIONS(624),
    [anon_sym_DOT_SQUOTE] = ACTIONS(624),
    [anon_sym_SQUOTE] = ACTIONS(624),
    [anon_sym_LBRACK] = ACTIONS(624),
    [anon_sym_LF] = ACTIONS(624),
    [anon_sym_LBRACE] = ACTIONS(624),
    [anon_sym_COLON] = ACTIONS(624),
    [anon_sym_return] = ACTIONS(624),
    [anon_sym_continue] = ACTIONS(624),
    [anon_sym_break] = ACTIONS(624),
    [anon_sym_elseif] = ACTIONS(624),
    [anon_sym_else] = ACTIONS(624),
    [anon_sym_if] = ACTIONS(624),
    [anon_sym_end] = ACTIONS(624),
    [anon_sym_for] = ACTIONS(624),
    [anon_sym_parfor] = ACTIONS(624),
    [anon_sym_while] = ACTIONS(624),
    [anon_sym_switch] = ACTIONS(624),
    [anon_sym_global] = ACTIONS(624),
    [anon_sym_persistent] = ACTIONS(624),
    [anon_sym_arguments] = ACTIONS(624),
    [anon_sym_function] = ACTIONS(624),
    [anon_sym_properties] = ACTIONS(624),
    [anon_sym_get] = ACTIONS(624),
    [anon_sym_set] = ACTIONS(624),
    [anon_sym_methods] = ACTIONS(624),
    [anon_sym_events] = ACTIONS(624),
    [anon_sym_enumeration] = ACTIONS(624),
    [anon_sym_classdef] = ACTIONS(624),
    [anon_sym_try] = ACTIONS(624),
    [anon_sym_spmd] = ACTIONS(624),
    [aux_sym_number_token1] = ACTIONS(624),
    [aux_sym_number_token2] = ACTIONS(624),
    [aux_sym_number_token3] = ACTIONS(624),
    [anon_sym_true] = ACTIONS(624),
    [anon_sym_false] = ACTIONS(624),
    [anon_sym_CR] = ACTIONS(624),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(626),
    [sym__single_quote_string_start] = ACTIONS(626),
    [sym__double_quote_string_start] = ACTIONS(626),
    [sym__multioutput_variable_start] = ACTIONS(626),
    [sym__external_identifier] = ACTIONS(626),
  },
  [STATE(130)] = {
    [anon_sym_SEMI] = ACTIONS(628),
    [anon_sym_COMMA] = ACTIONS(628),
    [anon_sym_LPAREN] = ACTIONS(628),
    [anon_sym_PLUS] = ACTIONS(628),
    [anon_sym_DOT_PLUS] = ACTIONS(628),
    [anon_sym_DASH] = ACTIONS(628),
    [anon_sym_DOT_DASH] = ACTIONS(628),
    [anon_sym_STAR] = ACTIONS(628),
    [anon_sym_DOT_STAR] = ACTIONS(628),
    [anon_sym_SLASH] = ACTIONS(628),
    [anon_sym_DOT_SLASH] = ACTIONS(628),
    [anon_sym_BSLASH] = ACTIONS(628),
    [anon_sym_DOT_BSLASH] = ACTIONS(628),
    [anon_sym_CARET] = ACTIONS(628),
    [anon_sym_DOT_CARET] = ACTIONS(628),
    [anon_sym_PIPE] = ACTIONS(628),
    [anon_sym_AMP] = ACTIONS(628),
    [anon_sym_TILDE] = ACTIONS(628),
    [anon_sym_QMARK] = ACTIONS(628),
    [anon_sym_AT] = ACTIONS(628),
    [anon_sym_LT] = ACTIONS(628),
    [anon_sym_LT_EQ] = ACTIONS(628),
    [anon_sym_EQ_EQ] = ACTIONS(628),
    [anon_sym_TILDE_EQ] = ACTIONS(628),
    [anon_sym_GT_EQ] = ACTIONS(628),
    [anon_sym_GT] = ACTIONS(628),
    [anon_sym_AMP_AMP] = ACTIONS(628),
    [anon_sym_PIPE_PIPE] = ACTIONS(628),
    [anon_sym_DOT_SQUOTE] = ACTIONS(628),
    [anon_sym_SQUOTE] = ACTIONS(628),
    [anon_sym_LBRACK] = ACTIONS(628),
    [anon_sym_LF] = ACTIONS(628),
    [anon_sym_LBRACE] = ACTIONS(628),
    [anon_sym_COLON] = ACTIONS(628),
    [anon_sym_return] = ACTIONS(628),
    [anon_sym_continue] = ACTIONS(628),
    [anon_sym_break] = ACTIONS(628),
    [anon_sym_elseif] = ACTIONS(628),
    [anon_sym_else] = ACTIONS(628),
    [anon_sym_if] = ACTIONS(628),
    [anon_sym_end] = ACTIONS(628),
    [anon_sym_for] = ACTIONS(628),
    [anon_sym_parfor] = ACTIONS(628),
    [anon_sym_while] = ACTIONS(628),
    [anon_sym_switch] = ACTIONS(628),
    [anon_sym_global] = ACTIONS(628),
    [anon_sym_persistent] = ACTIONS(628),
    [anon_sym_arguments] = ACTIONS(628),
    [anon_sym_function] = ACTIONS(628),
    [anon_sym_properties] = ACTIONS(628),
    [anon_sym_get] = ACTIONS(628),
    [anon_sym_set] = ACTIONS(628),
    [anon_sym_methods] = ACTIONS(628),
    [anon_sym_events] = ACTIONS(628),
    [anon_sym_enumeration] = ACTIONS(628),
    [anon_sym_classdef] = ACTIONS(628),
    [anon_sym_try] = ACTIONS(628),
    [anon_sym_spmd] = ACTIONS(628),
    [aux_sym_number_token1] = ACTIONS(628),
    [aux_sym_number_token2] = ACTIONS(628),
    [aux_sym_number_token3] = ACTIONS(628),
    [anon_sym_true] = ACTIONS(628),
    [anon_sym_false] = ACTIONS(628),
    [anon_sym_CR] = ACTIONS(628),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(630),
    [sym__single_quote_string_start] = ACTIONS(630),
    [sym__double_quote_string_start] = ACTIONS(630),
    [sym__multioutput_variable_start] = ACTIONS(630),
    [sym__external_identifier] = ACTIONS(630),
  },
  [STATE(131)] = {
    [anon_sym_SEMI] = ACTIONS(632),
    [anon_sym_COMMA] = ACTIONS(632),
    [anon_sym_LPAREN] = ACTIONS(632),
    [anon_sym_PLUS] = ACTIONS(632),
    [anon_sym_DOT_PLUS] = ACTIONS(632),
    [anon_sym_DASH] = ACTIONS(632),
    [anon_sym_DOT_DASH] = ACTIONS(632),
    [anon_sym_STAR] = ACTIONS(632),
    [anon_sym_DOT_STAR] = ACTIONS(632),
    [anon_sym_SLASH] = ACTIONS(632),
    [anon_sym_DOT_SLASH] = ACTIONS(632),
    [anon_sym_BSLASH] = ACTIONS(632),
    [anon_sym_DOT_BSLASH] = ACTIONS(632),
    [anon_sym_CARET] = ACTIONS(632),
    [anon_sym_DOT_CARET] = ACTIONS(632),
    [anon_sym_PIPE] = ACTIONS(632),
    [anon_sym_AMP] = ACTIONS(632),
    [anon_sym_TILDE] = ACTIONS(632),
    [anon_sym_QMARK] = ACTIONS(632),
    [anon_sym_AT] = ACTIONS(632),
    [anon_sym_LT] = ACTIONS(634),
    [anon_sym_LT_EQ] = ACTIONS(634),
    [anon_sym_EQ_EQ] = ACTIONS(634),
    [anon_sym_TILDE_EQ] = ACTIONS(634),
    [anon_sym_GT_EQ] = ACTIONS(634),
    [anon_sym_GT] = ACTIONS(634),
    [anon_sym_AMP_AMP] = ACTIONS(634),
    [anon_sym_PIPE_PIPE] = ACTIONS(634),
    [anon_sym_DOT_SQUOTE] = ACTIONS(632),
    [anon_sym_SQUOTE] = ACTIONS(632),
    [anon_sym_LBRACK] = ACTIONS(632),
    [anon_sym_LF] = ACTIONS(632),
    [anon_sym_LBRACE] = ACTIONS(632),
    [anon_sym_COLON] = ACTIONS(637),
    [anon_sym_return] = ACTIONS(632),
    [anon_sym_continue] = ACTIONS(632),
    [anon_sym_break] = ACTIONS(632),
    [anon_sym_elseif] = ACTIONS(632),
    [anon_sym_else] = ACTIONS(632),
    [anon_sym_if] = ACTIONS(632),
    [anon_sym_end] = ACTIONS(632),
    [anon_sym_for] = ACTIONS(632),
    [anon_sym_parfor] = ACTIONS(632),
    [anon_sym_while] = ACTIONS(632),
    [anon_sym_switch] = ACTIONS(632),
    [anon_sym_global] = ACTIONS(632),
    [anon_sym_persistent] = ACTIONS(632),
    [anon_sym_arguments] = ACTIONS(632),
    [anon_sym_function] = ACTIONS(632),
    [anon_sym_properties] = ACTIONS(632),
    [anon_sym_get] = ACTIONS(632),
    [anon_sym_set] = ACTIONS(632),
    [anon_sym_methods] = ACTIONS(632),
    [anon_sym_events] = ACTIONS(632),
    [anon_sym_enumeration] = ACTIONS(632),
    [anon_sym_classdef] = ACTIONS(632),
    [anon_sym_try] = ACTIONS(632),
    [anon_sym_spmd] = ACTIONS(632),
    [aux_sym_number_token1] = ACTIONS(632),
    [aux_sym_number_token2] = ACTIONS(632),
    [aux_sym_number_token3] = ACTIONS(632),
    [anon_sym_true] = ACTIONS(632),
    [anon_sym_false] = ACTIONS(632),
    [anon_sym_CR] = ACTIONS(632),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(639),
    [sym__single_quote_string_start] = ACTIONS(639),
    [sym__double_quote_string_start] = ACTIONS(639),
    [sym__multioutput_variable_start] = ACTIONS(639),
    [sym__external_identifier] = ACTIONS(639),
  },
  [STATE(132)] = {
    [anon_sym_SEMI] = ACTIONS(449),
    [anon_sym_COMMA] = ACTIONS(449),
    [anon_sym_LPAREN] = ACTIONS(449),
    [anon_sym_PLUS] = ACTIONS(451),
    [anon_sym_DOT_PLUS] = ACTIONS(451),
    [anon_sym_DASH] = ACTIONS(451),
    [anon_sym_DOT_DASH] = ACTIONS(451),
    [anon_sym_STAR] = ACTIONS(451),
    [anon_sym_DOT_STAR] = ACTIONS(451),
    [anon_sym_SLASH] = ACTIONS(451),
    [anon_sym_DOT_SLASH] = ACTIONS(451),
    [anon_sym_BSLASH] = ACTIONS(451),
    [anon_sym_DOT_BSLASH] = ACTIONS(451),
    [anon_sym_CARET] = ACTIONS(451),
    [anon_sym_DOT_CARET] = ACTIONS(451),
    [anon_sym_PIPE] = ACTIONS(451),
    [anon_sym_AMP] = ACTIONS(451),
    [anon_sym_TILDE] = ACTIONS(449),
    [anon_sym_QMARK] = ACTIONS(449),
    [anon_sym_AT] = ACTIONS(449),
    [anon_sym_LT] = ACTIONS(449),
    [anon_sym_LT_EQ] = ACTIONS(449),
    [anon_sym_EQ_EQ] = ACTIONS(449),
    [anon_sym_TILDE_EQ] = ACTIONS(449),
    [anon_sym_GT_EQ] = ACTIONS(449),
    [anon_sym_GT] = ACTIONS(449),
    [anon_sym_AMP_AMP] = ACTIONS(449),
    [anon_sym_PIPE_PIPE] = ACTIONS(449),
    [anon_sym_DOT_SQUOTE] = ACTIONS(443),
    [anon_sym_SQUOTE] = ACTIONS(443),
    [anon_sym_LBRACK] = ACTIONS(449),
    [anon_sym_LF] = ACTIONS(449),
    [anon_sym_LBRACE] = ACTIONS(449),
    [anon_sym_COLON] = ACTIONS(458),
    [anon_sym_return] = ACTIONS(449),
    [anon_sym_continue] = ACTIONS(449),
    [anon_sym_break] = ACTIONS(449),
    [anon_sym_elseif] = ACTIONS(449),
    [anon_sym_else] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(449),
    [anon_sym_end] = ACTIONS(449),
    [anon_sym_for] = ACTIONS(449),
    [anon_sym_parfor] = ACTIONS(449),
    [anon_sym_while] = ACTIONS(449),
    [anon_sym_switch] = ACTIONS(449),
    [anon_sym_global] = ACTIONS(449),
    [anon_sym_persistent] = ACTIONS(449),
    [anon_sym_arguments] = ACTIONS(449),
    [anon_sym_function] = ACTIONS(449),
    [anon_sym_properties] = ACTIONS(449),
    [anon_sym_get] = ACTIONS(449),
    [anon_sym_set] = ACTIONS(449),
    [anon_sym_methods] = ACTIONS(449),
    [anon_sym_events] = ACTIONS(449),
    [anon_sym_enumeration] = ACTIONS(449),
    [anon_sym_classdef] = ACTIONS(449),
    [anon_sym_try] = ACTIONS(449),
    [anon_sym_spmd] = ACTIONS(449),
    [aux_sym_number_token1] = ACTIONS(449),
    [aux_sym_number_token2] = ACTIONS(449),
    [aux_sym_number_token3] = ACTIONS(449),
    [anon_sym_true] = ACTIONS(449),
    [anon_sym_false] = ACTIONS(449),
    [anon_sym_CR] = ACTIONS(449),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(456),
    [sym__single_quote_string_start] = ACTIONS(456),
    [sym__double_quote_string_start] = ACTIONS(456),
    [sym__multioutput_variable_start] = ACTIONS(456),
    [sym__external_identifier] = ACTIONS(456),
  },
  [STATE(133)] = {
    [anon_sym_SEMI] = ACTIONS(449),
    [anon_sym_COMMA] = ACTIONS(449),
    [anon_sym_LPAREN] = ACTIONS(449),
    [anon_sym_PLUS] = ACTIONS(451),
    [anon_sym_DOT_PLUS] = ACTIONS(451),
    [anon_sym_DASH] = ACTIONS(451),
    [anon_sym_DOT_DASH] = ACTIONS(451),
    [anon_sym_STAR] = ACTIONS(451),
    [anon_sym_DOT_STAR] = ACTIONS(451),
    [anon_sym_SLASH] = ACTIONS(451),
    [anon_sym_DOT_SLASH] = ACTIONS(451),
    [anon_sym_BSLASH] = ACTIONS(451),
    [anon_sym_DOT_BSLASH] = ACTIONS(451),
    [anon_sym_CARET] = ACTIONS(451),
    [anon_sym_DOT_CARET] = ACTIONS(451),
    [anon_sym_PIPE] = ACTIONS(451),
    [anon_sym_AMP] = ACTIONS(451),
    [anon_sym_TILDE] = ACTIONS(449),
    [anon_sym_QMARK] = ACTIONS(449),
    [anon_sym_AT] = ACTIONS(449),
    [anon_sym_LT] = ACTIONS(449),
    [anon_sym_LT_EQ] = ACTIONS(449),
    [anon_sym_EQ_EQ] = ACTIONS(449),
    [anon_sym_TILDE_EQ] = ACTIONS(449),
    [anon_sym_GT_EQ] = ACTIONS(449),
    [anon_sym_GT] = ACTIONS(449),
    [anon_sym_AMP_AMP] = ACTIONS(449),
    [anon_sym_PIPE_PIPE] = ACTIONS(449),
    [anon_sym_DOT_SQUOTE] = ACTIONS(443),
    [anon_sym_SQUOTE] = ACTIONS(443),
    [anon_sym_LBRACK] = ACTIONS(449),
    [anon_sym_LF] = ACTIONS(449),
    [anon_sym_LBRACE] = ACTIONS(449),
    [anon_sym_COLON] = ACTIONS(641),
    [anon_sym_return] = ACTIONS(449),
    [anon_sym_continue] = ACTIONS(449),
    [anon_sym_break] = ACTIONS(449),
    [anon_sym_elseif] = ACTIONS(449),
    [anon_sym_else] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(449),
    [anon_sym_end] = ACTIONS(449),
    [anon_sym_for] = ACTIONS(449),
    [anon_sym_parfor] = ACTIONS(449),
    [anon_sym_while] = ACTIONS(449),
    [anon_sym_switch] = ACTIONS(449),
    [anon_sym_global] = ACTIONS(449),
    [anon_sym_persistent] = ACTIONS(449),
    [anon_sym_arguments] = ACTIONS(449),
    [anon_sym_function] = ACTIONS(449),
    [anon_sym_properties] = ACTIONS(449),
    [anon_sym_get] = ACTIONS(449),
    [anon_sym_set] = ACTIONS(449),
    [anon_sym_methods] = ACTIONS(449),
    [anon_sym_events] = ACTIONS(449),
    [anon_sym_enumeration] = ACTIONS(449),
    [anon_sym_classdef] = ACTIONS(449),
    [anon_sym_try] = ACTIONS(449),
    [anon_sym_spmd] = ACTIONS(449),
    [aux_sym_number_token1] = ACTIONS(449),
    [aux_sym_number_token2] = ACTIONS(449),
    [aux_sym_number_token3] = ACTIONS(449),
    [anon_sym_true] = ACTIONS(449),
    [anon_sym_false] = ACTIONS(449),
    [anon_sym_CR] = ACTIONS(449),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(456),
    [sym__single_quote_string_start] = ACTIONS(456),
    [sym__double_quote_string_start] = ACTIONS(456),
    [sym__multioutput_variable_start] = ACTIONS(456),
    [sym__external_identifier] = ACTIONS(456),
  },
  [STATE(134)] = {
    [anon_sym_SEMI] = ACTIONS(449),
    [anon_sym_COMMA] = ACTIONS(449),
    [anon_sym_LPAREN] = ACTIONS(449),
    [anon_sym_PLUS] = ACTIONS(451),
    [anon_sym_DOT_PLUS] = ACTIONS(451),
    [anon_sym_DASH] = ACTIONS(451),
    [anon_sym_DOT_DASH] = ACTIONS(451),
    [anon_sym_STAR] = ACTIONS(451),
    [anon_sym_DOT_STAR] = ACTIONS(451),
    [anon_sym_SLASH] = ACTIONS(451),
    [anon_sym_DOT_SLASH] = ACTIONS(451),
    [anon_sym_BSLASH] = ACTIONS(451),
    [anon_sym_DOT_BSLASH] = ACTIONS(451),
    [anon_sym_CARET] = ACTIONS(451),
    [anon_sym_DOT_CARET] = ACTIONS(451),
    [anon_sym_PIPE] = ACTIONS(451),
    [anon_sym_AMP] = ACTIONS(451),
    [anon_sym_TILDE] = ACTIONS(449),
    [anon_sym_QMARK] = ACTIONS(449),
    [anon_sym_AT] = ACTIONS(449),
    [anon_sym_LT] = ACTIONS(449),
    [anon_sym_LT_EQ] = ACTIONS(449),
    [anon_sym_EQ_EQ] = ACTIONS(449),
    [anon_sym_TILDE_EQ] = ACTIONS(449),
    [anon_sym_GT_EQ] = ACTIONS(449),
    [anon_sym_GT] = ACTIONS(449),
    [anon_sym_AMP_AMP] = ACTIONS(449),
    [anon_sym_PIPE_PIPE] = ACTIONS(449),
    [anon_sym_DOT_SQUOTE] = ACTIONS(443),
    [anon_sym_SQUOTE] = ACTIONS(443),
    [anon_sym_LBRACK] = ACTIONS(449),
    [anon_sym_LF] = ACTIONS(449),
    [anon_sym_LBRACE] = ACTIONS(449),
    [anon_sym_COLON] = ACTIONS(643),
    [anon_sym_return] = ACTIONS(449),
    [anon_sym_continue] = ACTIONS(449),
    [anon_sym_break] = ACTIONS(449),
    [anon_sym_elseif] = ACTIONS(449),
    [anon_sym_else] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(449),
    [anon_sym_end] = ACTIONS(449),
    [anon_sym_for] = ACTIONS(449),
    [anon_sym_parfor] = ACTIONS(449),
    [anon_sym_while] = ACTIONS(449),
    [anon_sym_switch] = ACTIONS(449),
    [anon_sym_global] = ACTIONS(449),
    [anon_sym_persistent] = ACTIONS(449),
    [anon_sym_arguments] = ACTIONS(449),
    [anon_sym_function] = ACTIONS(449),
    [anon_sym_properties] = ACTIONS(449),
    [anon_sym_get] = ACTIONS(449),
    [anon_sym_set] = ACTIONS(449),
    [anon_sym_methods] = ACTIONS(449),
    [anon_sym_events] = ACTIONS(449),
    [anon_sym_enumeration] = ACTIONS(449),
    [anon_sym_classdef] = ACTIONS(449),
    [anon_sym_try] = ACTIONS(449),
    [anon_sym_spmd] = ACTIONS(449),
    [aux_sym_number_token1] = ACTIONS(449),
    [aux_sym_number_token2] = ACTIONS(449),
    [aux_sym_number_token3] = ACTIONS(449),
    [anon_sym_true] = ACTIONS(449),
    [anon_sym_false] = ACTIONS(449),
    [anon_sym_CR] = ACTIONS(449),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(456),
    [sym__single_quote_string_start] = ACTIONS(456),
    [sym__double_quote_string_start] = ACTIONS(456),
    [sym__multioutput_variable_start] = ACTIONS(456),
    [sym__external_identifier] = ACTIONS(456),
  },
  [STATE(135)] = {
    [anon_sym_SEMI] = ACTIONS(449),
    [anon_sym_COMMA] = ACTIONS(449),
    [anon_sym_LPAREN] = ACTIONS(449),
    [anon_sym_PLUS] = ACTIONS(451),
    [anon_sym_DOT_PLUS] = ACTIONS(451),
    [anon_sym_DASH] = ACTIONS(451),
    [anon_sym_DOT_DASH] = ACTIONS(451),
    [anon_sym_STAR] = ACTIONS(451),
    [anon_sym_DOT_STAR] = ACTIONS(451),
    [anon_sym_SLASH] = ACTIONS(451),
    [anon_sym_DOT_SLASH] = ACTIONS(451),
    [anon_sym_BSLASH] = ACTIONS(451),
    [anon_sym_DOT_BSLASH] = ACTIONS(451),
    [anon_sym_CARET] = ACTIONS(451),
    [anon_sym_DOT_CARET] = ACTIONS(451),
    [anon_sym_PIPE] = ACTIONS(451),
    [anon_sym_AMP] = ACTIONS(451),
    [anon_sym_TILDE] = ACTIONS(449),
    [anon_sym_QMARK] = ACTIONS(449),
    [anon_sym_AT] = ACTIONS(449),
    [anon_sym_LT] = ACTIONS(449),
    [anon_sym_LT_EQ] = ACTIONS(449),
    [anon_sym_EQ_EQ] = ACTIONS(449),
    [anon_sym_TILDE_EQ] = ACTIONS(449),
    [anon_sym_GT_EQ] = ACTIONS(449),
    [anon_sym_GT] = ACTIONS(449),
    [anon_sym_AMP_AMP] = ACTIONS(449),
    [anon_sym_PIPE_PIPE] = ACTIONS(449),
    [anon_sym_DOT_SQUOTE] = ACTIONS(443),
    [anon_sym_SQUOTE] = ACTIONS(443),
    [anon_sym_LBRACK] = ACTIONS(449),
    [anon_sym_LF] = ACTIONS(449),
    [anon_sym_LBRACE] = ACTIONS(449),
    [anon_sym_COLON] = ACTIONS(453),
    [anon_sym_return] = ACTIONS(449),
    [anon_sym_continue] = ACTIONS(449),
    [anon_sym_break] = ACTIONS(449),
    [anon_sym_elseif] = ACTIONS(449),
    [anon_sym_else] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(449),
    [anon_sym_end] = ACTIONS(449),
    [anon_sym_for] = ACTIONS(449),
    [anon_sym_parfor] = ACTIONS(449),
    [anon_sym_while] = ACTIONS(449),
    [anon_sym_switch] = ACTIONS(449),
    [anon_sym_global] = ACTIONS(449),
    [anon_sym_persistent] = ACTIONS(449),
    [anon_sym_arguments] = ACTIONS(449),
    [anon_sym_function] = ACTIONS(449),
    [anon_sym_properties] = ACTIONS(449),
    [anon_sym_get] = ACTIONS(449),
    [anon_sym_set] = ACTIONS(449),
    [anon_sym_methods] = ACTIONS(449),
    [anon_sym_events] = ACTIONS(449),
    [anon_sym_enumeration] = ACTIONS(449),
    [anon_sym_classdef] = ACTIONS(449),
    [anon_sym_try] = ACTIONS(449),
    [anon_sym_spmd] = ACTIONS(449),
    [aux_sym_number_token1] = ACTIONS(449),
    [aux_sym_number_token2] = ACTIONS(449),
    [aux_sym_number_token3] = ACTIONS(449),
    [anon_sym_true] = ACTIONS(449),
    [anon_sym_false] = ACTIONS(449),
    [anon_sym_CR] = ACTIONS(449),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(456),
    [sym__single_quote_string_start] = ACTIONS(456),
    [sym__double_quote_string_start] = ACTIONS(456),
    [sym__multioutput_variable_start] = ACTIONS(456),
    [sym__external_identifier] = ACTIONS(456),
  },
  [STATE(136)] = {
    [anon_sym_SEMI] = ACTIONS(449),
    [anon_sym_COMMA] = ACTIONS(449),
    [anon_sym_LPAREN] = ACTIONS(449),
    [anon_sym_PLUS] = ACTIONS(451),
    [anon_sym_DOT_PLUS] = ACTIONS(451),
    [anon_sym_DASH] = ACTIONS(451),
    [anon_sym_DOT_DASH] = ACTIONS(451),
    [anon_sym_STAR] = ACTIONS(451),
    [anon_sym_DOT_STAR] = ACTIONS(451),
    [anon_sym_SLASH] = ACTIONS(451),
    [anon_sym_DOT_SLASH] = ACTIONS(451),
    [anon_sym_BSLASH] = ACTIONS(451),
    [anon_sym_DOT_BSLASH] = ACTIONS(451),
    [anon_sym_CARET] = ACTIONS(451),
    [anon_sym_DOT_CARET] = ACTIONS(451),
    [anon_sym_PIPE] = ACTIONS(451),
    [anon_sym_AMP] = ACTIONS(451),
    [anon_sym_TILDE] = ACTIONS(449),
    [anon_sym_QMARK] = ACTIONS(449),
    [anon_sym_AT] = ACTIONS(449),
    [anon_sym_LT] = ACTIONS(449),
    [anon_sym_LT_EQ] = ACTIONS(449),
    [anon_sym_EQ_EQ] = ACTIONS(449),
    [anon_sym_TILDE_EQ] = ACTIONS(449),
    [anon_sym_GT_EQ] = ACTIONS(449),
    [anon_sym_GT] = ACTIONS(449),
    [anon_sym_AMP_AMP] = ACTIONS(449),
    [anon_sym_PIPE_PIPE] = ACTIONS(449),
    [anon_sym_DOT_SQUOTE] = ACTIONS(449),
    [anon_sym_SQUOTE] = ACTIONS(449),
    [anon_sym_LBRACK] = ACTIONS(449),
    [anon_sym_LF] = ACTIONS(449),
    [anon_sym_LBRACE] = ACTIONS(449),
    [anon_sym_COLON] = ACTIONS(453),
    [anon_sym_return] = ACTIONS(449),
    [anon_sym_continue] = ACTIONS(449),
    [anon_sym_break] = ACTIONS(449),
    [anon_sym_elseif] = ACTIONS(449),
    [anon_sym_else] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(449),
    [anon_sym_end] = ACTIONS(449),
    [anon_sym_for] = ACTIONS(449),
    [anon_sym_parfor] = ACTIONS(449),
    [anon_sym_while] = ACTIONS(449),
    [anon_sym_switch] = ACTIONS(449),
    [anon_sym_global] = ACTIONS(449),
    [anon_sym_persistent] = ACTIONS(449),
    [anon_sym_arguments] = ACTIONS(449),
    [anon_sym_function] = ACTIONS(449),
    [anon_sym_properties] = ACTIONS(449),
    [anon_sym_get] = ACTIONS(449),
    [anon_sym_set] = ACTIONS(449),
    [anon_sym_methods] = ACTIONS(449),
    [anon_sym_events] = ACTIONS(449),
    [anon_sym_enumeration] = ACTIONS(449),
    [anon_sym_classdef] = ACTIONS(449),
    [anon_sym_try] = ACTIONS(449),
    [anon_sym_spmd] = ACTIONS(449),
    [aux_sym_number_token1] = ACTIONS(449),
    [aux_sym_number_token2] = ACTIONS(449),
    [aux_sym_number_token3] = ACTIONS(449),
    [anon_sym_true] = ACTIONS(449),
    [anon_sym_false] = ACTIONS(449),
    [anon_sym_CR] = ACTIONS(449),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(456),
    [sym__single_quote_string_start] = ACTIONS(456),
    [sym__double_quote_string_start] = ACTIONS(456),
    [sym__multioutput_variable_start] = ACTIONS(456),
    [sym__external_identifier] = ACTIONS(456),
  },
  [STATE(137)] = {
    [anon_sym_SEMI] = ACTIONS(451),
    [anon_sym_COMMA] = ACTIONS(451),
    [anon_sym_LPAREN] = ACTIONS(451),
    [anon_sym_PLUS] = ACTIONS(451),
    [anon_sym_DOT_PLUS] = ACTIONS(451),
    [anon_sym_DASH] = ACTIONS(451),
    [anon_sym_DOT_DASH] = ACTIONS(451),
    [anon_sym_STAR] = ACTIONS(451),
    [anon_sym_DOT_STAR] = ACTIONS(451),
    [anon_sym_SLASH] = ACTIONS(451),
    [anon_sym_DOT_SLASH] = ACTIONS(451),
    [anon_sym_BSLASH] = ACTIONS(451),
    [anon_sym_DOT_BSLASH] = ACTIONS(451),
    [anon_sym_CARET] = ACTIONS(451),
    [anon_sym_DOT_CARET] = ACTIONS(451),
    [anon_sym_PIPE] = ACTIONS(451),
    [anon_sym_AMP] = ACTIONS(451),
    [anon_sym_TILDE] = ACTIONS(451),
    [anon_sym_QMARK] = ACTIONS(451),
    [anon_sym_AT] = ACTIONS(451),
    [anon_sym_LT] = ACTIONS(451),
    [anon_sym_LT_EQ] = ACTIONS(451),
    [anon_sym_EQ_EQ] = ACTIONS(451),
    [anon_sym_TILDE_EQ] = ACTIONS(451),
    [anon_sym_GT_EQ] = ACTIONS(451),
    [anon_sym_GT] = ACTIONS(451),
    [anon_sym_AMP_AMP] = ACTIONS(451),
    [anon_sym_PIPE_PIPE] = ACTIONS(451),
    [anon_sym_DOT_SQUOTE] = ACTIONS(443),
    [anon_sym_SQUOTE] = ACTIONS(443),
    [anon_sym_LBRACK] = ACTIONS(451),
    [anon_sym_LF] = ACTIONS(451),
    [anon_sym_LBRACE] = ACTIONS(451),
    [anon_sym_COLON] = ACTIONS(451),
    [anon_sym_return] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(451),
    [anon_sym_break] = ACTIONS(451),
    [anon_sym_elseif] = ACTIONS(451),
    [anon_sym_else] = ACTIONS(451),
    [anon_sym_if] = ACTIONS(451),
    [anon_sym_end] = ACTIONS(451),
    [anon_sym_for] = ACTIONS(451),
    [anon_sym_parfor] = ACTIONS(451),
    [anon_sym_while] = ACTIONS(451),
    [anon_sym_switch] = ACTIONS(451),
    [anon_sym_global] = ACTIONS(451),
    [anon_sym_persistent] = ACTIONS(451),
    [anon_sym_arguments] = ACTIONS(451),
    [anon_sym_function] = ACTIONS(451),
    [anon_sym_properties] = ACTIONS(451),
    [anon_sym_get] = ACTIONS(451),
    [anon_sym_set] = ACTIONS(451),
    [anon_sym_methods] = ACTIONS(451),
    [anon_sym_events] = ACTIONS(451),
    [anon_sym_enumeration] = ACTIONS(451),
    [anon_sym_classdef] = ACTIONS(451),
    [anon_sym_try] = ACTIONS(451),
    [anon_sym_spmd] = ACTIONS(451),
    [aux_sym_number_token1] = ACTIONS(451),
    [aux_sym_number_token2] = ACTIONS(451),
    [aux_sym_number_token3] = ACTIONS(451),
    [anon_sym_true] = ACTIONS(451),
    [anon_sym_false] = ACTIONS(451),
    [anon_sym_CR] = ACTIONS(451),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(460),
    [sym__single_quote_string_start] = ACTIONS(460),
    [sym__double_quote_string_start] = ACTIONS(460),
    [sym__multioutput_variable_start] = ACTIONS(460),
    [sym__external_identifier] = ACTIONS(460),
  },
  [STATE(138)] = {
    [anon_sym_SEMI] = ACTIONS(449),
    [anon_sym_COMMA] = ACTIONS(449),
    [anon_sym_LPAREN] = ACTIONS(449),
    [anon_sym_PLUS] = ACTIONS(451),
    [anon_sym_DOT_PLUS] = ACTIONS(451),
    [anon_sym_DASH] = ACTIONS(451),
    [anon_sym_DOT_DASH] = ACTIONS(451),
    [anon_sym_STAR] = ACTIONS(451),
    [anon_sym_DOT_STAR] = ACTIONS(451),
    [anon_sym_SLASH] = ACTIONS(451),
    [anon_sym_DOT_SLASH] = ACTIONS(451),
    [anon_sym_BSLASH] = ACTIONS(451),
    [anon_sym_DOT_BSLASH] = ACTIONS(451),
    [anon_sym_CARET] = ACTIONS(451),
    [anon_sym_DOT_CARET] = ACTIONS(451),
    [anon_sym_PIPE] = ACTIONS(451),
    [anon_sym_AMP] = ACTIONS(451),
    [anon_sym_TILDE] = ACTIONS(449),
    [anon_sym_QMARK] = ACTIONS(449),
    [anon_sym_AT] = ACTIONS(449),
    [anon_sym_LT] = ACTIONS(449),
    [anon_sym_LT_EQ] = ACTIONS(449),
    [anon_sym_EQ_EQ] = ACTIONS(449),
    [anon_sym_TILDE_EQ] = ACTIONS(449),
    [anon_sym_GT_EQ] = ACTIONS(449),
    [anon_sym_GT] = ACTIONS(449),
    [anon_sym_AMP_AMP] = ACTIONS(449),
    [anon_sym_PIPE_PIPE] = ACTIONS(449),
    [anon_sym_DOT_SQUOTE] = ACTIONS(443),
    [anon_sym_SQUOTE] = ACTIONS(443),
    [anon_sym_LBRACK] = ACTIONS(449),
    [anon_sym_LF] = ACTIONS(449),
    [anon_sym_LBRACE] = ACTIONS(449),
    [anon_sym_COLON] = ACTIONS(646),
    [anon_sym_return] = ACTIONS(449),
    [anon_sym_continue] = ACTIONS(449),
    [anon_sym_break] = ACTIONS(449),
    [anon_sym_elseif] = ACTIONS(449),
    [anon_sym_else] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(449),
    [anon_sym_end] = ACTIONS(449),
    [anon_sym_for] = ACTIONS(449),
    [anon_sym_parfor] = ACTIONS(449),
    [anon_sym_while] = ACTIONS(449),
    [anon_sym_switch] = ACTIONS(449),
    [anon_sym_global] = ACTIONS(449),
    [anon_sym_persistent] = ACTIONS(449),
    [anon_sym_arguments] = ACTIONS(449),
    [anon_sym_function] = ACTIONS(449),
    [anon_sym_properties] = ACTIONS(449),
    [anon_sym_get] = ACTIONS(449),
    [anon_sym_set] = ACTIONS(449),
    [anon_sym_methods] = ACTIONS(449),
    [anon_sym_events] = ACTIONS(449),
    [anon_sym_enumeration] = ACTIONS(449),
    [anon_sym_classdef] = ACTIONS(449),
    [anon_sym_try] = ACTIONS(449),
    [anon_sym_spmd] = ACTIONS(449),
    [aux_sym_number_token1] = ACTIONS(449),
    [aux_sym_number_token2] = ACTIONS(449),
    [aux_sym_number_token3] = ACTIONS(449),
    [anon_sym_true] = ACTIONS(449),
    [anon_sym_false] = ACTIONS(449),
    [anon_sym_CR] = ACTIONS(449),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(456),
    [sym__single_quote_string_start] = ACTIONS(456),
    [sym__double_quote_string_start] = ACTIONS(456),
    [sym__multioutput_variable_start] = ACTIONS(456),
    [sym__external_identifier] = ACTIONS(456),
  },
  [STATE(139)] = {
    [anon_sym_SEMI] = ACTIONS(451),
    [anon_sym_COMMA] = ACTIONS(451),
    [anon_sym_LPAREN] = ACTIONS(451),
    [anon_sym_PLUS] = ACTIONS(451),
    [anon_sym_DOT_PLUS] = ACTIONS(451),
    [anon_sym_DASH] = ACTIONS(451),
    [anon_sym_DOT_DASH] = ACTIONS(451),
    [anon_sym_STAR] = ACTIONS(451),
    [anon_sym_DOT_STAR] = ACTIONS(451),
    [anon_sym_SLASH] = ACTIONS(451),
    [anon_sym_DOT_SLASH] = ACTIONS(451),
    [anon_sym_BSLASH] = ACTIONS(451),
    [anon_sym_DOT_BSLASH] = ACTIONS(451),
    [anon_sym_CARET] = ACTIONS(451),
    [anon_sym_DOT_CARET] = ACTIONS(451),
    [anon_sym_PIPE] = ACTIONS(451),
    [anon_sym_AMP] = ACTIONS(451),
    [anon_sym_TILDE] = ACTIONS(451),
    [anon_sym_QMARK] = ACTIONS(451),
    [anon_sym_AT] = ACTIONS(451),
    [anon_sym_LT] = ACTIONS(451),
    [anon_sym_LT_EQ] = ACTIONS(451),
    [anon_sym_EQ_EQ] = ACTIONS(451),
    [anon_sym_TILDE_EQ] = ACTIONS(451),
    [anon_sym_GT_EQ] = ACTIONS(451),
    [anon_sym_GT] = ACTIONS(451),
    [anon_sym_AMP_AMP] = ACTIONS(451),
    [anon_sym_PIPE_PIPE] = ACTIONS(451),
    [anon_sym_DOT_SQUOTE] = ACTIONS(443),
    [anon_sym_SQUOTE] = ACTIONS(443),
    [anon_sym_LBRACK] = ACTIONS(451),
    [anon_sym_LF] = ACTIONS(451),
    [anon_sym_LBRACE] = ACTIONS(451),
    [anon_sym_COLON] = ACTIONS(451),
    [anon_sym_return] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(451),
    [anon_sym_break] = ACTIONS(451),
    [anon_sym_elseif] = ACTIONS(451),
    [anon_sym_else] = ACTIONS(451),
    [anon_sym_if] = ACTIONS(451),
    [anon_sym_end] = ACTIONS(451),
    [anon_sym_for] = ACTIONS(451),
    [anon_sym_parfor] = ACTIONS(451),
    [anon_sym_while] = ACTIONS(451),
    [anon_sym_switch] = ACTIONS(451),
    [anon_sym_global] = ACTIONS(451),
    [anon_sym_persistent] = ACTIONS(451),
    [anon_sym_arguments] = ACTIONS(451),
    [anon_sym_function] = ACTIONS(451),
    [anon_sym_properties] = ACTIONS(451),
    [anon_sym_get] = ACTIONS(451),
    [anon_sym_set] = ACTIONS(451),
    [anon_sym_methods] = ACTIONS(451),
    [anon_sym_events] = ACTIONS(451),
    [anon_sym_enumeration] = ACTIONS(451),
    [anon_sym_classdef] = ACTIONS(451),
    [anon_sym_try] = ACTIONS(451),
    [anon_sym_spmd] = ACTIONS(451),
    [aux_sym_number_token1] = ACTIONS(451),
    [aux_sym_number_token2] = ACTIONS(451),
    [aux_sym_number_token3] = ACTIONS(451),
    [anon_sym_true] = ACTIONS(451),
    [anon_sym_false] = ACTIONS(451),
    [anon_sym_CR] = ACTIONS(451),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(460),
    [sym__single_quote_string_start] = ACTIONS(460),
    [sym__double_quote_string_start] = ACTIONS(460),
    [sym__multioutput_variable_start] = ACTIONS(460),
    [sym__external_identifier] = ACTIONS(460),
  },
  [STATE(140)] = {
    [anon_sym_SEMI] = ACTIONS(451),
    [anon_sym_COMMA] = ACTIONS(451),
    [anon_sym_LPAREN] = ACTIONS(451),
    [anon_sym_PLUS] = ACTIONS(451),
    [anon_sym_DOT_PLUS] = ACTIONS(451),
    [anon_sym_DASH] = ACTIONS(451),
    [anon_sym_DOT_DASH] = ACTIONS(451),
    [anon_sym_STAR] = ACTIONS(451),
    [anon_sym_DOT_STAR] = ACTIONS(451),
    [anon_sym_SLASH] = ACTIONS(451),
    [anon_sym_DOT_SLASH] = ACTIONS(451),
    [anon_sym_BSLASH] = ACTIONS(451),
    [anon_sym_DOT_BSLASH] = ACTIONS(451),
    [anon_sym_CARET] = ACTIONS(451),
    [anon_sym_DOT_CARET] = ACTIONS(451),
    [anon_sym_PIPE] = ACTIONS(451),
    [anon_sym_AMP] = ACTIONS(451),
    [anon_sym_TILDE] = ACTIONS(451),
    [anon_sym_QMARK] = ACTIONS(451),
    [anon_sym_AT] = ACTIONS(451),
    [anon_sym_LT] = ACTIONS(451),
    [anon_sym_LT_EQ] = ACTIONS(451),
    [anon_sym_EQ_EQ] = ACTIONS(451),
    [anon_sym_TILDE_EQ] = ACTIONS(451),
    [anon_sym_GT_EQ] = ACTIONS(451),
    [anon_sym_GT] = ACTIONS(451),
    [anon_sym_AMP_AMP] = ACTIONS(451),
    [anon_sym_PIPE_PIPE] = ACTIONS(451),
    [anon_sym_DOT_SQUOTE] = ACTIONS(443),
    [anon_sym_SQUOTE] = ACTIONS(443),
    [anon_sym_LBRACK] = ACTIONS(451),
    [anon_sym_LF] = ACTIONS(451),
    [anon_sym_LBRACE] = ACTIONS(451),
    [anon_sym_COLON] = ACTIONS(451),
    [anon_sym_return] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(451),
    [anon_sym_break] = ACTIONS(451),
    [anon_sym_elseif] = ACTIONS(451),
    [anon_sym_else] = ACTIONS(451),
    [anon_sym_if] = ACTIONS(451),
    [anon_sym_end] = ACTIONS(451),
    [anon_sym_for] = ACTIONS(451),
    [anon_sym_parfor] = ACTIONS(451),
    [anon_sym_while] = ACTIONS(451),
    [anon_sym_switch] = ACTIONS(451),
    [anon_sym_global] = ACTIONS(451),
    [anon_sym_persistent] = ACTIONS(451),
    [anon_sym_arguments] = ACTIONS(451),
    [anon_sym_function] = ACTIONS(451),
    [anon_sym_properties] = ACTIONS(451),
    [anon_sym_get] = ACTIONS(451),
    [anon_sym_set] = ACTIONS(451),
    [anon_sym_methods] = ACTIONS(451),
    [anon_sym_events] = ACTIONS(451),
    [anon_sym_enumeration] = ACTIONS(451),
    [anon_sym_classdef] = ACTIONS(451),
    [anon_sym_try] = ACTIONS(451),
    [anon_sym_spmd] = ACTIONS(451),
    [aux_sym_number_token1] = ACTIONS(451),
    [aux_sym_number_token2] = ACTIONS(451),
    [aux_sym_number_token3] = ACTIONS(451),
    [anon_sym_true] = ACTIONS(451),
    [anon_sym_false] = ACTIONS(451),
    [anon_sym_CR] = ACTIONS(451),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(460),
    [sym__single_quote_string_start] = ACTIONS(460),
    [sym__double_quote_string_start] = ACTIONS(460),
    [sym__multioutput_variable_start] = ACTIONS(460),
    [sym__external_identifier] = ACTIONS(460),
  },
  [STATE(141)] = {
    [anon_sym_SEMI] = ACTIONS(458),
    [anon_sym_COMMA] = ACTIONS(458),
    [anon_sym_LPAREN] = ACTIONS(458),
    [anon_sym_PLUS] = ACTIONS(451),
    [anon_sym_DOT_PLUS] = ACTIONS(451),
    [anon_sym_DASH] = ACTIONS(451),
    [anon_sym_DOT_DASH] = ACTIONS(451),
    [anon_sym_STAR] = ACTIONS(451),
    [anon_sym_DOT_STAR] = ACTIONS(451),
    [anon_sym_SLASH] = ACTIONS(451),
    [anon_sym_DOT_SLASH] = ACTIONS(451),
    [anon_sym_BSLASH] = ACTIONS(451),
    [anon_sym_DOT_BSLASH] = ACTIONS(451),
    [anon_sym_CARET] = ACTIONS(451),
    [anon_sym_DOT_CARET] = ACTIONS(451),
    [anon_sym_PIPE] = ACTIONS(451),
    [anon_sym_AMP] = ACTIONS(451),
    [anon_sym_TILDE] = ACTIONS(458),
    [anon_sym_QMARK] = ACTIONS(458),
    [anon_sym_AT] = ACTIONS(458),
    [anon_sym_LT] = ACTIONS(453),
    [anon_sym_LT_EQ] = ACTIONS(453),
    [anon_sym_EQ_EQ] = ACTIONS(453),
    [anon_sym_TILDE_EQ] = ACTIONS(453),
    [anon_sym_GT_EQ] = ACTIONS(453),
    [anon_sym_GT] = ACTIONS(453),
    [anon_sym_AMP_AMP] = ACTIONS(453),
    [anon_sym_PIPE_PIPE] = ACTIONS(453),
    [anon_sym_DOT_SQUOTE] = ACTIONS(443),
    [anon_sym_SQUOTE] = ACTIONS(443),
    [anon_sym_LBRACK] = ACTIONS(458),
    [anon_sym_LF] = ACTIONS(458),
    [anon_sym_LBRACE] = ACTIONS(458),
    [anon_sym_COLON] = ACTIONS(458),
    [anon_sym_return] = ACTIONS(458),
    [anon_sym_continue] = ACTIONS(458),
    [anon_sym_break] = ACTIONS(458),
    [anon_sym_elseif] = ACTIONS(458),
    [anon_sym_else] = ACTIONS(458),
    [anon_sym_if] = ACTIONS(458),
    [anon_sym_end] = ACTIONS(458),
    [anon_sym_for] = ACTIONS(458),
    [anon_sym_parfor] = ACTIONS(458),
    [anon_sym_while] = ACTIONS(458),
    [anon_sym_switch] = ACTIONS(458),
    [anon_sym_global] = ACTIONS(458),
    [anon_sym_persistent] = ACTIONS(458),
    [anon_sym_arguments] = ACTIONS(458),
    [anon_sym_function] = ACTIONS(458),
    [anon_sym_properties] = ACTIONS(458),
    [anon_sym_get] = ACTIONS(458),
    [anon_sym_set] = ACTIONS(458),
    [anon_sym_methods] = ACTIONS(458),
    [anon_sym_events] = ACTIONS(458),
    [anon_sym_enumeration] = ACTIONS(458),
    [anon_sym_classdef] = ACTIONS(458),
    [anon_sym_try] = ACTIONS(458),
    [anon_sym_spmd] = ACTIONS(458),
    [aux_sym_number_token1] = ACTIONS(458),
    [aux_sym_number_token2] = ACTIONS(458),
    [aux_sym_number_token3] = ACTIONS(458),
    [anon_sym_true] = ACTIONS(458),
    [anon_sym_false] = ACTIONS(458),
    [anon_sym_CR] = ACTIONS(458),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(462),
    [sym__single_quote_string_start] = ACTIONS(462),
    [sym__double_quote_string_start] = ACTIONS(462),
    [sym__multioutput_variable_start] = ACTIONS(462),
    [sym__external_identifier] = ACTIONS(462),
  },
  [STATE(142)] = {
    [anon_sym_SEMI] = ACTIONS(554),
    [anon_sym_COMMA] = ACTIONS(554),
    [anon_sym_LPAREN] = ACTIONS(554),
    [anon_sym_PLUS] = ACTIONS(451),
    [anon_sym_DOT_PLUS] = ACTIONS(451),
    [anon_sym_DASH] = ACTIONS(451),
    [anon_sym_DOT_DASH] = ACTIONS(451),
    [anon_sym_STAR] = ACTIONS(451),
    [anon_sym_DOT_STAR] = ACTIONS(451),
    [anon_sym_SLASH] = ACTIONS(451),
    [anon_sym_DOT_SLASH] = ACTIONS(451),
    [anon_sym_BSLASH] = ACTIONS(451),
    [anon_sym_DOT_BSLASH] = ACTIONS(451),
    [anon_sym_CARET] = ACTIONS(451),
    [anon_sym_DOT_CARET] = ACTIONS(451),
    [anon_sym_PIPE] = ACTIONS(451),
    [anon_sym_AMP] = ACTIONS(451),
    [anon_sym_TILDE] = ACTIONS(554),
    [anon_sym_QMARK] = ACTIONS(554),
    [anon_sym_AT] = ACTIONS(554),
    [anon_sym_LT] = ACTIONS(643),
    [anon_sym_LT_EQ] = ACTIONS(643),
    [anon_sym_EQ_EQ] = ACTIONS(643),
    [anon_sym_TILDE_EQ] = ACTIONS(643),
    [anon_sym_GT_EQ] = ACTIONS(643),
    [anon_sym_GT] = ACTIONS(643),
    [anon_sym_AMP_AMP] = ACTIONS(643),
    [anon_sym_PIPE_PIPE] = ACTIONS(643),
    [anon_sym_DOT_SQUOTE] = ACTIONS(443),
    [anon_sym_SQUOTE] = ACTIONS(443),
    [anon_sym_LBRACK] = ACTIONS(554),
    [anon_sym_LF] = ACTIONS(554),
    [anon_sym_LBRACE] = ACTIONS(554),
    [anon_sym_COLON] = ACTIONS(554),
    [anon_sym_return] = ACTIONS(554),
    [anon_sym_continue] = ACTIONS(554),
    [anon_sym_break] = ACTIONS(554),
    [anon_sym_elseif] = ACTIONS(554),
    [anon_sym_else] = ACTIONS(554),
    [anon_sym_if] = ACTIONS(554),
    [anon_sym_end] = ACTIONS(554),
    [anon_sym_for] = ACTIONS(554),
    [anon_sym_parfor] = ACTIONS(554),
    [anon_sym_while] = ACTIONS(554),
    [anon_sym_switch] = ACTIONS(554),
    [anon_sym_global] = ACTIONS(554),
    [anon_sym_persistent] = ACTIONS(554),
    [anon_sym_arguments] = ACTIONS(554),
    [anon_sym_function] = ACTIONS(554),
    [anon_sym_properties] = ACTIONS(554),
    [anon_sym_get] = ACTIONS(554),
    [anon_sym_set] = ACTIONS(554),
    [anon_sym_methods] = ACTIONS(554),
    [anon_sym_events] = ACTIONS(554),
    [anon_sym_enumeration] = ACTIONS(554),
    [anon_sym_classdef] = ACTIONS(554),
    [anon_sym_try] = ACTIONS(554),
    [anon_sym_spmd] = ACTIONS(554),
    [aux_sym_number_token1] = ACTIONS(554),
    [aux_sym_number_token2] = ACTIONS(554),
    [aux_sym_number_token3] = ACTIONS(554),
    [anon_sym_true] = ACTIONS(554),
    [anon_sym_false] = ACTIONS(554),
    [anon_sym_CR] = ACTIONS(554),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(649),
    [sym__single_quote_string_start] = ACTIONS(649),
    [sym__double_quote_string_start] = ACTIONS(649),
    [sym__multioutput_variable_start] = ACTIONS(649),
    [sym__external_identifier] = ACTIONS(649),
  },
  [STATE(143)] = {
    [anon_sym_SEMI] = ACTIONS(458),
    [anon_sym_COMMA] = ACTIONS(458),
    [anon_sym_LPAREN] = ACTIONS(458),
    [anon_sym_PLUS] = ACTIONS(451),
    [anon_sym_DOT_PLUS] = ACTIONS(451),
    [anon_sym_DASH] = ACTIONS(451),
    [anon_sym_DOT_DASH] = ACTIONS(451),
    [anon_sym_STAR] = ACTIONS(451),
    [anon_sym_DOT_STAR] = ACTIONS(451),
    [anon_sym_SLASH] = ACTIONS(451),
    [anon_sym_DOT_SLASH] = ACTIONS(451),
    [anon_sym_BSLASH] = ACTIONS(451),
    [anon_sym_DOT_BSLASH] = ACTIONS(451),
    [anon_sym_CARET] = ACTIONS(451),
    [anon_sym_DOT_CARET] = ACTIONS(451),
    [anon_sym_PIPE] = ACTIONS(451),
    [anon_sym_AMP] = ACTIONS(451),
    [anon_sym_TILDE] = ACTIONS(458),
    [anon_sym_QMARK] = ACTIONS(458),
    [anon_sym_AT] = ACTIONS(458),
    [anon_sym_LT] = ACTIONS(453),
    [anon_sym_LT_EQ] = ACTIONS(453),
    [anon_sym_EQ_EQ] = ACTIONS(453),
    [anon_sym_TILDE_EQ] = ACTIONS(453),
    [anon_sym_GT_EQ] = ACTIONS(453),
    [anon_sym_GT] = ACTIONS(453),
    [anon_sym_AMP_AMP] = ACTIONS(453),
    [anon_sym_PIPE_PIPE] = ACTIONS(453),
    [anon_sym_DOT_SQUOTE] = ACTIONS(458),
    [anon_sym_SQUOTE] = ACTIONS(458),
    [anon_sym_LBRACK] = ACTIONS(458),
    [anon_sym_LF] = ACTIONS(458),
    [anon_sym_LBRACE] = ACTIONS(458),
    [anon_sym_COLON] = ACTIONS(458),
    [anon_sym_return] = ACTIONS(458),
    [anon_sym_continue] = ACTIONS(458),
    [anon_sym_break] = ACTIONS(458),
    [anon_sym_elseif] = ACTIONS(458),
    [anon_sym_else] = ACTIONS(458),
    [anon_sym_if] = ACTIONS(458),
    [anon_sym_end] = ACTIONS(458),
    [anon_sym_for] = ACTIONS(458),
    [anon_sym_parfor] = ACTIONS(458),
    [anon_sym_while] = ACTIONS(458),
    [anon_sym_switch] = ACTIONS(458),
    [anon_sym_global] = ACTIONS(458),
    [anon_sym_persistent] = ACTIONS(458),
    [anon_sym_arguments] = ACTIONS(458),
    [anon_sym_function] = ACTIONS(458),
    [anon_sym_properties] = ACTIONS(458),
    [anon_sym_get] = ACTIONS(458),
    [anon_sym_set] = ACTIONS(458),
    [anon_sym_methods] = ACTIONS(458),
    [anon_sym_events] = ACTIONS(458),
    [anon_sym_enumeration] = ACTIONS(458),
    [anon_sym_classdef] = ACTIONS(458),
    [anon_sym_try] = ACTIONS(458),
    [anon_sym_spmd] = ACTIONS(458),
    [aux_sym_number_token1] = ACTIONS(458),
    [aux_sym_number_token2] = ACTIONS(458),
    [aux_sym_number_token3] = ACTIONS(458),
    [anon_sym_true] = ACTIONS(458),
    [anon_sym_false] = ACTIONS(458),
    [anon_sym_CR] = ACTIONS(458),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(462),
    [sym__single_quote_string_start] = ACTIONS(462),
    [sym__double_quote_string_start] = ACTIONS(462),
    [sym__multioutput_variable_start] = ACTIONS(462),
    [sym__external_identifier] = ACTIONS(462),
  },
  [STATE(144)] = {
    [anon_sym_SEMI] = ACTIONS(451),
    [anon_sym_COMMA] = ACTIONS(451),
    [anon_sym_LPAREN] = ACTIONS(451),
    [anon_sym_PLUS] = ACTIONS(451),
    [anon_sym_DOT_PLUS] = ACTIONS(451),
    [anon_sym_DASH] = ACTIONS(451),
    [anon_sym_DOT_DASH] = ACTIONS(451),
    [anon_sym_STAR] = ACTIONS(451),
    [anon_sym_DOT_STAR] = ACTIONS(451),
    [anon_sym_SLASH] = ACTIONS(451),
    [anon_sym_DOT_SLASH] = ACTIONS(451),
    [anon_sym_BSLASH] = ACTIONS(451),
    [anon_sym_DOT_BSLASH] = ACTIONS(451),
    [anon_sym_CARET] = ACTIONS(451),
    [anon_sym_DOT_CARET] = ACTIONS(451),
    [anon_sym_PIPE] = ACTIONS(451),
    [anon_sym_AMP] = ACTIONS(451),
    [anon_sym_TILDE] = ACTIONS(451),
    [anon_sym_QMARK] = ACTIONS(451),
    [anon_sym_AT] = ACTIONS(451),
    [anon_sym_LT] = ACTIONS(451),
    [anon_sym_LT_EQ] = ACTIONS(451),
    [anon_sym_EQ_EQ] = ACTIONS(451),
    [anon_sym_TILDE_EQ] = ACTIONS(451),
    [anon_sym_GT_EQ] = ACTIONS(451),
    [anon_sym_GT] = ACTIONS(451),
    [anon_sym_AMP_AMP] = ACTIONS(451),
    [anon_sym_PIPE_PIPE] = ACTIONS(451),
    [anon_sym_DOT_SQUOTE] = ACTIONS(443),
    [anon_sym_SQUOTE] = ACTIONS(443),
    [anon_sym_LBRACK] = ACTIONS(451),
    [anon_sym_LF] = ACTIONS(451),
    [anon_sym_LBRACE] = ACTIONS(451),
    [anon_sym_COLON] = ACTIONS(451),
    [anon_sym_return] = ACTIONS(451),
    [anon_sym_continue] = ACTIONS(451),
    [anon_sym_break] = ACTIONS(451),
    [anon_sym_elseif] = ACTIONS(451),
    [anon_sym_else] = ACTIONS(451),
    [anon_sym_if] = ACTIONS(451),
    [anon_sym_end] = ACTIONS(451),
    [anon_sym_for] = ACTIONS(451),
    [anon_sym_parfor] = ACTIONS(451),
    [anon_sym_while] = ACTIONS(451),
    [anon_sym_switch] = ACTIONS(451),
    [anon_sym_global] = ACTIONS(451),
    [anon_sym_persistent] = ACTIONS(451),
    [anon_sym_arguments] = ACTIONS(451),
    [anon_sym_function] = ACTIONS(451),
    [anon_sym_properties] = ACTIONS(451),
    [anon_sym_get] = ACTIONS(451),
    [anon_sym_set] = ACTIONS(451),
    [anon_sym_methods] = ACTIONS(451),
    [anon_sym_events] = ACTIONS(451),
    [anon_sym_enumeration] = ACTIONS(451),
    [anon_sym_classdef] = ACTIONS(451),
    [anon_sym_try] = ACTIONS(451),
    [anon_sym_spmd] = ACTIONS(451),
    [aux_sym_number_token1] = ACTIONS(451),
    [aux_sym_number_token2] = ACTIONS(451),
    [aux_sym_number_token3] = ACTIONS(451),
    [anon_sym_true] = ACTIONS(451),
    [anon_sym_false] = ACTIONS(451),
    [anon_sym_CR] = ACTIONS(451),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(460),
    [sym__single_quote_string_start] = ACTIONS(460),
    [sym__double_quote_string_start] = ACTIONS(460),
    [sym__multioutput_variable_start] = ACTIONS(460),
    [sym__external_identifier] = ACTIONS(460),
  },
  [STATE(145)] = {
    [anon_sym_SEMI] = ACTIONS(641),
    [anon_sym_COMMA] = ACTIONS(641),
    [anon_sym_LPAREN] = ACTIONS(641),
    [anon_sym_PLUS] = ACTIONS(451),
    [anon_sym_DOT_PLUS] = ACTIONS(451),
    [anon_sym_DASH] = ACTIONS(451),
    [anon_sym_DOT_DASH] = ACTIONS(451),
    [anon_sym_STAR] = ACTIONS(451),
    [anon_sym_DOT_STAR] = ACTIONS(451),
    [anon_sym_SLASH] = ACTIONS(451),
    [anon_sym_DOT_SLASH] = ACTIONS(451),
    [anon_sym_BSLASH] = ACTIONS(451),
    [anon_sym_DOT_BSLASH] = ACTIONS(451),
    [anon_sym_CARET] = ACTIONS(451),
    [anon_sym_DOT_CARET] = ACTIONS(451),
    [anon_sym_PIPE] = ACTIONS(451),
    [anon_sym_AMP] = ACTIONS(451),
    [anon_sym_TILDE] = ACTIONS(641),
    [anon_sym_QMARK] = ACTIONS(641),
    [anon_sym_AT] = ACTIONS(641),
    [anon_sym_LT] = ACTIONS(646),
    [anon_sym_LT_EQ] = ACTIONS(646),
    [anon_sym_EQ_EQ] = ACTIONS(646),
    [anon_sym_TILDE_EQ] = ACTIONS(646),
    [anon_sym_GT_EQ] = ACTIONS(646),
    [anon_sym_GT] = ACTIONS(646),
    [anon_sym_AMP_AMP] = ACTIONS(646),
    [anon_sym_PIPE_PIPE] = ACTIONS(646),
    [anon_sym_DOT_SQUOTE] = ACTIONS(443),
    [anon_sym_SQUOTE] = ACTIONS(443),
    [anon_sym_LBRACK] = ACTIONS(641),
    [anon_sym_LF] = ACTIONS(641),
    [anon_sym_LBRACE] = ACTIONS(641),
    [anon_sym_COLON] = ACTIONS(641),
    [anon_sym_return] = ACTIONS(641),
    [anon_sym_continue] = ACTIONS(641),
    [anon_sym_break] = ACTIONS(641),
    [anon_sym_elseif] = ACTIONS(641),
    [anon_sym_else] = ACTIONS(641),
    [anon_sym_if] = ACTIONS(641),
    [anon_sym_end] = ACTIONS(641),
    [anon_sym_for] = ACTIONS(641),
    [anon_sym_parfor] = ACTIONS(641),
    [anon_sym_while] = ACTIONS(641),
    [anon_sym_switch] = ACTIONS(641),
    [anon_sym_global] = ACTIONS(641),
    [anon_sym_persistent] = ACTIONS(641),
    [anon_sym_arguments] = ACTIONS(641),
    [anon_sym_function] = ACTIONS(641),
    [anon_sym_properties] = ACTIONS(641),
    [anon_sym_get] = ACTIONS(641),
    [anon_sym_set] = ACTIONS(641),
    [anon_sym_methods] = ACTIONS(641),
    [anon_sym_events] = ACTIONS(641),
    [anon_sym_enumeration] = ACTIONS(641),
    [anon_sym_classdef] = ACTIONS(641),
    [anon_sym_try] = ACTIONS(641),
    [anon_sym_spmd] = ACTIONS(641),
    [aux_sym_number_token1] = ACTIONS(641),
    [aux_sym_number_token2] = ACTIONS(641),
    [aux_sym_number_token3] = ACTIONS(641),
    [anon_sym_true] = ACTIONS(641),
    [anon_sym_false] = ACTIONS(641),
    [anon_sym_CR] = ACTIONS(641),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(651),
    [sym__single_quote_string_start] = ACTIONS(651),
    [sym__double_quote_string_start] = ACTIONS(651),
    [sym__multioutput_variable_start] = ACTIONS(651),
    [sym__external_identifier] = ACTIONS(651),
  },
  [STATE(146)] = {
    [anon_sym_SEMI] = ACTIONS(653),
    [anon_sym_COMMA] = ACTIONS(653),
    [anon_sym_LPAREN] = ACTIONS(653),
    [anon_sym_PLUS] = ACTIONS(653),
    [anon_sym_DOT_PLUS] = ACTIONS(653),
    [anon_sym_DASH] = ACTIONS(653),
    [anon_sym_DOT_DASH] = ACTIONS(653),
    [anon_sym_STAR] = ACTIONS(653),
    [anon_sym_DOT_STAR] = ACTIONS(653),
    [anon_sym_SLASH] = ACTIONS(653),
    [anon_sym_DOT_SLASH] = ACTIONS(653),
    [anon_sym_BSLASH] = ACTIONS(653),
    [anon_sym_DOT_BSLASH] = ACTIONS(653),
    [anon_sym_CARET] = ACTIONS(653),
    [anon_sym_DOT_CARET] = ACTIONS(653),
    [anon_sym_PIPE] = ACTIONS(653),
    [anon_sym_AMP] = ACTIONS(653),
    [anon_sym_TILDE] = ACTIONS(653),
    [anon_sym_QMARK] = ACTIONS(653),
    [anon_sym_AT] = ACTIONS(653),
    [anon_sym_LT] = ACTIONS(562),
    [anon_sym_LT_EQ] = ACTIONS(562),
    [anon_sym_EQ_EQ] = ACTIONS(562),
    [anon_sym_TILDE_EQ] = ACTIONS(562),
    [anon_sym_GT_EQ] = ACTIONS(562),
    [anon_sym_GT] = ACTIONS(562),
    [anon_sym_AMP_AMP] = ACTIONS(653),
    [anon_sym_PIPE_PIPE] = ACTIONS(653),
    [anon_sym_DOT_SQUOTE] = ACTIONS(653),
    [anon_sym_SQUOTE] = ACTIONS(653),
    [anon_sym_LBRACK] = ACTIONS(653),
    [anon_sym_LF] = ACTIONS(653),
    [anon_sym_LBRACE] = ACTIONS(653),
    [anon_sym_COLON] = ACTIONS(653),
    [anon_sym_return] = ACTIONS(653),
    [anon_sym_continue] = ACTIONS(653),
    [anon_sym_break] = ACTIONS(653),
    [anon_sym_elseif] = ACTIONS(653),
    [anon_sym_else] = ACTIONS(653),
    [anon_sym_if] = ACTIONS(653),
    [anon_sym_end] = ACTIONS(653),
    [anon_sym_for] = ACTIONS(653),
    [anon_sym_parfor] = ACTIONS(653),
    [anon_sym_while] = ACTIONS(653),
    [anon_sym_switch] = ACTIONS(653),
    [anon_sym_global] = ACTIONS(653),
    [anon_sym_persistent] = ACTIONS(653),
    [anon_sym_arguments] = ACTIONS(653),
    [anon_sym_function] = ACTIONS(653),
    [anon_sym_properties] = ACTIONS(653),
    [anon_sym_get] = ACTIONS(653),
    [anon_sym_set] = ACTIONS(653),
    [anon_sym_methods] = ACTIONS(653),
    [anon_sym_events] = ACTIONS(653),
    [anon_sym_enumeration] = ACTIONS(653),
    [anon_sym_classdef] = ACTIONS(653),
    [anon_sym_try] = ACTIONS(653),
    [anon_sym_spmd] = ACTIONS(653),
    [aux_sym_number_token1] = ACTIONS(653),
    [aux_sym_number_token2] = ACTIONS(653),
    [aux_sym_number_token3] = ACTIONS(653),
    [anon_sym_true] = ACTIONS(653),
    [anon_sym_false] = ACTIONS(653),
    [anon_sym_CR] = ACTIONS(653),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(655),
    [sym__single_quote_string_start] = ACTIONS(655),
    [sym__double_quote_string_start] = ACTIONS(655),
    [sym__multioutput_variable_start] = ACTIONS(655),
    [sym__external_identifier] = ACTIONS(655),
  },
  [STATE(147)] = {
    [anon_sym_SEMI] = ACTIONS(653),
    [anon_sym_COMMA] = ACTIONS(653),
    [anon_sym_LPAREN] = ACTIONS(653),
    [anon_sym_PLUS] = ACTIONS(653),
    [anon_sym_DOT_PLUS] = ACTIONS(653),
    [anon_sym_DASH] = ACTIONS(653),
    [anon_sym_DOT_DASH] = ACTIONS(653),
    [anon_sym_STAR] = ACTIONS(653),
    [anon_sym_DOT_STAR] = ACTIONS(653),
    [anon_sym_SLASH] = ACTIONS(653),
    [anon_sym_DOT_SLASH] = ACTIONS(653),
    [anon_sym_BSLASH] = ACTIONS(653),
    [anon_sym_DOT_BSLASH] = ACTIONS(653),
    [anon_sym_CARET] = ACTIONS(653),
    [anon_sym_DOT_CARET] = ACTIONS(653),
    [anon_sym_PIPE] = ACTIONS(653),
    [anon_sym_AMP] = ACTIONS(653),
    [anon_sym_TILDE] = ACTIONS(653),
    [anon_sym_QMARK] = ACTIONS(653),
    [anon_sym_AT] = ACTIONS(653),
    [anon_sym_LT] = ACTIONS(562),
    [anon_sym_LT_EQ] = ACTIONS(562),
    [anon_sym_EQ_EQ] = ACTIONS(562),
    [anon_sym_TILDE_EQ] = ACTIONS(562),
    [anon_sym_GT_EQ] = ACTIONS(562),
    [anon_sym_GT] = ACTIONS(562),
    [anon_sym_AMP_AMP] = ACTIONS(602),
    [anon_sym_PIPE_PIPE] = ACTIONS(653),
    [anon_sym_DOT_SQUOTE] = ACTIONS(653),
    [anon_sym_SQUOTE] = ACTIONS(653),
    [anon_sym_LBRACK] = ACTIONS(653),
    [anon_sym_LF] = ACTIONS(653),
    [anon_sym_LBRACE] = ACTIONS(653),
    [anon_sym_COLON] = ACTIONS(653),
    [anon_sym_return] = ACTIONS(653),
    [anon_sym_continue] = ACTIONS(653),
    [anon_sym_break] = ACTIONS(653),
    [anon_sym_elseif] = ACTIONS(653),
    [anon_sym_else] = ACTIONS(653),
    [anon_sym_if] = ACTIONS(653),
    [anon_sym_end] = ACTIONS(653),
    [anon_sym_for] = ACTIONS(653),
    [anon_sym_parfor] = ACTIONS(653),
    [anon_sym_while] = ACTIONS(653),
    [anon_sym_switch] = ACTIONS(653),
    [anon_sym_global] = ACTIONS(653),
    [anon_sym_persistent] = ACTIONS(653),
    [anon_sym_arguments] = ACTIONS(653),
    [anon_sym_function] = ACTIONS(653),
    [anon_sym_properties] = ACTIONS(653),
    [anon_sym_get] = ACTIONS(653),
    [anon_sym_set] = ACTIONS(653),
    [anon_sym_methods] = ACTIONS(653),
    [anon_sym_events] = ACTIONS(653),
    [anon_sym_enumeration] = ACTIONS(653),
    [anon_sym_classdef] = ACTIONS(653),
    [anon_sym_try] = ACTIONS(653),
    [anon_sym_spmd] = ACTIONS(653),
    [aux_sym_number_token1] = ACTIONS(653),
    [aux_sym_number_token2] = ACTIONS(653),
    [aux_sym_number_token3] = ACTIONS(653),
    [anon_sym_true] = ACTIONS(653),
    [anon_sym_false] = ACTIONS(653),
    [anon_sym_CR] = ACTIONS(653),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(655),
    [sym__single_quote_string_start] = ACTIONS(655),
    [sym__double_quote_string_start] = ACTIONS(655),
    [sym__multioutput_variable_start] = ACTIONS(655),
    [sym__external_identifier] = ACTIONS(655),
  },
  [STATE(148)] = {
    [anon_sym_SEMI] = ACTIONS(657),
    [anon_sym_COMMA] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(657),
    [anon_sym_PLUS] = ACTIONS(657),
    [anon_sym_DOT_PLUS] = ACTIONS(657),
    [anon_sym_DASH] = ACTIONS(657),
    [anon_sym_DOT_DASH] = ACTIONS(657),
    [anon_sym_STAR] = ACTIONS(657),
    [anon_sym_DOT_STAR] = ACTIONS(657),
    [anon_sym_SLASH] = ACTIONS(657),
    [anon_sym_DOT_SLASH] = ACTIONS(657),
    [anon_sym_BSLASH] = ACTIONS(657),
    [anon_sym_DOT_BSLASH] = ACTIONS(657),
    [anon_sym_CARET] = ACTIONS(657),
    [anon_sym_DOT_CARET] = ACTIONS(657),
    [anon_sym_PIPE] = ACTIONS(657),
    [anon_sym_AMP] = ACTIONS(657),
    [anon_sym_TILDE] = ACTIONS(657),
    [anon_sym_QMARK] = ACTIONS(657),
    [anon_sym_AT] = ACTIONS(657),
    [anon_sym_LT] = ACTIONS(562),
    [anon_sym_LT_EQ] = ACTIONS(562),
    [anon_sym_EQ_EQ] = ACTIONS(562),
    [anon_sym_TILDE_EQ] = ACTIONS(562),
    [anon_sym_GT_EQ] = ACTIONS(562),
    [anon_sym_GT] = ACTIONS(562),
    [anon_sym_AMP_AMP] = ACTIONS(602),
    [anon_sym_PIPE_PIPE] = ACTIONS(604),
    [anon_sym_DOT_SQUOTE] = ACTIONS(657),
    [anon_sym_SQUOTE] = ACTIONS(657),
    [anon_sym_LBRACK] = ACTIONS(657),
    [anon_sym_LF] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(657),
    [anon_sym_COLON] = ACTIONS(657),
    [anon_sym_return] = ACTIONS(657),
    [anon_sym_continue] = ACTIONS(657),
    [anon_sym_break] = ACTIONS(657),
    [anon_sym_elseif] = ACTIONS(657),
    [anon_sym_else] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(657),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_for] = ACTIONS(657),
    [anon_sym_parfor] = ACTIONS(657),
    [anon_sym_while] = ACTIONS(657),
    [anon_sym_switch] = ACTIONS(657),
    [anon_sym_global] = ACTIONS(657),
    [anon_sym_persistent] = ACTIONS(657),
    [anon_sym_arguments] = ACTIONS(657),
    [anon_sym_function] = ACTIONS(657),
    [anon_sym_properties] = ACTIONS(657),
    [anon_sym_get] = ACTIONS(657),
    [anon_sym_set] = ACTIONS(657),
    [anon_sym_methods] = ACTIONS(657),
    [anon_sym_events] = ACTIONS(657),
    [anon_sym_enumeration] = ACTIONS(657),
    [anon_sym_classdef] = ACTIONS(657),
    [anon_sym_try] = ACTIONS(657),
    [anon_sym_spmd] = ACTIONS(657),
    [aux_sym_number_token1] = ACTIONS(657),
    [aux_sym_number_token2] = ACTIONS(657),
    [aux_sym_number_token3] = ACTIONS(657),
    [anon_sym_true] = ACTIONS(657),
    [anon_sym_false] = ACTIONS(657),
    [anon_sym_CR] = ACTIONS(657),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(659),
    [sym__single_quote_string_start] = ACTIONS(659),
    [sym__double_quote_string_start] = ACTIONS(659),
    [sym__multioutput_variable_start] = ACTIONS(659),
    [sym__external_identifier] = ACTIONS(659),
  },
  [STATE(149)] = {
    [anon_sym_SEMI] = ACTIONS(592),
    [anon_sym_COMMA] = ACTIONS(592),
    [anon_sym_LPAREN] = ACTIONS(592),
    [anon_sym_PLUS] = ACTIONS(608),
    [anon_sym_DOT_PLUS] = ACTIONS(608),
    [anon_sym_DASH] = ACTIONS(608),
    [anon_sym_DOT_DASH] = ACTIONS(608),
    [anon_sym_STAR] = ACTIONS(594),
    [anon_sym_DOT_STAR] = ACTIONS(594),
    [anon_sym_SLASH] = ACTIONS(594),
    [anon_sym_DOT_SLASH] = ACTIONS(594),
    [anon_sym_BSLASH] = ACTIONS(594),
    [anon_sym_DOT_BSLASH] = ACTIONS(594),
    [anon_sym_CARET] = ACTIONS(596),
    [anon_sym_DOT_CARET] = ACTIONS(596),
    [anon_sym_PIPE] = ACTIONS(592),
    [anon_sym_AMP] = ACTIONS(661),
    [anon_sym_TILDE] = ACTIONS(592),
    [anon_sym_QMARK] = ACTIONS(592),
    [anon_sym_AT] = ACTIONS(592),
    [anon_sym_LT] = ACTIONS(592),
    [anon_sym_LT_EQ] = ACTIONS(592),
    [anon_sym_EQ_EQ] = ACTIONS(592),
    [anon_sym_TILDE_EQ] = ACTIONS(592),
    [anon_sym_GT_EQ] = ACTIONS(592),
    [anon_sym_GT] = ACTIONS(592),
    [anon_sym_AMP_AMP] = ACTIONS(592),
    [anon_sym_PIPE_PIPE] = ACTIONS(592),
    [anon_sym_DOT_SQUOTE] = ACTIONS(592),
    [anon_sym_SQUOTE] = ACTIONS(592),
    [anon_sym_LBRACK] = ACTIONS(592),
    [anon_sym_LF] = ACTIONS(592),
    [anon_sym_LBRACE] = ACTIONS(592),
    [anon_sym_COLON] = ACTIONS(592),
    [anon_sym_return] = ACTIONS(592),
    [anon_sym_continue] = ACTIONS(592),
    [anon_sym_break] = ACTIONS(592),
    [anon_sym_elseif] = ACTIONS(592),
    [anon_sym_else] = ACTIONS(592),
    [anon_sym_if] = ACTIONS(592),
    [anon_sym_end] = ACTIONS(592),
    [anon_sym_for] = ACTIONS(592),
    [anon_sym_parfor] = ACTIONS(592),
    [anon_sym_while] = ACTIONS(592),
    [anon_sym_switch] = ACTIONS(592),
    [anon_sym_global] = ACTIONS(592),
    [anon_sym_persistent] = ACTIONS(592),
    [anon_sym_arguments] = ACTIONS(592),
    [anon_sym_function] = ACTIONS(592),
    [anon_sym_properties] = ACTIONS(592),
    [anon_sym_get] = ACTIONS(592),
    [anon_sym_set] = ACTIONS(592),
    [anon_sym_methods] = ACTIONS(592),
    [anon_sym_events] = ACTIONS(592),
    [anon_sym_enumeration] = ACTIONS(592),
    [anon_sym_classdef] = ACTIONS(592),
    [anon_sym_try] = ACTIONS(592),
    [anon_sym_spmd] = ACTIONS(592),
    [aux_sym_number_token1] = ACTIONS(592),
    [aux_sym_number_token2] = ACTIONS(592),
    [aux_sym_number_token3] = ACTIONS(592),
    [anon_sym_true] = ACTIONS(592),
    [anon_sym_false] = ACTIONS(592),
    [anon_sym_CR] = ACTIONS(592),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(598),
    [sym__single_quote_string_start] = ACTIONS(598),
    [sym__double_quote_string_start] = ACTIONS(598),
    [sym__multioutput_variable_start] = ACTIONS(598),
    [sym__external_identifier] = ACTIONS(598),
  },
  [STATE(150)] = {
    [anon_sym_SEMI] = ACTIONS(449),
    [anon_sym_COMMA] = ACTIONS(449),
    [anon_sym_LPAREN] = ACTIONS(449),
    [anon_sym_PLUS] = ACTIONS(451),
    [anon_sym_DOT_PLUS] = ACTIONS(451),
    [anon_sym_DASH] = ACTIONS(451),
    [anon_sym_DOT_DASH] = ACTIONS(451),
    [anon_sym_STAR] = ACTIONS(451),
    [anon_sym_DOT_STAR] = ACTIONS(451),
    [anon_sym_SLASH] = ACTIONS(451),
    [anon_sym_DOT_SLASH] = ACTIONS(451),
    [anon_sym_BSLASH] = ACTIONS(451),
    [anon_sym_DOT_BSLASH] = ACTIONS(451),
    [anon_sym_CARET] = ACTIONS(451),
    [anon_sym_DOT_CARET] = ACTIONS(451),
    [anon_sym_PIPE] = ACTIONS(451),
    [anon_sym_AMP] = ACTIONS(451),
    [anon_sym_TILDE] = ACTIONS(449),
    [anon_sym_QMARK] = ACTIONS(449),
    [anon_sym_AT] = ACTIONS(449),
    [anon_sym_LT] = ACTIONS(449),
    [anon_sym_LT_EQ] = ACTIONS(449),
    [anon_sym_EQ_EQ] = ACTIONS(449),
    [anon_sym_TILDE_EQ] = ACTIONS(449),
    [anon_sym_GT_EQ] = ACTIONS(449),
    [anon_sym_GT] = ACTIONS(449),
    [anon_sym_AMP_AMP] = ACTIONS(449),
    [anon_sym_PIPE_PIPE] = ACTIONS(449),
    [anon_sym_LBRACK] = ACTIONS(449),
    [anon_sym_LF] = ACTIONS(449),
    [anon_sym_LBRACE] = ACTIONS(449),
    [anon_sym_COLON] = ACTIONS(458),
    [anon_sym_return] = ACTIONS(449),
    [anon_sym_continue] = ACTIONS(449),
    [anon_sym_break] = ACTIONS(449),
    [anon_sym_elseif] = ACTIONS(449),
    [anon_sym_else] = ACTIONS(449),
    [anon_sym_if] = ACTIONS(449),
    [anon_sym_end] = ACTIONS(449),
    [anon_sym_for] = ACTIONS(449),
    [anon_sym_parfor] = ACTIONS(449),
    [anon_sym_while] = ACTIONS(449),
    [anon_sym_switch] = ACTIONS(449),
    [anon_sym_global] = ACTIONS(449),
    [anon_sym_persistent] = ACTIONS(449),
    [anon_sym_arguments] = ACTIONS(449),
    [anon_sym_function] = ACTIONS(449),
    [anon_sym_properties] = ACTIONS(449),
    [anon_sym_get] = ACTIONS(449),
    [anon_sym_set] = ACTIONS(449),
    [anon_sym_methods] = ACTIONS(449),
    [anon_sym_events] = ACTIONS(449),
    [anon_sym_enumeration] = ACTIONS(449),
    [anon_sym_classdef] = ACTIONS(449),
    [anon_sym_try] = ACTIONS(449),
    [anon_sym_spmd] = ACTIONS(449),
    [aux_sym_number_token1] = ACTIONS(449),
    [aux_sym_number_token2] = ACTIONS(449),
    [aux_sym_number_token3] = ACTIONS(449),
    [anon_sym_true] = ACTIONS(449),
    [anon_sym_false] = ACTIONS(449),
    [anon_sym_CR] = ACTIONS(449),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(456),
    [sym__single_quote_string_start] = ACTIONS(456),
    [sym__double_quote_string_start] = ACTIONS(456),
    [sym__multioutput_variable_start] = ACTIONS(456),
    [sym__external_identifier] = ACTIONS(456),
  },
  [STATE(151)] = {
    [anon_sym_SEMI] = ACTIONS(653),
    [anon_sym_COMMA] = ACTIONS(653),
    [anon_sym_LPAREN] = ACTIONS(653),
    [anon_sym_PLUS] = ACTIONS(653),
    [anon_sym_DOT_PLUS] = ACTIONS(653),
    [anon_sym_DASH] = ACTIONS(653),
    [anon_sym_DOT_DASH] = ACTIONS(653),
    [anon_sym_STAR] = ACTIONS(653),
    [anon_sym_DOT_STAR] = ACTIONS(653),
    [anon_sym_SLASH] = ACTIONS(653),
    [anon_sym_DOT_SLASH] = ACTIONS(653),
    [anon_sym_BSLASH] = ACTIONS(653),
    [anon_sym_DOT_BSLASH] = ACTIONS(653),
    [anon_sym_CARET] = ACTIONS(653),
    [anon_sym_DOT_CARET] = ACTIONS(653),
    [anon_sym_PIPE] = ACTIONS(653),
    [anon_sym_AMP] = ACTIONS(653),
    [anon_sym_TILDE] = ACTIONS(653),
    [anon_sym_QMARK] = ACTIONS(653),
    [anon_sym_AT] = ACTIONS(653),
    [anon_sym_LT] = ACTIONS(119),
    [anon_sym_LT_EQ] = ACTIONS(119),
    [anon_sym_EQ_EQ] = ACTIONS(119),
    [anon_sym_TILDE_EQ] = ACTIONS(119),
    [anon_sym_GT_EQ] = ACTIONS(119),
    [anon_sym_GT] = ACTIONS(119),
    [anon_sym_AMP_AMP] = ACTIONS(653),
    [anon_sym_PIPE_PIPE] = ACTIONS(653),
    [anon_sym_LBRACK] = ACTIONS(653),
    [anon_sym_LF] = ACTIONS(653),
    [anon_sym_LBRACE] = ACTIONS(653),
    [anon_sym_return] = ACTIONS(653),
    [anon_sym_continue] = ACTIONS(653),
    [anon_sym_break] = ACTIONS(653),
    [anon_sym_elseif] = ACTIONS(653),
    [anon_sym_else] = ACTIONS(653),
    [anon_sym_if] = ACTIONS(653),
    [anon_sym_end] = ACTIONS(653),
    [anon_sym_for] = ACTIONS(653),
    [anon_sym_parfor] = ACTIONS(653),
    [anon_sym_while] = ACTIONS(653),
    [anon_sym_switch] = ACTIONS(653),
    [anon_sym_global] = ACTIONS(653),
    [anon_sym_persistent] = ACTIONS(653),
    [anon_sym_arguments] = ACTIONS(653),
    [anon_sym_function] = ACTIONS(653),
    [anon_sym_properties] = ACTIONS(653),
    [anon_sym_get] = ACTIONS(653),
    [anon_sym_set] = ACTIONS(653),
    [anon_sym_methods] = ACTIONS(653),
    [anon_sym_events] = ACTIONS(653),
    [anon_sym_enumeration] = ACTIONS(653),
    [anon_sym_classdef] = ACTIONS(653),
    [anon_sym_try] = ACTIONS(653),
    [anon_sym_spmd] = ACTIONS(653),
    [aux_sym_number_token1] = ACTIONS(653),
    [aux_sym_number_token2] = ACTIONS(653),
    [aux_sym_number_token3] = ACTIONS(653),
    [anon_sym_true] = ACTIONS(653),
    [anon_sym_false] = ACTIONS(653),
    [anon_sym_CR] = ACTIONS(653),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(655),
    [sym__single_quote_string_start] = ACTIONS(655),
    [sym__double_quote_string_start] = ACTIONS(655),
    [sym__multioutput_variable_start] = ACTIONS(655),
    [sym__external_identifier] = ACTIONS(655),
  },
  [STATE(152)] = {
    [anon_sym_SEMI] = ACTIONS(653),
    [anon_sym_COMMA] = ACTIONS(653),
    [anon_sym_LPAREN] = ACTIONS(653),
    [anon_sym_PLUS] = ACTIONS(653),
    [anon_sym_DOT_PLUS] = ACTIONS(653),
    [anon_sym_DASH] = ACTIONS(653),
    [anon_sym_DOT_DASH] = ACTIONS(653),
    [anon_sym_STAR] = ACTIONS(653),
    [anon_sym_DOT_STAR] = ACTIONS(653),
    [anon_sym_SLASH] = ACTIONS(653),
    [anon_sym_DOT_SLASH] = ACTIONS(653),
    [anon_sym_BSLASH] = ACTIONS(653),
    [anon_sym_DOT_BSLASH] = ACTIONS(653),
    [anon_sym_CARET] = ACTIONS(653),
    [anon_sym_DOT_CARET] = ACTIONS(653),
    [anon_sym_PIPE] = ACTIONS(653),
    [anon_sym_AMP] = ACTIONS(653),
    [anon_sym_TILDE] = ACTIONS(653),
    [anon_sym_QMARK] = ACTIONS(653),
    [anon_sym_AT] = ACTIONS(653),
    [anon_sym_LT] = ACTIONS(119),
    [anon_sym_LT_EQ] = ACTIONS(119),
    [anon_sym_EQ_EQ] = ACTIONS(119),
    [anon_sym_TILDE_EQ] = ACTIONS(119),
    [anon_sym_GT_EQ] = ACTIONS(119),
    [anon_sym_GT] = ACTIONS(119),
    [anon_sym_AMP_AMP] = ACTIONS(121),
    [anon_sym_PIPE_PIPE] = ACTIONS(653),
    [anon_sym_LBRACK] = ACTIONS(653),
    [anon_sym_LF] = ACTIONS(653),
    [anon_sym_LBRACE] = ACTIONS(653),
    [anon_sym_return] = ACTIONS(653),
    [anon_sym_continue] = ACTIONS(653),
    [anon_sym_break] = ACTIONS(653),
    [anon_sym_elseif] = ACTIONS(653),
    [anon_sym_else] = ACTIONS(653),
    [anon_sym_if] = ACTIONS(653),
    [anon_sym_end] = ACTIONS(653),
    [anon_sym_for] = ACTIONS(653),
    [anon_sym_parfor] = ACTIONS(653),
    [anon_sym_while] = ACTIONS(653),
    [anon_sym_switch] = ACTIONS(653),
    [anon_sym_global] = ACTIONS(653),
    [anon_sym_persistent] = ACTIONS(653),
    [anon_sym_arguments] = ACTIONS(653),
    [anon_sym_function] = ACTIONS(653),
    [anon_sym_properties] = ACTIONS(653),
    [anon_sym_get] = ACTIONS(653),
    [anon_sym_set] = ACTIONS(653),
    [anon_sym_methods] = ACTIONS(653),
    [anon_sym_events] = ACTIONS(653),
    [anon_sym_enumeration] = ACTIONS(653),
    [anon_sym_classdef] = ACTIONS(653),
    [anon_sym_try] = ACTIONS(653),
    [anon_sym_spmd] = ACTIONS(653),
    [aux_sym_number_token1] = ACTIONS(653),
    [aux_sym_number_token2] = ACTIONS(653),
    [aux_sym_number_token3] = ACTIONS(653),
    [anon_sym_true] = ACTIONS(653),
    [anon_sym_false] = ACTIONS(653),
    [anon_sym_CR] = ACTIONS(653),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(655),
    [sym__single_quote_string_start] = ACTIONS(655),
    [sym__double_quote_string_start] = ACTIONS(655),
    [sym__multioutput_variable_start] = ACTIONS(655),
    [sym__external_identifier] = ACTIONS(655),
  },
  [STATE(153)] = {
    [anon_sym_SEMI] = ACTIONS(600),
    [anon_sym_COMMA] = ACTIONS(600),
    [anon_sym_LPAREN] = ACTIONS(600),
    [anon_sym_PLUS] = ACTIONS(600),
    [anon_sym_DOT_PLUS] = ACTIONS(600),
    [anon_sym_DASH] = ACTIONS(600),
    [anon_sym_DOT_DASH] = ACTIONS(600),
    [anon_sym_STAR] = ACTIONS(600),
    [anon_sym_DOT_STAR] = ACTIONS(600),
    [anon_sym_SLASH] = ACTIONS(600),
    [anon_sym_DOT_SLASH] = ACTIONS(600),
    [anon_sym_BSLASH] = ACTIONS(600),
    [anon_sym_DOT_BSLASH] = ACTIONS(600),
    [anon_sym_CARET] = ACTIONS(600),
    [anon_sym_DOT_CARET] = ACTIONS(600),
    [anon_sym_PIPE] = ACTIONS(600),
    [anon_sym_AMP] = ACTIONS(600),
    [anon_sym_TILDE] = ACTIONS(600),
    [anon_sym_QMARK] = ACTIONS(600),
    [anon_sym_AT] = ACTIONS(600),
    [anon_sym_LT] = ACTIONS(119),
    [anon_sym_LT_EQ] = ACTIONS(119),
    [anon_sym_EQ_EQ] = ACTIONS(119),
    [anon_sym_TILDE_EQ] = ACTIONS(119),
    [anon_sym_GT_EQ] = ACTIONS(119),
    [anon_sym_GT] = ACTIONS(119),
    [anon_sym_AMP_AMP] = ACTIONS(121),
    [anon_sym_PIPE_PIPE] = ACTIONS(123),
    [anon_sym_LBRACK] = ACTIONS(600),
    [anon_sym_LF] = ACTIONS(600),
    [anon_sym_LBRACE] = ACTIONS(600),
    [anon_sym_return] = ACTIONS(600),
    [anon_sym_continue] = ACTIONS(600),
    [anon_sym_break] = ACTIONS(600),
    [anon_sym_elseif] = ACTIONS(600),
    [anon_sym_else] = ACTIONS(600),
    [anon_sym_if] = ACTIONS(600),
    [anon_sym_end] = ACTIONS(600),
    [anon_sym_for] = ACTIONS(600),
    [anon_sym_parfor] = ACTIONS(600),
    [anon_sym_while] = ACTIONS(600),
    [anon_sym_switch] = ACTIONS(600),
    [anon_sym_global] = ACTIONS(600),
    [anon_sym_persistent] = ACTIONS(600),
    [anon_sym_arguments] = ACTIONS(600),
    [anon_sym_function] = ACTIONS(600),
    [anon_sym_properties] = ACTIONS(600),
    [anon_sym_get] = ACTIONS(600),
    [anon_sym_set] = ACTIONS(600),
    [anon_sym_methods] = ACTIONS(600),
    [anon_sym_events] = ACTIONS(600),
    [anon_sym_enumeration] = ACTIONS(600),
    [anon_sym_classdef] = ACTIONS(600),
    [anon_sym_try] = ACTIONS(600),
    [anon_sym_spmd] = ACTIONS(600),
    [aux_sym_number_token1] = ACTIONS(600),
    [aux_sym_number_token2] = ACTIONS(600),
    [aux_sym_number_token3] = ACTIONS(600),
    [anon_sym_true] = ACTIONS(600),
    [anon_sym_false] = ACTIONS(600),
    [anon_sym_CR] = ACTIONS(600),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(606),
    [sym__single_quote_string_start] = ACTIONS(606),
    [sym__double_quote_string_start] = ACTIONS(606),
    [sym__multioutput_variable_start] = ACTIONS(606),
    [sym__external_identifier] = ACTIONS(606),
  },
  [STATE(154)] = {
    [anon_sym_SEMI] = ACTIONS(657),
    [anon_sym_COMMA] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(657),
    [anon_sym_PLUS] = ACTIONS(657),
    [anon_sym_DOT_PLUS] = ACTIONS(657),
    [anon_sym_DASH] = ACTIONS(657),
    [anon_sym_DOT_DASH] = ACTIONS(657),
    [anon_sym_STAR] = ACTIONS(657),
    [anon_sym_DOT_STAR] = ACTIONS(657),
    [anon_sym_SLASH] = ACTIONS(657),
    [anon_sym_DOT_SLASH] = ACTIONS(657),
    [anon_sym_BSLASH] = ACTIONS(657),
    [anon_sym_DOT_BSLASH] = ACTIONS(657),
    [anon_sym_CARET] = ACTIONS(657),
    [anon_sym_DOT_CARET] = ACTIONS(657),
    [anon_sym_PIPE] = ACTIONS(657),
    [anon_sym_AMP] = ACTIONS(657),
    [anon_sym_TILDE] = ACTIONS(657),
    [anon_sym_QMARK] = ACTIONS(657),
    [anon_sym_AT] = ACTIONS(657),
    [anon_sym_LT] = ACTIONS(119),
    [anon_sym_LT_EQ] = ACTIONS(119),
    [anon_sym_EQ_EQ] = ACTIONS(119),
    [anon_sym_TILDE_EQ] = ACTIONS(119),
    [anon_sym_GT_EQ] = ACTIONS(119),
    [anon_sym_GT] = ACTIONS(119),
    [anon_sym_AMP_AMP] = ACTIONS(121),
    [anon_sym_PIPE_PIPE] = ACTIONS(123),
    [anon_sym_LBRACK] = ACTIONS(657),
    [anon_sym_LF] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(657),
    [anon_sym_return] = ACTIONS(657),
    [anon_sym_continue] = ACTIONS(657),
    [anon_sym_break] = ACTIONS(657),
    [anon_sym_elseif] = ACTIONS(657),
    [anon_sym_else] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(657),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_for] = ACTIONS(657),
    [anon_sym_parfor] = ACTIONS(657),
    [anon_sym_while] = ACTIONS(657),
    [anon_sym_switch] = ACTIONS(657),
    [anon_sym_global] = ACTIONS(657),
    [anon_sym_persistent] = ACTIONS(657),
    [anon_sym_arguments] = ACTIONS(657),
    [anon_sym_function] = ACTIONS(657),
    [anon_sym_properties] = ACTIONS(657),
    [anon_sym_get] = ACTIONS(657),
    [anon_sym_set] = ACTIONS(657),
    [anon_sym_methods] = ACTIONS(657),
    [anon_sym_events] = ACTIONS(657),
    [anon_sym_enumeration] = ACTIONS(657),
    [anon_sym_classdef] = ACTIONS(657),
    [anon_sym_try] = ACTIONS(657),
    [anon_sym_spmd] = ACTIONS(657),
    [aux_sym_number_token1] = ACTIONS(657),
    [aux_sym_number_token2] = ACTIONS(657),
    [aux_sym_number_token3] = ACTIONS(657),
    [anon_sym_true] = ACTIONS(657),
    [anon_sym_false] = ACTIONS(657),
    [anon_sym_CR] = ACTIONS(657),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(659),
    [sym__single_quote_string_start] = ACTIONS(659),
    [sym__double_quote_string_start] = ACTIONS(659),
    [sym__multioutput_variable_start] = ACTIONS(659),
    [sym__external_identifier] = ACTIONS(659),
  },
  [STATE(155)] = {
    [sym_identifier] = STATE(406),
    [sym__expression] = STATE(921),
    [sym_parenthesis] = STATE(546),
    [sym__binary_expression] = STATE(914),
    [sym_binary_operator] = STATE(547),
    [sym_unary_operator] = STATE(613),
    [sym_indirect_access] = STATE(1321),
    [sym_field_expression] = STATE(604),
    [sym_not_operator] = STATE(707),
    [sym_metaclass_operator] = STATE(921),
    [sym_handle_operator] = STATE(921),
    [sym_comparison_operator] = STATE(728),
    [sym_boolean_operator] = STATE(728),
    [sym_postfix_operator] = STATE(604),
    [sym_string] = STATE(604),
    [sym_row] = STATE(1240),
    [sym_matrix] = STATE(546),
    [sym_cell] = STATE(640),
    [sym_ignored_argument] = STATE(1083),
    [sym__index_row] = STATE(1257),
    [sym__index_matrix] = STATE(782),
    [sym__index_range_element] = STATE(1485),
    [sym__index_range] = STATE(1195),
    [sym__index_parenthesis] = STATE(782),
    [sym__index_expression] = STATE(1195),
    [sym__index_binary_expression] = STATE(911),
    [sym__index_binary_operator] = STATE(796),
    [sym_function_call] = STATE(406),
    [sym__range_element] = STATE(1465),
    [sym_range] = STATE(921),
    [sym_lambda] = STATE(921),
    [sym_number] = STATE(604),
    [sym_boolean] = STATE(449),
    [sym_end_keyword] = STATE(782),
    [sym__keywords] = STATE(445),
    [aux_sym_matrix_repeat1] = STATE(161),
    [anon_sym_COMMA] = ACTIONS(663),
    [anon_sym_LPAREN] = ACTIONS(665),
    [anon_sym_PLUS] = ACTIONS(667),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(669),
    [anon_sym_QMARK] = ACTIONS(671),
    [anon_sym_AT] = ACTIONS(673),
    [anon_sym_LBRACK] = ACTIONS(675),
    [anon_sym_LF] = ACTIONS(677),
    [anon_sym_RBRACK] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(681),
    [anon_sym_end] = ACTIONS(683),
    [anon_sym_arguments] = ACTIONS(685),
    [anon_sym_properties] = ACTIONS(685),
    [anon_sym_get] = ACTIONS(685),
    [anon_sym_set] = ACTIONS(685),
    [anon_sym_methods] = ACTIONS(685),
    [anon_sym_events] = ACTIONS(685),
    [anon_sym_enumeration] = ACTIONS(685),
    [aux_sym_number_token1] = ACTIONS(687),
    [aux_sym_number_token2] = ACTIONS(687),
    [aux_sym_number_token3] = ACTIONS(687),
    [anon_sym_true] = ACTIONS(689),
    [anon_sym_false] = ACTIONS(689),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__single_quote_string_start] = ACTIONS(691),
    [sym__double_quote_string_start] = ACTIONS(693),
    [sym__external_identifier] = ACTIONS(695),
  },
  [STATE(156)] = {
    [sym_identifier] = STATE(406),
    [sym__expression] = STATE(921),
    [sym_parenthesis] = STATE(546),
    [sym__binary_expression] = STATE(914),
    [sym_binary_operator] = STATE(547),
    [sym_unary_operator] = STATE(613),
    [sym_indirect_access] = STATE(1321),
    [sym_field_expression] = STATE(604),
    [sym_not_operator] = STATE(707),
    [sym_metaclass_operator] = STATE(921),
    [sym_handle_operator] = STATE(921),
    [sym_comparison_operator] = STATE(728),
    [sym_boolean_operator] = STATE(728),
    [sym_postfix_operator] = STATE(604),
    [sym_string] = STATE(604),
    [sym_row] = STATE(1306),
    [sym_matrix] = STATE(546),
    [sym_cell] = STATE(640),
    [sym_ignored_argument] = STATE(1083),
    [sym__index_row] = STATE(1257),
    [sym__index_matrix] = STATE(782),
    [sym__index_range_element] = STATE(1485),
    [sym__index_range] = STATE(1195),
    [sym__index_parenthesis] = STATE(782),
    [sym__index_expression] = STATE(1195),
    [sym__index_binary_expression] = STATE(911),
    [sym__index_binary_operator] = STATE(796),
    [sym_function_call] = STATE(406),
    [sym__range_element] = STATE(1465),
    [sym_range] = STATE(921),
    [sym_lambda] = STATE(921),
    [sym_number] = STATE(604),
    [sym_boolean] = STATE(449),
    [sym_end_keyword] = STATE(782),
    [sym__keywords] = STATE(445),
    [aux_sym_matrix_repeat1] = STATE(158),
    [anon_sym_COMMA] = ACTIONS(663),
    [anon_sym_LPAREN] = ACTIONS(665),
    [anon_sym_PLUS] = ACTIONS(667),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(669),
    [anon_sym_QMARK] = ACTIONS(671),
    [anon_sym_AT] = ACTIONS(673),
    [anon_sym_LBRACK] = ACTIONS(675),
    [anon_sym_LF] = ACTIONS(697),
    [anon_sym_RBRACK] = ACTIONS(699),
    [anon_sym_LBRACE] = ACTIONS(681),
    [anon_sym_end] = ACTIONS(683),
    [anon_sym_arguments] = ACTIONS(685),
    [anon_sym_properties] = ACTIONS(685),
    [anon_sym_get] = ACTIONS(685),
    [anon_sym_set] = ACTIONS(685),
    [anon_sym_methods] = ACTIONS(685),
    [anon_sym_events] = ACTIONS(685),
    [anon_sym_enumeration] = ACTIONS(685),
    [aux_sym_number_token1] = ACTIONS(687),
    [aux_sym_number_token2] = ACTIONS(687),
    [aux_sym_number_token3] = ACTIONS(687),
    [anon_sym_true] = ACTIONS(689),
    [anon_sym_false] = ACTIONS(689),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__single_quote_string_start] = ACTIONS(691),
    [sym__double_quote_string_start] = ACTIONS(693),
    [sym__external_identifier] = ACTIONS(695),
  },
  [STATE(157)] = {
    [sym_identifier] = STATE(406),
    [sym__expression] = STATE(921),
    [sym_parenthesis] = STATE(546),
    [sym__binary_expression] = STATE(914),
    [sym_binary_operator] = STATE(547),
    [sym_unary_operator] = STATE(613),
    [sym_indirect_access] = STATE(1321),
    [sym_field_expression] = STATE(604),
    [sym_not_operator] = STATE(707),
    [sym_metaclass_operator] = STATE(921),
    [sym_handle_operator] = STATE(921),
    [sym_comparison_operator] = STATE(728),
    [sym_boolean_operator] = STATE(728),
    [sym_postfix_operator] = STATE(604),
    [sym_string] = STATE(604),
    [sym_row] = STATE(1246),
    [sym_matrix] = STATE(546),
    [sym_cell] = STATE(640),
    [sym_ignored_argument] = STATE(1083),
    [sym__index_row] = STATE(1279),
    [sym__index_matrix] = STATE(782),
    [sym__index_range_element] = STATE(1485),
    [sym__index_range] = STATE(1195),
    [sym__index_parenthesis] = STATE(782),
    [sym__index_expression] = STATE(1195),
    [sym__index_binary_expression] = STATE(911),
    [sym__index_binary_operator] = STATE(796),
    [sym_function_call] = STATE(406),
    [sym__range_element] = STATE(1465),
    [sym_range] = STATE(921),
    [sym_lambda] = STATE(921),
    [sym_number] = STATE(604),
    [sym_boolean] = STATE(449),
    [sym_end_keyword] = STATE(782),
    [sym__keywords] = STATE(445),
    [aux_sym_matrix_repeat1] = STATE(599),
    [anon_sym_COMMA] = ACTIONS(663),
    [anon_sym_LPAREN] = ACTIONS(665),
    [anon_sym_PLUS] = ACTIONS(667),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(669),
    [anon_sym_QMARK] = ACTIONS(671),
    [anon_sym_AT] = ACTIONS(673),
    [anon_sym_LBRACK] = ACTIONS(675),
    [anon_sym_LF] = ACTIONS(701),
    [anon_sym_RBRACK] = ACTIONS(703),
    [anon_sym_LBRACE] = ACTIONS(681),
    [anon_sym_end] = ACTIONS(683),
    [anon_sym_arguments] = ACTIONS(685),
    [anon_sym_properties] = ACTIONS(685),
    [anon_sym_get] = ACTIONS(685),
    [anon_sym_set] = ACTIONS(685),
    [anon_sym_methods] = ACTIONS(685),
    [anon_sym_events] = ACTIONS(685),
    [anon_sym_enumeration] = ACTIONS(685),
    [aux_sym_number_token1] = ACTIONS(687),
    [aux_sym_number_token2] = ACTIONS(687),
    [aux_sym_number_token3] = ACTIONS(687),
    [anon_sym_true] = ACTIONS(689),
    [anon_sym_false] = ACTIONS(689),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__single_quote_string_start] = ACTIONS(691),
    [sym__double_quote_string_start] = ACTIONS(693),
    [sym__external_identifier] = ACTIONS(695),
  },
  [STATE(158)] = {
    [sym_identifier] = STATE(406),
    [sym__expression] = STATE(921),
    [sym_parenthesis] = STATE(546),
    [sym__binary_expression] = STATE(914),
    [sym_binary_operator] = STATE(547),
    [sym_unary_operator] = STATE(613),
    [sym_indirect_access] = STATE(1321),
    [sym_field_expression] = STATE(604),
    [sym_not_operator] = STATE(707),
    [sym_metaclass_operator] = STATE(921),
    [sym_handle_operator] = STATE(921),
    [sym_comparison_operator] = STATE(728),
    [sym_boolean_operator] = STATE(728),
    [sym_postfix_operator] = STATE(604),
    [sym_string] = STATE(604),
    [sym_row] = STATE(1311),
    [sym_matrix] = STATE(546),
    [sym_cell] = STATE(640),
    [sym_ignored_argument] = STATE(1083),
    [sym__index_row] = STATE(1261),
    [sym__index_matrix] = STATE(782),
    [sym__index_range_element] = STATE(1485),
    [sym__index_range] = STATE(1195),
    [sym__index_parenthesis] = STATE(782),
    [sym__index_expression] = STATE(1195),
    [sym__index_binary_expression] = STATE(911),
    [sym__index_binary_operator] = STATE(796),
    [sym_function_call] = STATE(406),
    [sym__range_element] = STATE(1465),
    [sym_range] = STATE(921),
    [sym_lambda] = STATE(921),
    [sym_number] = STATE(604),
    [sym_boolean] = STATE(449),
    [sym_end_keyword] = STATE(782),
    [sym__keywords] = STATE(445),
    [aux_sym_matrix_repeat1] = STATE(599),
    [anon_sym_COMMA] = ACTIONS(663),
    [anon_sym_LPAREN] = ACTIONS(665),
    [anon_sym_PLUS] = ACTIONS(667),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(669),
    [anon_sym_QMARK] = ACTIONS(671),
    [anon_sym_AT] = ACTIONS(673),
    [anon_sym_LBRACK] = ACTIONS(675),
    [anon_sym_LF] = ACTIONS(701),
    [anon_sym_RBRACK] = ACTIONS(705),
    [anon_sym_LBRACE] = ACTIONS(681),
    [anon_sym_end] = ACTIONS(683),
    [anon_sym_arguments] = ACTIONS(685),
    [anon_sym_properties] = ACTIONS(685),
    [anon_sym_get] = ACTIONS(685),
    [anon_sym_set] = ACTIONS(685),
    [anon_sym_methods] = ACTIONS(685),
    [anon_sym_events] = ACTIONS(685),
    [anon_sym_enumeration] = ACTIONS(685),
    [aux_sym_number_token1] = ACTIONS(687),
    [aux_sym_number_token2] = ACTIONS(687),
    [aux_sym_number_token3] = ACTIONS(687),
    [anon_sym_true] = ACTIONS(689),
    [anon_sym_false] = ACTIONS(689),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__single_quote_string_start] = ACTIONS(691),
    [sym__double_quote_string_start] = ACTIONS(693),
    [sym__external_identifier] = ACTIONS(695),
  },
  [STATE(159)] = {
    [sym_identifier] = STATE(406),
    [sym__expression] = STATE(921),
    [sym_parenthesis] = STATE(546),
    [sym__binary_expression] = STATE(914),
    [sym_binary_operator] = STATE(547),
    [sym_unary_operator] = STATE(613),
    [sym_indirect_access] = STATE(1321),
    [sym_field_expression] = STATE(604),
    [sym_not_operator] = STATE(707),
    [sym_metaclass_operator] = STATE(921),
    [sym_handle_operator] = STATE(921),
    [sym_comparison_operator] = STATE(728),
    [sym_boolean_operator] = STATE(728),
    [sym_postfix_operator] = STATE(604),
    [sym_string] = STATE(604),
    [sym_row] = STATE(1240),
    [sym_matrix] = STATE(546),
    [sym_cell] = STATE(640),
    [sym_ignored_argument] = STATE(1083),
    [sym__index_row] = STATE(1280),
    [sym__index_matrix] = STATE(782),
    [sym__index_range_element] = STATE(1485),
    [sym__index_range] = STATE(1195),
    [sym__index_parenthesis] = STATE(782),
    [sym__index_expression] = STATE(1195),
    [sym__index_binary_expression] = STATE(911),
    [sym__index_binary_operator] = STATE(796),
    [sym_function_call] = STATE(406),
    [sym__range_element] = STATE(1465),
    [sym_range] = STATE(921),
    [sym_lambda] = STATE(921),
    [sym_number] = STATE(604),
    [sym_boolean] = STATE(449),
    [sym_end_keyword] = STATE(782),
    [sym__keywords] = STATE(445),
    [aux_sym_matrix_repeat1] = STATE(157),
    [anon_sym_COMMA] = ACTIONS(663),
    [anon_sym_LPAREN] = ACTIONS(665),
    [anon_sym_PLUS] = ACTIONS(667),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(669),
    [anon_sym_QMARK] = ACTIONS(671),
    [anon_sym_AT] = ACTIONS(673),
    [anon_sym_LBRACK] = ACTIONS(675),
    [anon_sym_LF] = ACTIONS(707),
    [anon_sym_RBRACK] = ACTIONS(709),
    [anon_sym_LBRACE] = ACTIONS(681),
    [anon_sym_end] = ACTIONS(683),
    [anon_sym_arguments] = ACTIONS(685),
    [anon_sym_properties] = ACTIONS(685),
    [anon_sym_get] = ACTIONS(685),
    [anon_sym_set] = ACTIONS(685),
    [anon_sym_methods] = ACTIONS(685),
    [anon_sym_events] = ACTIONS(685),
    [anon_sym_enumeration] = ACTIONS(685),
    [aux_sym_number_token1] = ACTIONS(687),
    [aux_sym_number_token2] = ACTIONS(687),
    [aux_sym_number_token3] = ACTIONS(687),
    [anon_sym_true] = ACTIONS(689),
    [anon_sym_false] = ACTIONS(689),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__single_quote_string_start] = ACTIONS(691),
    [sym__double_quote_string_start] = ACTIONS(693),
    [sym__external_identifier] = ACTIONS(695),
  },
  [STATE(160)] = {
    [sym_identifier] = STATE(406),
    [sym__expression] = STATE(921),
    [sym_parenthesis] = STATE(546),
    [sym__binary_expression] = STATE(914),
    [sym_binary_operator] = STATE(547),
    [sym_unary_operator] = STATE(613),
    [sym_indirect_access] = STATE(1321),
    [sym_field_expression] = STATE(604),
    [sym_not_operator] = STATE(707),
    [sym_metaclass_operator] = STATE(921),
    [sym_handle_operator] = STATE(921),
    [sym_comparison_operator] = STATE(728),
    [sym_boolean_operator] = STATE(728),
    [sym_postfix_operator] = STATE(604),
    [sym_string] = STATE(604),
    [sym_row] = STATE(1240),
    [sym_matrix] = STATE(546),
    [sym_cell] = STATE(640),
    [sym_ignored_argument] = STATE(1083),
    [sym__index_row] = STATE(1280),
    [sym__index_matrix] = STATE(782),
    [sym__index_range_element] = STATE(1485),
    [sym__index_range] = STATE(1195),
    [sym__index_parenthesis] = STATE(782),
    [sym__index_expression] = STATE(1195),
    [sym__index_binary_expression] = STATE(911),
    [sym__index_binary_operator] = STATE(796),
    [sym_function_call] = STATE(406),
    [sym__range_element] = STATE(1465),
    [sym_range] = STATE(921),
    [sym_lambda] = STATE(921),
    [sym_number] = STATE(604),
    [sym_boolean] = STATE(449),
    [sym_end_keyword] = STATE(782),
    [sym__keywords] = STATE(445),
    [aux_sym_matrix_repeat1] = STATE(164),
    [anon_sym_COMMA] = ACTIONS(663),
    [anon_sym_LPAREN] = ACTIONS(665),
    [anon_sym_PLUS] = ACTIONS(667),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(669),
    [anon_sym_QMARK] = ACTIONS(671),
    [anon_sym_AT] = ACTIONS(673),
    [anon_sym_LBRACK] = ACTIONS(675),
    [anon_sym_LF] = ACTIONS(711),
    [anon_sym_RBRACK] = ACTIONS(713),
    [anon_sym_LBRACE] = ACTIONS(681),
    [anon_sym_end] = ACTIONS(683),
    [anon_sym_arguments] = ACTIONS(685),
    [anon_sym_properties] = ACTIONS(685),
    [anon_sym_get] = ACTIONS(685),
    [anon_sym_set] = ACTIONS(685),
    [anon_sym_methods] = ACTIONS(685),
    [anon_sym_events] = ACTIONS(685),
    [anon_sym_enumeration] = ACTIONS(685),
    [aux_sym_number_token1] = ACTIONS(687),
    [aux_sym_number_token2] = ACTIONS(687),
    [aux_sym_number_token3] = ACTIONS(687),
    [anon_sym_true] = ACTIONS(689),
    [anon_sym_false] = ACTIONS(689),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__single_quote_string_start] = ACTIONS(691),
    [sym__double_quote_string_start] = ACTIONS(693),
    [sym__external_identifier] = ACTIONS(695),
  },
  [STATE(161)] = {
    [sym_identifier] = STATE(406),
    [sym__expression] = STATE(921),
    [sym_parenthesis] = STATE(546),
    [sym__binary_expression] = STATE(914),
    [sym_binary_operator] = STATE(547),
    [sym_unary_operator] = STATE(613),
    [sym_indirect_access] = STATE(1321),
    [sym_field_expression] = STATE(604),
    [sym_not_operator] = STATE(707),
    [sym_metaclass_operator] = STATE(921),
    [sym_handle_operator] = STATE(921),
    [sym_comparison_operator] = STATE(728),
    [sym_boolean_operator] = STATE(728),
    [sym_postfix_operator] = STATE(604),
    [sym_string] = STATE(604),
    [sym_row] = STATE(1246),
    [sym_matrix] = STATE(546),
    [sym_cell] = STATE(640),
    [sym_ignored_argument] = STATE(1083),
    [sym__index_row] = STATE(1261),
    [sym__index_matrix] = STATE(782),
    [sym__index_range_element] = STATE(1485),
    [sym__index_range] = STATE(1195),
    [sym__index_parenthesis] = STATE(782),
    [sym__index_expression] = STATE(1195),
    [sym__index_binary_expression] = STATE(911),
    [sym__index_binary_operator] = STATE(796),
    [sym_function_call] = STATE(406),
    [sym__range_element] = STATE(1465),
    [sym_range] = STATE(921),
    [sym_lambda] = STATE(921),
    [sym_number] = STATE(604),
    [sym_boolean] = STATE(449),
    [sym_end_keyword] = STATE(782),
    [sym__keywords] = STATE(445),
    [aux_sym_matrix_repeat1] = STATE(599),
    [anon_sym_COMMA] = ACTIONS(663),
    [anon_sym_LPAREN] = ACTIONS(665),
    [anon_sym_PLUS] = ACTIONS(667),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(669),
    [anon_sym_QMARK] = ACTIONS(671),
    [anon_sym_AT] = ACTIONS(673),
    [anon_sym_LBRACK] = ACTIONS(675),
    [anon_sym_LF] = ACTIONS(701),
    [anon_sym_RBRACK] = ACTIONS(715),
    [anon_sym_LBRACE] = ACTIONS(681),
    [anon_sym_end] = ACTIONS(683),
    [anon_sym_arguments] = ACTIONS(685),
    [anon_sym_properties] = ACTIONS(685),
    [anon_sym_get] = ACTIONS(685),
    [anon_sym_set] = ACTIONS(685),
    [anon_sym_methods] = ACTIONS(685),
    [anon_sym_events] = ACTIONS(685),
    [anon_sym_enumeration] = ACTIONS(685),
    [aux_sym_number_token1] = ACTIONS(687),
    [aux_sym_number_token2] = ACTIONS(687),
    [aux_sym_number_token3] = ACTIONS(687),
    [anon_sym_true] = ACTIONS(689),
    [anon_sym_false] = ACTIONS(689),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__single_quote_string_start] = ACTIONS(691),
    [sym__double_quote_string_start] = ACTIONS(693),
    [sym__external_identifier] = ACTIONS(695),
  },
  [STATE(162)] = {
    [sym_identifier] = STATE(406),
    [sym__expression] = STATE(921),
    [sym_parenthesis] = STATE(546),
    [sym__binary_expression] = STATE(914),
    [sym_binary_operator] = STATE(547),
    [sym_unary_operator] = STATE(613),
    [sym_indirect_access] = STATE(1321),
    [sym_field_expression] = STATE(604),
    [sym_not_operator] = STATE(707),
    [sym_metaclass_operator] = STATE(921),
    [sym_handle_operator] = STATE(921),
    [sym_comparison_operator] = STATE(728),
    [sym_boolean_operator] = STATE(728),
    [sym_postfix_operator] = STATE(604),
    [sym_string] = STATE(604),
    [sym_row] = STATE(1246),
    [sym_matrix] = STATE(546),
    [sym_cell] = STATE(640),
    [sym_ignored_argument] = STATE(1083),
    [sym__index_row] = STATE(1279),
    [sym__index_matrix] = STATE(782),
    [sym__index_range_element] = STATE(1485),
    [sym__index_range] = STATE(1195),
    [sym__index_parenthesis] = STATE(782),
    [sym__index_expression] = STATE(1195),
    [sym__index_binary_expression] = STATE(911),
    [sym__index_binary_operator] = STATE(796),
    [sym_function_call] = STATE(406),
    [sym__range_element] = STATE(1465),
    [sym_range] = STATE(921),
    [sym_lambda] = STATE(921),
    [sym_number] = STATE(604),
    [sym_boolean] = STATE(449),
    [sym_end_keyword] = STATE(782),
    [sym__keywords] = STATE(445),
    [aux_sym_matrix_repeat1] = STATE(599),
    [anon_sym_COMMA] = ACTIONS(663),
    [anon_sym_LPAREN] = ACTIONS(665),
    [anon_sym_PLUS] = ACTIONS(667),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(669),
    [anon_sym_QMARK] = ACTIONS(671),
    [anon_sym_AT] = ACTIONS(673),
    [anon_sym_LBRACK] = ACTIONS(675),
    [anon_sym_LF] = ACTIONS(701),
    [anon_sym_RBRACK] = ACTIONS(717),
    [anon_sym_LBRACE] = ACTIONS(681),
    [anon_sym_end] = ACTIONS(683),
    [anon_sym_arguments] = ACTIONS(685),
    [anon_sym_properties] = ACTIONS(685),
    [anon_sym_get] = ACTIONS(685),
    [anon_sym_set] = ACTIONS(685),
    [anon_sym_methods] = ACTIONS(685),
    [anon_sym_events] = ACTIONS(685),
    [anon_sym_enumeration] = ACTIONS(685),
    [aux_sym_number_token1] = ACTIONS(687),
    [aux_sym_number_token2] = ACTIONS(687),
    [aux_sym_number_token3] = ACTIONS(687),
    [anon_sym_true] = ACTIONS(689),
    [anon_sym_false] = ACTIONS(689),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__single_quote_string_start] = ACTIONS(691),
    [sym__double_quote_string_start] = ACTIONS(693),
    [sym__external_identifier] = ACTIONS(695),
  },
  [STATE(163)] = {
    [sym_identifier] = STATE(406),
    [sym__expression] = STATE(921),
    [sym_parenthesis] = STATE(546),
    [sym__binary_expression] = STATE(914),
    [sym_binary_operator] = STATE(547),
    [sym_unary_operator] = STATE(613),
    [sym_indirect_access] = STATE(1321),
    [sym_field_expression] = STATE(604),
    [sym_not_operator] = STATE(707),
    [sym_metaclass_operator] = STATE(921),
    [sym_handle_operator] = STATE(921),
    [sym_comparison_operator] = STATE(728),
    [sym_boolean_operator] = STATE(728),
    [sym_postfix_operator] = STATE(604),
    [sym_string] = STATE(604),
    [sym_row] = STATE(1240),
    [sym_matrix] = STATE(546),
    [sym_cell] = STATE(640),
    [sym_ignored_argument] = STATE(1083),
    [sym__index_row] = STATE(1280),
    [sym__index_matrix] = STATE(782),
    [sym__index_range_element] = STATE(1485),
    [sym__index_range] = STATE(1195),
    [sym__index_parenthesis] = STATE(782),
    [sym__index_expression] = STATE(1195),
    [sym__index_binary_expression] = STATE(911),
    [sym__index_binary_operator] = STATE(796),
    [sym_function_call] = STATE(406),
    [sym__range_element] = STATE(1465),
    [sym_range] = STATE(921),
    [sym_lambda] = STATE(921),
    [sym_number] = STATE(604),
    [sym_boolean] = STATE(449),
    [sym_end_keyword] = STATE(782),
    [sym__keywords] = STATE(445),
    [aux_sym_matrix_repeat1] = STATE(162),
    [anon_sym_COMMA] = ACTIONS(663),
    [anon_sym_LPAREN] = ACTIONS(665),
    [anon_sym_PLUS] = ACTIONS(667),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(669),
    [anon_sym_QMARK] = ACTIONS(671),
    [anon_sym_AT] = ACTIONS(673),
    [anon_sym_LBRACK] = ACTIONS(675),
    [anon_sym_LF] = ACTIONS(719),
    [anon_sym_RBRACK] = ACTIONS(721),
    [anon_sym_LBRACE] = ACTIONS(681),
    [anon_sym_end] = ACTIONS(683),
    [anon_sym_arguments] = ACTIONS(685),
    [anon_sym_properties] = ACTIONS(685),
    [anon_sym_get] = ACTIONS(685),
    [anon_sym_set] = ACTIONS(685),
    [anon_sym_methods] = ACTIONS(685),
    [anon_sym_events] = ACTIONS(685),
    [anon_sym_enumeration] = ACTIONS(685),
    [aux_sym_number_token1] = ACTIONS(687),
    [aux_sym_number_token2] = ACTIONS(687),
    [aux_sym_number_token3] = ACTIONS(687),
    [anon_sym_true] = ACTIONS(689),
    [anon_sym_false] = ACTIONS(689),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__single_quote_string_start] = ACTIONS(691),
    [sym__double_quote_string_start] = ACTIONS(693),
    [sym__external_identifier] = ACTIONS(695),
  },
  [STATE(164)] = {
    [sym_identifier] = STATE(406),
    [sym__expression] = STATE(921),
    [sym_parenthesis] = STATE(546),
    [sym__binary_expression] = STATE(914),
    [sym_binary_operator] = STATE(547),
    [sym_unary_operator] = STATE(613),
    [sym_indirect_access] = STATE(1321),
    [sym_field_expression] = STATE(604),
    [sym_not_operator] = STATE(707),
    [sym_metaclass_operator] = STATE(921),
    [sym_handle_operator] = STATE(921),
    [sym_comparison_operator] = STATE(728),
    [sym_boolean_operator] = STATE(728),
    [sym_postfix_operator] = STATE(604),
    [sym_string] = STATE(604),
    [sym_row] = STATE(1246),
    [sym_matrix] = STATE(546),
    [sym_cell] = STATE(640),
    [sym_ignored_argument] = STATE(1083),
    [sym__index_row] = STATE(1279),
    [sym__index_matrix] = STATE(782),
    [sym__index_range_element] = STATE(1485),
    [sym__index_range] = STATE(1195),
    [sym__index_parenthesis] = STATE(782),
    [sym__index_expression] = STATE(1195),
    [sym__index_binary_expression] = STATE(911),
    [sym__index_binary_operator] = STATE(796),
    [sym_function_call] = STATE(406),
    [sym__range_element] = STATE(1465),
    [sym_range] = STATE(921),
    [sym_lambda] = STATE(921),
    [sym_number] = STATE(604),
    [sym_boolean] = STATE(449),
    [sym_end_keyword] = STATE(782),
    [sym__keywords] = STATE(445),
    [aux_sym_matrix_repeat1] = STATE(599),
    [anon_sym_COMMA] = ACTIONS(663),
    [anon_sym_LPAREN] = ACTIONS(665),
    [anon_sym_PLUS] = ACTIONS(667),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(669),
    [anon_sym_QMARK] = ACTIONS(671),
    [anon_sym_AT] = ACTIONS(673),
    [anon_sym_LBRACK] = ACTIONS(675),
    [anon_sym_LF] = ACTIONS(701),
    [anon_sym_RBRACK] = ACTIONS(723),
    [anon_sym_LBRACE] = ACTIONS(681),
    [anon_sym_end] = ACTIONS(683),
    [anon_sym_arguments] = ACTIONS(685),
    [anon_sym_properties] = ACTIONS(685),
    [anon_sym_get] = ACTIONS(685),
    [anon_sym_set] = ACTIONS(685),
    [anon_sym_methods] = ACTIONS(685),
    [anon_sym_events] = ACTIONS(685),
    [anon_sym_enumeration] = ACTIONS(685),
    [aux_sym_number_token1] = ACTIONS(687),
    [aux_sym_number_token2] = ACTIONS(687),
    [aux_sym_number_token3] = ACTIONS(687),
    [anon_sym_true] = ACTIONS(689),
    [anon_sym_false] = ACTIONS(689),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__single_quote_string_start] = ACTIONS(691),
    [sym__double_quote_string_start] = ACTIONS(693),
    [sym__external_identifier] = ACTIONS(695),
  },
  [STATE(165)] = {
    [sym_identifier] = STATE(406),
    [sym__expression] = STATE(921),
    [sym_parenthesis] = STATE(546),
    [sym__binary_expression] = STATE(914),
    [sym_binary_operator] = STATE(547),
    [sym_unary_operator] = STATE(613),
    [sym_indirect_access] = STATE(1321),
    [sym_field_expression] = STATE(604),
    [sym_not_operator] = STATE(707),
    [sym_metaclass_operator] = STATE(921),
    [sym_handle_operator] = STATE(921),
    [sym_comparison_operator] = STATE(728),
    [sym_boolean_operator] = STATE(728),
    [sym_postfix_operator] = STATE(604),
    [sym_string] = STATE(604),
    [sym_row] = STATE(1240),
    [sym_matrix] = STATE(546),
    [sym_cell] = STATE(640),
    [sym_ignored_argument] = STATE(1083),
    [sym__index_row] = STATE(1257),
    [sym__index_matrix] = STATE(782),
    [sym__index_range_element] = STATE(1485),
    [sym__index_range] = STATE(1195),
    [sym__index_parenthesis] = STATE(782),
    [sym__index_expression] = STATE(1195),
    [sym__index_binary_expression] = STATE(911),
    [sym__index_binary_operator] = STATE(796),
    [sym_function_call] = STATE(406),
    [sym__range_element] = STATE(1465),
    [sym_range] = STATE(921),
    [sym_lambda] = STATE(921),
    [sym_number] = STATE(604),
    [sym_boolean] = STATE(449),
    [sym_end_keyword] = STATE(782),
    [sym__keywords] = STATE(445),
    [aux_sym_matrix_repeat1] = STATE(166),
    [anon_sym_COMMA] = ACTIONS(663),
    [anon_sym_LPAREN] = ACTIONS(665),
    [anon_sym_PLUS] = ACTIONS(667),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(669),
    [anon_sym_QMARK] = ACTIONS(671),
    [anon_sym_AT] = ACTIONS(673),
    [anon_sym_LBRACK] = ACTIONS(675),
    [anon_sym_LF] = ACTIONS(725),
    [anon_sym_RBRACK] = ACTIONS(727),
    [anon_sym_LBRACE] = ACTIONS(681),
    [anon_sym_end] = ACTIONS(683),
    [anon_sym_arguments] = ACTIONS(685),
    [anon_sym_properties] = ACTIONS(685),
    [anon_sym_get] = ACTIONS(685),
    [anon_sym_set] = ACTIONS(685),
    [anon_sym_methods] = ACTIONS(685),
    [anon_sym_events] = ACTIONS(685),
    [anon_sym_enumeration] = ACTIONS(685),
    [aux_sym_number_token1] = ACTIONS(687),
    [aux_sym_number_token2] = ACTIONS(687),
    [aux_sym_number_token3] = ACTIONS(687),
    [anon_sym_true] = ACTIONS(689),
    [anon_sym_false] = ACTIONS(689),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__single_quote_string_start] = ACTIONS(691),
    [sym__double_quote_string_start] = ACTIONS(693),
    [sym__external_identifier] = ACTIONS(695),
  },
  [STATE(166)] = {
    [sym_identifier] = STATE(406),
    [sym__expression] = STATE(921),
    [sym_parenthesis] = STATE(546),
    [sym__binary_expression] = STATE(914),
    [sym_binary_operator] = STATE(547),
    [sym_unary_operator] = STATE(613),
    [sym_indirect_access] = STATE(1321),
    [sym_field_expression] = STATE(604),
    [sym_not_operator] = STATE(707),
    [sym_metaclass_operator] = STATE(921),
    [sym_handle_operator] = STATE(921),
    [sym_comparison_operator] = STATE(728),
    [sym_boolean_operator] = STATE(728),
    [sym_postfix_operator] = STATE(604),
    [sym_string] = STATE(604),
    [sym_row] = STATE(1246),
    [sym_matrix] = STATE(546),
    [sym_cell] = STATE(640),
    [sym_ignored_argument] = STATE(1083),
    [sym__index_row] = STATE(1261),
    [sym__index_matrix] = STATE(782),
    [sym__index_range_element] = STATE(1485),
    [sym__index_range] = STATE(1195),
    [sym__index_parenthesis] = STATE(782),
    [sym__index_expression] = STATE(1195),
    [sym__index_binary_expression] = STATE(911),
    [sym__index_binary_operator] = STATE(796),
    [sym_function_call] = STATE(406),
    [sym__range_element] = STATE(1465),
    [sym_range] = STATE(921),
    [sym_lambda] = STATE(921),
    [sym_number] = STATE(604),
    [sym_boolean] = STATE(449),
    [sym_end_keyword] = STATE(782),
    [sym__keywords] = STATE(445),
    [aux_sym_matrix_repeat1] = STATE(599),
    [anon_sym_COMMA] = ACTIONS(663),
    [anon_sym_LPAREN] = ACTIONS(665),
    [anon_sym_PLUS] = ACTIONS(667),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(669),
    [anon_sym_QMARK] = ACTIONS(671),
    [anon_sym_AT] = ACTIONS(673),
    [anon_sym_LBRACK] = ACTIONS(675),
    [anon_sym_LF] = ACTIONS(701),
    [anon_sym_RBRACK] = ACTIONS(729),
    [anon_sym_LBRACE] = ACTIONS(681),
    [anon_sym_end] = ACTIONS(683),
    [anon_sym_arguments] = ACTIONS(685),
    [anon_sym_properties] = ACTIONS(685),
    [anon_sym_get] = ACTIONS(685),
    [anon_sym_set] = ACTIONS(685),
    [anon_sym_methods] = ACTIONS(685),
    [anon_sym_events] = ACTIONS(685),
    [anon_sym_enumeration] = ACTIONS(685),
    [aux_sym_number_token1] = ACTIONS(687),
    [aux_sym_number_token2] = ACTIONS(687),
    [aux_sym_number_token3] = ACTIONS(687),
    [anon_sym_true] = ACTIONS(689),
    [anon_sym_false] = ACTIONS(689),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__single_quote_string_start] = ACTIONS(691),
    [sym__double_quote_string_start] = ACTIONS(693),
    [sym__external_identifier] = ACTIONS(695),
  },
};

static const uint16_t ts_small_parse_table[] = {
  [0] = 40,
    ACTIONS(731), 1,
      anon_sym_LPAREN,
    ACTIONS(733), 1,
      anon_sym_RPAREN,
    ACTIONS(737), 1,
      anon_sym_TILDE,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(743), 1,
      anon_sym_LBRACK,
    ACTIONS(745), 1,
      anon_sym_LBRACE,
    ACTIONS(747), 1,
      anon_sym_COLON,
    ACTIONS(749), 1,
      anon_sym_end,
    ACTIONS(753), 1,
      aux_sym_number_token1,
    ACTIONS(759), 1,
      sym__single_quote_string_start,
    ACTIONS(761), 1,
      sym__double_quote_string_start,
    STATE(437), 1,
      sym_identifier,
    STATE(452), 1,
      sym__keywords,
    STATE(456), 1,
      sym_function_call,
    STATE(525), 1,
      sym_boolean,
    STATE(652), 1,
      sym_number,
    STATE(697), 1,
      sym_cell,
    STATE(700), 1,
      sym_unary_operator,
    STATE(705), 1,
      sym_binary_operator,
    STATE(722), 1,
      sym_not_operator,
    STATE(825), 1,
      sym__index_binary_operator,
    STATE(908), 1,
      sym__binary_expression,
    STATE(913), 1,
      sym__index_binary_expression,
    STATE(1370), 1,
      sym_indirect_access,
    STATE(1372), 1,
      sym__index_arguments,
    STATE(1457), 1,
      sym_arguments,
    STATE(1461), 1,
      sym__range_element,
    STATE(1513), 1,
      sym__index_range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(735), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(755), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(757), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(704), 2,
      sym_parenthesis,
      sym_matrix,
    STATE(739), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(703), 3,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
    STATE(824), 3,
      sym__index_matrix,
      sym__index_parenthesis,
      sym_end_keyword,
    STATE(1295), 4,
      sym_spread_operator,
      sym__index_range,
      sym__index_expression,
      sym__index_argument,
    STATE(972), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [145] = 38,
    ACTIONS(669), 1,
      anon_sym_TILDE,
    ACTIONS(683), 1,
      anon_sym_end,
    ACTIONS(691), 1,
      sym__single_quote_string_start,
    ACTIONS(693), 1,
      sym__double_quote_string_start,
    ACTIONS(695), 1,
      sym__external_identifier,
    ACTIONS(765), 1,
      anon_sym_COMMA,
    ACTIONS(767), 1,
      anon_sym_LPAREN,
    ACTIONS(769), 1,
      anon_sym_QMARK,
    ACTIONS(771), 1,
      anon_sym_AT,
    ACTIONS(773), 1,
      anon_sym_LBRACK,
    ACTIONS(775), 1,
      aux_sym_matrix_token1,
    ACTIONS(777), 1,
      anon_sym_LBRACE,
    STATE(445), 1,
      sym__keywords,
    STATE(448), 1,
      sym_boolean,
    STATE(605), 1,
      sym_unary_operator,
    STATE(698), 1,
      sym_not_operator,
    STATE(742), 1,
      sym_binary_operator,
    STATE(747), 1,
      sym_cell,
    STATE(796), 1,
      sym__index_binary_operator,
    STATE(908), 1,
      sym__binary_expression,
    STATE(911), 1,
      sym__index_binary_expression,
    STATE(1321), 1,
      sym_indirect_access,
    STATE(1381), 1,
      sym__index_row,
    STATE(1461), 1,
      sym__range_element,
    STATE(1485), 1,
      sym__index_range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(667), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(689), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(763), 2,
      anon_sym_SEMI,
      anon_sym_RBRACK,
    STATE(407), 2,
      sym_identifier,
      sym_function_call,
    STATE(739), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(740), 2,
      sym_parenthesis,
      sym_matrix,
    ACTIONS(687), 3,
      aux_sym_number_token1,
      aux_sym_number_token2,
      aux_sym_number_token3,
    STATE(782), 3,
      sym__index_matrix,
      sym__index_parenthesis,
      sym_end_keyword,
    STATE(1195), 3,
      sym_ignored_argument,
      sym__index_range,
      sym__index_expression,
    STATE(606), 4,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_number,
    STATE(1058), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    ACTIONS(685), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [286] = 39,
    ACTIONS(731), 1,
      anon_sym_LPAREN,
    ACTIONS(737), 1,
      anon_sym_TILDE,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(743), 1,
      anon_sym_LBRACK,
    ACTIONS(745), 1,
      anon_sym_LBRACE,
    ACTIONS(747), 1,
      anon_sym_COLON,
    ACTIONS(749), 1,
      anon_sym_end,
    ACTIONS(753), 1,
      aux_sym_number_token1,
    ACTIONS(759), 1,
      sym__single_quote_string_start,
    ACTIONS(761), 1,
      sym__double_quote_string_start,
    ACTIONS(779), 1,
      anon_sym_RBRACE,
    STATE(411), 1,
      sym_identifier,
    STATE(432), 1,
      sym_function_call,
    STATE(452), 1,
      sym__keywords,
    STATE(525), 1,
      sym_boolean,
    STATE(639), 1,
      sym_binary_operator,
    STATE(651), 1,
      sym_unary_operator,
    STATE(697), 1,
      sym_cell,
    STATE(722), 1,
      sym_not_operator,
    STATE(825), 1,
      sym__index_binary_operator,
    STATE(908), 1,
      sym__binary_expression,
    STATE(913), 1,
      sym__index_binary_expression,
    STATE(1370), 1,
      sym_indirect_access,
    STATE(1372), 1,
      sym__index_arguments,
    STATE(1461), 1,
      sym__range_element,
    STATE(1473), 1,
      sym_arguments,
    STATE(1513), 1,
      sym__index_range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(735), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(755), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(757), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(632), 2,
      sym_parenthesis,
      sym_matrix,
    STATE(739), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(824), 3,
      sym__index_matrix,
      sym__index_parenthesis,
      sym_end_keyword,
    STATE(652), 4,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_number,
    STATE(1295), 4,
      sym_spread_operator,
      sym__index_range,
      sym__index_expression,
      sym__index_argument,
    STATE(972), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [429] = 39,
    ACTIONS(731), 1,
      anon_sym_LPAREN,
    ACTIONS(733), 1,
      anon_sym_RBRACE,
    ACTIONS(737), 1,
      anon_sym_TILDE,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(743), 1,
      anon_sym_LBRACK,
    ACTIONS(745), 1,
      anon_sym_LBRACE,
    ACTIONS(747), 1,
      anon_sym_COLON,
    ACTIONS(749), 1,
      anon_sym_end,
    ACTIONS(753), 1,
      aux_sym_number_token1,
    ACTIONS(759), 1,
      sym__single_quote_string_start,
    ACTIONS(761), 1,
      sym__double_quote_string_start,
    STATE(411), 1,
      sym_identifier,
    STATE(432), 1,
      sym_function_call,
    STATE(452), 1,
      sym__keywords,
    STATE(525), 1,
      sym_boolean,
    STATE(639), 1,
      sym_binary_operator,
    STATE(651), 1,
      sym_unary_operator,
    STATE(697), 1,
      sym_cell,
    STATE(722), 1,
      sym_not_operator,
    STATE(825), 1,
      sym__index_binary_operator,
    STATE(908), 1,
      sym__binary_expression,
    STATE(913), 1,
      sym__index_binary_expression,
    STATE(1370), 1,
      sym_indirect_access,
    STATE(1372), 1,
      sym__index_arguments,
    STATE(1461), 1,
      sym__range_element,
    STATE(1471), 1,
      sym_arguments,
    STATE(1513), 1,
      sym__index_range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(735), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(755), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(757), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(632), 2,
      sym_parenthesis,
      sym_matrix,
    STATE(739), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(824), 3,
      sym__index_matrix,
      sym__index_parenthesis,
      sym_end_keyword,
    STATE(652), 4,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_number,
    STATE(1295), 4,
      sym_spread_operator,
      sym__index_range,
      sym__index_expression,
      sym__index_argument,
    STATE(972), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [572] = 39,
    ACTIONS(731), 1,
      anon_sym_LPAREN,
    ACTIONS(733), 1,
      anon_sym_RPAREN,
    ACTIONS(737), 1,
      anon_sym_TILDE,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(743), 1,
      anon_sym_LBRACK,
    ACTIONS(745), 1,
      anon_sym_LBRACE,
    ACTIONS(747), 1,
      anon_sym_COLON,
    ACTIONS(749), 1,
      anon_sym_end,
    ACTIONS(753), 1,
      aux_sym_number_token1,
    ACTIONS(759), 1,
      sym__single_quote_string_start,
    ACTIONS(761), 1,
      sym__double_quote_string_start,
    STATE(411), 1,
      sym_identifier,
    STATE(432), 1,
      sym_function_call,
    STATE(452), 1,
      sym__keywords,
    STATE(525), 1,
      sym_boolean,
    STATE(639), 1,
      sym_binary_operator,
    STATE(651), 1,
      sym_unary_operator,
    STATE(697), 1,
      sym_cell,
    STATE(722), 1,
      sym_not_operator,
    STATE(825), 1,
      sym__index_binary_operator,
    STATE(908), 1,
      sym__binary_expression,
    STATE(913), 1,
      sym__index_binary_expression,
    STATE(1370), 1,
      sym_indirect_access,
    STATE(1372), 1,
      sym__index_arguments,
    STATE(1457), 1,
      sym_arguments,
    STATE(1461), 1,
      sym__range_element,
    STATE(1513), 1,
      sym__index_range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(735), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(755), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(757), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(632), 2,
      sym_parenthesis,
      sym_matrix,
    STATE(739), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(824), 3,
      sym__index_matrix,
      sym__index_parenthesis,
      sym_end_keyword,
    STATE(652), 4,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_number,
    STATE(1295), 4,
      sym_spread_operator,
      sym__index_range,
      sym__index_expression,
      sym__index_argument,
    STATE(972), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [715] = 39,
    ACTIONS(731), 1,
      anon_sym_LPAREN,
    ACTIONS(737), 1,
      anon_sym_TILDE,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(743), 1,
      anon_sym_LBRACK,
    ACTIONS(745), 1,
      anon_sym_LBRACE,
    ACTIONS(747), 1,
      anon_sym_COLON,
    ACTIONS(749), 1,
      anon_sym_end,
    ACTIONS(753), 1,
      aux_sym_number_token1,
    ACTIONS(759), 1,
      sym__single_quote_string_start,
    ACTIONS(761), 1,
      sym__double_quote_string_start,
    ACTIONS(779), 1,
      anon_sym_RPAREN,
    STATE(411), 1,
      sym_identifier,
    STATE(432), 1,
      sym_function_call,
    STATE(452), 1,
      sym__keywords,
    STATE(525), 1,
      sym_boolean,
    STATE(639), 1,
      sym_binary_operator,
    STATE(651), 1,
      sym_unary_operator,
    STATE(697), 1,
      sym_cell,
    STATE(722), 1,
      sym_not_operator,
    STATE(825), 1,
      sym__index_binary_operator,
    STATE(908), 1,
      sym__binary_expression,
    STATE(913), 1,
      sym__index_binary_expression,
    STATE(1370), 1,
      sym_indirect_access,
    STATE(1372), 1,
      sym__index_arguments,
    STATE(1461), 1,
      sym__range_element,
    STATE(1513), 1,
      sym__index_range_element,
    STATE(1521), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(735), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(755), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(757), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(632), 2,
      sym_parenthesis,
      sym_matrix,
    STATE(739), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(824), 3,
      sym__index_matrix,
      sym__index_parenthesis,
      sym_end_keyword,
    STATE(652), 4,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_number,
    STATE(1295), 4,
      sym_spread_operator,
      sym__index_range,
      sym__index_expression,
      sym__index_argument,
    STATE(972), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [858] = 39,
    ACTIONS(731), 1,
      anon_sym_LPAREN,
    ACTIONS(737), 1,
      anon_sym_TILDE,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(743), 1,
      anon_sym_LBRACK,
    ACTIONS(745), 1,
      anon_sym_LBRACE,
    ACTIONS(747), 1,
      anon_sym_COLON,
    ACTIONS(749), 1,
      anon_sym_end,
    ACTIONS(753), 1,
      aux_sym_number_token1,
    ACTIONS(759), 1,
      sym__single_quote_string_start,
    ACTIONS(761), 1,
      sym__double_quote_string_start,
    ACTIONS(781), 1,
      anon_sym_RBRACE,
    STATE(411), 1,
      sym_identifier,
    STATE(432), 1,
      sym_function_call,
    STATE(452), 1,
      sym__keywords,
    STATE(525), 1,
      sym_boolean,
    STATE(639), 1,
      sym_binary_operator,
    STATE(651), 1,
      sym_unary_operator,
    STATE(697), 1,
      sym_cell,
    STATE(722), 1,
      sym_not_operator,
    STATE(825), 1,
      sym__index_binary_operator,
    STATE(908), 1,
      sym__binary_expression,
    STATE(913), 1,
      sym__index_binary_expression,
    STATE(1370), 1,
      sym_indirect_access,
    STATE(1372), 1,
      sym__index_arguments,
    STATE(1461), 1,
      sym__range_element,
    STATE(1481), 1,
      sym_arguments,
    STATE(1513), 1,
      sym__index_range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(735), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(755), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(757), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(632), 2,
      sym_parenthesis,
      sym_matrix,
    STATE(739), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(824), 3,
      sym__index_matrix,
      sym__index_parenthesis,
      sym_end_keyword,
    STATE(652), 4,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_number,
    STATE(1295), 4,
      sym_spread_operator,
      sym__index_range,
      sym__index_expression,
      sym__index_argument,
    STATE(972), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [1001] = 39,
    ACTIONS(731), 1,
      anon_sym_LPAREN,
    ACTIONS(737), 1,
      anon_sym_TILDE,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(743), 1,
      anon_sym_LBRACK,
    ACTIONS(745), 1,
      anon_sym_LBRACE,
    ACTIONS(747), 1,
      anon_sym_COLON,
    ACTIONS(749), 1,
      anon_sym_end,
    ACTIONS(753), 1,
      aux_sym_number_token1,
    ACTIONS(759), 1,
      sym__single_quote_string_start,
    ACTIONS(761), 1,
      sym__double_quote_string_start,
    ACTIONS(783), 1,
      anon_sym_RPAREN,
    STATE(411), 1,
      sym_identifier,
    STATE(432), 1,
      sym_function_call,
    STATE(452), 1,
      sym__keywords,
    STATE(525), 1,
      sym_boolean,
    STATE(639), 1,
      sym_binary_operator,
    STATE(651), 1,
      sym_unary_operator,
    STATE(697), 1,
      sym_cell,
    STATE(722), 1,
      sym_not_operator,
    STATE(825), 1,
      sym__index_binary_operator,
    STATE(908), 1,
      sym__binary_expression,
    STATE(913), 1,
      sym__index_binary_expression,
    STATE(1370), 1,
      sym_indirect_access,
    STATE(1372), 1,
      sym__index_arguments,
    STATE(1461), 1,
      sym__range_element,
    STATE(1466), 1,
      sym_arguments,
    STATE(1513), 1,
      sym__index_range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(735), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(755), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(757), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(632), 2,
      sym_parenthesis,
      sym_matrix,
    STATE(739), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(824), 3,
      sym__index_matrix,
      sym__index_parenthesis,
      sym_end_keyword,
    STATE(652), 4,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_number,
    STATE(1295), 4,
      sym_spread_operator,
      sym__index_range,
      sym__index_expression,
      sym__index_argument,
    STATE(972), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [1144] = 39,
    ACTIONS(731), 1,
      anon_sym_LPAREN,
    ACTIONS(737), 1,
      anon_sym_TILDE,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(743), 1,
      anon_sym_LBRACK,
    ACTIONS(745), 1,
      anon_sym_LBRACE,
    ACTIONS(747), 1,
      anon_sym_COLON,
    ACTIONS(749), 1,
      anon_sym_end,
    ACTIONS(753), 1,
      aux_sym_number_token1,
    ACTIONS(759), 1,
      sym__single_quote_string_start,
    ACTIONS(761), 1,
      sym__double_quote_string_start,
    ACTIONS(785), 1,
      anon_sym_RPAREN,
    STATE(411), 1,
      sym_identifier,
    STATE(432), 1,
      sym_function_call,
    STATE(452), 1,
      sym__keywords,
    STATE(525), 1,
      sym_boolean,
    STATE(639), 1,
      sym_binary_operator,
    STATE(651), 1,
      sym_unary_operator,
    STATE(697), 1,
      sym_cell,
    STATE(722), 1,
      sym_not_operator,
    STATE(825), 1,
      sym__index_binary_operator,
    STATE(908), 1,
      sym__binary_expression,
    STATE(913), 1,
      sym__index_binary_expression,
    STATE(1370), 1,
      sym_indirect_access,
    STATE(1372), 1,
      sym__index_arguments,
    STATE(1461), 1,
      sym__range_element,
    STATE(1511), 1,
      sym_arguments,
    STATE(1513), 1,
      sym__index_range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(735), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(755), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(757), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(632), 2,
      sym_parenthesis,
      sym_matrix,
    STATE(739), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(824), 3,
      sym__index_matrix,
      sym__index_parenthesis,
      sym_end_keyword,
    STATE(652), 4,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_number,
    STATE(1295), 4,
      sym_spread_operator,
      sym__index_range,
      sym__index_expression,
      sym__index_argument,
    STATE(972), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [1287] = 39,
    ACTIONS(731), 1,
      anon_sym_LPAREN,
    ACTIONS(737), 1,
      anon_sym_TILDE,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(743), 1,
      anon_sym_LBRACK,
    ACTIONS(745), 1,
      anon_sym_LBRACE,
    ACTIONS(747), 1,
      anon_sym_COLON,
    ACTIONS(749), 1,
      anon_sym_end,
    ACTIONS(753), 1,
      aux_sym_number_token1,
    ACTIONS(759), 1,
      sym__single_quote_string_start,
    ACTIONS(761), 1,
      sym__double_quote_string_start,
    ACTIONS(785), 1,
      anon_sym_RBRACE,
    STATE(411), 1,
      sym_identifier,
    STATE(432), 1,
      sym_function_call,
    STATE(452), 1,
      sym__keywords,
    STATE(525), 1,
      sym_boolean,
    STATE(639), 1,
      sym_binary_operator,
    STATE(651), 1,
      sym_unary_operator,
    STATE(697), 1,
      sym_cell,
    STATE(722), 1,
      sym_not_operator,
    STATE(825), 1,
      sym__index_binary_operator,
    STATE(908), 1,
      sym__binary_expression,
    STATE(913), 1,
      sym__index_binary_expression,
    STATE(1370), 1,
      sym_indirect_access,
    STATE(1372), 1,
      sym__index_arguments,
    STATE(1461), 1,
      sym__range_element,
    STATE(1513), 1,
      sym__index_range_element,
    STATE(1518), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(735), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(755), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(757), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(632), 2,
      sym_parenthesis,
      sym_matrix,
    STATE(739), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(824), 3,
      sym__index_matrix,
      sym__index_parenthesis,
      sym_end_keyword,
    STATE(652), 4,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_number,
    STATE(1295), 4,
      sym_spread_operator,
      sym__index_range,
      sym__index_expression,
      sym__index_argument,
    STATE(972), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [1430] = 39,
    ACTIONS(731), 1,
      anon_sym_LPAREN,
    ACTIONS(737), 1,
      anon_sym_TILDE,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(743), 1,
      anon_sym_LBRACK,
    ACTIONS(745), 1,
      anon_sym_LBRACE,
    ACTIONS(747), 1,
      anon_sym_COLON,
    ACTIONS(749), 1,
      anon_sym_end,
    ACTIONS(753), 1,
      aux_sym_number_token1,
    ACTIONS(759), 1,
      sym__single_quote_string_start,
    ACTIONS(761), 1,
      sym__double_quote_string_start,
    ACTIONS(783), 1,
      anon_sym_RBRACE,
    STATE(411), 1,
      sym_identifier,
    STATE(432), 1,
      sym_function_call,
    STATE(452), 1,
      sym__keywords,
    STATE(525), 1,
      sym_boolean,
    STATE(639), 1,
      sym_binary_operator,
    STATE(651), 1,
      sym_unary_operator,
    STATE(697), 1,
      sym_cell,
    STATE(722), 1,
      sym_not_operator,
    STATE(825), 1,
      sym__index_binary_operator,
    STATE(908), 1,
      sym__binary_expression,
    STATE(913), 1,
      sym__index_binary_expression,
    STATE(1370), 1,
      sym_indirect_access,
    STATE(1372), 1,
      sym__index_arguments,
    STATE(1461), 1,
      sym__range_element,
    STATE(1468), 1,
      sym_arguments,
    STATE(1513), 1,
      sym__index_range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(735), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(755), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(757), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(632), 2,
      sym_parenthesis,
      sym_matrix,
    STATE(739), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(824), 3,
      sym__index_matrix,
      sym__index_parenthesis,
      sym_end_keyword,
    STATE(652), 4,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_number,
    STATE(1295), 4,
      sym_spread_operator,
      sym__index_range,
      sym__index_expression,
      sym__index_argument,
    STATE(972), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [1573] = 39,
    ACTIONS(731), 1,
      anon_sym_LPAREN,
    ACTIONS(737), 1,
      anon_sym_TILDE,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(743), 1,
      anon_sym_LBRACK,
    ACTIONS(745), 1,
      anon_sym_LBRACE,
    ACTIONS(747), 1,
      anon_sym_COLON,
    ACTIONS(749), 1,
      anon_sym_end,
    ACTIONS(753), 1,
      aux_sym_number_token1,
    ACTIONS(759), 1,
      sym__single_quote_string_start,
    ACTIONS(761), 1,
      sym__double_quote_string_start,
    ACTIONS(781), 1,
      anon_sym_RPAREN,
    STATE(411), 1,
      sym_identifier,
    STATE(432), 1,
      sym_function_call,
    STATE(452), 1,
      sym__keywords,
    STATE(525), 1,
      sym_boolean,
    STATE(639), 1,
      sym_binary_operator,
    STATE(651), 1,
      sym_unary_operator,
    STATE(697), 1,
      sym_cell,
    STATE(722), 1,
      sym_not_operator,
    STATE(825), 1,
      sym__index_binary_operator,
    STATE(908), 1,
      sym__binary_expression,
    STATE(913), 1,
      sym__index_binary_expression,
    STATE(1370), 1,
      sym_indirect_access,
    STATE(1372), 1,
      sym__index_arguments,
    STATE(1448), 1,
      sym_arguments,
    STATE(1461), 1,
      sym__range_element,
    STATE(1513), 1,
      sym__index_range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(735), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(755), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(757), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(632), 2,
      sym_parenthesis,
      sym_matrix,
    STATE(739), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(824), 3,
      sym__index_matrix,
      sym__index_parenthesis,
      sym_end_keyword,
    STATE(652), 4,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_number,
    STATE(1295), 4,
      sym_spread_operator,
      sym__index_range,
      sym__index_expression,
      sym__index_argument,
    STATE(972), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [1716] = 36,
    ACTIONS(669), 1,
      anon_sym_TILDE,
    ACTIONS(683), 1,
      anon_sym_end,
    ACTIONS(691), 1,
      sym__single_quote_string_start,
    ACTIONS(693), 1,
      sym__double_quote_string_start,
    ACTIONS(695), 1,
      sym__external_identifier,
    ACTIONS(767), 1,
      anon_sym_LPAREN,
    ACTIONS(769), 1,
      anon_sym_QMARK,
    ACTIONS(771), 1,
      anon_sym_AT,
    ACTIONS(773), 1,
      anon_sym_LBRACK,
    ACTIONS(777), 1,
      anon_sym_LBRACE,
    ACTIONS(789), 1,
      aux_sym_matrix_token1,
    STATE(445), 1,
      sym__keywords,
    STATE(448), 1,
      sym_boolean,
    STATE(605), 1,
      sym_unary_operator,
    STATE(698), 1,
      sym_not_operator,
    STATE(742), 1,
      sym_binary_operator,
    STATE(747), 1,
      sym_cell,
    STATE(796), 1,
      sym__index_binary_operator,
    STATE(908), 1,
      sym__binary_expression,
    STATE(911), 1,
      sym__index_binary_expression,
    STATE(1321), 1,
      sym_indirect_access,
    STATE(1461), 1,
      sym__range_element,
    STATE(1485), 1,
      sym__index_range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(667), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(689), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(787), 2,
      anon_sym_SEMI,
      anon_sym_RBRACK,
    STATE(407), 2,
      sym_identifier,
      sym_function_call,
    STATE(739), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(740), 2,
      sym_parenthesis,
      sym_matrix,
    ACTIONS(687), 3,
      aux_sym_number_token1,
      aux_sym_number_token2,
      aux_sym_number_token3,
    STATE(782), 3,
      sym__index_matrix,
      sym__index_parenthesis,
      sym_end_keyword,
    STATE(1299), 3,
      sym_ignored_argument,
      sym__index_range,
      sym__index_expression,
    STATE(606), 4,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_number,
    STATE(1058), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    ACTIONS(685), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [1851] = 37,
    ACTIONS(665), 1,
      anon_sym_LPAREN,
    ACTIONS(669), 1,
      anon_sym_TILDE,
    ACTIONS(671), 1,
      anon_sym_QMARK,
    ACTIONS(673), 1,
      anon_sym_AT,
    ACTIONS(675), 1,
      anon_sym_LBRACK,
    ACTIONS(681), 1,
      anon_sym_LBRACE,
    ACTIONS(683), 1,
      anon_sym_end,
    ACTIONS(691), 1,
      sym__single_quote_string_start,
    ACTIONS(693), 1,
      sym__double_quote_string_start,
    ACTIONS(695), 1,
      sym__external_identifier,
    ACTIONS(794), 1,
      aux_sym_matrix_token1,
    STATE(445), 1,
      sym__keywords,
    STATE(449), 1,
      sym_boolean,
    STATE(547), 1,
      sym_binary_operator,
    STATE(613), 1,
      sym_unary_operator,
    STATE(640), 1,
      sym_cell,
    STATE(707), 1,
      sym_not_operator,
    STATE(796), 1,
      sym__index_binary_operator,
    STATE(911), 1,
      sym__index_binary_expression,
    STATE(914), 1,
      sym__binary_expression,
    STATE(1286), 1,
      sym_ignored_argument,
    STATE(1321), 1,
      sym_indirect_access,
    STATE(1465), 1,
      sym__range_element,
    STATE(1485), 1,
      sym__index_range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(667), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(689), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(791), 2,
      anon_sym_SEMI,
      anon_sym_RBRACK,
    STATE(406), 2,
      sym_identifier,
      sym_function_call,
    STATE(546), 2,
      sym_parenthesis,
      sym_matrix,
    STATE(728), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1299), 2,
      sym__index_range,
      sym__index_expression,
    ACTIONS(687), 3,
      aux_sym_number_token1,
      aux_sym_number_token2,
      aux_sym_number_token3,
    STATE(782), 3,
      sym__index_matrix,
      sym__index_parenthesis,
      sym_end_keyword,
    STATE(604), 4,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_number,
    STATE(932), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    ACTIONS(685), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [1988] = 36,
    ACTIONS(669), 1,
      anon_sym_TILDE,
    ACTIONS(683), 1,
      anon_sym_end,
    ACTIONS(691), 1,
      sym__single_quote_string_start,
    ACTIONS(693), 1,
      sym__double_quote_string_start,
    ACTIONS(695), 1,
      sym__external_identifier,
    ACTIONS(767), 1,
      anon_sym_LPAREN,
    ACTIONS(769), 1,
      anon_sym_QMARK,
    ACTIONS(771), 1,
      anon_sym_AT,
    ACTIONS(773), 1,
      anon_sym_LBRACK,
    ACTIONS(777), 1,
      anon_sym_LBRACE,
    ACTIONS(799), 1,
      aux_sym_matrix_token1,
    STATE(445), 1,
      sym__keywords,
    STATE(448), 1,
      sym_boolean,
    STATE(605), 1,
      sym_unary_operator,
    STATE(698), 1,
      sym_not_operator,
    STATE(742), 1,
      sym_binary_operator,
    STATE(747), 1,
      sym_cell,
    STATE(796), 1,
      sym__index_binary_operator,
    STATE(908), 1,
      sym__binary_expression,
    STATE(911), 1,
      sym__index_binary_expression,
    STATE(1321), 1,
      sym_indirect_access,
    STATE(1461), 1,
      sym__range_element,
    STATE(1485), 1,
      sym__index_range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(667), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(689), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(797), 2,
      anon_sym_SEMI,
      anon_sym_RBRACK,
    STATE(407), 2,
      sym_identifier,
      sym_function_call,
    STATE(739), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(740), 2,
      sym_parenthesis,
      sym_matrix,
    ACTIONS(687), 3,
      aux_sym_number_token1,
      aux_sym_number_token2,
      aux_sym_number_token3,
    STATE(782), 3,
      sym__index_matrix,
      sym__index_parenthesis,
      sym_end_keyword,
    STATE(1299), 3,
      sym_ignored_argument,
      sym__index_range,
      sym__index_expression,
    STATE(606), 4,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_number,
    STATE(1058), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    ACTIONS(685), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [2123] = 36,
    ACTIONS(669), 1,
      anon_sym_TILDE,
    ACTIONS(683), 1,
      anon_sym_end,
    ACTIONS(691), 1,
      sym__single_quote_string_start,
    ACTIONS(693), 1,
      sym__double_quote_string_start,
    ACTIONS(695), 1,
      sym__external_identifier,
    ACTIONS(767), 1,
      anon_sym_LPAREN,
    ACTIONS(769), 1,
      anon_sym_QMARK,
    ACTIONS(771), 1,
      anon_sym_AT,
    ACTIONS(773), 1,
      anon_sym_LBRACK,
    ACTIONS(777), 1,
      anon_sym_LBRACE,
    ACTIONS(803), 1,
      aux_sym_matrix_token1,
    STATE(445), 1,
      sym__keywords,
    STATE(448), 1,
      sym_boolean,
    STATE(605), 1,
      sym_unary_operator,
    STATE(698), 1,
      sym_not_operator,
    STATE(742), 1,
      sym_binary_operator,
    STATE(747), 1,
      sym_cell,
    STATE(796), 1,
      sym__index_binary_operator,
    STATE(908), 1,
      sym__binary_expression,
    STATE(911), 1,
      sym__index_binary_expression,
    STATE(1321), 1,
      sym_indirect_access,
    STATE(1461), 1,
      sym__range_element,
    STATE(1485), 1,
      sym__index_range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(667), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(689), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(801), 2,
      anon_sym_SEMI,
      anon_sym_RBRACK,
    STATE(407), 2,
      sym_identifier,
      sym_function_call,
    STATE(739), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(740), 2,
      sym_parenthesis,
      sym_matrix,
    ACTIONS(687), 3,
      aux_sym_number_token1,
      aux_sym_number_token2,
      aux_sym_number_token3,
    STATE(782), 3,
      sym__index_matrix,
      sym__index_parenthesis,
      sym_end_keyword,
    STATE(1299), 3,
      sym_ignored_argument,
      sym__index_range,
      sym__index_expression,
    STATE(606), 4,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_number,
    STATE(1058), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    ACTIONS(685), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [2258] = 37,
    ACTIONS(665), 1,
      anon_sym_LPAREN,
    ACTIONS(669), 1,
      anon_sym_TILDE,
    ACTIONS(671), 1,
      anon_sym_QMARK,
    ACTIONS(673), 1,
      anon_sym_AT,
    ACTIONS(675), 1,
      anon_sym_LBRACK,
    ACTIONS(681), 1,
      anon_sym_LBRACE,
    ACTIONS(683), 1,
      anon_sym_end,
    ACTIONS(691), 1,
      sym__single_quote_string_start,
    ACTIONS(693), 1,
      sym__double_quote_string_start,
    ACTIONS(695), 1,
      sym__external_identifier,
    ACTIONS(808), 1,
      aux_sym_matrix_token1,
    STATE(445), 1,
      sym__keywords,
    STATE(449), 1,
      sym_boolean,
    STATE(547), 1,
      sym_binary_operator,
    STATE(613), 1,
      sym_unary_operator,
    STATE(640), 1,
      sym_cell,
    STATE(707), 1,
      sym_not_operator,
    STATE(796), 1,
      sym__index_binary_operator,
    STATE(911), 1,
      sym__index_binary_expression,
    STATE(914), 1,
      sym__binary_expression,
    STATE(1286), 1,
      sym_ignored_argument,
    STATE(1321), 1,
      sym_indirect_access,
    STATE(1465), 1,
      sym__range_element,
    STATE(1485), 1,
      sym__index_range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(667), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(689), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(805), 2,
      anon_sym_SEMI,
      anon_sym_RBRACK,
    STATE(406), 2,
      sym_identifier,
      sym_function_call,
    STATE(546), 2,
      sym_parenthesis,
      sym_matrix,
    STATE(728), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1299), 2,
      sym__index_range,
      sym__index_expression,
    ACTIONS(687), 3,
      aux_sym_number_token1,
      aux_sym_number_token2,
      aux_sym_number_token3,
    STATE(782), 3,
      sym__index_matrix,
      sym__index_parenthesis,
      sym_end_keyword,
    STATE(604), 4,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_number,
    STATE(932), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    ACTIONS(685), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [2395] = 35,
    ACTIONS(731), 1,
      anon_sym_LPAREN,
    ACTIONS(737), 1,
      anon_sym_TILDE,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(743), 1,
      anon_sym_LBRACK,
    ACTIONS(745), 1,
      anon_sym_LBRACE,
    ACTIONS(747), 1,
      anon_sym_COLON,
    ACTIONS(749), 1,
      anon_sym_end,
    ACTIONS(753), 1,
      aux_sym_number_token1,
    ACTIONS(759), 1,
      sym__single_quote_string_start,
    ACTIONS(761), 1,
      sym__double_quote_string_start,
    STATE(452), 1,
      sym__keywords,
    STATE(525), 1,
      sym_boolean,
    STATE(639), 1,
      sym_binary_operator,
    STATE(651), 1,
      sym_unary_operator,
    STATE(697), 1,
      sym_cell,
    STATE(722), 1,
      sym_not_operator,
    STATE(825), 1,
      sym__index_binary_operator,
    STATE(908), 1,
      sym__binary_expression,
    STATE(913), 1,
      sym__index_binary_expression,
    STATE(1370), 1,
      sym_indirect_access,
    STATE(1461), 1,
      sym__range_element,
    STATE(1513), 1,
      sym__index_range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(735), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(755), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(757), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(432), 2,
      sym_identifier,
      sym_function_call,
    STATE(632), 2,
      sym_parenthesis,
      sym_matrix,
    STATE(739), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(824), 3,
      sym__index_matrix,
      sym__index_parenthesis,
      sym_end_keyword,
    STATE(652), 4,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_number,
    STATE(1371), 4,
      sym_spread_operator,
      sym__index_range,
      sym__index_expression,
      sym__index_argument,
    STATE(972), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [2527] = 35,
    ACTIONS(687), 1,
      aux_sym_number_token1,
    ACTIONS(691), 1,
      sym__single_quote_string_start,
    ACTIONS(693), 1,
      sym__double_quote_string_start,
    ACTIONS(811), 1,
      anon_sym_LPAREN,
    ACTIONS(815), 1,
      anon_sym_TILDE,
    ACTIONS(817), 1,
      anon_sym_QMARK,
    ACTIONS(819), 1,
      anon_sym_AT,
    ACTIONS(821), 1,
      anon_sym_LBRACK,
    ACTIONS(823), 1,
      anon_sym_LBRACE,
    ACTIONS(825), 1,
      anon_sym_end,
    STATE(445), 1,
      sym__keywords,
    STATE(449), 1,
      sym_boolean,
    STATE(547), 1,
      sym_binary_operator,
    STATE(613), 1,
      sym_unary_operator,
    STATE(640), 1,
      sym_cell,
    STATE(707), 1,
      sym_not_operator,
    STATE(796), 1,
      sym__index_binary_operator,
    STATE(911), 1,
      sym__index_binary_expression,
    STATE(914), 1,
      sym__binary_expression,
    STATE(1096), 1,
      sym_ignored_argument,
    STATE(1321), 1,
      sym_indirect_access,
    STATE(1465), 1,
      sym__range_element,
    STATE(1485), 1,
      sym__index_range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(813), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(827), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(829), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(406), 2,
      sym_identifier,
      sym_function_call,
    STATE(546), 2,
      sym_parenthesis,
      sym_matrix,
    STATE(728), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1166), 2,
      sym__index_range,
      sym__index_expression,
    STATE(782), 3,
      sym__index_matrix,
      sym__index_parenthesis,
      sym_end_keyword,
    STATE(604), 4,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_number,
    STATE(901), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    ACTIONS(695), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [2657] = 34,
    ACTIONS(687), 1,
      aux_sym_number_token1,
    ACTIONS(691), 1,
      sym__single_quote_string_start,
    ACTIONS(693), 1,
      sym__double_quote_string_start,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(745), 1,
      anon_sym_LBRACE,
    ACTIONS(815), 1,
      anon_sym_TILDE,
    ACTIONS(825), 1,
      anon_sym_end,
    ACTIONS(831), 1,
      anon_sym_LPAREN,
    ACTIONS(833), 1,
      anon_sym_LBRACK,
    STATE(445), 1,
      sym__keywords,
    STATE(448), 1,
      sym_boolean,
    STATE(605), 1,
      sym_unary_operator,
    STATE(698), 1,
      sym_not_operator,
    STATE(742), 1,
      sym_binary_operator,
    STATE(747), 1,
      sym_cell,
    STATE(796), 1,
      sym__index_binary_operator,
    STATE(908), 1,
      sym__binary_expression,
    STATE(911), 1,
      sym__index_binary_expression,
    STATE(1321), 1,
      sym_indirect_access,
    STATE(1461), 1,
      sym__range_element,
    STATE(1485), 1,
      sym__index_range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(813), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(827), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(829), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(407), 2,
      sym_identifier,
      sym_function_call,
    STATE(739), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(740), 2,
      sym_parenthesis,
      sym_matrix,
    STATE(782), 3,
      sym__index_matrix,
      sym__index_parenthesis,
      sym_end_keyword,
    STATE(1299), 3,
      sym_ignored_argument,
      sym__index_range,
      sym__index_expression,
    STATE(606), 4,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_number,
    STATE(1058), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    ACTIONS(695), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [2785] = 34,
    ACTIONS(687), 1,
      aux_sym_number_token1,
    ACTIONS(691), 1,
      sym__single_quote_string_start,
    ACTIONS(693), 1,
      sym__double_quote_string_start,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(745), 1,
      anon_sym_LBRACE,
    ACTIONS(815), 1,
      anon_sym_TILDE,
    ACTIONS(825), 1,
      anon_sym_end,
    ACTIONS(831), 1,
      anon_sym_LPAREN,
    ACTIONS(833), 1,
      anon_sym_LBRACK,
    STATE(445), 1,
      sym__keywords,
    STATE(448), 1,
      sym_boolean,
    STATE(605), 1,
      sym_unary_operator,
    STATE(698), 1,
      sym_not_operator,
    STATE(742), 1,
      sym_binary_operator,
    STATE(747), 1,
      sym_cell,
    STATE(796), 1,
      sym__index_binary_operator,
    STATE(908), 1,
      sym__binary_expression,
    STATE(911), 1,
      sym__index_binary_expression,
    STATE(1321), 1,
      sym_indirect_access,
    STATE(1461), 1,
      sym__range_element,
    STATE(1485), 1,
      sym__index_range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(813), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(827), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(829), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(407), 2,
      sym_identifier,
      sym_function_call,
    STATE(739), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(740), 2,
      sym_parenthesis,
      sym_matrix,
    STATE(782), 3,
      sym__index_matrix,
      sym__index_parenthesis,
      sym_end_keyword,
    STATE(1166), 3,
      sym_ignored_argument,
      sym__index_range,
      sym__index_expression,
    STATE(606), 4,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_number,
    STATE(1058), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    ACTIONS(695), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [2913] = 35,
    ACTIONS(731), 1,
      anon_sym_LPAREN,
    ACTIONS(737), 1,
      anon_sym_TILDE,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(743), 1,
      anon_sym_LBRACK,
    ACTIONS(745), 1,
      anon_sym_LBRACE,
    ACTIONS(749), 1,
      anon_sym_end,
    ACTIONS(753), 1,
      aux_sym_number_token1,
    ACTIONS(759), 1,
      sym__single_quote_string_start,
    ACTIONS(761), 1,
      sym__double_quote_string_start,
    STATE(452), 1,
      sym__keywords,
    STATE(525), 1,
      sym_boolean,
    STATE(652), 1,
      sym_number,
    STATE(697), 1,
      sym_cell,
    STATE(700), 1,
      sym_unary_operator,
    STATE(705), 1,
      sym_binary_operator,
    STATE(722), 1,
      sym_not_operator,
    STATE(825), 1,
      sym__index_binary_operator,
    STATE(908), 1,
      sym__binary_expression,
    STATE(913), 1,
      sym__index_binary_expression,
    STATE(1370), 1,
      sym_indirect_access,
    STATE(1461), 1,
      sym__range_element,
    STATE(1513), 1,
      sym__index_range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(735), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(755), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(757), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(516), 2,
      sym_identifier,
      sym_function_call,
    STATE(704), 2,
      sym_parenthesis,
      sym_matrix,
    STATE(739), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1505), 2,
      sym__index_range,
      sym__index_expression,
    STATE(703), 3,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
    STATE(824), 3,
      sym__index_matrix,
      sym__index_parenthesis,
      sym_end_keyword,
    STATE(1044), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [3042] = 35,
    ACTIONS(731), 1,
      anon_sym_LPAREN,
    ACTIONS(737), 1,
      anon_sym_TILDE,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(743), 1,
      anon_sym_LBRACK,
    ACTIONS(745), 1,
      anon_sym_LBRACE,
    ACTIONS(749), 1,
      anon_sym_end,
    ACTIONS(753), 1,
      aux_sym_number_token1,
    ACTIONS(759), 1,
      sym__single_quote_string_start,
    ACTIONS(761), 1,
      sym__double_quote_string_start,
    STATE(452), 1,
      sym__keywords,
    STATE(525), 1,
      sym_boolean,
    STATE(652), 1,
      sym_number,
    STATE(697), 1,
      sym_cell,
    STATE(700), 1,
      sym_unary_operator,
    STATE(705), 1,
      sym_binary_operator,
    STATE(722), 1,
      sym_not_operator,
    STATE(825), 1,
      sym__index_binary_operator,
    STATE(908), 1,
      sym__binary_expression,
    STATE(913), 1,
      sym__index_binary_expression,
    STATE(1370), 1,
      sym_indirect_access,
    STATE(1461), 1,
      sym__range_element,
    STATE(1513), 1,
      sym__index_range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(735), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(755), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(757), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(516), 2,
      sym_identifier,
      sym_function_call,
    STATE(704), 2,
      sym_parenthesis,
      sym_matrix,
    STATE(739), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1452), 2,
      sym__index_range,
      sym__index_expression,
    STATE(703), 3,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
    STATE(824), 3,
      sym__index_matrix,
      sym__index_parenthesis,
      sym_end_keyword,
    STATE(1044), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [3171] = 5,
    ACTIONS(835), 1,
      anon_sym_DOT,
    STATE(191), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(487), 5,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      sym__external_identifier,
    ACTIONS(485), 49,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_LF,
      anon_sym_LBRACE,
      anon_sym_return,
      anon_sym_continue,
      anon_sym_break,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_arguments,
      anon_sym_function,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_classdef,
      anon_sym_try,
      anon_sym_spmd,
      aux_sym_number_token1,
      aux_sym_number_token2,
      aux_sym_number_token3,
      anon_sym_true,
      anon_sym_false,
      anon_sym_CR,
  [3240] = 5,
    ACTIONS(837), 1,
      anon_sym_DOT,
    STATE(191), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(498), 5,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      sym__external_identifier,
    ACTIONS(493), 49,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_LF,
      anon_sym_LBRACE,
      anon_sym_return,
      anon_sym_continue,
      anon_sym_break,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_arguments,
      anon_sym_function,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_classdef,
      anon_sym_try,
      anon_sym_spmd,
      aux_sym_number_token1,
      aux_sym_number_token2,
      aux_sym_number_token3,
      anon_sym_true,
      anon_sym_false,
      anon_sym_CR,
  [3309] = 5,
    ACTIONS(835), 1,
      anon_sym_DOT,
    STATE(194), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(468), 5,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      sym__external_identifier,
    ACTIONS(464), 49,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_LF,
      anon_sym_LBRACE,
      anon_sym_return,
      anon_sym_continue,
      anon_sym_break,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_arguments,
      anon_sym_function,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_classdef,
      anon_sym_try,
      anon_sym_spmd,
      aux_sym_number_token1,
      aux_sym_number_token2,
      aux_sym_number_token3,
      anon_sym_true,
      anon_sym_false,
      anon_sym_CR,
  [3378] = 5,
    ACTIONS(835), 1,
      anon_sym_DOT,
    STATE(190), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(491), 5,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      sym__external_identifier,
    ACTIONS(489), 49,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_LF,
      anon_sym_LBRACE,
      anon_sym_return,
      anon_sym_continue,
      anon_sym_break,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_arguments,
      anon_sym_function,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_classdef,
      anon_sym_try,
      anon_sym_spmd,
      aux_sym_number_token1,
      aux_sym_number_token2,
      aux_sym_number_token3,
      anon_sym_true,
      anon_sym_false,
      anon_sym_CR,
  [3447] = 5,
    ACTIONS(835), 1,
      anon_sym_DOT,
    STATE(191), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(483), 5,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      sym__external_identifier,
    ACTIONS(481), 49,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_LF,
      anon_sym_LBRACE,
      anon_sym_return,
      anon_sym_continue,
      anon_sym_break,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_arguments,
      anon_sym_function,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_classdef,
      anon_sym_try,
      anon_sym_spmd,
      aux_sym_number_token1,
      aux_sym_number_token2,
      aux_sym_number_token3,
      anon_sym_true,
      anon_sym_false,
      anon_sym_CR,
  [3516] = 35,
    ACTIONS(731), 1,
      anon_sym_LPAREN,
    ACTIONS(737), 1,
      anon_sym_TILDE,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(743), 1,
      anon_sym_LBRACK,
    ACTIONS(745), 1,
      anon_sym_LBRACE,
    ACTIONS(749), 1,
      anon_sym_end,
    ACTIONS(753), 1,
      aux_sym_number_token1,
    ACTIONS(759), 1,
      sym__single_quote_string_start,
    ACTIONS(761), 1,
      sym__double_quote_string_start,
    STATE(452), 1,
      sym__keywords,
    STATE(525), 1,
      sym_boolean,
    STATE(652), 1,
      sym_number,
    STATE(697), 1,
      sym_cell,
    STATE(700), 1,
      sym_unary_operator,
    STATE(705), 1,
      sym_binary_operator,
    STATE(722), 1,
      sym_not_operator,
    STATE(825), 1,
      sym__index_binary_operator,
    STATE(908), 1,
      sym__binary_expression,
    STATE(913), 1,
      sym__index_binary_expression,
    STATE(1370), 1,
      sym_indirect_access,
    STATE(1461), 1,
      sym__range_element,
    STATE(1513), 1,
      sym__index_range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(735), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(755), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(757), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(516), 2,
      sym_identifier,
      sym_function_call,
    STATE(704), 2,
      sym_parenthesis,
      sym_matrix,
    STATE(739), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1452), 2,
      sym__index_range,
      sym__index_expression,
    STATE(703), 3,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
    STATE(824), 3,
      sym__index_matrix,
      sym__index_parenthesis,
      sym_end_keyword,
    STATE(1045), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [3645] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(498), 5,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      sym__external_identifier,
    ACTIONS(493), 50,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_LF,
      anon_sym_LBRACE,
      anon_sym_return,
      anon_sym_continue,
      anon_sym_break,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_arguments,
      anon_sym_function,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_classdef,
      anon_sym_try,
      anon_sym_spmd,
      aux_sym_number_token1,
      aux_sym_number_token2,
      aux_sym_number_token3,
      anon_sym_true,
      anon_sym_false,
      anon_sym_CR,
  [3709] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(530), 5,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      sym__external_identifier,
    ACTIONS(528), 50,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_LF,
      anon_sym_LBRACE,
      anon_sym_return,
      anon_sym_continue,
      anon_sym_break,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_arguments,
      anon_sym_function,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_classdef,
      anon_sym_try,
      anon_sym_spmd,
      aux_sym_number_token1,
      aux_sym_number_token2,
      aux_sym_number_token3,
      anon_sym_true,
      anon_sym_false,
      anon_sym_CR,
  [3773] = 33,
    ACTIONS(687), 1,
      aux_sym_number_token1,
    ACTIONS(691), 1,
      sym__single_quote_string_start,
    ACTIONS(693), 1,
      sym__double_quote_string_start,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(745), 1,
      anon_sym_LBRACE,
    ACTIONS(825), 1,
      anon_sym_end,
    ACTIONS(831), 1,
      anon_sym_LPAREN,
    ACTIONS(833), 1,
      anon_sym_LBRACK,
    ACTIONS(840), 1,
      anon_sym_TILDE,
    STATE(445), 1,
      sym__keywords,
    STATE(450), 1,
      sym_boolean,
    STATE(609), 1,
      sym_unary_operator,
    STATE(692), 1,
      sym_not_operator,
    STATE(742), 1,
      sym_binary_operator,
    STATE(747), 1,
      sym_cell,
    STATE(779), 1,
      sym__index_binary_operator,
    STATE(908), 1,
      sym__binary_expression,
    STATE(911), 1,
      sym__index_binary_expression,
    STATE(1176), 1,
      sym__index_range_element,
    STATE(1321), 1,
      sym_indirect_access,
    STATE(1461), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(813), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(827), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(829), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(414), 2,
      sym_identifier,
      sym_function_call,
    STATE(739), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(740), 2,
      sym_parenthesis,
      sym_matrix,
    STATE(778), 3,
      sym__index_matrix,
      sym__index_parenthesis,
      sym_end_keyword,
    STATE(610), 4,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_number,
    STATE(1058), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    ACTIONS(695), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [3896] = 32,
    ACTIONS(669), 1,
      anon_sym_TILDE,
    ACTIONS(671), 1,
      anon_sym_QMARK,
    ACTIONS(673), 1,
      anon_sym_AT,
    ACTIONS(681), 1,
      anon_sym_LBRACE,
    ACTIONS(691), 1,
      sym__single_quote_string_start,
    ACTIONS(693), 1,
      sym__double_quote_string_start,
    ACTIONS(695), 1,
      sym__external_identifier,
    ACTIONS(844), 1,
      anon_sym_COMMA,
    ACTIONS(846), 1,
      anon_sym_LPAREN,
    ACTIONS(848), 1,
      anon_sym_LBRACK,
    ACTIONS(850), 1,
      aux_sym_matrix_token1,
    STATE(424), 1,
      sym_boolean,
    STATE(445), 1,
      sym__keywords,
    STATE(547), 1,
      sym_binary_operator,
    STATE(548), 1,
      sym_unary_operator,
    STATE(551), 1,
      sym_cell,
    STATE(642), 1,
      sym_not_operator,
    STATE(914), 1,
      sym__binary_expression,
    STATE(1149), 1,
      sym_ignored_argument,
    STATE(1241), 1,
      sym_row,
    STATE(1321), 1,
      sym_indirect_access,
    STATE(1465), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(667), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(689), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(396), 2,
      sym_identifier,
      sym_function_call,
    STATE(550), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(687), 3,
      aux_sym_number_token1,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(842), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    STATE(921), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(546), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(685), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [4017] = 33,
    ACTIONS(687), 1,
      aux_sym_number_token1,
    ACTIONS(691), 1,
      sym__single_quote_string_start,
    ACTIONS(693), 1,
      sym__double_quote_string_start,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(745), 1,
      anon_sym_LBRACE,
    ACTIONS(825), 1,
      anon_sym_end,
    ACTIONS(831), 1,
      anon_sym_LPAREN,
    ACTIONS(840), 1,
      anon_sym_TILDE,
    ACTIONS(852), 1,
      anon_sym_LBRACK,
    STATE(445), 1,
      sym__keywords,
    STATE(457), 1,
      sym_boolean,
    STATE(620), 1,
      sym_unary_operator,
    STATE(710), 1,
      sym_not_operator,
    STATE(742), 1,
      sym_binary_operator,
    STATE(747), 1,
      sym_cell,
    STATE(779), 1,
      sym__index_binary_operator,
    STATE(908), 1,
      sym__binary_expression,
    STATE(917), 1,
      sym__index_binary_expression,
    STATE(1252), 1,
      sym__index_range_element,
    STATE(1321), 1,
      sym_indirect_access,
    STATE(1461), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(813), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(827), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(829), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(405), 2,
      sym_identifier,
      sym_function_call,
    STATE(739), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(740), 2,
      sym_parenthesis,
      sym_matrix,
    STATE(778), 3,
      sym__index_matrix,
      sym__index_parenthesis,
      sym_end_keyword,
    STATE(625), 4,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_number,
    STATE(1058), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    ACTIONS(695), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [4140] = 33,
    ACTIONS(731), 1,
      anon_sym_LPAREN,
    ACTIONS(737), 1,
      anon_sym_TILDE,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(745), 1,
      anon_sym_LBRACE,
    ACTIONS(749), 1,
      anon_sym_end,
    ACTIONS(753), 1,
      aux_sym_number_token1,
    ACTIONS(759), 1,
      sym__single_quote_string_start,
    ACTIONS(761), 1,
      sym__double_quote_string_start,
    ACTIONS(854), 1,
      anon_sym_LBRACK,
    STATE(452), 1,
      sym__keywords,
    STATE(479), 1,
      sym_boolean,
    STATE(639), 1,
      sym_binary_operator,
    STATE(688), 1,
      sym_unary_operator,
    STATE(697), 1,
      sym_cell,
    STATE(732), 1,
      sym_not_operator,
    STATE(821), 1,
      sym__index_binary_operator,
    STATE(908), 1,
      sym__binary_expression,
    STATE(926), 1,
      sym__index_binary_expression,
    STATE(1370), 1,
      sym_indirect_access,
    STATE(1412), 1,
      sym__index_range_element,
    STATE(1461), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(735), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(755), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(757), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(447), 2,
      sym_identifier,
      sym_function_call,
    STATE(632), 2,
      sym_parenthesis,
      sym_matrix,
    STATE(739), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(819), 3,
      sym__index_matrix,
      sym__index_parenthesis,
      sym_end_keyword,
    STATE(646), 4,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_number,
    STATE(1058), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [4263] = 33,
    ACTIONS(731), 1,
      anon_sym_LPAREN,
    ACTIONS(737), 1,
      anon_sym_TILDE,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(745), 1,
      anon_sym_LBRACE,
    ACTIONS(749), 1,
      anon_sym_end,
    ACTIONS(753), 1,
      aux_sym_number_token1,
    ACTIONS(759), 1,
      sym__single_quote_string_start,
    ACTIONS(761), 1,
      sym__double_quote_string_start,
    ACTIONS(856), 1,
      anon_sym_LBRACK,
    STATE(452), 1,
      sym__keywords,
    STATE(466), 1,
      sym_boolean,
    STATE(639), 1,
      sym_binary_operator,
    STATE(678), 1,
      sym_unary_operator,
    STATE(697), 1,
      sym_cell,
    STATE(721), 1,
      sym_not_operator,
    STATE(821), 1,
      sym__index_binary_operator,
    STATE(908), 1,
      sym__binary_expression,
    STATE(913), 1,
      sym__index_binary_expression,
    STATE(1283), 1,
      sym__index_range_element,
    STATE(1370), 1,
      sym_indirect_access,
    STATE(1461), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(735), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(755), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(757), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(429), 2,
      sym_identifier,
      sym_function_call,
    STATE(632), 2,
      sym_parenthesis,
      sym_matrix,
    STATE(739), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(819), 3,
      sym__index_matrix,
      sym__index_parenthesis,
      sym_end_keyword,
    STATE(644), 4,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_number,
    STATE(1058), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [4386] = 31,
    ACTIONS(687), 1,
      aux_sym_number_token1,
    ACTIONS(691), 1,
      sym__single_quote_string_start,
    ACTIONS(693), 1,
      sym__double_quote_string_start,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(823), 1,
      anon_sym_LBRACE,
    ACTIONS(825), 1,
      anon_sym_end,
    ACTIONS(831), 1,
      anon_sym_LPAREN,
    ACTIONS(833), 1,
      anon_sym_LBRACK,
    ACTIONS(840), 1,
      anon_sym_TILDE,
    STATE(445), 1,
      sym__keywords,
    STATE(451), 1,
      sym_boolean,
    STATE(607), 1,
      sym_cell,
    STATE(621), 1,
      sym_unary_operator,
    STATE(694), 1,
      sym_not_operator,
    STATE(742), 1,
      sym_binary_operator,
    STATE(785), 1,
      sym__index_binary_operator,
    STATE(908), 1,
      sym__binary_expression,
    STATE(1321), 1,
      sym_indirect_access,
    STATE(1461), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(813), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(827), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(829), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(415), 2,
      sym_identifier,
      sym_function_call,
    STATE(699), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(740), 2,
      sym_parenthesis,
      sym_matrix,
    STATE(624), 4,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_number,
    STATE(784), 4,
      sym__index_matrix,
      sym__index_parenthesis,
      sym__index_binary_expression,
      sym_end_keyword,
    STATE(1051), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    ACTIONS(695), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [4504] = 31,
    ACTIONS(687), 1,
      aux_sym_number_token1,
    ACTIONS(691), 1,
      sym__single_quote_string_start,
    ACTIONS(693), 1,
      sym__double_quote_string_start,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(823), 1,
      anon_sym_LBRACE,
    ACTIONS(825), 1,
      anon_sym_end,
    ACTIONS(831), 1,
      anon_sym_LPAREN,
    ACTIONS(833), 1,
      anon_sym_LBRACK,
    ACTIONS(840), 1,
      anon_sym_TILDE,
    STATE(445), 1,
      sym__keywords,
    STATE(451), 1,
      sym_boolean,
    STATE(607), 1,
      sym_cell,
    STATE(621), 1,
      sym_unary_operator,
    STATE(694), 1,
      sym_not_operator,
    STATE(742), 1,
      sym_binary_operator,
    STATE(785), 1,
      sym__index_binary_operator,
    STATE(908), 1,
      sym__binary_expression,
    STATE(1321), 1,
      sym_indirect_access,
    STATE(1461), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(813), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(827), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(829), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(415), 2,
      sym_identifier,
      sym_function_call,
    STATE(699), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(740), 2,
      sym_parenthesis,
      sym_matrix,
    STATE(624), 4,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_number,
    STATE(789), 4,
      sym__index_matrix,
      sym__index_parenthesis,
      sym__index_binary_expression,
      sym_end_keyword,
    STATE(1051), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    ACTIONS(695), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [4622] = 33,
    ACTIONS(669), 1,
      anon_sym_TILDE,
    ACTIONS(671), 1,
      anon_sym_QMARK,
    ACTIONS(673), 1,
      anon_sym_AT,
    ACTIONS(681), 1,
      anon_sym_LBRACE,
    ACTIONS(691), 1,
      sym__single_quote_string_start,
    ACTIONS(693), 1,
      sym__double_quote_string_start,
    ACTIONS(695), 1,
      sym__external_identifier,
    ACTIONS(844), 1,
      anon_sym_COMMA,
    ACTIONS(846), 1,
      anon_sym_LPAREN,
    ACTIONS(848), 1,
      anon_sym_LBRACK,
    ACTIONS(858), 1,
      anon_sym_LF,
    ACTIONS(860), 1,
      anon_sym_RBRACK,
    STATE(207), 1,
      aux_sym_matrix_repeat1,
    STATE(424), 1,
      sym_boolean,
    STATE(445), 1,
      sym__keywords,
    STATE(547), 1,
      sym_binary_operator,
    STATE(548), 1,
      sym_unary_operator,
    STATE(551), 1,
      sym_cell,
    STATE(642), 1,
      sym_not_operator,
    STATE(914), 1,
      sym__binary_expression,
    STATE(1149), 1,
      sym_ignored_argument,
    STATE(1240), 1,
      sym_row,
    STATE(1321), 1,
      sym_indirect_access,
    STATE(1465), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(667), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(689), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(396), 2,
      sym_identifier,
      sym_function_call,
    STATE(550), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(687), 3,
      aux_sym_number_token1,
      aux_sym_number_token2,
      aux_sym_number_token3,
    STATE(921), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(546), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(685), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [4744] = 33,
    ACTIONS(669), 1,
      anon_sym_TILDE,
    ACTIONS(671), 1,
      anon_sym_QMARK,
    ACTIONS(673), 1,
      anon_sym_AT,
    ACTIONS(681), 1,
      anon_sym_LBRACE,
    ACTIONS(691), 1,
      sym__single_quote_string_start,
    ACTIONS(693), 1,
      sym__double_quote_string_start,
    ACTIONS(695), 1,
      sym__external_identifier,
    ACTIONS(844), 1,
      anon_sym_COMMA,
    ACTIONS(846), 1,
      anon_sym_LPAREN,
    ACTIONS(848), 1,
      anon_sym_LBRACK,
    ACTIONS(862), 1,
      anon_sym_LF,
    ACTIONS(864), 1,
      anon_sym_RBRACE,
    STATE(208), 1,
      aux_sym_matrix_repeat1,
    STATE(424), 1,
      sym_boolean,
    STATE(445), 1,
      sym__keywords,
    STATE(547), 1,
      sym_binary_operator,
    STATE(548), 1,
      sym_unary_operator,
    STATE(551), 1,
      sym_cell,
    STATE(642), 1,
      sym_not_operator,
    STATE(914), 1,
      sym__binary_expression,
    STATE(1149), 1,
      sym_ignored_argument,
    STATE(1210), 1,
      sym_row,
    STATE(1321), 1,
      sym_indirect_access,
    STATE(1465), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(667), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(689), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(396), 2,
      sym_identifier,
      sym_function_call,
    STATE(550), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(687), 3,
      aux_sym_number_token1,
      aux_sym_number_token2,
      aux_sym_number_token3,
    STATE(921), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(546), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(685), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [4866] = 33,
    ACTIONS(669), 1,
      anon_sym_TILDE,
    ACTIONS(671), 1,
      anon_sym_QMARK,
    ACTIONS(673), 1,
      anon_sym_AT,
    ACTIONS(681), 1,
      anon_sym_LBRACE,
    ACTIONS(691), 1,
      sym__single_quote_string_start,
    ACTIONS(693), 1,
      sym__double_quote_string_start,
    ACTIONS(695), 1,
      sym__external_identifier,
    ACTIONS(701), 1,
      anon_sym_LF,
    ACTIONS(844), 1,
      anon_sym_COMMA,
    ACTIONS(846), 1,
      anon_sym_LPAREN,
    ACTIONS(848), 1,
      anon_sym_LBRACK,
    ACTIONS(866), 1,
      anon_sym_RBRACK,
    STATE(424), 1,
      sym_boolean,
    STATE(445), 1,
      sym__keywords,
    STATE(547), 1,
      sym_binary_operator,
    STATE(548), 1,
      sym_unary_operator,
    STATE(551), 1,
      sym_cell,
    STATE(599), 1,
      aux_sym_matrix_repeat1,
    STATE(642), 1,
      sym_not_operator,
    STATE(914), 1,
      sym__binary_expression,
    STATE(1149), 1,
      sym_ignored_argument,
    STATE(1246), 1,
      sym_row,
    STATE(1321), 1,
      sym_indirect_access,
    STATE(1465), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(667), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(689), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(396), 2,
      sym_identifier,
      sym_function_call,
    STATE(550), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(687), 3,
      aux_sym_number_token1,
      aux_sym_number_token2,
      aux_sym_number_token3,
    STATE(921), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(546), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(685), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [4988] = 33,
    ACTIONS(669), 1,
      anon_sym_TILDE,
    ACTIONS(671), 1,
      anon_sym_QMARK,
    ACTIONS(673), 1,
      anon_sym_AT,
    ACTIONS(681), 1,
      anon_sym_LBRACE,
    ACTIONS(691), 1,
      sym__single_quote_string_start,
    ACTIONS(693), 1,
      sym__double_quote_string_start,
    ACTIONS(695), 1,
      sym__external_identifier,
    ACTIONS(701), 1,
      anon_sym_LF,
    ACTIONS(844), 1,
      anon_sym_COMMA,
    ACTIONS(846), 1,
      anon_sym_LPAREN,
    ACTIONS(848), 1,
      anon_sym_LBRACK,
    ACTIONS(868), 1,
      anon_sym_RBRACE,
    STATE(424), 1,
      sym_boolean,
    STATE(445), 1,
      sym__keywords,
    STATE(547), 1,
      sym_binary_operator,
    STATE(548), 1,
      sym_unary_operator,
    STATE(551), 1,
      sym_cell,
    STATE(599), 1,
      aux_sym_matrix_repeat1,
    STATE(642), 1,
      sym_not_operator,
    STATE(914), 1,
      sym__binary_expression,
    STATE(1149), 1,
      sym_ignored_argument,
    STATE(1248), 1,
      sym_row,
    STATE(1321), 1,
      sym_indirect_access,
    STATE(1465), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(667), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(689), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(396), 2,
      sym_identifier,
      sym_function_call,
    STATE(550), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(687), 3,
      aux_sym_number_token1,
      aux_sym_number_token2,
      aux_sym_number_token3,
    STATE(921), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(546), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(685), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [5110] = 31,
    ACTIONS(731), 1,
      anon_sym_LPAREN,
    ACTIONS(737), 1,
      anon_sym_TILDE,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(745), 1,
      anon_sym_LBRACE,
    ACTIONS(749), 1,
      anon_sym_end,
    ACTIONS(753), 1,
      aux_sym_number_token1,
    ACTIONS(759), 1,
      sym__single_quote_string_start,
    ACTIONS(761), 1,
      sym__double_quote_string_start,
    ACTIONS(856), 1,
      anon_sym_LBRACK,
    STATE(452), 1,
      sym__keywords,
    STATE(468), 1,
      sym_boolean,
    STATE(628), 1,
      sym_cell,
    STATE(639), 1,
      sym_binary_operator,
    STATE(676), 1,
      sym_unary_operator,
    STATE(712), 1,
      sym_not_operator,
    STATE(832), 1,
      sym__index_binary_operator,
    STATE(908), 1,
      sym__binary_expression,
    STATE(1370), 1,
      sym_indirect_access,
    STATE(1461), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(735), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(755), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(757), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(430), 2,
      sym_identifier,
      sym_function_call,
    STATE(632), 2,
      sym_parenthesis,
      sym_matrix,
    STATE(724), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(634), 4,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_number,
    STATE(829), 4,
      sym__index_matrix,
      sym__index_parenthesis,
      sym__index_binary_expression,
      sym_end_keyword,
    STATE(1064), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [5228] = 31,
    ACTIONS(687), 1,
      aux_sym_number_token1,
    ACTIONS(691), 1,
      sym__single_quote_string_start,
    ACTIONS(693), 1,
      sym__double_quote_string_start,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(823), 1,
      anon_sym_LBRACE,
    ACTIONS(825), 1,
      anon_sym_end,
    ACTIONS(831), 1,
      anon_sym_LPAREN,
    ACTIONS(833), 1,
      anon_sym_LBRACK,
    ACTIONS(840), 1,
      anon_sym_TILDE,
    STATE(445), 1,
      sym__keywords,
    STATE(451), 1,
      sym_boolean,
    STATE(607), 1,
      sym_cell,
    STATE(621), 1,
      sym_unary_operator,
    STATE(694), 1,
      sym_not_operator,
    STATE(742), 1,
      sym_binary_operator,
    STATE(785), 1,
      sym__index_binary_operator,
    STATE(908), 1,
      sym__binary_expression,
    STATE(1321), 1,
      sym_indirect_access,
    STATE(1461), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(813), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(827), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(829), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(415), 2,
      sym_identifier,
      sym_function_call,
    STATE(699), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(740), 2,
      sym_parenthesis,
      sym_matrix,
    STATE(624), 4,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_number,
    STATE(790), 4,
      sym__index_matrix,
      sym__index_parenthesis,
      sym__index_binary_expression,
      sym_end_keyword,
    STATE(1051), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    ACTIONS(695), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [5346] = 31,
    ACTIONS(731), 1,
      anon_sym_LPAREN,
    ACTIONS(737), 1,
      anon_sym_TILDE,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(745), 1,
      anon_sym_LBRACE,
    ACTIONS(749), 1,
      anon_sym_end,
    ACTIONS(753), 1,
      aux_sym_number_token1,
    ACTIONS(759), 1,
      sym__single_quote_string_start,
    ACTIONS(761), 1,
      sym__double_quote_string_start,
    ACTIONS(854), 1,
      anon_sym_LBRACK,
    STATE(452), 1,
      sym__keywords,
    STATE(480), 1,
      sym_boolean,
    STATE(628), 1,
      sym_cell,
    STATE(639), 1,
      sym_binary_operator,
    STATE(682), 1,
      sym_unary_operator,
    STATE(735), 1,
      sym_not_operator,
    STATE(832), 1,
      sym__index_binary_operator,
    STATE(908), 1,
      sym__binary_expression,
    STATE(1370), 1,
      sym_indirect_access,
    STATE(1461), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(735), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(755), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(757), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(418), 2,
      sym_identifier,
      sym_function_call,
    STATE(632), 2,
      sym_parenthesis,
      sym_matrix,
    STATE(724), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(638), 4,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_number,
    STATE(843), 4,
      sym__index_matrix,
      sym__index_parenthesis,
      sym__index_binary_expression,
      sym_end_keyword,
    STATE(1058), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [5464] = 31,
    ACTIONS(731), 1,
      anon_sym_LPAREN,
    ACTIONS(737), 1,
      anon_sym_TILDE,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(745), 1,
      anon_sym_LBRACE,
    ACTIONS(749), 1,
      anon_sym_end,
    ACTIONS(753), 1,
      aux_sym_number_token1,
    ACTIONS(759), 1,
      sym__single_quote_string_start,
    ACTIONS(761), 1,
      sym__double_quote_string_start,
    ACTIONS(854), 1,
      anon_sym_LBRACK,
    STATE(452), 1,
      sym__keywords,
    STATE(480), 1,
      sym_boolean,
    STATE(628), 1,
      sym_cell,
    STATE(639), 1,
      sym_binary_operator,
    STATE(682), 1,
      sym_unary_operator,
    STATE(735), 1,
      sym_not_operator,
    STATE(832), 1,
      sym__index_binary_operator,
    STATE(908), 1,
      sym__binary_expression,
    STATE(1370), 1,
      sym_indirect_access,
    STATE(1461), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(735), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(755), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(757), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(418), 2,
      sym_identifier,
      sym_function_call,
    STATE(632), 2,
      sym_parenthesis,
      sym_matrix,
    STATE(724), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(638), 4,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_number,
    STATE(846), 4,
      sym__index_matrix,
      sym__index_parenthesis,
      sym__index_binary_expression,
      sym_end_keyword,
    STATE(1058), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [5582] = 31,
    ACTIONS(731), 1,
      anon_sym_LPAREN,
    ACTIONS(737), 1,
      anon_sym_TILDE,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(745), 1,
      anon_sym_LBRACE,
    ACTIONS(749), 1,
      anon_sym_end,
    ACTIONS(753), 1,
      aux_sym_number_token1,
    ACTIONS(759), 1,
      sym__single_quote_string_start,
    ACTIONS(761), 1,
      sym__double_quote_string_start,
    ACTIONS(854), 1,
      anon_sym_LBRACK,
    STATE(452), 1,
      sym__keywords,
    STATE(480), 1,
      sym_boolean,
    STATE(628), 1,
      sym_cell,
    STATE(639), 1,
      sym_binary_operator,
    STATE(682), 1,
      sym_unary_operator,
    STATE(735), 1,
      sym_not_operator,
    STATE(832), 1,
      sym__index_binary_operator,
    STATE(908), 1,
      sym__binary_expression,
    STATE(1370), 1,
      sym_indirect_access,
    STATE(1461), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(735), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(755), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(757), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(418), 2,
      sym_identifier,
      sym_function_call,
    STATE(632), 2,
      sym_parenthesis,
      sym_matrix,
    STATE(724), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(638), 4,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_number,
    STATE(837), 4,
      sym__index_matrix,
      sym__index_parenthesis,
      sym__index_binary_expression,
      sym_end_keyword,
    STATE(1058), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [5700] = 31,
    ACTIONS(731), 1,
      anon_sym_LPAREN,
    ACTIONS(737), 1,
      anon_sym_TILDE,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(745), 1,
      anon_sym_LBRACE,
    ACTIONS(749), 1,
      anon_sym_end,
    ACTIONS(753), 1,
      aux_sym_number_token1,
    ACTIONS(759), 1,
      sym__single_quote_string_start,
    ACTIONS(761), 1,
      sym__double_quote_string_start,
    ACTIONS(854), 1,
      anon_sym_LBRACK,
    STATE(452), 1,
      sym__keywords,
    STATE(480), 1,
      sym_boolean,
    STATE(628), 1,
      sym_cell,
    STATE(639), 1,
      sym_binary_operator,
    STATE(682), 1,
      sym_unary_operator,
    STATE(735), 1,
      sym_not_operator,
    STATE(832), 1,
      sym__index_binary_operator,
    STATE(908), 1,
      sym__binary_expression,
    STATE(1370), 1,
      sym_indirect_access,
    STATE(1461), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(735), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(755), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(757), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(418), 2,
      sym_identifier,
      sym_function_call,
    STATE(632), 2,
      sym_parenthesis,
      sym_matrix,
    STATE(724), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(638), 4,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_number,
    STATE(839), 4,
      sym__index_matrix,
      sym__index_parenthesis,
      sym__index_binary_expression,
      sym_end_keyword,
    STATE(1058), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [5818] = 31,
    ACTIONS(731), 1,
      anon_sym_LPAREN,
    ACTIONS(737), 1,
      anon_sym_TILDE,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(745), 1,
      anon_sym_LBRACE,
    ACTIONS(749), 1,
      anon_sym_end,
    ACTIONS(753), 1,
      aux_sym_number_token1,
    ACTIONS(759), 1,
      sym__single_quote_string_start,
    ACTIONS(761), 1,
      sym__double_quote_string_start,
    ACTIONS(854), 1,
      anon_sym_LBRACK,
    STATE(452), 1,
      sym__keywords,
    STATE(480), 1,
      sym_boolean,
    STATE(628), 1,
      sym_cell,
    STATE(639), 1,
      sym_binary_operator,
    STATE(682), 1,
      sym_unary_operator,
    STATE(735), 1,
      sym_not_operator,
    STATE(832), 1,
      sym__index_binary_operator,
    STATE(908), 1,
      sym__binary_expression,
    STATE(1370), 1,
      sym_indirect_access,
    STATE(1461), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(735), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(755), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(757), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(418), 2,
      sym_identifier,
      sym_function_call,
    STATE(632), 2,
      sym_parenthesis,
      sym_matrix,
    STATE(724), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(638), 4,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_number,
    STATE(840), 4,
      sym__index_matrix,
      sym__index_parenthesis,
      sym__index_binary_expression,
      sym_end_keyword,
    STATE(1058), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [5936] = 31,
    ACTIONS(687), 1,
      aux_sym_number_token1,
    ACTIONS(691), 1,
      sym__single_quote_string_start,
    ACTIONS(693), 1,
      sym__double_quote_string_start,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(823), 1,
      anon_sym_LBRACE,
    ACTIONS(825), 1,
      anon_sym_end,
    ACTIONS(831), 1,
      anon_sym_LPAREN,
    ACTIONS(840), 1,
      anon_sym_TILDE,
    ACTIONS(852), 1,
      anon_sym_LBRACK,
    STATE(445), 1,
      sym__keywords,
    STATE(458), 1,
      sym_boolean,
    STATE(601), 1,
      sym_unary_operator,
    STATE(607), 1,
      sym_cell,
    STATE(693), 1,
      sym_not_operator,
    STATE(742), 1,
      sym_binary_operator,
    STATE(785), 1,
      sym__index_binary_operator,
    STATE(908), 1,
      sym__binary_expression,
    STATE(1321), 1,
      sym_indirect_access,
    STATE(1461), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(813), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(827), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(829), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(408), 2,
      sym_identifier,
      sym_function_call,
    STATE(699), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(740), 2,
      sym_parenthesis,
      sym_matrix,
    STATE(602), 4,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_number,
    STATE(813), 4,
      sym__index_matrix,
      sym__index_parenthesis,
      sym__index_binary_expression,
      sym_end_keyword,
    STATE(1059), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    ACTIONS(695), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [6054] = 31,
    ACTIONS(687), 1,
      aux_sym_number_token1,
    ACTIONS(691), 1,
      sym__single_quote_string_start,
    ACTIONS(693), 1,
      sym__double_quote_string_start,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(823), 1,
      anon_sym_LBRACE,
    ACTIONS(825), 1,
      anon_sym_end,
    ACTIONS(831), 1,
      anon_sym_LPAREN,
    ACTIONS(840), 1,
      anon_sym_TILDE,
    ACTIONS(852), 1,
      anon_sym_LBRACK,
    STATE(445), 1,
      sym__keywords,
    STATE(458), 1,
      sym_boolean,
    STATE(601), 1,
      sym_unary_operator,
    STATE(607), 1,
      sym_cell,
    STATE(693), 1,
      sym_not_operator,
    STATE(742), 1,
      sym_binary_operator,
    STATE(785), 1,
      sym__index_binary_operator,
    STATE(908), 1,
      sym__binary_expression,
    STATE(1321), 1,
      sym_indirect_access,
    STATE(1461), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(813), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(827), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(829), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(408), 2,
      sym_identifier,
      sym_function_call,
    STATE(699), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(740), 2,
      sym_parenthesis,
      sym_matrix,
    STATE(602), 4,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_number,
    STATE(814), 4,
      sym__index_matrix,
      sym__index_parenthesis,
      sym__index_binary_expression,
      sym_end_keyword,
    STATE(1059), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    ACTIONS(695), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [6172] = 31,
    ACTIONS(687), 1,
      aux_sym_number_token1,
    ACTIONS(691), 1,
      sym__single_quote_string_start,
    ACTIONS(693), 1,
      sym__double_quote_string_start,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(823), 1,
      anon_sym_LBRACE,
    ACTIONS(825), 1,
      anon_sym_end,
    ACTIONS(831), 1,
      anon_sym_LPAREN,
    ACTIONS(840), 1,
      anon_sym_TILDE,
    ACTIONS(852), 1,
      anon_sym_LBRACK,
    STATE(445), 1,
      sym__keywords,
    STATE(458), 1,
      sym_boolean,
    STATE(601), 1,
      sym_unary_operator,
    STATE(607), 1,
      sym_cell,
    STATE(693), 1,
      sym_not_operator,
    STATE(742), 1,
      sym_binary_operator,
    STATE(785), 1,
      sym__index_binary_operator,
    STATE(908), 1,
      sym__binary_expression,
    STATE(1321), 1,
      sym_indirect_access,
    STATE(1461), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(813), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(827), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(829), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(408), 2,
      sym_identifier,
      sym_function_call,
    STATE(699), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(740), 2,
      sym_parenthesis,
      sym_matrix,
    STATE(602), 4,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_number,
    STATE(815), 4,
      sym__index_matrix,
      sym__index_parenthesis,
      sym__index_binary_expression,
      sym_end_keyword,
    STATE(1059), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    ACTIONS(695), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [6290] = 31,
    ACTIONS(687), 1,
      aux_sym_number_token1,
    ACTIONS(691), 1,
      sym__single_quote_string_start,
    ACTIONS(693), 1,
      sym__double_quote_string_start,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(823), 1,
      anon_sym_LBRACE,
    ACTIONS(825), 1,
      anon_sym_end,
    ACTIONS(831), 1,
      anon_sym_LPAREN,
    ACTIONS(840), 1,
      anon_sym_TILDE,
    ACTIONS(852), 1,
      anon_sym_LBRACK,
    STATE(445), 1,
      sym__keywords,
    STATE(458), 1,
      sym_boolean,
    STATE(601), 1,
      sym_unary_operator,
    STATE(607), 1,
      sym_cell,
    STATE(693), 1,
      sym_not_operator,
    STATE(742), 1,
      sym_binary_operator,
    STATE(785), 1,
      sym__index_binary_operator,
    STATE(908), 1,
      sym__binary_expression,
    STATE(1321), 1,
      sym_indirect_access,
    STATE(1461), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(813), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(827), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(829), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(408), 2,
      sym_identifier,
      sym_function_call,
    STATE(699), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(740), 2,
      sym_parenthesis,
      sym_matrix,
    STATE(602), 4,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_number,
    STATE(816), 4,
      sym__index_matrix,
      sym__index_parenthesis,
      sym__index_binary_expression,
      sym_end_keyword,
    STATE(1059), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    ACTIONS(695), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [6408] = 31,
    ACTIONS(687), 1,
      aux_sym_number_token1,
    ACTIONS(691), 1,
      sym__single_quote_string_start,
    ACTIONS(693), 1,
      sym__double_quote_string_start,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(823), 1,
      anon_sym_LBRACE,
    ACTIONS(825), 1,
      anon_sym_end,
    ACTIONS(831), 1,
      anon_sym_LPAREN,
    ACTIONS(840), 1,
      anon_sym_TILDE,
    ACTIONS(852), 1,
      anon_sym_LBRACK,
    STATE(445), 1,
      sym__keywords,
    STATE(458), 1,
      sym_boolean,
    STATE(601), 1,
      sym_unary_operator,
    STATE(607), 1,
      sym_cell,
    STATE(693), 1,
      sym_not_operator,
    STATE(742), 1,
      sym_binary_operator,
    STATE(785), 1,
      sym__index_binary_operator,
    STATE(908), 1,
      sym__binary_expression,
    STATE(1321), 1,
      sym_indirect_access,
    STATE(1461), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(813), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(827), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(829), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(408), 2,
      sym_identifier,
      sym_function_call,
    STATE(699), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(740), 2,
      sym_parenthesis,
      sym_matrix,
    STATE(602), 4,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_number,
    STATE(836), 4,
      sym__index_matrix,
      sym__index_parenthesis,
      sym__index_binary_expression,
      sym_end_keyword,
    STATE(1059), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    ACTIONS(695), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [6526] = 31,
    ACTIONS(687), 1,
      aux_sym_number_token1,
    ACTIONS(691), 1,
      sym__single_quote_string_start,
    ACTIONS(693), 1,
      sym__double_quote_string_start,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(823), 1,
      anon_sym_LBRACE,
    ACTIONS(825), 1,
      anon_sym_end,
    ACTIONS(831), 1,
      anon_sym_LPAREN,
    ACTIONS(833), 1,
      anon_sym_LBRACK,
    ACTIONS(840), 1,
      anon_sym_TILDE,
    STATE(445), 1,
      sym__keywords,
    STATE(451), 1,
      sym_boolean,
    STATE(607), 1,
      sym_cell,
    STATE(621), 1,
      sym_unary_operator,
    STATE(694), 1,
      sym_not_operator,
    STATE(742), 1,
      sym_binary_operator,
    STATE(785), 1,
      sym__index_binary_operator,
    STATE(908), 1,
      sym__binary_expression,
    STATE(1321), 1,
      sym_indirect_access,
    STATE(1461), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(813), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(827), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(829), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(415), 2,
      sym_identifier,
      sym_function_call,
    STATE(699), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(740), 2,
      sym_parenthesis,
      sym_matrix,
    STATE(624), 4,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_number,
    STATE(786), 4,
      sym__index_matrix,
      sym__index_parenthesis,
      sym__index_binary_expression,
      sym_end_keyword,
    STATE(1051), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    ACTIONS(695), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [6644] = 33,
    ACTIONS(669), 1,
      anon_sym_TILDE,
    ACTIONS(671), 1,
      anon_sym_QMARK,
    ACTIONS(673), 1,
      anon_sym_AT,
    ACTIONS(681), 1,
      anon_sym_LBRACE,
    ACTIONS(691), 1,
      sym__single_quote_string_start,
    ACTIONS(693), 1,
      sym__double_quote_string_start,
    ACTIONS(695), 1,
      sym__external_identifier,
    ACTIONS(844), 1,
      anon_sym_COMMA,
    ACTIONS(846), 1,
      anon_sym_LPAREN,
    ACTIONS(848), 1,
      anon_sym_LBRACK,
    ACTIONS(870), 1,
      anon_sym_LF,
    ACTIONS(872), 1,
      anon_sym_RBRACK,
    STATE(230), 1,
      aux_sym_matrix_repeat1,
    STATE(424), 1,
      sym_boolean,
    STATE(445), 1,
      sym__keywords,
    STATE(547), 1,
      sym_binary_operator,
    STATE(548), 1,
      sym_unary_operator,
    STATE(551), 1,
      sym_cell,
    STATE(642), 1,
      sym_not_operator,
    STATE(914), 1,
      sym__binary_expression,
    STATE(1149), 1,
      sym_ignored_argument,
    STATE(1321), 1,
      sym_indirect_access,
    STATE(1357), 1,
      sym_row,
    STATE(1465), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(667), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(689), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(396), 2,
      sym_identifier,
      sym_function_call,
    STATE(550), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(687), 3,
      aux_sym_number_token1,
      aux_sym_number_token2,
      aux_sym_number_token3,
    STATE(921), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(546), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(685), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [6766] = 33,
    ACTIONS(669), 1,
      anon_sym_TILDE,
    ACTIONS(671), 1,
      anon_sym_QMARK,
    ACTIONS(673), 1,
      anon_sym_AT,
    ACTIONS(681), 1,
      anon_sym_LBRACE,
    ACTIONS(691), 1,
      sym__single_quote_string_start,
    ACTIONS(693), 1,
      sym__double_quote_string_start,
    ACTIONS(695), 1,
      sym__external_identifier,
    ACTIONS(844), 1,
      anon_sym_COMMA,
    ACTIONS(846), 1,
      anon_sym_LPAREN,
    ACTIONS(848), 1,
      anon_sym_LBRACK,
    ACTIONS(874), 1,
      anon_sym_LF,
    ACTIONS(876), 1,
      anon_sym_RBRACE,
    STATE(236), 1,
      aux_sym_matrix_repeat1,
    STATE(424), 1,
      sym_boolean,
    STATE(445), 1,
      sym__keywords,
    STATE(547), 1,
      sym_binary_operator,
    STATE(548), 1,
      sym_unary_operator,
    STATE(551), 1,
      sym_cell,
    STATE(642), 1,
      sym_not_operator,
    STATE(914), 1,
      sym__binary_expression,
    STATE(1149), 1,
      sym_ignored_argument,
    STATE(1249), 1,
      sym_row,
    STATE(1321), 1,
      sym_indirect_access,
    STATE(1465), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(667), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(689), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(396), 2,
      sym_identifier,
      sym_function_call,
    STATE(550), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(687), 3,
      aux_sym_number_token1,
      aux_sym_number_token2,
      aux_sym_number_token3,
    STATE(921), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(546), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(685), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [6888] = 33,
    ACTIONS(669), 1,
      anon_sym_TILDE,
    ACTIONS(671), 1,
      anon_sym_QMARK,
    ACTIONS(673), 1,
      anon_sym_AT,
    ACTIONS(681), 1,
      anon_sym_LBRACE,
    ACTIONS(691), 1,
      sym__single_quote_string_start,
    ACTIONS(693), 1,
      sym__double_quote_string_start,
    ACTIONS(695), 1,
      sym__external_identifier,
    ACTIONS(844), 1,
      anon_sym_COMMA,
    ACTIONS(846), 1,
      anon_sym_LPAREN,
    ACTIONS(848), 1,
      anon_sym_LBRACK,
    ACTIONS(878), 1,
      anon_sym_LF,
    ACTIONS(880), 1,
      anon_sym_RBRACK,
    STATE(226), 1,
      aux_sym_matrix_repeat1,
    STATE(424), 1,
      sym_boolean,
    STATE(445), 1,
      sym__keywords,
    STATE(547), 1,
      sym_binary_operator,
    STATE(548), 1,
      sym_unary_operator,
    STATE(551), 1,
      sym_cell,
    STATE(642), 1,
      sym_not_operator,
    STATE(914), 1,
      sym__binary_expression,
    STATE(1149), 1,
      sym_ignored_argument,
    STATE(1306), 1,
      sym_row,
    STATE(1321), 1,
      sym_indirect_access,
    STATE(1465), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(667), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(689), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(396), 2,
      sym_identifier,
      sym_function_call,
    STATE(550), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(687), 3,
      aux_sym_number_token1,
      aux_sym_number_token2,
      aux_sym_number_token3,
    STATE(921), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(546), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(685), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [7010] = 33,
    ACTIONS(669), 1,
      anon_sym_TILDE,
    ACTIONS(671), 1,
      anon_sym_QMARK,
    ACTIONS(673), 1,
      anon_sym_AT,
    ACTIONS(681), 1,
      anon_sym_LBRACE,
    ACTIONS(691), 1,
      sym__single_quote_string_start,
    ACTIONS(693), 1,
      sym__double_quote_string_start,
    ACTIONS(695), 1,
      sym__external_identifier,
    ACTIONS(844), 1,
      anon_sym_COMMA,
    ACTIONS(846), 1,
      anon_sym_LPAREN,
    ACTIONS(848), 1,
      anon_sym_LBRACK,
    ACTIONS(882), 1,
      anon_sym_LF,
    ACTIONS(884), 1,
      anon_sym_RBRACE,
    STATE(227), 1,
      aux_sym_matrix_repeat1,
    STATE(424), 1,
      sym_boolean,
    STATE(445), 1,
      sym__keywords,
    STATE(547), 1,
      sym_binary_operator,
    STATE(548), 1,
      sym_unary_operator,
    STATE(551), 1,
      sym_cell,
    STATE(642), 1,
      sym_not_operator,
    STATE(914), 1,
      sym__binary_expression,
    STATE(1149), 1,
      sym_ignored_argument,
    STATE(1307), 1,
      sym_row,
    STATE(1321), 1,
      sym_indirect_access,
    STATE(1465), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(667), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(689), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(396), 2,
      sym_identifier,
      sym_function_call,
    STATE(550), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(687), 3,
      aux_sym_number_token1,
      aux_sym_number_token2,
      aux_sym_number_token3,
    STATE(921), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(546), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(685), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [7132] = 33,
    ACTIONS(669), 1,
      anon_sym_TILDE,
    ACTIONS(671), 1,
      anon_sym_QMARK,
    ACTIONS(673), 1,
      anon_sym_AT,
    ACTIONS(681), 1,
      anon_sym_LBRACE,
    ACTIONS(691), 1,
      sym__single_quote_string_start,
    ACTIONS(693), 1,
      sym__double_quote_string_start,
    ACTIONS(695), 1,
      sym__external_identifier,
    ACTIONS(701), 1,
      anon_sym_LF,
    ACTIONS(844), 1,
      anon_sym_COMMA,
    ACTIONS(846), 1,
      anon_sym_LPAREN,
    ACTIONS(848), 1,
      anon_sym_LBRACK,
    ACTIONS(886), 1,
      anon_sym_RBRACK,
    STATE(424), 1,
      sym_boolean,
    STATE(445), 1,
      sym__keywords,
    STATE(547), 1,
      sym_binary_operator,
    STATE(548), 1,
      sym_unary_operator,
    STATE(551), 1,
      sym_cell,
    STATE(599), 1,
      aux_sym_matrix_repeat1,
    STATE(642), 1,
      sym_not_operator,
    STATE(914), 1,
      sym__binary_expression,
    STATE(1149), 1,
      sym_ignored_argument,
    STATE(1311), 1,
      sym_row,
    STATE(1321), 1,
      sym_indirect_access,
    STATE(1465), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(667), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(689), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(396), 2,
      sym_identifier,
      sym_function_call,
    STATE(550), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(687), 3,
      aux_sym_number_token1,
      aux_sym_number_token2,
      aux_sym_number_token3,
    STATE(921), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(546), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(685), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [7254] = 33,
    ACTIONS(669), 1,
      anon_sym_TILDE,
    ACTIONS(671), 1,
      anon_sym_QMARK,
    ACTIONS(673), 1,
      anon_sym_AT,
    ACTIONS(681), 1,
      anon_sym_LBRACE,
    ACTIONS(691), 1,
      sym__single_quote_string_start,
    ACTIONS(693), 1,
      sym__double_quote_string_start,
    ACTIONS(695), 1,
      sym__external_identifier,
    ACTIONS(701), 1,
      anon_sym_LF,
    ACTIONS(844), 1,
      anon_sym_COMMA,
    ACTIONS(846), 1,
      anon_sym_LPAREN,
    ACTIONS(848), 1,
      anon_sym_LBRACK,
    ACTIONS(888), 1,
      anon_sym_RBRACE,
    STATE(424), 1,
      sym_boolean,
    STATE(445), 1,
      sym__keywords,
    STATE(547), 1,
      sym_binary_operator,
    STATE(548), 1,
      sym_unary_operator,
    STATE(551), 1,
      sym_cell,
    STATE(599), 1,
      aux_sym_matrix_repeat1,
    STATE(642), 1,
      sym_not_operator,
    STATE(914), 1,
      sym__binary_expression,
    STATE(1149), 1,
      sym_ignored_argument,
    STATE(1313), 1,
      sym_row,
    STATE(1321), 1,
      sym_indirect_access,
    STATE(1465), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(667), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(689), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(396), 2,
      sym_identifier,
      sym_function_call,
    STATE(550), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(687), 3,
      aux_sym_number_token1,
      aux_sym_number_token2,
      aux_sym_number_token3,
    STATE(921), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(546), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(685), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [7376] = 31,
    ACTIONS(731), 1,
      anon_sym_LPAREN,
    ACTIONS(737), 1,
      anon_sym_TILDE,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(745), 1,
      anon_sym_LBRACE,
    ACTIONS(749), 1,
      anon_sym_end,
    ACTIONS(753), 1,
      aux_sym_number_token1,
    ACTIONS(759), 1,
      sym__single_quote_string_start,
    ACTIONS(761), 1,
      sym__double_quote_string_start,
    ACTIONS(856), 1,
      anon_sym_LBRACK,
    STATE(452), 1,
      sym__keywords,
    STATE(468), 1,
      sym_boolean,
    STATE(628), 1,
      sym_cell,
    STATE(639), 1,
      sym_binary_operator,
    STATE(676), 1,
      sym_unary_operator,
    STATE(712), 1,
      sym_not_operator,
    STATE(832), 1,
      sym__index_binary_operator,
    STATE(908), 1,
      sym__binary_expression,
    STATE(1370), 1,
      sym_indirect_access,
    STATE(1461), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(735), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(755), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(757), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(430), 2,
      sym_identifier,
      sym_function_call,
    STATE(632), 2,
      sym_parenthesis,
      sym_matrix,
    STATE(724), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(634), 4,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_number,
    STATE(803), 4,
      sym__index_matrix,
      sym__index_parenthesis,
      sym__index_binary_expression,
      sym_end_keyword,
    STATE(1064), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [7494] = 31,
    ACTIONS(687), 1,
      aux_sym_number_token1,
    ACTIONS(691), 1,
      sym__single_quote_string_start,
    ACTIONS(693), 1,
      sym__double_quote_string_start,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(823), 1,
      anon_sym_LBRACE,
    ACTIONS(825), 1,
      anon_sym_end,
    ACTIONS(831), 1,
      anon_sym_LPAREN,
    ACTIONS(833), 1,
      anon_sym_LBRACK,
    ACTIONS(840), 1,
      anon_sym_TILDE,
    STATE(445), 1,
      sym__keywords,
    STATE(451), 1,
      sym_boolean,
    STATE(607), 1,
      sym_cell,
    STATE(621), 1,
      sym_unary_operator,
    STATE(694), 1,
      sym_not_operator,
    STATE(742), 1,
      sym_binary_operator,
    STATE(785), 1,
      sym__index_binary_operator,
    STATE(908), 1,
      sym__binary_expression,
    STATE(1321), 1,
      sym_indirect_access,
    STATE(1461), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(813), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(827), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(829), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(415), 2,
      sym_identifier,
      sym_function_call,
    STATE(699), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(740), 2,
      sym_parenthesis,
      sym_matrix,
    STATE(624), 4,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_number,
    STATE(787), 4,
      sym__index_matrix,
      sym__index_parenthesis,
      sym__index_binary_expression,
      sym_end_keyword,
    STATE(1051), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    ACTIONS(695), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [7612] = 33,
    ACTIONS(669), 1,
      anon_sym_TILDE,
    ACTIONS(671), 1,
      anon_sym_QMARK,
    ACTIONS(673), 1,
      anon_sym_AT,
    ACTIONS(681), 1,
      anon_sym_LBRACE,
    ACTIONS(691), 1,
      sym__single_quote_string_start,
    ACTIONS(693), 1,
      sym__double_quote_string_start,
    ACTIONS(695), 1,
      sym__external_identifier,
    ACTIONS(701), 1,
      anon_sym_LF,
    ACTIONS(844), 1,
      anon_sym_COMMA,
    ACTIONS(846), 1,
      anon_sym_LPAREN,
    ACTIONS(848), 1,
      anon_sym_LBRACK,
    ACTIONS(890), 1,
      anon_sym_RBRACK,
    STATE(424), 1,
      sym_boolean,
    STATE(445), 1,
      sym__keywords,
    STATE(547), 1,
      sym_binary_operator,
    STATE(548), 1,
      sym_unary_operator,
    STATE(551), 1,
      sym_cell,
    STATE(599), 1,
      aux_sym_matrix_repeat1,
    STATE(642), 1,
      sym_not_operator,
    STATE(914), 1,
      sym__binary_expression,
    STATE(1149), 1,
      sym_ignored_argument,
    STATE(1291), 1,
      sym_row,
    STATE(1321), 1,
      sym_indirect_access,
    STATE(1465), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(667), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(689), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(396), 2,
      sym_identifier,
      sym_function_call,
    STATE(550), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(687), 3,
      aux_sym_number_token1,
      aux_sym_number_token2,
      aux_sym_number_token3,
    STATE(921), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(546), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(685), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [7734] = 33,
    ACTIONS(669), 1,
      anon_sym_TILDE,
    ACTIONS(671), 1,
      anon_sym_QMARK,
    ACTIONS(673), 1,
      anon_sym_AT,
    ACTIONS(681), 1,
      anon_sym_LBRACE,
    ACTIONS(691), 1,
      sym__single_quote_string_start,
    ACTIONS(693), 1,
      sym__double_quote_string_start,
    ACTIONS(695), 1,
      sym__external_identifier,
    ACTIONS(844), 1,
      anon_sym_COMMA,
    ACTIONS(846), 1,
      anon_sym_LPAREN,
    ACTIONS(848), 1,
      anon_sym_LBRACK,
    ACTIONS(892), 1,
      anon_sym_LF,
    ACTIONS(894), 1,
      anon_sym_RBRACK,
    STATE(233), 1,
      aux_sym_matrix_repeat1,
    STATE(424), 1,
      sym_boolean,
    STATE(445), 1,
      sym__keywords,
    STATE(547), 1,
      sym_binary_operator,
    STATE(548), 1,
      sym_unary_operator,
    STATE(551), 1,
      sym_cell,
    STATE(642), 1,
      sym_not_operator,
    STATE(914), 1,
      sym__binary_expression,
    STATE(1149), 1,
      sym_ignored_argument,
    STATE(1321), 1,
      sym_indirect_access,
    STATE(1327), 1,
      sym_row,
    STATE(1465), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(667), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(689), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(396), 2,
      sym_identifier,
      sym_function_call,
    STATE(550), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(687), 3,
      aux_sym_number_token1,
      aux_sym_number_token2,
      aux_sym_number_token3,
    STATE(921), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(546), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(685), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [7856] = 33,
    ACTIONS(669), 1,
      anon_sym_TILDE,
    ACTIONS(671), 1,
      anon_sym_QMARK,
    ACTIONS(673), 1,
      anon_sym_AT,
    ACTIONS(681), 1,
      anon_sym_LBRACE,
    ACTIONS(691), 1,
      sym__single_quote_string_start,
    ACTIONS(693), 1,
      sym__double_quote_string_start,
    ACTIONS(695), 1,
      sym__external_identifier,
    ACTIONS(844), 1,
      anon_sym_COMMA,
    ACTIONS(846), 1,
      anon_sym_LPAREN,
    ACTIONS(848), 1,
      anon_sym_LBRACK,
    ACTIONS(896), 1,
      anon_sym_LF,
    ACTIONS(898), 1,
      anon_sym_RBRACE,
    STATE(234), 1,
      aux_sym_matrix_repeat1,
    STATE(424), 1,
      sym_boolean,
    STATE(445), 1,
      sym__keywords,
    STATE(547), 1,
      sym_binary_operator,
    STATE(548), 1,
      sym_unary_operator,
    STATE(551), 1,
      sym_cell,
    STATE(642), 1,
      sym_not_operator,
    STATE(914), 1,
      sym__binary_expression,
    STATE(1149), 1,
      sym_ignored_argument,
    STATE(1321), 1,
      sym_indirect_access,
    STATE(1328), 1,
      sym_row,
    STATE(1465), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(667), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(689), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(396), 2,
      sym_identifier,
      sym_function_call,
    STATE(550), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(687), 3,
      aux_sym_number_token1,
      aux_sym_number_token2,
      aux_sym_number_token3,
    STATE(921), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(546), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(685), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [7978] = 33,
    ACTIONS(669), 1,
      anon_sym_TILDE,
    ACTIONS(671), 1,
      anon_sym_QMARK,
    ACTIONS(673), 1,
      anon_sym_AT,
    ACTIONS(681), 1,
      anon_sym_LBRACE,
    ACTIONS(691), 1,
      sym__single_quote_string_start,
    ACTIONS(693), 1,
      sym__double_quote_string_start,
    ACTIONS(695), 1,
      sym__external_identifier,
    ACTIONS(701), 1,
      anon_sym_LF,
    ACTIONS(844), 1,
      anon_sym_COMMA,
    ACTIONS(846), 1,
      anon_sym_LPAREN,
    ACTIONS(848), 1,
      anon_sym_LBRACK,
    ACTIONS(900), 1,
      anon_sym_RBRACK,
    STATE(424), 1,
      sym_boolean,
    STATE(445), 1,
      sym__keywords,
    STATE(547), 1,
      sym_binary_operator,
    STATE(548), 1,
      sym_unary_operator,
    STATE(551), 1,
      sym_cell,
    STATE(599), 1,
      aux_sym_matrix_repeat1,
    STATE(642), 1,
      sym_not_operator,
    STATE(914), 1,
      sym__binary_expression,
    STATE(1149), 1,
      sym_ignored_argument,
    STATE(1321), 1,
      sym_indirect_access,
    STATE(1332), 1,
      sym_row,
    STATE(1465), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(667), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(689), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(396), 2,
      sym_identifier,
      sym_function_call,
    STATE(550), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(687), 3,
      aux_sym_number_token1,
      aux_sym_number_token2,
      aux_sym_number_token3,
    STATE(921), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(546), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(685), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [8100] = 33,
    ACTIONS(669), 1,
      anon_sym_TILDE,
    ACTIONS(671), 1,
      anon_sym_QMARK,
    ACTIONS(673), 1,
      anon_sym_AT,
    ACTIONS(681), 1,
      anon_sym_LBRACE,
    ACTIONS(691), 1,
      sym__single_quote_string_start,
    ACTIONS(693), 1,
      sym__double_quote_string_start,
    ACTIONS(695), 1,
      sym__external_identifier,
    ACTIONS(701), 1,
      anon_sym_LF,
    ACTIONS(844), 1,
      anon_sym_COMMA,
    ACTIONS(846), 1,
      anon_sym_LPAREN,
    ACTIONS(848), 1,
      anon_sym_LBRACK,
    ACTIONS(902), 1,
      anon_sym_RBRACE,
    STATE(424), 1,
      sym_boolean,
    STATE(445), 1,
      sym__keywords,
    STATE(547), 1,
      sym_binary_operator,
    STATE(548), 1,
      sym_unary_operator,
    STATE(551), 1,
      sym_cell,
    STATE(599), 1,
      aux_sym_matrix_repeat1,
    STATE(642), 1,
      sym_not_operator,
    STATE(914), 1,
      sym__binary_expression,
    STATE(1149), 1,
      sym_ignored_argument,
    STATE(1321), 1,
      sym_indirect_access,
    STATE(1334), 1,
      sym_row,
    STATE(1465), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(667), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(689), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(396), 2,
      sym_identifier,
      sym_function_call,
    STATE(550), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(687), 3,
      aux_sym_number_token1,
      aux_sym_number_token2,
      aux_sym_number_token3,
    STATE(921), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(546), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(685), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [8222] = 31,
    ACTIONS(731), 1,
      anon_sym_LPAREN,
    ACTIONS(737), 1,
      anon_sym_TILDE,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(745), 1,
      anon_sym_LBRACE,
    ACTIONS(749), 1,
      anon_sym_end,
    ACTIONS(753), 1,
      aux_sym_number_token1,
    ACTIONS(759), 1,
      sym__single_quote_string_start,
    ACTIONS(761), 1,
      sym__double_quote_string_start,
    ACTIONS(856), 1,
      anon_sym_LBRACK,
    STATE(452), 1,
      sym__keywords,
    STATE(468), 1,
      sym_boolean,
    STATE(628), 1,
      sym_cell,
    STATE(639), 1,
      sym_binary_operator,
    STATE(676), 1,
      sym_unary_operator,
    STATE(712), 1,
      sym_not_operator,
    STATE(832), 1,
      sym__index_binary_operator,
    STATE(908), 1,
      sym__binary_expression,
    STATE(1370), 1,
      sym_indirect_access,
    STATE(1461), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(735), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(755), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(757), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(430), 2,
      sym_identifier,
      sym_function_call,
    STATE(632), 2,
      sym_parenthesis,
      sym_matrix,
    STATE(724), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(634), 4,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_number,
    STATE(801), 4,
      sym__index_matrix,
      sym__index_parenthesis,
      sym__index_binary_expression,
      sym_end_keyword,
    STATE(1064), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [8340] = 33,
    ACTIONS(669), 1,
      anon_sym_TILDE,
    ACTIONS(671), 1,
      anon_sym_QMARK,
    ACTIONS(673), 1,
      anon_sym_AT,
    ACTIONS(681), 1,
      anon_sym_LBRACE,
    ACTIONS(691), 1,
      sym__single_quote_string_start,
    ACTIONS(693), 1,
      sym__double_quote_string_start,
    ACTIONS(695), 1,
      sym__external_identifier,
    ACTIONS(701), 1,
      anon_sym_LF,
    ACTIONS(844), 1,
      anon_sym_COMMA,
    ACTIONS(846), 1,
      anon_sym_LPAREN,
    ACTIONS(848), 1,
      anon_sym_LBRACK,
    ACTIONS(904), 1,
      anon_sym_RBRACE,
    STATE(424), 1,
      sym_boolean,
    STATE(445), 1,
      sym__keywords,
    STATE(547), 1,
      sym_binary_operator,
    STATE(548), 1,
      sym_unary_operator,
    STATE(551), 1,
      sym_cell,
    STATE(599), 1,
      aux_sym_matrix_repeat1,
    STATE(642), 1,
      sym_not_operator,
    STATE(914), 1,
      sym__binary_expression,
    STATE(1149), 1,
      sym_ignored_argument,
    STATE(1293), 1,
      sym_row,
    STATE(1321), 1,
      sym_indirect_access,
    STATE(1465), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(667), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(689), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(396), 2,
      sym_identifier,
      sym_function_call,
    STATE(550), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(687), 3,
      aux_sym_number_token1,
      aux_sym_number_token2,
      aux_sym_number_token3,
    STATE(921), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(546), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(685), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [8462] = 31,
    ACTIONS(731), 1,
      anon_sym_LPAREN,
    ACTIONS(737), 1,
      anon_sym_TILDE,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(745), 1,
      anon_sym_LBRACE,
    ACTIONS(749), 1,
      anon_sym_end,
    ACTIONS(753), 1,
      aux_sym_number_token1,
    ACTIONS(759), 1,
      sym__single_quote_string_start,
    ACTIONS(761), 1,
      sym__double_quote_string_start,
    ACTIONS(856), 1,
      anon_sym_LBRACK,
    STATE(452), 1,
      sym__keywords,
    STATE(468), 1,
      sym_boolean,
    STATE(628), 1,
      sym_cell,
    STATE(639), 1,
      sym_binary_operator,
    STATE(676), 1,
      sym_unary_operator,
    STATE(712), 1,
      sym_not_operator,
    STATE(832), 1,
      sym__index_binary_operator,
    STATE(908), 1,
      sym__binary_expression,
    STATE(1370), 1,
      sym_indirect_access,
    STATE(1461), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(735), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(755), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(757), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(430), 2,
      sym_identifier,
      sym_function_call,
    STATE(632), 2,
      sym_parenthesis,
      sym_matrix,
    STATE(724), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(634), 4,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_number,
    STATE(817), 4,
      sym__index_matrix,
      sym__index_parenthesis,
      sym__index_binary_expression,
      sym_end_keyword,
    STATE(1064), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [8580] = 31,
    ACTIONS(731), 1,
      anon_sym_LPAREN,
    ACTIONS(737), 1,
      anon_sym_TILDE,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(745), 1,
      anon_sym_LBRACE,
    ACTIONS(749), 1,
      anon_sym_end,
    ACTIONS(753), 1,
      aux_sym_number_token1,
    ACTIONS(759), 1,
      sym__single_quote_string_start,
    ACTIONS(761), 1,
      sym__double_quote_string_start,
    ACTIONS(856), 1,
      anon_sym_LBRACK,
    STATE(452), 1,
      sym__keywords,
    STATE(468), 1,
      sym_boolean,
    STATE(628), 1,
      sym_cell,
    STATE(639), 1,
      sym_binary_operator,
    STATE(676), 1,
      sym_unary_operator,
    STATE(712), 1,
      sym_not_operator,
    STATE(832), 1,
      sym__index_binary_operator,
    STATE(908), 1,
      sym__binary_expression,
    STATE(1370), 1,
      sym_indirect_access,
    STATE(1461), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(735), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(755), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(757), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(430), 2,
      sym_identifier,
      sym_function_call,
    STATE(632), 2,
      sym_parenthesis,
      sym_matrix,
    STATE(724), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(634), 4,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_number,
    STATE(835), 4,
      sym__index_matrix,
      sym__index_parenthesis,
      sym__index_binary_expression,
      sym_end_keyword,
    STATE(1064), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [8698] = 30,
    ACTIONS(669), 1,
      anon_sym_TILDE,
    ACTIONS(671), 1,
      anon_sym_QMARK,
    ACTIONS(673), 1,
      anon_sym_AT,
    ACTIONS(681), 1,
      anon_sym_LBRACE,
    ACTIONS(691), 1,
      sym__single_quote_string_start,
    ACTIONS(693), 1,
      sym__double_quote_string_start,
    ACTIONS(695), 1,
      sym__external_identifier,
    ACTIONS(846), 1,
      anon_sym_LPAREN,
    ACTIONS(848), 1,
      anon_sym_LBRACK,
    ACTIONS(908), 1,
      aux_sym_matrix_token1,
    STATE(424), 1,
      sym_boolean,
    STATE(445), 1,
      sym__keywords,
    STATE(547), 1,
      sym_binary_operator,
    STATE(548), 1,
      sym_unary_operator,
    STATE(551), 1,
      sym_cell,
    STATE(642), 1,
      sym_not_operator,
    STATE(914), 1,
      sym__binary_expression,
    STATE(1188), 1,
      sym_ignored_argument,
    STATE(1321), 1,
      sym_indirect_access,
    STATE(1465), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(667), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(689), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(396), 2,
      sym_identifier,
      sym_function_call,
    STATE(550), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(687), 3,
      aux_sym_number_token1,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(906), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    STATE(932), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(546), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(685), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [8813] = 29,
    ACTIONS(681), 1,
      anon_sym_LBRACE,
    ACTIONS(691), 1,
      sym__single_quote_string_start,
    ACTIONS(693), 1,
      sym__double_quote_string_start,
    ACTIONS(695), 1,
      sym__external_identifier,
    ACTIONS(846), 1,
      anon_sym_LPAREN,
    ACTIONS(848), 1,
      anon_sym_LBRACK,
    ACTIONS(912), 1,
      anon_sym_TILDE,
    ACTIONS(914), 1,
      anon_sym_QMARK,
    ACTIONS(916), 1,
      anon_sym_AT,
    STATE(440), 1,
      sym_boolean,
    STATE(445), 1,
      sym__keywords,
    STATE(551), 1,
      sym_cell,
    STATE(559), 1,
      sym_unary_operator,
    STATE(566), 1,
      sym_not_operator,
    STATE(571), 1,
      sym_binary_operator,
    STATE(914), 1,
      sym__binary_expression,
    STATE(1321), 1,
      sym_indirect_access,
    STATE(1465), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(667), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(689), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(918), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    STATE(398), 2,
      sym_identifier,
      sym_function_call,
    STATE(550), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(687), 3,
      aux_sym_number_token1,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(910), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    STATE(557), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(565), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(685), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [8926] = 30,
    ACTIONS(669), 1,
      anon_sym_TILDE,
    ACTIONS(671), 1,
      anon_sym_QMARK,
    ACTIONS(673), 1,
      anon_sym_AT,
    ACTIONS(681), 1,
      anon_sym_LBRACE,
    ACTIONS(691), 1,
      sym__single_quote_string_start,
    ACTIONS(693), 1,
      sym__double_quote_string_start,
    ACTIONS(695), 1,
      sym__external_identifier,
    ACTIONS(846), 1,
      anon_sym_LPAREN,
    ACTIONS(848), 1,
      anon_sym_LBRACK,
    ACTIONS(922), 1,
      aux_sym_matrix_token1,
    STATE(424), 1,
      sym_boolean,
    STATE(445), 1,
      sym__keywords,
    STATE(547), 1,
      sym_binary_operator,
    STATE(548), 1,
      sym_unary_operator,
    STATE(551), 1,
      sym_cell,
    STATE(642), 1,
      sym_not_operator,
    STATE(914), 1,
      sym__binary_expression,
    STATE(1188), 1,
      sym_ignored_argument,
    STATE(1321), 1,
      sym_indirect_access,
    STATE(1465), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(667), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(689), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(396), 2,
      sym_identifier,
      sym_function_call,
    STATE(550), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(687), 3,
      aux_sym_number_token1,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(920), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    STATE(932), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(546), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(685), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [9041] = 30,
    ACTIONS(669), 1,
      anon_sym_TILDE,
    ACTIONS(671), 1,
      anon_sym_QMARK,
    ACTIONS(673), 1,
      anon_sym_AT,
    ACTIONS(681), 1,
      anon_sym_LBRACE,
    ACTIONS(691), 1,
      sym__single_quote_string_start,
    ACTIONS(693), 1,
      sym__double_quote_string_start,
    ACTIONS(695), 1,
      sym__external_identifier,
    ACTIONS(846), 1,
      anon_sym_LPAREN,
    ACTIONS(848), 1,
      anon_sym_LBRACK,
    ACTIONS(926), 1,
      aux_sym_matrix_token1,
    STATE(424), 1,
      sym_boolean,
    STATE(445), 1,
      sym__keywords,
    STATE(547), 1,
      sym_binary_operator,
    STATE(548), 1,
      sym_unary_operator,
    STATE(551), 1,
      sym_cell,
    STATE(642), 1,
      sym_not_operator,
    STATE(914), 1,
      sym__binary_expression,
    STATE(1188), 1,
      sym_ignored_argument,
    STATE(1321), 1,
      sym_indirect_access,
    STATE(1465), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(667), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(689), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(396), 2,
      sym_identifier,
      sym_function_call,
    STATE(550), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(687), 3,
      aux_sym_number_token1,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(924), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    STATE(932), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(546), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(685), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [9156] = 6,
    ACTIONS(121), 1,
      anon_sym_AMP_AMP,
    ACTIONS(123), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(930), 5,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      sym__external_identifier,
    ACTIONS(119), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(928), 39,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LF,
      anon_sym_LBRACE,
      anon_sym_return,
      anon_sym_continue,
      anon_sym_break,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_arguments,
      anon_sym_function,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_classdef,
      anon_sym_try,
      anon_sym_spmd,
      aux_sym_number_token1,
      aux_sym_number_token2,
      aux_sym_number_token3,
      anon_sym_true,
      anon_sym_false,
      anon_sym_CR,
  [9223] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(244), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    ACTIONS(932), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(937), 5,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      sym__external_identifier,
    ACTIONS(935), 40,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_return,
      anon_sym_continue,
      anon_sym_break,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_arguments,
      anon_sym_function,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_classdef,
      anon_sym_catch,
      anon_sym_try,
      anon_sym_spmd,
      aux_sym_number_token1,
      aux_sym_number_token2,
      aux_sym_number_token3,
      anon_sym_true,
      anon_sym_false,
  [9287] = 5,
    STATE(249), 1,
      aux_sym__block_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(941), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    ACTIONS(943), 2,
      anon_sym_else,
      aux_sym_number_token1,
    ACTIONS(939), 44,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      sym__external_identifier,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_return,
      anon_sym_continue,
      anon_sym_break,
      anon_sym_elseif,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_arguments,
      anon_sym_function,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_classdef,
      anon_sym_catch,
      anon_sym_try,
      anon_sym_spmd,
      aux_sym_number_token2,
      aux_sym_number_token3,
      anon_sym_true,
      anon_sym_false,
  [9349] = 5,
    STATE(249), 1,
      aux_sym__block_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(941), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    ACTIONS(947), 2,
      anon_sym_else,
      aux_sym_number_token1,
    ACTIONS(945), 44,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      sym__external_identifier,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_return,
      anon_sym_continue,
      anon_sym_break,
      anon_sym_elseif,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_arguments,
      anon_sym_function,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_classdef,
      anon_sym_catch,
      anon_sym_try,
      anon_sym_spmd,
      aux_sym_number_token2,
      aux_sym_number_token3,
      anon_sym_true,
      anon_sym_false,
  [9411] = 5,
    STATE(245), 1,
      aux_sym__block_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(951), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    ACTIONS(953), 2,
      anon_sym_else,
      aux_sym_number_token1,
    ACTIONS(949), 44,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      sym__external_identifier,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_return,
      anon_sym_continue,
      anon_sym_break,
      anon_sym_elseif,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_arguments,
      anon_sym_function,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_classdef,
      anon_sym_catch,
      anon_sym_try,
      anon_sym_spmd,
      aux_sym_number_token2,
      aux_sym_number_token3,
      anon_sym_true,
      anon_sym_false,
  [9473] = 5,
    STATE(246), 1,
      aux_sym__block_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(335), 2,
      anon_sym_else,
      aux_sym_number_token1,
    ACTIONS(955), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    ACTIONS(333), 44,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      sym__external_identifier,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_return,
      anon_sym_continue,
      anon_sym_break,
      anon_sym_elseif,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_arguments,
      anon_sym_function,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_classdef,
      anon_sym_catch,
      anon_sym_try,
      anon_sym_spmd,
      aux_sym_number_token2,
      aux_sym_number_token3,
      anon_sym_true,
      anon_sym_false,
  [9535] = 5,
    STATE(249), 1,
      aux_sym__block_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(959), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    ACTIONS(962), 2,
      anon_sym_else,
      aux_sym_number_token1,
    ACTIONS(957), 44,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      sym__external_identifier,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_return,
      anon_sym_continue,
      anon_sym_break,
      anon_sym_elseif,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_arguments,
      anon_sym_function,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_classdef,
      anon_sym_catch,
      anon_sym_try,
      anon_sym_spmd,
      aux_sym_number_token2,
      aux_sym_number_token3,
      anon_sym_true,
      anon_sym_false,
  [9597] = 28,
    ACTIONS(687), 1,
      aux_sym_number_token1,
    ACTIONS(691), 1,
      sym__single_quote_string_start,
    ACTIONS(693), 1,
      sym__double_quote_string_start,
    ACTIONS(815), 1,
      anon_sym_TILDE,
    ACTIONS(817), 1,
      anon_sym_QMARK,
    ACTIONS(819), 1,
      anon_sym_AT,
    ACTIONS(823), 1,
      anon_sym_LBRACE,
    ACTIONS(964), 1,
      anon_sym_LPAREN,
    ACTIONS(966), 1,
      anon_sym_LBRACK,
    STATE(424), 1,
      sym_boolean,
    STATE(445), 1,
      sym__keywords,
    STATE(547), 1,
      sym_binary_operator,
    STATE(548), 1,
      sym_unary_operator,
    STATE(551), 1,
      sym_cell,
    STATE(642), 1,
      sym_not_operator,
    STATE(914), 1,
      sym__binary_expression,
    STATE(1188), 1,
      sym_ignored_argument,
    STATE(1321), 1,
      sym_indirect_access,
    STATE(1465), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(813), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(827), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(829), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(396), 2,
      sym_identifier,
      sym_function_call,
    STATE(550), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(932), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(546), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(695), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [9704] = 28,
    ACTIONS(687), 1,
      aux_sym_number_token1,
    ACTIONS(691), 1,
      sym__single_quote_string_start,
    ACTIONS(693), 1,
      sym__double_quote_string_start,
    ACTIONS(815), 1,
      anon_sym_TILDE,
    ACTIONS(817), 1,
      anon_sym_QMARK,
    ACTIONS(819), 1,
      anon_sym_AT,
    ACTIONS(823), 1,
      anon_sym_LBRACE,
    ACTIONS(964), 1,
      anon_sym_LPAREN,
    ACTIONS(966), 1,
      anon_sym_LBRACK,
    STATE(424), 1,
      sym_boolean,
    STATE(445), 1,
      sym__keywords,
    STATE(547), 1,
      sym_binary_operator,
    STATE(548), 1,
      sym_unary_operator,
    STATE(551), 1,
      sym_cell,
    STATE(642), 1,
      sym_not_operator,
    STATE(914), 1,
      sym__binary_expression,
    STATE(1153), 1,
      sym_ignored_argument,
    STATE(1321), 1,
      sym_indirect_access,
    STATE(1465), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(813), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(827), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(829), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(396), 2,
      sym_identifier,
      sym_function_call,
    STATE(550), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(901), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(546), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(695), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [9811] = 28,
    ACTIONS(7), 1,
      anon_sym_LPAREN,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(51), 1,
      aux_sym_number_token1,
    ACTIONS(59), 1,
      sym__single_quote_string_start,
    ACTIONS(61), 1,
      sym__double_quote_string_start,
    ACTIONS(918), 1,
      anon_sym_EQ,
    ACTIONS(968), 1,
      anon_sym_TILDE,
    ACTIONS(970), 1,
      anon_sym_QMARK,
    ACTIONS(972), 1,
      anon_sym_AT,
    STATE(373), 1,
      sym__keywords,
    STATE(404), 1,
      sym_boolean,
    STATE(462), 1,
      sym_binary_operator,
    STATE(463), 1,
      sym_not_operator,
    STATE(471), 1,
      sym_cell,
    STATE(513), 1,
      sym_unary_operator,
    STATE(910), 1,
      sym__binary_expression,
    STATE(1361), 1,
      sym_indirect_access,
    STATE(1509), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(9), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(53), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(55), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(374), 2,
      sym_identifier,
      sym_function_call,
    STATE(498), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(489), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(461), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(41), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [9918] = 29,
    ACTIONS(737), 1,
      anon_sym_TILDE,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(745), 1,
      anon_sym_LBRACE,
    ACTIONS(753), 1,
      aux_sym_number_token1,
    ACTIONS(759), 1,
      sym__single_quote_string_start,
    ACTIONS(761), 1,
      sym__double_quote_string_start,
    ACTIONS(974), 1,
      anon_sym_LPAREN,
    ACTIONS(976), 1,
      anon_sym_RPAREN,
    ACTIONS(978), 1,
      anon_sym_LBRACK,
    STATE(452), 1,
      sym__keywords,
    STATE(518), 1,
      sym_boolean,
    STATE(632), 1,
      sym_number,
    STATE(636), 1,
      sym_cell,
    STATE(705), 1,
      sym_binary_operator,
    STATE(706), 1,
      sym_unary_operator,
    STATE(729), 1,
      sym_not_operator,
    STATE(908), 1,
      sym__binary_expression,
    STATE(1370), 1,
      sym_indirect_access,
    STATE(1461), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(735), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(755), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(757), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(459), 2,
      sym_identifier,
      sym_function_call,
    STATE(635), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(704), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(1015), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [10027] = 27,
    ACTIONS(7), 1,
      anon_sym_LPAREN,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(51), 1,
      aux_sym_number_token1,
    ACTIONS(59), 1,
      sym__single_quote_string_start,
    ACTIONS(61), 1,
      sym__double_quote_string_start,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(968), 1,
      anon_sym_TILDE,
    STATE(373), 1,
      sym__keywords,
    STATE(403), 1,
      sym_boolean,
    STATE(478), 1,
      sym_not_operator,
    STATE(497), 1,
      sym_unary_operator,
    STATE(523), 1,
      sym_cell,
    STATE(737), 1,
      sym_binary_operator,
    STATE(908), 1,
      sym__binary_expression,
    STATE(1361), 1,
      sym_indirect_access,
    STATE(1461), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(9), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(53), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(55), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(379), 2,
      sym_identifier,
      sym_function_call,
    STATE(635), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1058), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(536), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(41), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [10131] = 27,
    ACTIONS(980), 1,
      anon_sym_LPAREN,
    ACTIONS(984), 1,
      anon_sym_TILDE,
    ACTIONS(986), 1,
      anon_sym_QMARK,
    ACTIONS(988), 1,
      anon_sym_AT,
    ACTIONS(990), 1,
      anon_sym_LBRACK,
    ACTIONS(992), 1,
      anon_sym_LBRACE,
    ACTIONS(996), 1,
      aux_sym_number_token1,
    ACTIONS(1002), 1,
      sym__single_quote_string_start,
    ACTIONS(1004), 1,
      sym__double_quote_string_start,
    STATE(93), 1,
      sym__keywords,
    STATE(95), 1,
      sym_boolean,
    STATE(105), 1,
      sym_unary_operator,
    STATE(107), 1,
      sym_cell,
    STATE(133), 1,
      sym_binary_operator,
    STATE(150), 1,
      sym_not_operator,
    STATE(918), 1,
      sym__binary_expression,
    STATE(1342), 1,
      sym_indirect_access,
    STATE(1470), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(998), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1000), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(74), 2,
      sym_identifier,
      sym_function_call,
    STATE(106), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(153), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(132), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(994), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [10235] = 27,
    ACTIONS(7), 1,
      anon_sym_LPAREN,
    ACTIONS(13), 1,
      anon_sym_QMARK,
    ACTIONS(15), 1,
      anon_sym_AT,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(51), 1,
      aux_sym_number_token1,
    ACTIONS(59), 1,
      sym__single_quote_string_start,
    ACTIONS(61), 1,
      sym__double_quote_string_start,
    ACTIONS(968), 1,
      anon_sym_TILDE,
    STATE(373), 1,
      sym__keywords,
    STATE(397), 1,
      sym_boolean,
    STATE(471), 1,
      sym_cell,
    STATE(519), 1,
      sym_binary_operator,
    STATE(528), 1,
      sym_unary_operator,
    STATE(549), 1,
      sym_not_operator,
    STATE(910), 1,
      sym__binary_expression,
    STATE(1361), 1,
      sym_indirect_access,
    STATE(1509), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(9), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(53), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(55), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(377), 2,
      sym_identifier,
      sym_function_call,
    STATE(498), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(619), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(512), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(41), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [10339] = 27,
    ACTIONS(737), 1,
      anon_sym_TILDE,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(745), 1,
      anon_sym_LBRACE,
    ACTIONS(753), 1,
      aux_sym_number_token1,
    ACTIONS(759), 1,
      sym__single_quote_string_start,
    ACTIONS(761), 1,
      sym__double_quote_string_start,
    ACTIONS(974), 1,
      anon_sym_LPAREN,
    ACTIONS(978), 1,
      anon_sym_LBRACK,
    STATE(452), 1,
      sym__keywords,
    STATE(518), 1,
      sym_boolean,
    STATE(636), 1,
      sym_cell,
    STATE(637), 1,
      sym_unary_operator,
    STATE(639), 1,
      sym_binary_operator,
    STATE(729), 1,
      sym_not_operator,
    STATE(908), 1,
      sym__binary_expression,
    STATE(1370), 1,
      sym_indirect_access,
    STATE(1461), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(735), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(755), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(757), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(421), 2,
      sym_identifier,
      sym_function_call,
    STATE(635), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1011), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(632), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [10443] = 27,
    ACTIONS(737), 1,
      anon_sym_TILDE,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(745), 1,
      anon_sym_LBRACE,
    ACTIONS(753), 1,
      aux_sym_number_token1,
    ACTIONS(759), 1,
      sym__single_quote_string_start,
    ACTIONS(761), 1,
      sym__double_quote_string_start,
    ACTIONS(974), 1,
      anon_sym_LPAREN,
    ACTIONS(978), 1,
      anon_sym_LBRACK,
    STATE(452), 1,
      sym__keywords,
    STATE(518), 1,
      sym_boolean,
    STATE(636), 1,
      sym_cell,
    STATE(637), 1,
      sym_unary_operator,
    STATE(639), 1,
      sym_binary_operator,
    STATE(729), 1,
      sym_not_operator,
    STATE(908), 1,
      sym__binary_expression,
    STATE(1370), 1,
      sym_indirect_access,
    STATE(1461), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(735), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(755), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(757), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(421), 2,
      sym_identifier,
      sym_function_call,
    STATE(635), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1048), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(632), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [10547] = 28,
    ACTIONS(737), 1,
      anon_sym_TILDE,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(745), 1,
      anon_sym_LBRACE,
    ACTIONS(753), 1,
      aux_sym_number_token1,
    ACTIONS(759), 1,
      sym__single_quote_string_start,
    ACTIONS(761), 1,
      sym__double_quote_string_start,
    ACTIONS(974), 1,
      anon_sym_LPAREN,
    ACTIONS(978), 1,
      anon_sym_LBRACK,
    STATE(452), 1,
      sym__keywords,
    STATE(518), 1,
      sym_boolean,
    STATE(632), 1,
      sym_number,
    STATE(636), 1,
      sym_cell,
    STATE(719), 1,
      sym_binary_operator,
    STATE(720), 1,
      sym_unary_operator,
    STATE(729), 1,
      sym_not_operator,
    STATE(908), 1,
      sym__binary_expression,
    STATE(1370), 1,
      sym_indirect_access,
    STATE(1461), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(735), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(755), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(757), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(521), 2,
      sym_identifier,
      sym_function_call,
    STATE(635), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(718), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(1058), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [10653] = 27,
    ACTIONS(737), 1,
      anon_sym_TILDE,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(745), 1,
      anon_sym_LBRACE,
    ACTIONS(753), 1,
      aux_sym_number_token1,
    ACTIONS(759), 1,
      sym__single_quote_string_start,
    ACTIONS(761), 1,
      sym__double_quote_string_start,
    ACTIONS(974), 1,
      anon_sym_LPAREN,
    ACTIONS(978), 1,
      anon_sym_LBRACK,
    STATE(452), 1,
      sym__keywords,
    STATE(518), 1,
      sym_boolean,
    STATE(636), 1,
      sym_cell,
    STATE(637), 1,
      sym_unary_operator,
    STATE(639), 1,
      sym_binary_operator,
    STATE(729), 1,
      sym_not_operator,
    STATE(908), 1,
      sym__binary_expression,
    STATE(1370), 1,
      sym_indirect_access,
    STATE(1461), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(735), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(755), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(757), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(421), 2,
      sym_identifier,
      sym_function_call,
    STATE(635), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(945), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(632), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [10757] = 27,
    ACTIONS(737), 1,
      anon_sym_TILDE,
    ACTIONS(745), 1,
      anon_sym_LBRACE,
    ACTIONS(753), 1,
      aux_sym_number_token1,
    ACTIONS(759), 1,
      sym__single_quote_string_start,
    ACTIONS(761), 1,
      sym__double_quote_string_start,
    ACTIONS(974), 1,
      anon_sym_LPAREN,
    ACTIONS(978), 1,
      anon_sym_LBRACK,
    ACTIONS(1006), 1,
      anon_sym_QMARK,
    ACTIONS(1008), 1,
      anon_sym_AT,
    STATE(452), 1,
      sym__keywords,
    STATE(496), 1,
      sym_boolean,
    STATE(633), 1,
      sym_unary_operator,
    STATE(636), 1,
      sym_cell,
    STATE(641), 1,
      sym_not_operator,
    STATE(673), 1,
      sym_binary_operator,
    STATE(908), 1,
      sym__binary_expression,
    STATE(1370), 1,
      sym_indirect_access,
    STATE(1461), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(735), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(755), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(757), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(419), 2,
      sym_identifier,
      sym_function_call,
    STATE(635), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(663), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(631), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [10861] = 27,
    ACTIONS(7), 1,
      anon_sym_LPAREN,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(51), 1,
      aux_sym_number_token1,
    ACTIONS(59), 1,
      sym__single_quote_string_start,
    ACTIONS(61), 1,
      sym__double_quote_string_start,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(745), 1,
      anon_sym_LBRACE,
    ACTIONS(968), 1,
      anon_sym_TILDE,
    STATE(373), 1,
      sym__keywords,
    STATE(402), 1,
      sym_boolean,
    STATE(473), 1,
      sym__range_element,
    STATE(505), 1,
      sym_unary_operator,
    STATE(507), 1,
      sym_not_operator,
    STATE(511), 1,
      sym_binary_operator,
    STATE(750), 1,
      sym_cell,
    STATE(910), 1,
      sym__binary_expression,
    STATE(1361), 1,
      sym_indirect_access,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(9), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(53), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(55), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(376), 2,
      sym_identifier,
      sym_function_call,
    STATE(635), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1058), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(506), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(41), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [10965] = 27,
    ACTIONS(737), 1,
      anon_sym_TILDE,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(745), 1,
      anon_sym_LBRACE,
    ACTIONS(753), 1,
      aux_sym_number_token1,
    ACTIONS(759), 1,
      sym__single_quote_string_start,
    ACTIONS(761), 1,
      sym__double_quote_string_start,
    ACTIONS(974), 1,
      anon_sym_LPAREN,
    ACTIONS(978), 1,
      anon_sym_LBRACK,
    STATE(452), 1,
      sym__keywords,
    STATE(518), 1,
      sym_boolean,
    STATE(636), 1,
      sym_cell,
    STATE(637), 1,
      sym_unary_operator,
    STATE(639), 1,
      sym_binary_operator,
    STATE(729), 1,
      sym_not_operator,
    STATE(908), 1,
      sym__binary_expression,
    STATE(1370), 1,
      sym_indirect_access,
    STATE(1461), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(735), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(755), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(757), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(421), 2,
      sym_identifier,
      sym_function_call,
    STATE(635), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(946), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(632), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [11069] = 27,
    ACTIONS(7), 1,
      anon_sym_LPAREN,
    ACTIONS(13), 1,
      anon_sym_QMARK,
    ACTIONS(15), 1,
      anon_sym_AT,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(51), 1,
      aux_sym_number_token1,
    ACTIONS(59), 1,
      sym__single_quote_string_start,
    ACTIONS(61), 1,
      sym__double_quote_string_start,
    ACTIONS(968), 1,
      anon_sym_TILDE,
    STATE(373), 1,
      sym__keywords,
    STATE(397), 1,
      sym_boolean,
    STATE(471), 1,
      sym_cell,
    STATE(519), 1,
      sym_binary_operator,
    STATE(528), 1,
      sym_unary_operator,
    STATE(549), 1,
      sym_not_operator,
    STATE(910), 1,
      sym__binary_expression,
    STATE(1361), 1,
      sym_indirect_access,
    STATE(1509), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(9), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(53), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(55), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(377), 2,
      sym_identifier,
      sym_function_call,
    STATE(498), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(949), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(512), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(41), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [11173] = 27,
    ACTIONS(737), 1,
      anon_sym_TILDE,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(745), 1,
      anon_sym_LBRACE,
    ACTIONS(753), 1,
      aux_sym_number_token1,
    ACTIONS(759), 1,
      sym__single_quote_string_start,
    ACTIONS(761), 1,
      sym__double_quote_string_start,
    ACTIONS(974), 1,
      anon_sym_LPAREN,
    ACTIONS(978), 1,
      anon_sym_LBRACK,
    STATE(452), 1,
      sym__keywords,
    STATE(518), 1,
      sym_boolean,
    STATE(636), 1,
      sym_cell,
    STATE(637), 1,
      sym_unary_operator,
    STATE(639), 1,
      sym_binary_operator,
    STATE(729), 1,
      sym_not_operator,
    STATE(908), 1,
      sym__binary_expression,
    STATE(1370), 1,
      sym_indirect_access,
    STATE(1461), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(735), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(755), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(757), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(421), 2,
      sym_identifier,
      sym_function_call,
    STATE(635), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(959), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(632), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [11277] = 27,
    ACTIONS(980), 1,
      anon_sym_LPAREN,
    ACTIONS(984), 1,
      anon_sym_TILDE,
    ACTIONS(990), 1,
      anon_sym_LBRACK,
    ACTIONS(992), 1,
      anon_sym_LBRACE,
    ACTIONS(996), 1,
      aux_sym_number_token1,
    ACTIONS(1002), 1,
      sym__single_quote_string_start,
    ACTIONS(1004), 1,
      sym__double_quote_string_start,
    ACTIONS(1010), 1,
      anon_sym_QMARK,
    ACTIONS(1012), 1,
      anon_sym_AT,
    STATE(93), 1,
      sym__keywords,
    STATE(95), 1,
      sym_boolean,
    STATE(105), 1,
      sym_unary_operator,
    STATE(107), 1,
      sym_cell,
    STATE(133), 1,
      sym_binary_operator,
    STATE(150), 1,
      sym_not_operator,
    STATE(918), 1,
      sym__binary_expression,
    STATE(1342), 1,
      sym_indirect_access,
    STATE(1470), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(998), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1000), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(74), 2,
      sym_identifier,
      sym_function_call,
    STATE(106), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(3), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(132), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(994), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [11381] = 27,
    ACTIONS(737), 1,
      anon_sym_TILDE,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(745), 1,
      anon_sym_LBRACE,
    ACTIONS(753), 1,
      aux_sym_number_token1,
    ACTIONS(759), 1,
      sym__single_quote_string_start,
    ACTIONS(761), 1,
      sym__double_quote_string_start,
    ACTIONS(974), 1,
      anon_sym_LPAREN,
    ACTIONS(978), 1,
      anon_sym_LBRACK,
    STATE(452), 1,
      sym__keywords,
    STATE(518), 1,
      sym_boolean,
    STATE(636), 1,
      sym_cell,
    STATE(637), 1,
      sym_unary_operator,
    STATE(639), 1,
      sym_binary_operator,
    STATE(729), 1,
      sym_not_operator,
    STATE(908), 1,
      sym__binary_expression,
    STATE(1370), 1,
      sym_indirect_access,
    STATE(1461), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(735), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(755), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(757), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(421), 2,
      sym_identifier,
      sym_function_call,
    STATE(635), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(960), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(632), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [11485] = 27,
    ACTIONS(737), 1,
      anon_sym_TILDE,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(745), 1,
      anon_sym_LBRACE,
    ACTIONS(753), 1,
      aux_sym_number_token1,
    ACTIONS(759), 1,
      sym__single_quote_string_start,
    ACTIONS(761), 1,
      sym__double_quote_string_start,
    ACTIONS(974), 1,
      anon_sym_LPAREN,
    ACTIONS(978), 1,
      anon_sym_LBRACK,
    STATE(452), 1,
      sym__keywords,
    STATE(518), 1,
      sym_boolean,
    STATE(636), 1,
      sym_cell,
    STATE(637), 1,
      sym_unary_operator,
    STATE(639), 1,
      sym_binary_operator,
    STATE(729), 1,
      sym_not_operator,
    STATE(908), 1,
      sym__binary_expression,
    STATE(1370), 1,
      sym_indirect_access,
    STATE(1461), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(735), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(755), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(757), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(421), 2,
      sym_identifier,
      sym_function_call,
    STATE(635), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1007), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(632), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [11589] = 27,
    ACTIONS(737), 1,
      anon_sym_TILDE,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(745), 1,
      anon_sym_LBRACE,
    ACTIONS(753), 1,
      aux_sym_number_token1,
    ACTIONS(759), 1,
      sym__single_quote_string_start,
    ACTIONS(761), 1,
      sym__double_quote_string_start,
    ACTIONS(974), 1,
      anon_sym_LPAREN,
    ACTIONS(978), 1,
      anon_sym_LBRACK,
    STATE(452), 1,
      sym__keywords,
    STATE(522), 1,
      sym_boolean,
    STATE(639), 1,
      sym_binary_operator,
    STATE(655), 1,
      sym_unary_operator,
    STATE(656), 1,
      sym_not_operator,
    STATE(657), 1,
      sym_cell,
    STATE(908), 1,
      sym__binary_expression,
    STATE(1370), 1,
      sym_indirect_access,
    STATE(1461), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(735), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(755), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(757), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(426), 2,
      sym_identifier,
      sym_function_call,
    STATE(635), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1058), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(654), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [11693] = 27,
    ACTIONS(7), 1,
      anon_sym_LPAREN,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(51), 1,
      aux_sym_number_token1,
    ACTIONS(59), 1,
      sym__single_quote_string_start,
    ACTIONS(61), 1,
      sym__double_quote_string_start,
    ACTIONS(968), 1,
      anon_sym_TILDE,
    ACTIONS(970), 1,
      anon_sym_QMARK,
    ACTIONS(972), 1,
      anon_sym_AT,
    STATE(373), 1,
      sym__keywords,
    STATE(404), 1,
      sym_boolean,
    STATE(462), 1,
      sym_binary_operator,
    STATE(463), 1,
      sym_not_operator,
    STATE(471), 1,
      sym_cell,
    STATE(513), 1,
      sym_unary_operator,
    STATE(910), 1,
      sym__binary_expression,
    STATE(1361), 1,
      sym_indirect_access,
    STATE(1509), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(9), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(53), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(55), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(374), 2,
      sym_identifier,
      sym_function_call,
    STATE(498), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(489), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(461), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(41), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [11797] = 27,
    ACTIONS(737), 1,
      anon_sym_TILDE,
    ACTIONS(745), 1,
      anon_sym_LBRACE,
    ACTIONS(753), 1,
      aux_sym_number_token1,
    ACTIONS(759), 1,
      sym__single_quote_string_start,
    ACTIONS(761), 1,
      sym__double_quote_string_start,
    ACTIONS(974), 1,
      anon_sym_LPAREN,
    ACTIONS(978), 1,
      anon_sym_LBRACK,
    ACTIONS(1006), 1,
      anon_sym_QMARK,
    ACTIONS(1014), 1,
      anon_sym_AT,
    STATE(452), 1,
      sym__keywords,
    STATE(518), 1,
      sym_boolean,
    STATE(636), 1,
      sym_cell,
    STATE(637), 1,
      sym_unary_operator,
    STATE(639), 1,
      sym_binary_operator,
    STATE(729), 1,
      sym_not_operator,
    STATE(908), 1,
      sym__binary_expression,
    STATE(1370), 1,
      sym_indirect_access,
    STATE(1461), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(735), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(755), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(757), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(421), 2,
      sym_identifier,
      sym_function_call,
    STATE(635), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(650), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(632), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [11901] = 27,
    ACTIONS(737), 1,
      anon_sym_TILDE,
    ACTIONS(745), 1,
      anon_sym_LBRACE,
    ACTIONS(753), 1,
      aux_sym_number_token1,
    ACTIONS(759), 1,
      sym__single_quote_string_start,
    ACTIONS(761), 1,
      sym__double_quote_string_start,
    ACTIONS(974), 1,
      anon_sym_LPAREN,
    ACTIONS(978), 1,
      anon_sym_LBRACK,
    ACTIONS(1006), 1,
      anon_sym_QMARK,
    ACTIONS(1014), 1,
      anon_sym_AT,
    STATE(452), 1,
      sym__keywords,
    STATE(518), 1,
      sym_boolean,
    STATE(636), 1,
      sym_cell,
    STATE(637), 1,
      sym_unary_operator,
    STATE(639), 1,
      sym_binary_operator,
    STATE(729), 1,
      sym_not_operator,
    STATE(908), 1,
      sym__binary_expression,
    STATE(1370), 1,
      sym_indirect_access,
    STATE(1461), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(735), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(755), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(757), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(421), 2,
      sym_identifier,
      sym_function_call,
    STATE(635), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(738), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(632), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [12005] = 27,
    ACTIONS(737), 1,
      anon_sym_TILDE,
    ACTIONS(745), 1,
      anon_sym_LBRACE,
    ACTIONS(753), 1,
      aux_sym_number_token1,
    ACTIONS(759), 1,
      sym__single_quote_string_start,
    ACTIONS(761), 1,
      sym__double_quote_string_start,
    ACTIONS(974), 1,
      anon_sym_LPAREN,
    ACTIONS(978), 1,
      anon_sym_LBRACK,
    ACTIONS(1006), 1,
      anon_sym_QMARK,
    ACTIONS(1014), 1,
      anon_sym_AT,
    STATE(452), 1,
      sym__keywords,
    STATE(518), 1,
      sym_boolean,
    STATE(636), 1,
      sym_cell,
    STATE(637), 1,
      sym_unary_operator,
    STATE(639), 1,
      sym_binary_operator,
    STATE(729), 1,
      sym_not_operator,
    STATE(908), 1,
      sym__binary_expression,
    STATE(1370), 1,
      sym_indirect_access,
    STATE(1461), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(735), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(755), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(757), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(421), 2,
      sym_identifier,
      sym_function_call,
    STATE(635), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(741), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(632), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [12109] = 25,
    ACTIONS(737), 1,
      anon_sym_TILDE,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(745), 1,
      anon_sym_LBRACE,
    ACTIONS(753), 1,
      aux_sym_number_token1,
    ACTIONS(759), 1,
      sym__single_quote_string_start,
    ACTIONS(761), 1,
      sym__double_quote_string_start,
    ACTIONS(974), 1,
      anon_sym_LPAREN,
    ACTIONS(978), 1,
      anon_sym_LBRACK,
    STATE(452), 1,
      sym__keywords,
    STATE(508), 1,
      sym_boolean,
    STATE(659), 1,
      sym_unary_operator,
    STATE(679), 1,
      sym_binary_operator,
    STATE(681), 1,
      sym_cell,
    STATE(1370), 1,
      sym_indirect_access,
    STATE(1461), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(735), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(755), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(757), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(422), 2,
      sym_identifier,
      sym_function_call,
    STATE(662), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1064), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(645), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [12209] = 25,
    ACTIONS(737), 1,
      anon_sym_TILDE,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(745), 1,
      anon_sym_LBRACE,
    ACTIONS(753), 1,
      aux_sym_number_token1,
    ACTIONS(759), 1,
      sym__single_quote_string_start,
    ACTIONS(761), 1,
      sym__double_quote_string_start,
    ACTIONS(974), 1,
      anon_sym_LPAREN,
    ACTIONS(978), 1,
      anon_sym_LBRACK,
    STATE(452), 1,
      sym__keywords,
    STATE(508), 1,
      sym_boolean,
    STATE(659), 1,
      sym_unary_operator,
    STATE(679), 1,
      sym_binary_operator,
    STATE(681), 1,
      sym_cell,
    STATE(1370), 1,
      sym_indirect_access,
    STATE(1461), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(735), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(755), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(757), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(422), 2,
      sym_identifier,
      sym_function_call,
    STATE(691), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1064), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(645), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [12309] = 25,
    ACTIONS(737), 1,
      anon_sym_TILDE,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(745), 1,
      anon_sym_LBRACE,
    ACTIONS(753), 1,
      aux_sym_number_token1,
    ACTIONS(759), 1,
      sym__single_quote_string_start,
    ACTIONS(761), 1,
      sym__double_quote_string_start,
    ACTIONS(974), 1,
      anon_sym_LPAREN,
    ACTIONS(978), 1,
      anon_sym_LBRACK,
    STATE(452), 1,
      sym__keywords,
    STATE(508), 1,
      sym_boolean,
    STATE(659), 1,
      sym_unary_operator,
    STATE(679), 1,
      sym_binary_operator,
    STATE(681), 1,
      sym_cell,
    STATE(1370), 1,
      sym_indirect_access,
    STATE(1461), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(735), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(755), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(757), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(422), 2,
      sym_identifier,
      sym_function_call,
    STATE(669), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1064), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(645), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [12409] = 25,
    ACTIONS(737), 1,
      anon_sym_TILDE,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(745), 1,
      anon_sym_LBRACE,
    ACTIONS(753), 1,
      aux_sym_number_token1,
    ACTIONS(759), 1,
      sym__single_quote_string_start,
    ACTIONS(761), 1,
      sym__double_quote_string_start,
    ACTIONS(974), 1,
      anon_sym_LPAREN,
    ACTIONS(978), 1,
      anon_sym_LBRACK,
    STATE(452), 1,
      sym__keywords,
    STATE(508), 1,
      sym_boolean,
    STATE(659), 1,
      sym_unary_operator,
    STATE(679), 1,
      sym_binary_operator,
    STATE(681), 1,
      sym_cell,
    STATE(1370), 1,
      sym_indirect_access,
    STATE(1461), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(735), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(755), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(757), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(422), 2,
      sym_identifier,
      sym_function_call,
    STATE(670), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1064), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(645), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [12509] = 25,
    ACTIONS(737), 1,
      anon_sym_TILDE,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(745), 1,
      anon_sym_LBRACE,
    ACTIONS(753), 1,
      aux_sym_number_token1,
    ACTIONS(759), 1,
      sym__single_quote_string_start,
    ACTIONS(761), 1,
      sym__double_quote_string_start,
    ACTIONS(974), 1,
      anon_sym_LPAREN,
    ACTIONS(978), 1,
      anon_sym_LBRACK,
    STATE(452), 1,
      sym__keywords,
    STATE(508), 1,
      sym_boolean,
    STATE(659), 1,
      sym_unary_operator,
    STATE(679), 1,
      sym_binary_operator,
    STATE(681), 1,
      sym_cell,
    STATE(1370), 1,
      sym_indirect_access,
    STATE(1461), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(735), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(755), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(757), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(422), 2,
      sym_identifier,
      sym_function_call,
    STATE(672), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1064), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(645), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [12609] = 27,
    ACTIONS(737), 1,
      anon_sym_TILDE,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(745), 1,
      anon_sym_LBRACE,
    ACTIONS(753), 1,
      aux_sym_number_token1,
    ACTIONS(759), 1,
      sym__single_quote_string_start,
    ACTIONS(761), 1,
      sym__double_quote_string_start,
    ACTIONS(974), 1,
      anon_sym_LPAREN,
    ACTIONS(978), 1,
      anon_sym_LBRACK,
    STATE(452), 1,
      sym__keywords,
    STATE(510), 1,
      sym_boolean,
    STATE(629), 1,
      sym_binary_operator,
    STATE(636), 1,
      sym_cell,
    STATE(666), 1,
      sym_unary_operator,
    STATE(668), 1,
      sym_not_operator,
    STATE(680), 1,
      sym__range_element,
    STATE(908), 1,
      sym__binary_expression,
    STATE(1370), 1,
      sym_indirect_access,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(735), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(755), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(757), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(423), 2,
      sym_identifier,
      sym_function_call,
    STATE(635), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1058), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(661), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [12713] = 27,
    ACTIONS(737), 1,
      anon_sym_TILDE,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(745), 1,
      anon_sym_LBRACE,
    ACTIONS(753), 1,
      aux_sym_number_token1,
    ACTIONS(759), 1,
      sym__single_quote_string_start,
    ACTIONS(761), 1,
      sym__double_quote_string_start,
    ACTIONS(974), 1,
      anon_sym_LPAREN,
    ACTIONS(978), 1,
      anon_sym_LBRACK,
    STATE(452), 1,
      sym__keywords,
    STATE(518), 1,
      sym_boolean,
    STATE(636), 1,
      sym_cell,
    STATE(637), 1,
      sym_unary_operator,
    STATE(639), 1,
      sym_binary_operator,
    STATE(729), 1,
      sym_not_operator,
    STATE(908), 1,
      sym__binary_expression,
    STATE(1370), 1,
      sym_indirect_access,
    STATE(1461), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(735), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(755), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(757), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(421), 2,
      sym_identifier,
      sym_function_call,
    STATE(635), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(744), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(632), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [12817] = 27,
    ACTIONS(737), 1,
      anon_sym_TILDE,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(745), 1,
      anon_sym_LBRACE,
    ACTIONS(753), 1,
      aux_sym_number_token1,
    ACTIONS(759), 1,
      sym__single_quote_string_start,
    ACTIONS(761), 1,
      sym__double_quote_string_start,
    ACTIONS(974), 1,
      anon_sym_LPAREN,
    ACTIONS(978), 1,
      anon_sym_LBRACK,
    STATE(452), 1,
      sym__keywords,
    STATE(518), 1,
      sym_boolean,
    STATE(636), 1,
      sym_cell,
    STATE(637), 1,
      sym_unary_operator,
    STATE(639), 1,
      sym_binary_operator,
    STATE(729), 1,
      sym_not_operator,
    STATE(908), 1,
      sym__binary_expression,
    STATE(1370), 1,
      sym_indirect_access,
    STATE(1461), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(735), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(755), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(757), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(421), 2,
      sym_identifier,
      sym_function_call,
    STATE(635), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(736), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(632), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [12921] = 27,
    ACTIONS(980), 1,
      anon_sym_LPAREN,
    ACTIONS(984), 1,
      anon_sym_TILDE,
    ACTIONS(990), 1,
      anon_sym_LBRACK,
    ACTIONS(992), 1,
      anon_sym_LBRACE,
    ACTIONS(996), 1,
      aux_sym_number_token1,
    ACTIONS(1002), 1,
      sym__single_quote_string_start,
    ACTIONS(1004), 1,
      sym__double_quote_string_start,
    ACTIONS(1010), 1,
      anon_sym_QMARK,
    ACTIONS(1012), 1,
      anon_sym_AT,
    STATE(93), 1,
      sym__keywords,
    STATE(95), 1,
      sym_boolean,
    STATE(105), 1,
      sym_unary_operator,
    STATE(107), 1,
      sym_cell,
    STATE(133), 1,
      sym_binary_operator,
    STATE(150), 1,
      sym_not_operator,
    STATE(918), 1,
      sym__binary_expression,
    STATE(1342), 1,
      sym_indirect_access,
    STATE(1470), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(998), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1000), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(74), 2,
      sym_identifier,
      sym_function_call,
    STATE(106), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(5), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(132), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(994), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [13025] = 27,
    ACTIONS(7), 1,
      anon_sym_LPAREN,
    ACTIONS(13), 1,
      anon_sym_QMARK,
    ACTIONS(15), 1,
      anon_sym_AT,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(51), 1,
      aux_sym_number_token1,
    ACTIONS(59), 1,
      sym__single_quote_string_start,
    ACTIONS(61), 1,
      sym__double_quote_string_start,
    ACTIONS(968), 1,
      anon_sym_TILDE,
    STATE(373), 1,
      sym__keywords,
    STATE(397), 1,
      sym_boolean,
    STATE(471), 1,
      sym_cell,
    STATE(519), 1,
      sym_binary_operator,
    STATE(528), 1,
      sym_unary_operator,
    STATE(549), 1,
      sym_not_operator,
    STATE(910), 1,
      sym__binary_expression,
    STATE(1361), 1,
      sym_indirect_access,
    STATE(1509), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(9), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(53), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(55), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(377), 2,
      sym_identifier,
      sym_function_call,
    STATE(498), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(764), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(512), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(41), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [13129] = 27,
    ACTIONS(737), 1,
      anon_sym_TILDE,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(745), 1,
      anon_sym_LBRACE,
    ACTIONS(753), 1,
      aux_sym_number_token1,
    ACTIONS(759), 1,
      sym__single_quote_string_start,
    ACTIONS(761), 1,
      sym__double_quote_string_start,
    ACTIONS(974), 1,
      anon_sym_LPAREN,
    ACTIONS(978), 1,
      anon_sym_LBRACK,
    STATE(452), 1,
      sym__keywords,
    STATE(510), 1,
      sym_boolean,
    STATE(629), 1,
      sym_binary_operator,
    STATE(636), 1,
      sym_cell,
    STATE(666), 1,
      sym_unary_operator,
    STATE(668), 1,
      sym_not_operator,
    STATE(686), 1,
      sym__range_element,
    STATE(908), 1,
      sym__binary_expression,
    STATE(1370), 1,
      sym_indirect_access,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(735), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(755), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(757), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(423), 2,
      sym_identifier,
      sym_function_call,
    STATE(635), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1058), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(661), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [13233] = 27,
    ACTIONS(7), 1,
      anon_sym_LPAREN,
    ACTIONS(13), 1,
      anon_sym_QMARK,
    ACTIONS(15), 1,
      anon_sym_AT,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(51), 1,
      aux_sym_number_token1,
    ACTIONS(59), 1,
      sym__single_quote_string_start,
    ACTIONS(61), 1,
      sym__double_quote_string_start,
    ACTIONS(968), 1,
      anon_sym_TILDE,
    STATE(373), 1,
      sym__keywords,
    STATE(397), 1,
      sym_boolean,
    STATE(471), 1,
      sym_cell,
    STATE(519), 1,
      sym_binary_operator,
    STATE(528), 1,
      sym_unary_operator,
    STATE(549), 1,
      sym_not_operator,
    STATE(910), 1,
      sym__binary_expression,
    STATE(1361), 1,
      sym_indirect_access,
    STATE(1509), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(9), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(53), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(55), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(377), 2,
      sym_identifier,
      sym_function_call,
    STATE(498), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(947), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(512), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(41), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [13337] = 27,
    ACTIONS(687), 1,
      aux_sym_number_token1,
    ACTIONS(691), 1,
      sym__single_quote_string_start,
    ACTIONS(693), 1,
      sym__double_quote_string_start,
    ACTIONS(823), 1,
      anon_sym_LBRACE,
    ACTIONS(840), 1,
      anon_sym_TILDE,
    ACTIONS(964), 1,
      anon_sym_LPAREN,
    ACTIONS(966), 1,
      anon_sym_LBRACK,
    ACTIONS(1016), 1,
      anon_sym_QMARK,
    ACTIONS(1018), 1,
      anon_sym_AT,
    STATE(424), 1,
      sym_boolean,
    STATE(445), 1,
      sym__keywords,
    STATE(547), 1,
      sym_binary_operator,
    STATE(548), 1,
      sym_unary_operator,
    STATE(551), 1,
      sym_cell,
    STATE(642), 1,
      sym_not_operator,
    STATE(914), 1,
      sym__binary_expression,
    STATE(1321), 1,
      sym_indirect_access,
    STATE(1465), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(813), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(827), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(829), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(396), 2,
      sym_identifier,
      sym_function_call,
    STATE(550), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(582), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(546), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(695), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [13441] = 27,
    ACTIONS(687), 1,
      aux_sym_number_token1,
    ACTIONS(691), 1,
      sym__single_quote_string_start,
    ACTIONS(693), 1,
      sym__double_quote_string_start,
    ACTIONS(823), 1,
      anon_sym_LBRACE,
    ACTIONS(840), 1,
      anon_sym_TILDE,
    ACTIONS(964), 1,
      anon_sym_LPAREN,
    ACTIONS(966), 1,
      anon_sym_LBRACK,
    ACTIONS(1016), 1,
      anon_sym_QMARK,
    ACTIONS(1018), 1,
      anon_sym_AT,
    STATE(424), 1,
      sym_boolean,
    STATE(445), 1,
      sym__keywords,
    STATE(547), 1,
      sym_binary_operator,
    STATE(548), 1,
      sym_unary_operator,
    STATE(551), 1,
      sym_cell,
    STATE(642), 1,
      sym_not_operator,
    STATE(914), 1,
      sym__binary_expression,
    STATE(1321), 1,
      sym_indirect_access,
    STATE(1465), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(813), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(827), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(829), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(396), 2,
      sym_identifier,
      sym_function_call,
    STATE(550), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(708), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(546), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(695), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [13545] = 27,
    ACTIONS(687), 1,
      aux_sym_number_token1,
    ACTIONS(691), 1,
      sym__single_quote_string_start,
    ACTIONS(693), 1,
      sym__double_quote_string_start,
    ACTIONS(823), 1,
      anon_sym_LBRACE,
    ACTIONS(840), 1,
      anon_sym_TILDE,
    ACTIONS(964), 1,
      anon_sym_LPAREN,
    ACTIONS(966), 1,
      anon_sym_LBRACK,
    ACTIONS(1016), 1,
      anon_sym_QMARK,
    ACTIONS(1018), 1,
      anon_sym_AT,
    STATE(424), 1,
      sym_boolean,
    STATE(445), 1,
      sym__keywords,
    STATE(547), 1,
      sym_binary_operator,
    STATE(548), 1,
      sym_unary_operator,
    STATE(551), 1,
      sym_cell,
    STATE(642), 1,
      sym_not_operator,
    STATE(914), 1,
      sym__binary_expression,
    STATE(1321), 1,
      sym_indirect_access,
    STATE(1465), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(813), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(827), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(829), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(396), 2,
      sym_identifier,
      sym_function_call,
    STATE(550), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(709), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(546), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(695), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [13649] = 25,
    ACTIONS(687), 1,
      aux_sym_number_token1,
    ACTIONS(691), 1,
      sym__single_quote_string_start,
    ACTIONS(693), 1,
      sym__double_quote_string_start,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(823), 1,
      anon_sym_LBRACE,
    ACTIONS(840), 1,
      anon_sym_TILDE,
    ACTIONS(964), 1,
      anon_sym_LPAREN,
    ACTIONS(966), 1,
      anon_sym_LBRACK,
    STATE(425), 1,
      sym_boolean,
    STATE(445), 1,
      sym__keywords,
    STATE(569), 1,
      sym_cell,
    STATE(575), 1,
      sym_unary_operator,
    STATE(579), 1,
      sym_binary_operator,
    STATE(1321), 1,
      sym_indirect_access,
    STATE(1461), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(813), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(827), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(829), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(395), 2,
      sym_identifier,
      sym_function_call,
    STATE(583), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1051), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(574), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(695), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [13749] = 25,
    ACTIONS(687), 1,
      aux_sym_number_token1,
    ACTIONS(691), 1,
      sym__single_quote_string_start,
    ACTIONS(693), 1,
      sym__double_quote_string_start,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(823), 1,
      anon_sym_LBRACE,
    ACTIONS(840), 1,
      anon_sym_TILDE,
    ACTIONS(964), 1,
      anon_sym_LPAREN,
    ACTIONS(966), 1,
      anon_sym_LBRACK,
    STATE(425), 1,
      sym_boolean,
    STATE(445), 1,
      sym__keywords,
    STATE(569), 1,
      sym_cell,
    STATE(575), 1,
      sym_unary_operator,
    STATE(579), 1,
      sym_binary_operator,
    STATE(1321), 1,
      sym_indirect_access,
    STATE(1461), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(813), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(827), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(829), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(395), 2,
      sym_identifier,
      sym_function_call,
    STATE(584), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1051), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(574), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(695), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [13849] = 25,
    ACTIONS(687), 1,
      aux_sym_number_token1,
    ACTIONS(691), 1,
      sym__single_quote_string_start,
    ACTIONS(693), 1,
      sym__double_quote_string_start,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(823), 1,
      anon_sym_LBRACE,
    ACTIONS(840), 1,
      anon_sym_TILDE,
    ACTIONS(964), 1,
      anon_sym_LPAREN,
    ACTIONS(966), 1,
      anon_sym_LBRACK,
    STATE(425), 1,
      sym_boolean,
    STATE(445), 1,
      sym__keywords,
    STATE(569), 1,
      sym_cell,
    STATE(575), 1,
      sym_unary_operator,
    STATE(579), 1,
      sym_binary_operator,
    STATE(1321), 1,
      sym_indirect_access,
    STATE(1461), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(813), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(827), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(829), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(395), 2,
      sym_identifier,
      sym_function_call,
    STATE(585), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1051), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(574), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(695), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [13949] = 25,
    ACTIONS(687), 1,
      aux_sym_number_token1,
    ACTIONS(691), 1,
      sym__single_quote_string_start,
    ACTIONS(693), 1,
      sym__double_quote_string_start,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(823), 1,
      anon_sym_LBRACE,
    ACTIONS(840), 1,
      anon_sym_TILDE,
    ACTIONS(964), 1,
      anon_sym_LPAREN,
    ACTIONS(966), 1,
      anon_sym_LBRACK,
    STATE(425), 1,
      sym_boolean,
    STATE(445), 1,
      sym__keywords,
    STATE(569), 1,
      sym_cell,
    STATE(575), 1,
      sym_unary_operator,
    STATE(579), 1,
      sym_binary_operator,
    STATE(1321), 1,
      sym_indirect_access,
    STATE(1461), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(813), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(827), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(829), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(395), 2,
      sym_identifier,
      sym_function_call,
    STATE(586), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1051), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(574), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(695), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [14049] = 25,
    ACTIONS(687), 1,
      aux_sym_number_token1,
    ACTIONS(691), 1,
      sym__single_quote_string_start,
    ACTIONS(693), 1,
      sym__double_quote_string_start,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(823), 1,
      anon_sym_LBRACE,
    ACTIONS(840), 1,
      anon_sym_TILDE,
    ACTIONS(964), 1,
      anon_sym_LPAREN,
    ACTIONS(966), 1,
      anon_sym_LBRACK,
    STATE(425), 1,
      sym_boolean,
    STATE(445), 1,
      sym__keywords,
    STATE(569), 1,
      sym_cell,
    STATE(575), 1,
      sym_unary_operator,
    STATE(579), 1,
      sym_binary_operator,
    STATE(1321), 1,
      sym_indirect_access,
    STATE(1461), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(813), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(827), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(829), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(395), 2,
      sym_identifier,
      sym_function_call,
    STATE(591), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1051), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(574), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(695), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [14149] = 27,
    ACTIONS(687), 1,
      aux_sym_number_token1,
    ACTIONS(691), 1,
      sym__single_quote_string_start,
    ACTIONS(693), 1,
      sym__double_quote_string_start,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(745), 1,
      anon_sym_LBRACE,
    ACTIONS(840), 1,
      anon_sym_TILDE,
    ACTIONS(964), 1,
      anon_sym_LPAREN,
    ACTIONS(966), 1,
      anon_sym_LBRACK,
    STATE(427), 1,
      sym_boolean,
    STATE(445), 1,
      sym__keywords,
    STATE(577), 1,
      sym_unary_operator,
    STATE(578), 1,
      sym_not_operator,
    STATE(580), 1,
      sym_binary_operator,
    STATE(593), 1,
      sym__range_element,
    STATE(748), 1,
      sym_cell,
    STATE(914), 1,
      sym__binary_expression,
    STATE(1321), 1,
      sym_indirect_access,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(813), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(827), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(829), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(399), 2,
      sym_identifier,
      sym_function_call,
    STATE(635), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1058), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(576), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(695), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [14253] = 27,
    ACTIONS(7), 1,
      anon_sym_LPAREN,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(51), 1,
      aux_sym_number_token1,
    ACTIONS(59), 1,
      sym__single_quote_string_start,
    ACTIONS(61), 1,
      sym__double_quote_string_start,
    ACTIONS(968), 1,
      anon_sym_TILDE,
    ACTIONS(970), 1,
      anon_sym_QMARK,
    ACTIONS(972), 1,
      anon_sym_AT,
    STATE(373), 1,
      sym__keywords,
    STATE(404), 1,
      sym_boolean,
    STATE(462), 1,
      sym_binary_operator,
    STATE(463), 1,
      sym_not_operator,
    STATE(471), 1,
      sym_cell,
    STATE(513), 1,
      sym_unary_operator,
    STATE(910), 1,
      sym__binary_expression,
    STATE(1361), 1,
      sym_indirect_access,
    STATE(1509), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(9), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(53), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(55), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(374), 2,
      sym_identifier,
      sym_function_call,
    STATE(498), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(517), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(461), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(41), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [14357] = 28,
    ACTIONS(737), 1,
      anon_sym_TILDE,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(745), 1,
      anon_sym_LBRACE,
    ACTIONS(753), 1,
      aux_sym_number_token1,
    ACTIONS(759), 1,
      sym__single_quote_string_start,
    ACTIONS(761), 1,
      sym__double_quote_string_start,
    ACTIONS(974), 1,
      anon_sym_LPAREN,
    ACTIONS(978), 1,
      anon_sym_LBRACK,
    STATE(452), 1,
      sym__keywords,
    STATE(518), 1,
      sym_boolean,
    STATE(632), 1,
      sym_number,
    STATE(636), 1,
      sym_cell,
    STATE(705), 1,
      sym_binary_operator,
    STATE(706), 1,
      sym_unary_operator,
    STATE(729), 1,
      sym_not_operator,
    STATE(908), 1,
      sym__binary_expression,
    STATE(1370), 1,
      sym_indirect_access,
    STATE(1461), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(735), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(755), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(757), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(459), 2,
      sym_identifier,
      sym_function_call,
    STATE(635), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(704), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(1047), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [14463] = 27,
    ACTIONS(7), 1,
      anon_sym_LPAREN,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(51), 1,
      aux_sym_number_token1,
    ACTIONS(59), 1,
      sym__single_quote_string_start,
    ACTIONS(61), 1,
      sym__double_quote_string_start,
    ACTIONS(968), 1,
      anon_sym_TILDE,
    ACTIONS(970), 1,
      anon_sym_QMARK,
    ACTIONS(972), 1,
      anon_sym_AT,
    STATE(373), 1,
      sym__keywords,
    STATE(404), 1,
      sym_boolean,
    STATE(462), 1,
      sym_binary_operator,
    STATE(463), 1,
      sym_not_operator,
    STATE(471), 1,
      sym_cell,
    STATE(513), 1,
      sym_unary_operator,
    STATE(910), 1,
      sym__binary_expression,
    STATE(1361), 1,
      sym_indirect_access,
    STATE(1509), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(9), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(53), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(55), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(374), 2,
      sym_identifier,
      sym_function_call,
    STATE(498), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(520), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(461), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(41), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [14567] = 27,
    ACTIONS(687), 1,
      aux_sym_number_token1,
    ACTIONS(691), 1,
      sym__single_quote_string_start,
    ACTIONS(693), 1,
      sym__double_quote_string_start,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(745), 1,
      anon_sym_LBRACE,
    ACTIONS(840), 1,
      anon_sym_TILDE,
    ACTIONS(964), 1,
      anon_sym_LPAREN,
    ACTIONS(966), 1,
      anon_sym_LBRACK,
    STATE(427), 1,
      sym_boolean,
    STATE(445), 1,
      sym__keywords,
    STATE(545), 1,
      sym__range_element,
    STATE(577), 1,
      sym_unary_operator,
    STATE(578), 1,
      sym_not_operator,
    STATE(580), 1,
      sym_binary_operator,
    STATE(748), 1,
      sym_cell,
    STATE(914), 1,
      sym__binary_expression,
    STATE(1321), 1,
      sym_indirect_access,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(813), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(827), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(829), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(399), 2,
      sym_identifier,
      sym_function_call,
    STATE(635), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1058), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(576), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(695), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [14671] = 27,
    ACTIONS(7), 1,
      anon_sym_LPAREN,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(51), 1,
      aux_sym_number_token1,
    ACTIONS(59), 1,
      sym__single_quote_string_start,
    ACTIONS(61), 1,
      sym__double_quote_string_start,
    ACTIONS(968), 1,
      anon_sym_TILDE,
    ACTIONS(970), 1,
      anon_sym_QMARK,
    ACTIONS(1020), 1,
      anon_sym_AT,
    STATE(373), 1,
      sym__keywords,
    STATE(397), 1,
      sym_boolean,
    STATE(471), 1,
      sym_cell,
    STATE(519), 1,
      sym_binary_operator,
    STATE(528), 1,
      sym_unary_operator,
    STATE(549), 1,
      sym_not_operator,
    STATE(910), 1,
      sym__binary_expression,
    STATE(1361), 1,
      sym_indirect_access,
    STATE(1509), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(9), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(53), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(55), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(377), 2,
      sym_identifier,
      sym_function_call,
    STATE(498), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(529), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(512), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(41), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [14775] = 27,
    ACTIONS(7), 1,
      anon_sym_LPAREN,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(51), 1,
      aux_sym_number_token1,
    ACTIONS(59), 1,
      sym__single_quote_string_start,
    ACTIONS(61), 1,
      sym__double_quote_string_start,
    ACTIONS(968), 1,
      anon_sym_TILDE,
    ACTIONS(970), 1,
      anon_sym_QMARK,
    ACTIONS(1020), 1,
      anon_sym_AT,
    STATE(373), 1,
      sym__keywords,
    STATE(397), 1,
      sym_boolean,
    STATE(471), 1,
      sym_cell,
    STATE(519), 1,
      sym_binary_operator,
    STATE(528), 1,
      sym_unary_operator,
    STATE(549), 1,
      sym_not_operator,
    STATE(910), 1,
      sym__binary_expression,
    STATE(1361), 1,
      sym_indirect_access,
    STATE(1509), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(9), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(53), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(55), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(377), 2,
      sym_identifier,
      sym_function_call,
    STATE(498), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(622), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(512), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(41), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [14879] = 27,
    ACTIONS(7), 1,
      anon_sym_LPAREN,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(51), 1,
      aux_sym_number_token1,
    ACTIONS(59), 1,
      sym__single_quote_string_start,
    ACTIONS(61), 1,
      sym__double_quote_string_start,
    ACTIONS(968), 1,
      anon_sym_TILDE,
    ACTIONS(970), 1,
      anon_sym_QMARK,
    ACTIONS(1020), 1,
      anon_sym_AT,
    STATE(373), 1,
      sym__keywords,
    STATE(397), 1,
      sym_boolean,
    STATE(471), 1,
      sym_cell,
    STATE(519), 1,
      sym_binary_operator,
    STATE(528), 1,
      sym_unary_operator,
    STATE(549), 1,
      sym_not_operator,
    STATE(910), 1,
      sym__binary_expression,
    STATE(1361), 1,
      sym_indirect_access,
    STATE(1509), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(9), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(53), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(55), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(377), 2,
      sym_identifier,
      sym_function_call,
    STATE(498), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(623), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(512), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(41), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [14983] = 25,
    ACTIONS(7), 1,
      anon_sym_LPAREN,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(51), 1,
      aux_sym_number_token1,
    ACTIONS(59), 1,
      sym__single_quote_string_start,
    ACTIONS(61), 1,
      sym__double_quote_string_start,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(968), 1,
      anon_sym_TILDE,
    STATE(373), 1,
      sym__keywords,
    STATE(394), 1,
      sym_boolean,
    STATE(491), 1,
      sym_cell,
    STATE(503), 1,
      sym_unary_operator,
    STATE(509), 1,
      sym_binary_operator,
    STATE(1361), 1,
      sym_indirect_access,
    STATE(1461), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(9), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(53), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(55), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(375), 2,
      sym_identifier,
      sym_function_call,
    STATE(531), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1050), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(504), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(41), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [15083] = 25,
    ACTIONS(7), 1,
      anon_sym_LPAREN,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(51), 1,
      aux_sym_number_token1,
    ACTIONS(59), 1,
      sym__single_quote_string_start,
    ACTIONS(61), 1,
      sym__double_quote_string_start,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(968), 1,
      anon_sym_TILDE,
    STATE(373), 1,
      sym__keywords,
    STATE(394), 1,
      sym_boolean,
    STATE(491), 1,
      sym_cell,
    STATE(503), 1,
      sym_unary_operator,
    STATE(509), 1,
      sym_binary_operator,
    STATE(1361), 1,
      sym_indirect_access,
    STATE(1461), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(9), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(53), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(55), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(375), 2,
      sym_identifier,
      sym_function_call,
    STATE(532), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1050), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(504), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(41), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [15183] = 25,
    ACTIONS(7), 1,
      anon_sym_LPAREN,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(51), 1,
      aux_sym_number_token1,
    ACTIONS(59), 1,
      sym__single_quote_string_start,
    ACTIONS(61), 1,
      sym__double_quote_string_start,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(968), 1,
      anon_sym_TILDE,
    STATE(373), 1,
      sym__keywords,
    STATE(394), 1,
      sym_boolean,
    STATE(491), 1,
      sym_cell,
    STATE(503), 1,
      sym_unary_operator,
    STATE(509), 1,
      sym_binary_operator,
    STATE(1361), 1,
      sym_indirect_access,
    STATE(1461), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(9), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(53), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(55), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(375), 2,
      sym_identifier,
      sym_function_call,
    STATE(533), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1050), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(504), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(41), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [15283] = 25,
    ACTIONS(7), 1,
      anon_sym_LPAREN,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(51), 1,
      aux_sym_number_token1,
    ACTIONS(59), 1,
      sym__single_quote_string_start,
    ACTIONS(61), 1,
      sym__double_quote_string_start,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(968), 1,
      anon_sym_TILDE,
    STATE(373), 1,
      sym__keywords,
    STATE(394), 1,
      sym_boolean,
    STATE(491), 1,
      sym_cell,
    STATE(503), 1,
      sym_unary_operator,
    STATE(509), 1,
      sym_binary_operator,
    STATE(1361), 1,
      sym_indirect_access,
    STATE(1461), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(9), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(53), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(55), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(375), 2,
      sym_identifier,
      sym_function_call,
    STATE(534), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1050), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(504), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(41), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [15383] = 25,
    ACTIONS(7), 1,
      anon_sym_LPAREN,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(51), 1,
      aux_sym_number_token1,
    ACTIONS(59), 1,
      sym__single_quote_string_start,
    ACTIONS(61), 1,
      sym__double_quote_string_start,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(968), 1,
      anon_sym_TILDE,
    STATE(373), 1,
      sym__keywords,
    STATE(394), 1,
      sym_boolean,
    STATE(491), 1,
      sym_cell,
    STATE(503), 1,
      sym_unary_operator,
    STATE(509), 1,
      sym_binary_operator,
    STATE(1361), 1,
      sym_indirect_access,
    STATE(1461), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(9), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(53), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(55), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(375), 2,
      sym_identifier,
      sym_function_call,
    STATE(535), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1050), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(504), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(41), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [15483] = 27,
    ACTIONS(7), 1,
      anon_sym_LPAREN,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(51), 1,
      aux_sym_number_token1,
    ACTIONS(59), 1,
      sym__single_quote_string_start,
    ACTIONS(61), 1,
      sym__double_quote_string_start,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(745), 1,
      anon_sym_LBRACE,
    ACTIONS(968), 1,
      anon_sym_TILDE,
    STATE(373), 1,
      sym__keywords,
    STATE(402), 1,
      sym_boolean,
    STATE(472), 1,
      sym__range_element,
    STATE(505), 1,
      sym_unary_operator,
    STATE(507), 1,
      sym_not_operator,
    STATE(511), 1,
      sym_binary_operator,
    STATE(750), 1,
      sym_cell,
    STATE(910), 1,
      sym__binary_expression,
    STATE(1361), 1,
      sym_indirect_access,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(9), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(53), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(55), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(376), 2,
      sym_identifier,
      sym_function_call,
    STATE(635), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1058), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(506), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(41), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [15587] = 27,
    ACTIONS(980), 1,
      anon_sym_LPAREN,
    ACTIONS(984), 1,
      anon_sym_TILDE,
    ACTIONS(986), 1,
      anon_sym_QMARK,
    ACTIONS(988), 1,
      anon_sym_AT,
    ACTIONS(990), 1,
      anon_sym_LBRACK,
    ACTIONS(992), 1,
      anon_sym_LBRACE,
    ACTIONS(996), 1,
      aux_sym_number_token1,
    ACTIONS(1002), 1,
      sym__single_quote_string_start,
    ACTIONS(1004), 1,
      sym__double_quote_string_start,
    STATE(93), 1,
      sym__keywords,
    STATE(95), 1,
      sym_boolean,
    STATE(105), 1,
      sym_unary_operator,
    STATE(107), 1,
      sym_cell,
    STATE(133), 1,
      sym_binary_operator,
    STATE(150), 1,
      sym_not_operator,
    STATE(918), 1,
      sym__binary_expression,
    STATE(1342), 1,
      sym_indirect_access,
    STATE(1470), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(998), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1000), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(74), 2,
      sym_identifier,
      sym_function_call,
    STATE(106), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(120), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(132), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(994), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [15691] = 27,
    ACTIONS(980), 1,
      anon_sym_LPAREN,
    ACTIONS(984), 1,
      anon_sym_TILDE,
    ACTIONS(986), 1,
      anon_sym_QMARK,
    ACTIONS(988), 1,
      anon_sym_AT,
    ACTIONS(990), 1,
      anon_sym_LBRACK,
    ACTIONS(992), 1,
      anon_sym_LBRACE,
    ACTIONS(996), 1,
      aux_sym_number_token1,
    ACTIONS(1002), 1,
      sym__single_quote_string_start,
    ACTIONS(1004), 1,
      sym__double_quote_string_start,
    STATE(93), 1,
      sym__keywords,
    STATE(95), 1,
      sym_boolean,
    STATE(105), 1,
      sym_unary_operator,
    STATE(107), 1,
      sym_cell,
    STATE(133), 1,
      sym_binary_operator,
    STATE(150), 1,
      sym_not_operator,
    STATE(918), 1,
      sym__binary_expression,
    STATE(1342), 1,
      sym_indirect_access,
    STATE(1470), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(998), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1000), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(74), 2,
      sym_identifier,
      sym_function_call,
    STATE(106), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(151), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(132), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(994), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [15795] = 27,
    ACTIONS(980), 1,
      anon_sym_LPAREN,
    ACTIONS(984), 1,
      anon_sym_TILDE,
    ACTIONS(986), 1,
      anon_sym_QMARK,
    ACTIONS(988), 1,
      anon_sym_AT,
    ACTIONS(990), 1,
      anon_sym_LBRACK,
    ACTIONS(992), 1,
      anon_sym_LBRACE,
    ACTIONS(996), 1,
      aux_sym_number_token1,
    ACTIONS(1002), 1,
      sym__single_quote_string_start,
    ACTIONS(1004), 1,
      sym__double_quote_string_start,
    STATE(93), 1,
      sym__keywords,
    STATE(95), 1,
      sym_boolean,
    STATE(105), 1,
      sym_unary_operator,
    STATE(107), 1,
      sym_cell,
    STATE(133), 1,
      sym_binary_operator,
    STATE(150), 1,
      sym_not_operator,
    STATE(918), 1,
      sym__binary_expression,
    STATE(1342), 1,
      sym_indirect_access,
    STATE(1470), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(998), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1000), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(74), 2,
      sym_identifier,
      sym_function_call,
    STATE(106), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(152), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(132), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(994), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [15899] = 25,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(980), 1,
      anon_sym_LPAREN,
    ACTIONS(984), 1,
      anon_sym_TILDE,
    ACTIONS(990), 1,
      anon_sym_LBRACK,
    ACTIONS(992), 1,
      anon_sym_LBRACE,
    ACTIONS(996), 1,
      aux_sym_number_token1,
    ACTIONS(1002), 1,
      sym__single_quote_string_start,
    ACTIONS(1004), 1,
      sym__double_quote_string_start,
    STATE(93), 1,
      sym__keywords,
    STATE(98), 1,
      sym_boolean,
    STATE(137), 1,
      sym_cell,
    STATE(140), 1,
      sym_unary_operator,
    STATE(144), 1,
      sym_binary_operator,
    STATE(1342), 1,
      sym_indirect_access,
    STATE(1461), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(998), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1000), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(75), 2,
      sym_identifier,
      sym_function_call,
    STATE(121), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1055), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(139), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(994), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [15999] = 25,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(980), 1,
      anon_sym_LPAREN,
    ACTIONS(984), 1,
      anon_sym_TILDE,
    ACTIONS(990), 1,
      anon_sym_LBRACK,
    ACTIONS(992), 1,
      anon_sym_LBRACE,
    ACTIONS(996), 1,
      aux_sym_number_token1,
    ACTIONS(1002), 1,
      sym__single_quote_string_start,
    ACTIONS(1004), 1,
      sym__double_quote_string_start,
    STATE(93), 1,
      sym__keywords,
    STATE(98), 1,
      sym_boolean,
    STATE(137), 1,
      sym_cell,
    STATE(140), 1,
      sym_unary_operator,
    STATE(144), 1,
      sym_binary_operator,
    STATE(1342), 1,
      sym_indirect_access,
    STATE(1461), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(998), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1000), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(75), 2,
      sym_identifier,
      sym_function_call,
    STATE(122), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1055), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(139), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(994), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [16099] = 25,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(980), 1,
      anon_sym_LPAREN,
    ACTIONS(984), 1,
      anon_sym_TILDE,
    ACTIONS(990), 1,
      anon_sym_LBRACK,
    ACTIONS(992), 1,
      anon_sym_LBRACE,
    ACTIONS(996), 1,
      aux_sym_number_token1,
    ACTIONS(1002), 1,
      sym__single_quote_string_start,
    ACTIONS(1004), 1,
      sym__double_quote_string_start,
    STATE(93), 1,
      sym__keywords,
    STATE(98), 1,
      sym_boolean,
    STATE(137), 1,
      sym_cell,
    STATE(140), 1,
      sym_unary_operator,
    STATE(144), 1,
      sym_binary_operator,
    STATE(1342), 1,
      sym_indirect_access,
    STATE(1461), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(998), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1000), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(75), 2,
      sym_identifier,
      sym_function_call,
    STATE(123), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1055), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(139), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(994), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [16199] = 25,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(980), 1,
      anon_sym_LPAREN,
    ACTIONS(984), 1,
      anon_sym_TILDE,
    ACTIONS(990), 1,
      anon_sym_LBRACK,
    ACTIONS(992), 1,
      anon_sym_LBRACE,
    ACTIONS(996), 1,
      aux_sym_number_token1,
    ACTIONS(1002), 1,
      sym__single_quote_string_start,
    ACTIONS(1004), 1,
      sym__double_quote_string_start,
    STATE(93), 1,
      sym__keywords,
    STATE(98), 1,
      sym_boolean,
    STATE(137), 1,
      sym_cell,
    STATE(140), 1,
      sym_unary_operator,
    STATE(144), 1,
      sym_binary_operator,
    STATE(1342), 1,
      sym_indirect_access,
    STATE(1461), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(998), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1000), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(75), 2,
      sym_identifier,
      sym_function_call,
    STATE(149), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1055), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(139), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(994), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [16299] = 28,
    ACTIONS(737), 1,
      anon_sym_TILDE,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(745), 1,
      anon_sym_LBRACE,
    ACTIONS(753), 1,
      aux_sym_number_token1,
    ACTIONS(759), 1,
      sym__single_quote_string_start,
    ACTIONS(761), 1,
      sym__double_quote_string_start,
    ACTIONS(974), 1,
      anon_sym_LPAREN,
    ACTIONS(978), 1,
      anon_sym_LBRACK,
    STATE(452), 1,
      sym__keywords,
    STATE(518), 1,
      sym_boolean,
    STATE(632), 1,
      sym_number,
    STATE(636), 1,
      sym_cell,
    STATE(705), 1,
      sym_binary_operator,
    STATE(706), 1,
      sym_unary_operator,
    STATE(729), 1,
      sym_not_operator,
    STATE(908), 1,
      sym__binary_expression,
    STATE(1370), 1,
      sym_indirect_access,
    STATE(1461), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(735), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(755), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(757), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(459), 2,
      sym_identifier,
      sym_function_call,
    STATE(635), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(704), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(1045), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [16405] = 27,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(745), 1,
      anon_sym_LBRACE,
    ACTIONS(980), 1,
      anon_sym_LPAREN,
    ACTIONS(984), 1,
      anon_sym_TILDE,
    ACTIONS(990), 1,
      anon_sym_LBRACK,
    ACTIONS(996), 1,
      aux_sym_number_token1,
    ACTIONS(1002), 1,
      sym__single_quote_string_start,
    ACTIONS(1004), 1,
      sym__double_quote_string_start,
    STATE(93), 1,
      sym__keywords,
    STATE(100), 1,
      sym_boolean,
    STATE(126), 1,
      sym__range_element,
    STATE(142), 1,
      sym_unary_operator,
    STATE(143), 1,
      sym_not_operator,
    STATE(145), 1,
      sym_binary_operator,
    STATE(745), 1,
      sym_cell,
    STATE(918), 1,
      sym__binary_expression,
    STATE(1342), 1,
      sym_indirect_access,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(998), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1000), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(76), 2,
      sym_identifier,
      sym_function_call,
    STATE(635), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1058), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(141), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(994), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [16509] = 27,
    ACTIONS(687), 1,
      aux_sym_number_token1,
    ACTIONS(691), 1,
      sym__single_quote_string_start,
    ACTIONS(693), 1,
      sym__double_quote_string_start,
    ACTIONS(817), 1,
      anon_sym_QMARK,
    ACTIONS(819), 1,
      anon_sym_AT,
    ACTIONS(823), 1,
      anon_sym_LBRACE,
    ACTIONS(840), 1,
      anon_sym_TILDE,
    ACTIONS(964), 1,
      anon_sym_LPAREN,
    ACTIONS(966), 1,
      anon_sym_LBRACK,
    STATE(424), 1,
      sym_boolean,
    STATE(445), 1,
      sym__keywords,
    STATE(547), 1,
      sym_binary_operator,
    STATE(548), 1,
      sym_unary_operator,
    STATE(551), 1,
      sym_cell,
    STATE(642), 1,
      sym_not_operator,
    STATE(914), 1,
      sym__binary_expression,
    STATE(1321), 1,
      sym_indirect_access,
    STATE(1465), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(813), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(827), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(829), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(396), 2,
      sym_identifier,
      sym_function_call,
    STATE(550), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(695), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(546), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(695), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [16613] = 27,
    ACTIONS(687), 1,
      aux_sym_number_token1,
    ACTIONS(691), 1,
      sym__single_quote_string_start,
    ACTIONS(693), 1,
      sym__double_quote_string_start,
    ACTIONS(817), 1,
      anon_sym_QMARK,
    ACTIONS(819), 1,
      anon_sym_AT,
    ACTIONS(823), 1,
      anon_sym_LBRACE,
    ACTIONS(840), 1,
      anon_sym_TILDE,
    ACTIONS(964), 1,
      anon_sym_LPAREN,
    ACTIONS(966), 1,
      anon_sym_LBRACK,
    STATE(424), 1,
      sym_boolean,
    STATE(445), 1,
      sym__keywords,
    STATE(547), 1,
      sym_binary_operator,
    STATE(548), 1,
      sym_unary_operator,
    STATE(551), 1,
      sym_cell,
    STATE(642), 1,
      sym_not_operator,
    STATE(914), 1,
      sym__binary_expression,
    STATE(1321), 1,
      sym_indirect_access,
    STATE(1465), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(813), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(827), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(829), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(396), 2,
      sym_identifier,
      sym_function_call,
    STATE(550), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(701), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(546), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(695), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [16717] = 27,
    ACTIONS(7), 1,
      anon_sym_LPAREN,
    ACTIONS(13), 1,
      anon_sym_QMARK,
    ACTIONS(15), 1,
      anon_sym_AT,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(51), 1,
      aux_sym_number_token1,
    ACTIONS(59), 1,
      sym__single_quote_string_start,
    ACTIONS(61), 1,
      sym__double_quote_string_start,
    ACTIONS(968), 1,
      anon_sym_TILDE,
    STATE(373), 1,
      sym__keywords,
    STATE(397), 1,
      sym_boolean,
    STATE(471), 1,
      sym_cell,
    STATE(519), 1,
      sym_binary_operator,
    STATE(528), 1,
      sym_unary_operator,
    STATE(549), 1,
      sym_not_operator,
    STATE(910), 1,
      sym__binary_expression,
    STATE(1361), 1,
      sym_indirect_access,
    STATE(1509), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(9), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(53), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(55), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(377), 2,
      sym_identifier,
      sym_function_call,
    STATE(498), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(612), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(512), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(41), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [16821] = 27,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(745), 1,
      anon_sym_LBRACE,
    ACTIONS(980), 1,
      anon_sym_LPAREN,
    ACTIONS(984), 1,
      anon_sym_TILDE,
    ACTIONS(990), 1,
      anon_sym_LBRACK,
    ACTIONS(996), 1,
      aux_sym_number_token1,
    ACTIONS(1002), 1,
      sym__single_quote_string_start,
    ACTIONS(1004), 1,
      sym__double_quote_string_start,
    STATE(93), 1,
      sym__keywords,
    STATE(100), 1,
      sym_boolean,
    STATE(131), 1,
      sym__range_element,
    STATE(142), 1,
      sym_unary_operator,
    STATE(143), 1,
      sym_not_operator,
    STATE(145), 1,
      sym_binary_operator,
    STATE(745), 1,
      sym_cell,
    STATE(918), 1,
      sym__binary_expression,
    STATE(1342), 1,
      sym_indirect_access,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(998), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1000), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(76), 2,
      sym_identifier,
      sym_function_call,
    STATE(635), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1058), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(141), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(994), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [16925] = 27,
    ACTIONS(980), 1,
      anon_sym_LPAREN,
    ACTIONS(984), 1,
      anon_sym_TILDE,
    ACTIONS(990), 1,
      anon_sym_LBRACK,
    ACTIONS(992), 1,
      anon_sym_LBRACE,
    ACTIONS(996), 1,
      aux_sym_number_token1,
    ACTIONS(1002), 1,
      sym__single_quote_string_start,
    ACTIONS(1004), 1,
      sym__double_quote_string_start,
    ACTIONS(1010), 1,
      anon_sym_QMARK,
    ACTIONS(1012), 1,
      anon_sym_AT,
    STATE(93), 1,
      sym__keywords,
    STATE(95), 1,
      sym_boolean,
    STATE(105), 1,
      sym_unary_operator,
    STATE(107), 1,
      sym_cell,
    STATE(133), 1,
      sym_binary_operator,
    STATE(150), 1,
      sym_not_operator,
    STATE(918), 1,
      sym__binary_expression,
    STATE(1342), 1,
      sym_indirect_access,
    STATE(1470), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(998), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1000), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(74), 2,
      sym_identifier,
      sym_function_call,
    STATE(106), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(4), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(132), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(994), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [17029] = 28,
    ACTIONS(737), 1,
      anon_sym_TILDE,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(745), 1,
      anon_sym_LBRACE,
    ACTIONS(753), 1,
      aux_sym_number_token1,
    ACTIONS(759), 1,
      sym__single_quote_string_start,
    ACTIONS(761), 1,
      sym__double_quote_string_start,
    ACTIONS(974), 1,
      anon_sym_LPAREN,
    ACTIONS(978), 1,
      anon_sym_LBRACK,
    STATE(452), 1,
      sym__keywords,
    STATE(518), 1,
      sym_boolean,
    STATE(632), 1,
      sym_number,
    STATE(636), 1,
      sym_cell,
    STATE(705), 1,
      sym_binary_operator,
    STATE(706), 1,
      sym_unary_operator,
    STATE(729), 1,
      sym_not_operator,
    STATE(908), 1,
      sym__binary_expression,
    STATE(1370), 1,
      sym_indirect_access,
    STATE(1461), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(735), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(755), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(757), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(459), 2,
      sym_identifier,
      sym_function_call,
    STATE(635), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(704), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(1046), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [17135] = 27,
    ACTIONS(980), 1,
      anon_sym_LPAREN,
    ACTIONS(984), 1,
      anon_sym_TILDE,
    ACTIONS(990), 1,
      anon_sym_LBRACK,
    ACTIONS(992), 1,
      anon_sym_LBRACE,
    ACTIONS(996), 1,
      aux_sym_number_token1,
    ACTIONS(1002), 1,
      sym__single_quote_string_start,
    ACTIONS(1004), 1,
      sym__double_quote_string_start,
    ACTIONS(1010), 1,
      anon_sym_QMARK,
    ACTIONS(1012), 1,
      anon_sym_AT,
    STATE(93), 1,
      sym__keywords,
    STATE(95), 1,
      sym_boolean,
    STATE(105), 1,
      sym_unary_operator,
    STATE(107), 1,
      sym_cell,
    STATE(133), 1,
      sym_binary_operator,
    STATE(150), 1,
      sym_not_operator,
    STATE(918), 1,
      sym__binary_expression,
    STATE(1342), 1,
      sym_indirect_access,
    STATE(1470), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(998), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1000), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(74), 2,
      sym_identifier,
      sym_function_call,
    STATE(106), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(154), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(132), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(994), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [17239] = 27,
    ACTIONS(980), 1,
      anon_sym_LPAREN,
    ACTIONS(984), 1,
      anon_sym_TILDE,
    ACTIONS(990), 1,
      anon_sym_LBRACK,
    ACTIONS(992), 1,
      anon_sym_LBRACE,
    ACTIONS(996), 1,
      aux_sym_number_token1,
    ACTIONS(1002), 1,
      sym__single_quote_string_start,
    ACTIONS(1004), 1,
      sym__double_quote_string_start,
    ACTIONS(1010), 1,
      anon_sym_QMARK,
    ACTIONS(1012), 1,
      anon_sym_AT,
    STATE(93), 1,
      sym__keywords,
    STATE(95), 1,
      sym_boolean,
    STATE(105), 1,
      sym_unary_operator,
    STATE(107), 1,
      sym_cell,
    STATE(133), 1,
      sym_binary_operator,
    STATE(150), 1,
      sym_not_operator,
    STATE(918), 1,
      sym__binary_expression,
    STATE(1342), 1,
      sym_indirect_access,
    STATE(1470), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(998), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1000), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(74), 2,
      sym_identifier,
      sym_function_call,
    STATE(106), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(243), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(132), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(994), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [17343] = 27,
    ACTIONS(980), 1,
      anon_sym_LPAREN,
    ACTIONS(984), 1,
      anon_sym_TILDE,
    ACTIONS(990), 1,
      anon_sym_LBRACK,
    ACTIONS(992), 1,
      anon_sym_LBRACE,
    ACTIONS(996), 1,
      aux_sym_number_token1,
    ACTIONS(1002), 1,
      sym__single_quote_string_start,
    ACTIONS(1004), 1,
      sym__double_quote_string_start,
    ACTIONS(1010), 1,
      anon_sym_QMARK,
    ACTIONS(1012), 1,
      anon_sym_AT,
    STATE(93), 1,
      sym__keywords,
    STATE(95), 1,
      sym_boolean,
    STATE(105), 1,
      sym_unary_operator,
    STATE(107), 1,
      sym_cell,
    STATE(133), 1,
      sym_binary_operator,
    STATE(150), 1,
      sym_not_operator,
    STATE(918), 1,
      sym__binary_expression,
    STATE(1342), 1,
      sym_indirect_access,
    STATE(1470), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(998), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1000), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(74), 2,
      sym_identifier,
      sym_function_call,
    STATE(106), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(153), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(132), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(994), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [17447] = 27,
    ACTIONS(7), 1,
      anon_sym_LPAREN,
    ACTIONS(13), 1,
      anon_sym_QMARK,
    ACTIONS(15), 1,
      anon_sym_AT,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(51), 1,
      aux_sym_number_token1,
    ACTIONS(59), 1,
      sym__single_quote_string_start,
    ACTIONS(61), 1,
      sym__double_quote_string_start,
    ACTIONS(968), 1,
      anon_sym_TILDE,
    STATE(373), 1,
      sym__keywords,
    STATE(397), 1,
      sym_boolean,
    STATE(471), 1,
      sym_cell,
    STATE(519), 1,
      sym_binary_operator,
    STATE(528), 1,
      sym_unary_operator,
    STATE(549), 1,
      sym_not_operator,
    STATE(910), 1,
      sym__binary_expression,
    STATE(1361), 1,
      sym_indirect_access,
    STATE(1509), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(9), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(53), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(55), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(377), 2,
      sym_identifier,
      sym_function_call,
    STATE(498), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(899), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(512), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(41), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [17551] = 28,
    ACTIONS(737), 1,
      anon_sym_TILDE,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(745), 1,
      anon_sym_LBRACE,
    ACTIONS(753), 1,
      aux_sym_number_token1,
    ACTIONS(759), 1,
      sym__single_quote_string_start,
    ACTIONS(761), 1,
      sym__double_quote_string_start,
    ACTIONS(974), 1,
      anon_sym_LPAREN,
    ACTIONS(978), 1,
      anon_sym_LBRACK,
    STATE(452), 1,
      sym__keywords,
    STATE(518), 1,
      sym_boolean,
    STATE(632), 1,
      sym_number,
    STATE(636), 1,
      sym_cell,
    STATE(726), 1,
      sym_binary_operator,
    STATE(727), 1,
      sym_unary_operator,
    STATE(729), 1,
      sym_not_operator,
    STATE(908), 1,
      sym__binary_expression,
    STATE(1370), 1,
      sym_indirect_access,
    STATE(1461), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(735), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(755), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(757), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(464), 2,
      sym_identifier,
      sym_function_call,
    STATE(635), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(725), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(1058), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [17657] = 27,
    ACTIONS(980), 1,
      anon_sym_LPAREN,
    ACTIONS(984), 1,
      anon_sym_TILDE,
    ACTIONS(986), 1,
      anon_sym_QMARK,
    ACTIONS(990), 1,
      anon_sym_LBRACK,
    ACTIONS(992), 1,
      anon_sym_LBRACE,
    ACTIONS(996), 1,
      aux_sym_number_token1,
    ACTIONS(1002), 1,
      sym__single_quote_string_start,
    ACTIONS(1004), 1,
      sym__double_quote_string_start,
    ACTIONS(1022), 1,
      anon_sym_AT,
    STATE(93), 1,
      sym__keywords,
    STATE(96), 1,
      sym_boolean,
    STATE(107), 1,
      sym_cell,
    STATE(134), 1,
      sym_unary_operator,
    STATE(136), 1,
      sym_not_operator,
    STATE(138), 1,
      sym_binary_operator,
    STATE(918), 1,
      sym__binary_expression,
    STATE(1342), 1,
      sym_indirect_access,
    STATE(1470), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(998), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1000), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(73), 2,
      sym_identifier,
      sym_function_call,
    STATE(106), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(113), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(135), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(994), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [17761] = 27,
    ACTIONS(7), 1,
      anon_sym_LPAREN,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(51), 1,
      aux_sym_number_token1,
    ACTIONS(59), 1,
      sym__single_quote_string_start,
    ACTIONS(61), 1,
      sym__double_quote_string_start,
    ACTIONS(968), 1,
      anon_sym_TILDE,
    ACTIONS(970), 1,
      anon_sym_QMARK,
    ACTIONS(972), 1,
      anon_sym_AT,
    STATE(373), 1,
      sym__keywords,
    STATE(404), 1,
      sym_boolean,
    STATE(462), 1,
      sym_binary_operator,
    STATE(463), 1,
      sym_not_operator,
    STATE(471), 1,
      sym_cell,
    STATE(513), 1,
      sym_unary_operator,
    STATE(910), 1,
      sym__binary_expression,
    STATE(1361), 1,
      sym_indirect_access,
    STATE(1509), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(9), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(53), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(55), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(374), 2,
      sym_identifier,
      sym_function_call,
    STATE(498), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(529), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(461), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(41), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [17865] = 27,
    ACTIONS(7), 1,
      anon_sym_LPAREN,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(51), 1,
      aux_sym_number_token1,
    ACTIONS(59), 1,
      sym__single_quote_string_start,
    ACTIONS(61), 1,
      sym__double_quote_string_start,
    ACTIONS(968), 1,
      anon_sym_TILDE,
    ACTIONS(970), 1,
      anon_sym_QMARK,
    ACTIONS(972), 1,
      anon_sym_AT,
    STATE(373), 1,
      sym__keywords,
    STATE(404), 1,
      sym_boolean,
    STATE(462), 1,
      sym_binary_operator,
    STATE(463), 1,
      sym_not_operator,
    STATE(471), 1,
      sym_cell,
    STATE(513), 1,
      sym_unary_operator,
    STATE(910), 1,
      sym__binary_expression,
    STATE(1361), 1,
      sym_indirect_access,
    STATE(1509), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(9), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(53), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(55), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(374), 2,
      sym_identifier,
      sym_function_call,
    STATE(498), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(514), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(461), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(41), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [17969] = 27,
    ACTIONS(7), 1,
      anon_sym_LPAREN,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(51), 1,
      aux_sym_number_token1,
    ACTIONS(59), 1,
      sym__single_quote_string_start,
    ACTIONS(61), 1,
      sym__double_quote_string_start,
    ACTIONS(968), 1,
      anon_sym_TILDE,
    ACTIONS(970), 1,
      anon_sym_QMARK,
    ACTIONS(972), 1,
      anon_sym_AT,
    STATE(373), 1,
      sym__keywords,
    STATE(404), 1,
      sym_boolean,
    STATE(462), 1,
      sym_binary_operator,
    STATE(463), 1,
      sym_not_operator,
    STATE(471), 1,
      sym_cell,
    STATE(513), 1,
      sym_unary_operator,
    STATE(910), 1,
      sym__binary_expression,
    STATE(1361), 1,
      sym_indirect_access,
    STATE(1509), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(9), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(53), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(55), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(374), 2,
      sym_identifier,
      sym_function_call,
    STATE(498), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(515), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(461), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(41), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [18073] = 27,
    ACTIONS(737), 1,
      anon_sym_TILDE,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(745), 1,
      anon_sym_LBRACE,
    ACTIONS(753), 1,
      aux_sym_number_token1,
    ACTIONS(759), 1,
      sym__single_quote_string_start,
    ACTIONS(761), 1,
      sym__double_quote_string_start,
    ACTIONS(974), 1,
      anon_sym_LPAREN,
    ACTIONS(978), 1,
      anon_sym_LBRACK,
    STATE(452), 1,
      sym__keywords,
    STATE(518), 1,
      sym_boolean,
    STATE(636), 1,
      sym_cell,
    STATE(637), 1,
      sym_unary_operator,
    STATE(639), 1,
      sym_binary_operator,
    STATE(729), 1,
      sym_not_operator,
    STATE(908), 1,
      sym__binary_expression,
    STATE(1370), 1,
      sym_indirect_access,
    STATE(1461), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(735), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(755), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(757), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(421), 2,
      sym_identifier,
      sym_function_call,
    STATE(635), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1043), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(632), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [18177] = 27,
    ACTIONS(687), 1,
      aux_sym_number_token1,
    ACTIONS(691), 1,
      sym__single_quote_string_start,
    ACTIONS(693), 1,
      sym__double_quote_string_start,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(823), 1,
      anon_sym_LBRACE,
    ACTIONS(840), 1,
      anon_sym_TILDE,
    ACTIONS(964), 1,
      anon_sym_LPAREN,
    ACTIONS(966), 1,
      anon_sym_LBRACK,
    STATE(417), 1,
      sym_boolean,
    STATE(445), 1,
      sym__keywords,
    STATE(554), 1,
      sym_unary_operator,
    STATE(555), 1,
      sym_not_operator,
    STATE(556), 1,
      sym_cell,
    STATE(742), 1,
      sym_binary_operator,
    STATE(908), 1,
      sym__binary_expression,
    STATE(1321), 1,
      sym_indirect_access,
    STATE(1461), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(813), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(827), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(829), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(400), 2,
      sym_identifier,
      sym_function_call,
    STATE(635), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1058), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(553), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(695), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [18281] = 27,
    ACTIONS(737), 1,
      anon_sym_TILDE,
    ACTIONS(745), 1,
      anon_sym_LBRACE,
    ACTIONS(753), 1,
      aux_sym_number_token1,
    ACTIONS(759), 1,
      sym__single_quote_string_start,
    ACTIONS(761), 1,
      sym__double_quote_string_start,
    ACTIONS(974), 1,
      anon_sym_LPAREN,
    ACTIONS(978), 1,
      anon_sym_LBRACK,
    ACTIONS(1006), 1,
      anon_sym_QMARK,
    ACTIONS(1008), 1,
      anon_sym_AT,
    STATE(452), 1,
      sym__keywords,
    STATE(496), 1,
      sym_boolean,
    STATE(633), 1,
      sym_unary_operator,
    STATE(636), 1,
      sym_cell,
    STATE(641), 1,
      sym_not_operator,
    STATE(673), 1,
      sym_binary_operator,
    STATE(908), 1,
      sym__binary_expression,
    STATE(1370), 1,
      sym_indirect_access,
    STATE(1461), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(735), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(755), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(757), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(419), 2,
      sym_identifier,
      sym_function_call,
    STATE(635), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(650), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(631), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [18385] = 27,
    ACTIONS(737), 1,
      anon_sym_TILDE,
    ACTIONS(745), 1,
      anon_sym_LBRACE,
    ACTIONS(753), 1,
      aux_sym_number_token1,
    ACTIONS(759), 1,
      sym__single_quote_string_start,
    ACTIONS(761), 1,
      sym__double_quote_string_start,
    ACTIONS(974), 1,
      anon_sym_LPAREN,
    ACTIONS(978), 1,
      anon_sym_LBRACK,
    ACTIONS(1006), 1,
      anon_sym_QMARK,
    ACTIONS(1008), 1,
      anon_sym_AT,
    STATE(452), 1,
      sym__keywords,
    STATE(496), 1,
      sym_boolean,
    STATE(633), 1,
      sym_unary_operator,
    STATE(636), 1,
      sym_cell,
    STATE(641), 1,
      sym_not_operator,
    STATE(673), 1,
      sym_binary_operator,
    STATE(908), 1,
      sym__binary_expression,
    STATE(1370), 1,
      sym_indirect_access,
    STATE(1461), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(735), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(755), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(757), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(419), 2,
      sym_identifier,
      sym_function_call,
    STATE(635), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(647), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(631), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [18489] = 27,
    ACTIONS(737), 1,
      anon_sym_TILDE,
    ACTIONS(745), 1,
      anon_sym_LBRACE,
    ACTIONS(753), 1,
      aux_sym_number_token1,
    ACTIONS(759), 1,
      sym__single_quote_string_start,
    ACTIONS(761), 1,
      sym__double_quote_string_start,
    ACTIONS(974), 1,
      anon_sym_LPAREN,
    ACTIONS(978), 1,
      anon_sym_LBRACK,
    ACTIONS(1006), 1,
      anon_sym_QMARK,
    ACTIONS(1008), 1,
      anon_sym_AT,
    STATE(452), 1,
      sym__keywords,
    STATE(496), 1,
      sym_boolean,
    STATE(633), 1,
      sym_unary_operator,
    STATE(636), 1,
      sym_cell,
    STATE(641), 1,
      sym_not_operator,
    STATE(673), 1,
      sym_binary_operator,
    STATE(908), 1,
      sym__binary_expression,
    STATE(1370), 1,
      sym_indirect_access,
    STATE(1461), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(735), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(755), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(757), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(419), 2,
      sym_identifier,
      sym_function_call,
    STATE(635), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(648), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(631), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [18593] = 27,
    ACTIONS(737), 1,
      anon_sym_TILDE,
    ACTIONS(745), 1,
      anon_sym_LBRACE,
    ACTIONS(753), 1,
      aux_sym_number_token1,
    ACTIONS(759), 1,
      sym__single_quote_string_start,
    ACTIONS(761), 1,
      sym__double_quote_string_start,
    ACTIONS(974), 1,
      anon_sym_LPAREN,
    ACTIONS(978), 1,
      anon_sym_LBRACK,
    ACTIONS(1006), 1,
      anon_sym_QMARK,
    ACTIONS(1008), 1,
      anon_sym_AT,
    STATE(452), 1,
      sym__keywords,
    STATE(496), 1,
      sym_boolean,
    STATE(633), 1,
      sym_unary_operator,
    STATE(636), 1,
      sym_cell,
    STATE(641), 1,
      sym_not_operator,
    STATE(673), 1,
      sym_binary_operator,
    STATE(908), 1,
      sym__binary_expression,
    STATE(1370), 1,
      sym_indirect_access,
    STATE(1461), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(735), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(755), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(757), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(419), 2,
      sym_identifier,
      sym_function_call,
    STATE(635), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(649), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(631), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [18697] = 27,
    ACTIONS(737), 1,
      anon_sym_TILDE,
    ACTIONS(745), 1,
      anon_sym_LBRACE,
    ACTIONS(753), 1,
      aux_sym_number_token1,
    ACTIONS(759), 1,
      sym__single_quote_string_start,
    ACTIONS(761), 1,
      sym__double_quote_string_start,
    ACTIONS(974), 1,
      anon_sym_LPAREN,
    ACTIONS(978), 1,
      anon_sym_LBRACK,
    ACTIONS(1006), 1,
      anon_sym_QMARK,
    ACTIONS(1008), 1,
      anon_sym_AT,
    STATE(452), 1,
      sym__keywords,
    STATE(496), 1,
      sym_boolean,
    STATE(633), 1,
      sym_unary_operator,
    STATE(636), 1,
      sym_cell,
    STATE(641), 1,
      sym_not_operator,
    STATE(673), 1,
      sym_binary_operator,
    STATE(908), 1,
      sym__binary_expression,
    STATE(1370), 1,
      sym_indirect_access,
    STATE(1461), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(735), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(755), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(757), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(419), 2,
      sym_identifier,
      sym_function_call,
    STATE(635), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(653), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(631), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [18801] = 27,
    ACTIONS(687), 1,
      aux_sym_number_token1,
    ACTIONS(691), 1,
      sym__single_quote_string_start,
    ACTIONS(693), 1,
      sym__double_quote_string_start,
    ACTIONS(823), 1,
      anon_sym_LBRACE,
    ACTIONS(840), 1,
      anon_sym_TILDE,
    ACTIONS(964), 1,
      anon_sym_LPAREN,
    ACTIONS(966), 1,
      anon_sym_LBRACK,
    ACTIONS(1016), 1,
      anon_sym_QMARK,
    ACTIONS(1024), 1,
      anon_sym_AT,
    STATE(440), 1,
      sym_boolean,
    STATE(445), 1,
      sym__keywords,
    STATE(551), 1,
      sym_cell,
    STATE(559), 1,
      sym_unary_operator,
    STATE(566), 1,
      sym_not_operator,
    STATE(571), 1,
      sym_binary_operator,
    STATE(914), 1,
      sym__binary_expression,
    STATE(1321), 1,
      sym_indirect_access,
    STATE(1465), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(813), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(827), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(829), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(398), 2,
      sym_identifier,
      sym_function_call,
    STATE(550), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(582), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(565), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(695), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [18905] = 27,
    ACTIONS(687), 1,
      aux_sym_number_token1,
    ACTIONS(691), 1,
      sym__single_quote_string_start,
    ACTIONS(693), 1,
      sym__double_quote_string_start,
    ACTIONS(823), 1,
      anon_sym_LBRACE,
    ACTIONS(840), 1,
      anon_sym_TILDE,
    ACTIONS(964), 1,
      anon_sym_LPAREN,
    ACTIONS(966), 1,
      anon_sym_LBRACK,
    ACTIONS(1016), 1,
      anon_sym_QMARK,
    ACTIONS(1024), 1,
      anon_sym_AT,
    STATE(440), 1,
      sym_boolean,
    STATE(445), 1,
      sym__keywords,
    STATE(551), 1,
      sym_cell,
    STATE(559), 1,
      sym_unary_operator,
    STATE(566), 1,
      sym_not_operator,
    STATE(571), 1,
      sym_binary_operator,
    STATE(914), 1,
      sym__binary_expression,
    STATE(1321), 1,
      sym_indirect_access,
    STATE(1465), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(813), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(827), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(829), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(398), 2,
      sym_identifier,
      sym_function_call,
    STATE(550), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(588), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(565), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(695), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [19009] = 27,
    ACTIONS(687), 1,
      aux_sym_number_token1,
    ACTIONS(691), 1,
      sym__single_quote_string_start,
    ACTIONS(693), 1,
      sym__double_quote_string_start,
    ACTIONS(823), 1,
      anon_sym_LBRACE,
    ACTIONS(840), 1,
      anon_sym_TILDE,
    ACTIONS(964), 1,
      anon_sym_LPAREN,
    ACTIONS(966), 1,
      anon_sym_LBRACK,
    ACTIONS(1016), 1,
      anon_sym_QMARK,
    ACTIONS(1024), 1,
      anon_sym_AT,
    STATE(440), 1,
      sym_boolean,
    STATE(445), 1,
      sym__keywords,
    STATE(551), 1,
      sym_cell,
    STATE(559), 1,
      sym_unary_operator,
    STATE(566), 1,
      sym_not_operator,
    STATE(571), 1,
      sym_binary_operator,
    STATE(914), 1,
      sym__binary_expression,
    STATE(1321), 1,
      sym_indirect_access,
    STATE(1465), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(813), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(827), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(829), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(398), 2,
      sym_identifier,
      sym_function_call,
    STATE(550), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(589), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(565), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(695), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [19113] = 27,
    ACTIONS(7), 1,
      anon_sym_LPAREN,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(51), 1,
      aux_sym_number_token1,
    ACTIONS(59), 1,
      sym__single_quote_string_start,
    ACTIONS(61), 1,
      sym__double_quote_string_start,
    ACTIONS(968), 1,
      anon_sym_TILDE,
    ACTIONS(970), 1,
      anon_sym_QMARK,
    ACTIONS(1020), 1,
      anon_sym_AT,
    STATE(373), 1,
      sym__keywords,
    STATE(397), 1,
      sym_boolean,
    STATE(471), 1,
      sym_cell,
    STATE(519), 1,
      sym_binary_operator,
    STATE(528), 1,
      sym_unary_operator,
    STATE(549), 1,
      sym_not_operator,
    STATE(910), 1,
      sym__binary_expression,
    STATE(1361), 1,
      sym_indirect_access,
    STATE(1509), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(9), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(53), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(55), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(377), 2,
      sym_identifier,
      sym_function_call,
    STATE(498), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(612), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(512), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(41), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [19217] = 27,
    ACTIONS(7), 1,
      anon_sym_LPAREN,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(51), 1,
      aux_sym_number_token1,
    ACTIONS(59), 1,
      sym__single_quote_string_start,
    ACTIONS(61), 1,
      sym__double_quote_string_start,
    ACTIONS(968), 1,
      anon_sym_TILDE,
    ACTIONS(970), 1,
      anon_sym_QMARK,
    ACTIONS(1020), 1,
      anon_sym_AT,
    STATE(373), 1,
      sym__keywords,
    STATE(397), 1,
      sym_boolean,
    STATE(471), 1,
      sym_cell,
    STATE(519), 1,
      sym_binary_operator,
    STATE(528), 1,
      sym_unary_operator,
    STATE(549), 1,
      sym_not_operator,
    STATE(910), 1,
      sym__binary_expression,
    STATE(1361), 1,
      sym_indirect_access,
    STATE(1509), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(9), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(53), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(55), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(377), 2,
      sym_identifier,
      sym_function_call,
    STATE(498), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(619), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(512), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(41), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [19321] = 27,
    ACTIONS(980), 1,
      anon_sym_LPAREN,
    ACTIONS(984), 1,
      anon_sym_TILDE,
    ACTIONS(986), 1,
      anon_sym_QMARK,
    ACTIONS(990), 1,
      anon_sym_LBRACK,
    ACTIONS(992), 1,
      anon_sym_LBRACE,
    ACTIONS(996), 1,
      aux_sym_number_token1,
    ACTIONS(1002), 1,
      sym__single_quote_string_start,
    ACTIONS(1004), 1,
      sym__double_quote_string_start,
    ACTIONS(1022), 1,
      anon_sym_AT,
    STATE(93), 1,
      sym__keywords,
    STATE(96), 1,
      sym_boolean,
    STATE(107), 1,
      sym_cell,
    STATE(134), 1,
      sym_unary_operator,
    STATE(136), 1,
      sym_not_operator,
    STATE(138), 1,
      sym_binary_operator,
    STATE(918), 1,
      sym__binary_expression,
    STATE(1342), 1,
      sym_indirect_access,
    STATE(1470), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(998), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1000), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(73), 2,
      sym_identifier,
      sym_function_call,
    STATE(106), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(120), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(135), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(994), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [19425] = 27,
    ACTIONS(980), 1,
      anon_sym_LPAREN,
    ACTIONS(984), 1,
      anon_sym_TILDE,
    ACTIONS(986), 1,
      anon_sym_QMARK,
    ACTIONS(990), 1,
      anon_sym_LBRACK,
    ACTIONS(992), 1,
      anon_sym_LBRACE,
    ACTIONS(996), 1,
      aux_sym_number_token1,
    ACTIONS(1002), 1,
      sym__single_quote_string_start,
    ACTIONS(1004), 1,
      sym__double_quote_string_start,
    ACTIONS(1022), 1,
      anon_sym_AT,
    STATE(93), 1,
      sym__keywords,
    STATE(96), 1,
      sym_boolean,
    STATE(107), 1,
      sym_cell,
    STATE(134), 1,
      sym_unary_operator,
    STATE(136), 1,
      sym_not_operator,
    STATE(138), 1,
      sym_binary_operator,
    STATE(918), 1,
      sym__binary_expression,
    STATE(1342), 1,
      sym_indirect_access,
    STATE(1470), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(998), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1000), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(73), 2,
      sym_identifier,
      sym_function_call,
    STATE(106), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(146), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(135), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(994), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [19529] = 27,
    ACTIONS(980), 1,
      anon_sym_LPAREN,
    ACTIONS(984), 1,
      anon_sym_TILDE,
    ACTIONS(986), 1,
      anon_sym_QMARK,
    ACTIONS(990), 1,
      anon_sym_LBRACK,
    ACTIONS(992), 1,
      anon_sym_LBRACE,
    ACTIONS(996), 1,
      aux_sym_number_token1,
    ACTIONS(1002), 1,
      sym__single_quote_string_start,
    ACTIONS(1004), 1,
      sym__double_quote_string_start,
    ACTIONS(1022), 1,
      anon_sym_AT,
    STATE(93), 1,
      sym__keywords,
    STATE(96), 1,
      sym_boolean,
    STATE(107), 1,
      sym_cell,
    STATE(134), 1,
      sym_unary_operator,
    STATE(136), 1,
      sym_not_operator,
    STATE(138), 1,
      sym_binary_operator,
    STATE(918), 1,
      sym__binary_expression,
    STATE(1342), 1,
      sym_indirect_access,
    STATE(1470), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(998), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1000), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(73), 2,
      sym_identifier,
      sym_function_call,
    STATE(106), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(147), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(135), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(994), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [19633] = 27,
    ACTIONS(687), 1,
      aux_sym_number_token1,
    ACTIONS(691), 1,
      sym__single_quote_string_start,
    ACTIONS(693), 1,
      sym__double_quote_string_start,
    ACTIONS(823), 1,
      anon_sym_LBRACE,
    ACTIONS(840), 1,
      anon_sym_TILDE,
    ACTIONS(964), 1,
      anon_sym_LPAREN,
    ACTIONS(966), 1,
      anon_sym_LBRACK,
    ACTIONS(1016), 1,
      anon_sym_QMARK,
    ACTIONS(1024), 1,
      anon_sym_AT,
    STATE(440), 1,
      sym_boolean,
    STATE(445), 1,
      sym__keywords,
    STATE(551), 1,
      sym_cell,
    STATE(559), 1,
      sym_unary_operator,
    STATE(566), 1,
      sym_not_operator,
    STATE(571), 1,
      sym_binary_operator,
    STATE(914), 1,
      sym__binary_expression,
    STATE(1321), 1,
      sym_indirect_access,
    STATE(1465), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(813), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(827), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(829), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(398), 2,
      sym_identifier,
      sym_function_call,
    STATE(550), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(590), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(565), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(695), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [19737] = 27,
    ACTIONS(687), 1,
      aux_sym_number_token1,
    ACTIONS(691), 1,
      sym__single_quote_string_start,
    ACTIONS(693), 1,
      sym__double_quote_string_start,
    ACTIONS(823), 1,
      anon_sym_LBRACE,
    ACTIONS(840), 1,
      anon_sym_TILDE,
    ACTIONS(964), 1,
      anon_sym_LPAREN,
    ACTIONS(966), 1,
      anon_sym_LBRACK,
    ACTIONS(1016), 1,
      anon_sym_QMARK,
    ACTIONS(1024), 1,
      anon_sym_AT,
    STATE(440), 1,
      sym_boolean,
    STATE(445), 1,
      sym__keywords,
    STATE(551), 1,
      sym_cell,
    STATE(559), 1,
      sym_unary_operator,
    STATE(566), 1,
      sym_not_operator,
    STATE(571), 1,
      sym_binary_operator,
    STATE(914), 1,
      sym__binary_expression,
    STATE(1321), 1,
      sym_indirect_access,
    STATE(1465), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(813), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(827), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(829), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(398), 2,
      sym_identifier,
      sym_function_call,
    STATE(550), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(592), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(565), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(695), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [19841] = 27,
    ACTIONS(980), 1,
      anon_sym_LPAREN,
    ACTIONS(984), 1,
      anon_sym_TILDE,
    ACTIONS(986), 1,
      anon_sym_QMARK,
    ACTIONS(990), 1,
      anon_sym_LBRACK,
    ACTIONS(992), 1,
      anon_sym_LBRACE,
    ACTIONS(996), 1,
      aux_sym_number_token1,
    ACTIONS(1002), 1,
      sym__single_quote_string_start,
    ACTIONS(1004), 1,
      sym__double_quote_string_start,
    ACTIONS(1022), 1,
      anon_sym_AT,
    STATE(93), 1,
      sym__keywords,
    STATE(96), 1,
      sym_boolean,
    STATE(107), 1,
      sym_cell,
    STATE(134), 1,
      sym_unary_operator,
    STATE(136), 1,
      sym_not_operator,
    STATE(138), 1,
      sym_binary_operator,
    STATE(918), 1,
      sym__binary_expression,
    STATE(1342), 1,
      sym_indirect_access,
    STATE(1470), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(998), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1000), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(73), 2,
      sym_identifier,
      sym_function_call,
    STATE(106), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(148), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(135), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(994), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [19945] = 27,
    ACTIONS(980), 1,
      anon_sym_LPAREN,
    ACTIONS(984), 1,
      anon_sym_TILDE,
    ACTIONS(986), 1,
      anon_sym_QMARK,
    ACTIONS(990), 1,
      anon_sym_LBRACK,
    ACTIONS(992), 1,
      anon_sym_LBRACE,
    ACTIONS(996), 1,
      aux_sym_number_token1,
    ACTIONS(1002), 1,
      sym__single_quote_string_start,
    ACTIONS(1004), 1,
      sym__double_quote_string_start,
    ACTIONS(1022), 1,
      anon_sym_AT,
    STATE(93), 1,
      sym__keywords,
    STATE(96), 1,
      sym_boolean,
    STATE(107), 1,
      sym_cell,
    STATE(134), 1,
      sym_unary_operator,
    STATE(136), 1,
      sym_not_operator,
    STATE(138), 1,
      sym_binary_operator,
    STATE(918), 1,
      sym__binary_expression,
    STATE(1342), 1,
      sym_indirect_access,
    STATE(1470), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(998), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1000), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(73), 2,
      sym_identifier,
      sym_function_call,
    STATE(106), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(124), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(135), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(994), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [20049] = 28,
    ACTIONS(737), 1,
      anon_sym_TILDE,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(745), 1,
      anon_sym_LBRACE,
    ACTIONS(753), 1,
      aux_sym_number_token1,
    ACTIONS(759), 1,
      sym__single_quote_string_start,
    ACTIONS(761), 1,
      sym__double_quote_string_start,
    ACTIONS(974), 1,
      anon_sym_LPAREN,
    ACTIONS(978), 1,
      anon_sym_LBRACK,
    STATE(452), 1,
      sym__keywords,
    STATE(518), 1,
      sym_boolean,
    STATE(632), 1,
      sym_number,
    STATE(636), 1,
      sym_cell,
    STATE(717), 1,
      sym_unary_operator,
    STATE(729), 1,
      sym_not_operator,
    STATE(734), 1,
      sym_binary_operator,
    STATE(908), 1,
      sym__binary_expression,
    STATE(1370), 1,
      sym_indirect_access,
    STATE(1461), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(735), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(755), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(757), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(482), 2,
      sym_identifier,
      sym_function_call,
    STATE(635), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(733), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(1058), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [20155] = 27,
    ACTIONS(687), 1,
      aux_sym_number_token1,
    ACTIONS(691), 1,
      sym__single_quote_string_start,
    ACTIONS(693), 1,
      sym__double_quote_string_start,
    ACTIONS(823), 1,
      anon_sym_LBRACE,
    ACTIONS(840), 1,
      anon_sym_TILDE,
    ACTIONS(964), 1,
      anon_sym_LPAREN,
    ACTIONS(966), 1,
      anon_sym_LBRACK,
    ACTIONS(1016), 1,
      anon_sym_QMARK,
    ACTIONS(1024), 1,
      anon_sym_AT,
    STATE(440), 1,
      sym_boolean,
    STATE(445), 1,
      sym__keywords,
    STATE(551), 1,
      sym_cell,
    STATE(559), 1,
      sym_unary_operator,
    STATE(566), 1,
      sym_not_operator,
    STATE(571), 1,
      sym_binary_operator,
    STATE(914), 1,
      sym__binary_expression,
    STATE(1321), 1,
      sym_indirect_access,
    STATE(1465), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(813), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(827), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(829), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(398), 2,
      sym_identifier,
      sym_function_call,
    STATE(550), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(557), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(565), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(695), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [20259] = 27,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(980), 1,
      anon_sym_LPAREN,
    ACTIONS(984), 1,
      anon_sym_TILDE,
    ACTIONS(990), 1,
      anon_sym_LBRACK,
    ACTIONS(992), 1,
      anon_sym_LBRACE,
    ACTIONS(996), 1,
      aux_sym_number_token1,
    ACTIONS(1002), 1,
      sym__single_quote_string_start,
    ACTIONS(1004), 1,
      sym__double_quote_string_start,
    STATE(93), 1,
      sym__keywords,
    STATE(94), 1,
      sym_boolean,
    STATE(110), 1,
      sym_unary_operator,
    STATE(111), 1,
      sym_not_operator,
    STATE(112), 1,
      sym_cell,
    STATE(743), 1,
      sym_binary_operator,
    STATE(908), 1,
      sym__binary_expression,
    STATE(1342), 1,
      sym_indirect_access,
    STATE(1461), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(998), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1000), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(72), 2,
      sym_identifier,
      sym_function_call,
    STATE(635), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1058), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(109), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(994), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [20363] = 28,
    ACTIONS(737), 1,
      anon_sym_TILDE,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(745), 1,
      anon_sym_LBRACE,
    ACTIONS(753), 1,
      aux_sym_number_token1,
    ACTIONS(759), 1,
      sym__single_quote_string_start,
    ACTIONS(761), 1,
      sym__double_quote_string_start,
    ACTIONS(974), 1,
      anon_sym_LPAREN,
    ACTIONS(978), 1,
      anon_sym_LBRACK,
    STATE(452), 1,
      sym__keywords,
    STATE(518), 1,
      sym_boolean,
    STATE(632), 1,
      sym_number,
    STATE(636), 1,
      sym_cell,
    STATE(716), 1,
      sym_unary_operator,
    STATE(729), 1,
      sym_not_operator,
    STATE(730), 1,
      sym_binary_operator,
    STATE(908), 1,
      sym__binary_expression,
    STATE(1370), 1,
      sym_indirect_access,
    STATE(1461), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(735), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(755), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(757), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(493), 2,
      sym_identifier,
      sym_function_call,
    STATE(635), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(723), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(1058), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [20469] = 28,
    ACTIONS(737), 1,
      anon_sym_TILDE,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(745), 1,
      anon_sym_LBRACE,
    ACTIONS(753), 1,
      aux_sym_number_token1,
    ACTIONS(759), 1,
      sym__single_quote_string_start,
    ACTIONS(761), 1,
      sym__double_quote_string_start,
    ACTIONS(974), 1,
      anon_sym_LPAREN,
    ACTIONS(978), 1,
      anon_sym_LBRACK,
    STATE(452), 1,
      sym__keywords,
    STATE(518), 1,
      sym_boolean,
    STATE(632), 1,
      sym_number,
    STATE(636), 1,
      sym_cell,
    STATE(714), 1,
      sym_binary_operator,
    STATE(715), 1,
      sym_unary_operator,
    STATE(729), 1,
      sym_not_operator,
    STATE(908), 1,
      sym__binary_expression,
    STATE(1370), 1,
      sym_indirect_access,
    STATE(1461), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(735), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(755), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(757), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(460), 2,
      sym_identifier,
      sym_function_call,
    STATE(635), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(713), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(1058), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [20575] = 28,
    ACTIONS(737), 1,
      anon_sym_TILDE,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(745), 1,
      anon_sym_LBRACE,
    ACTIONS(753), 1,
      aux_sym_number_token1,
    ACTIONS(759), 1,
      sym__single_quote_string_start,
    ACTIONS(761), 1,
      sym__double_quote_string_start,
    ACTIONS(974), 1,
      anon_sym_LPAREN,
    ACTIONS(978), 1,
      anon_sym_LBRACK,
    STATE(452), 1,
      sym__keywords,
    STATE(518), 1,
      sym_boolean,
    STATE(632), 1,
      sym_number,
    STATE(636), 1,
      sym_cell,
    STATE(705), 1,
      sym_binary_operator,
    STATE(706), 1,
      sym_unary_operator,
    STATE(729), 1,
      sym_not_operator,
    STATE(908), 1,
      sym__binary_expression,
    STATE(1370), 1,
      sym_indirect_access,
    STATE(1461), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(735), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(755), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(757), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(459), 2,
      sym_identifier,
      sym_function_call,
    STATE(635), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(704), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(1044), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [20681] = 27,
    ACTIONS(737), 1,
      anon_sym_TILDE,
    ACTIONS(745), 1,
      anon_sym_LBRACE,
    ACTIONS(753), 1,
      aux_sym_number_token1,
    ACTIONS(759), 1,
      sym__single_quote_string_start,
    ACTIONS(761), 1,
      sym__double_quote_string_start,
    ACTIONS(974), 1,
      anon_sym_LPAREN,
    ACTIONS(978), 1,
      anon_sym_LBRACK,
    ACTIONS(1006), 1,
      anon_sym_QMARK,
    ACTIONS(1014), 1,
      anon_sym_AT,
    STATE(452), 1,
      sym__keywords,
    STATE(518), 1,
      sym_boolean,
    STATE(636), 1,
      sym_cell,
    STATE(637), 1,
      sym_unary_operator,
    STATE(639), 1,
      sym_binary_operator,
    STATE(729), 1,
      sym_not_operator,
    STATE(908), 1,
      sym__binary_expression,
    STATE(1370), 1,
      sym_indirect_access,
    STATE(1461), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(735), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(755), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(757), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(421), 2,
      sym_identifier,
      sym_function_call,
    STATE(635), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(744), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(632), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [20785] = 27,
    ACTIONS(737), 1,
      anon_sym_TILDE,
    ACTIONS(745), 1,
      anon_sym_LBRACE,
    ACTIONS(753), 1,
      aux_sym_number_token1,
    ACTIONS(759), 1,
      sym__single_quote_string_start,
    ACTIONS(761), 1,
      sym__double_quote_string_start,
    ACTIONS(974), 1,
      anon_sym_LPAREN,
    ACTIONS(978), 1,
      anon_sym_LBRACK,
    ACTIONS(1006), 1,
      anon_sym_QMARK,
    ACTIONS(1014), 1,
      anon_sym_AT,
    STATE(452), 1,
      sym__keywords,
    STATE(518), 1,
      sym_boolean,
    STATE(636), 1,
      sym_cell,
    STATE(637), 1,
      sym_unary_operator,
    STATE(639), 1,
      sym_binary_operator,
    STATE(729), 1,
      sym_not_operator,
    STATE(908), 1,
      sym__binary_expression,
    STATE(1370), 1,
      sym_indirect_access,
    STATE(1461), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(735), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(755), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(757), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(421), 2,
      sym_identifier,
      sym_function_call,
    STATE(635), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(736), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(632), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [20889] = 27,
    ACTIONS(687), 1,
      aux_sym_number_token1,
    ACTIONS(691), 1,
      sym__single_quote_string_start,
    ACTIONS(693), 1,
      sym__double_quote_string_start,
    ACTIONS(823), 1,
      anon_sym_LBRACE,
    ACTIONS(840), 1,
      anon_sym_TILDE,
    ACTIONS(964), 1,
      anon_sym_LPAREN,
    ACTIONS(966), 1,
      anon_sym_LBRACK,
    ACTIONS(1016), 1,
      anon_sym_QMARK,
    ACTIONS(1018), 1,
      anon_sym_AT,
    STATE(424), 1,
      sym_boolean,
    STATE(445), 1,
      sym__keywords,
    STATE(547), 1,
      sym_binary_operator,
    STATE(548), 1,
      sym_unary_operator,
    STATE(551), 1,
      sym_cell,
    STATE(642), 1,
      sym_not_operator,
    STATE(914), 1,
      sym__binary_expression,
    STATE(1321), 1,
      sym_indirect_access,
    STATE(1465), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(813), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(827), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(829), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(396), 2,
      sym_identifier,
      sym_function_call,
    STATE(550), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(695), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(546), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(695), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [20993] = 27,
    ACTIONS(687), 1,
      aux_sym_number_token1,
    ACTIONS(691), 1,
      sym__single_quote_string_start,
    ACTIONS(693), 1,
      sym__double_quote_string_start,
    ACTIONS(823), 1,
      anon_sym_LBRACE,
    ACTIONS(840), 1,
      anon_sym_TILDE,
    ACTIONS(964), 1,
      anon_sym_LPAREN,
    ACTIONS(966), 1,
      anon_sym_LBRACK,
    ACTIONS(1016), 1,
      anon_sym_QMARK,
    ACTIONS(1018), 1,
      anon_sym_AT,
    STATE(424), 1,
      sym_boolean,
    STATE(445), 1,
      sym__keywords,
    STATE(547), 1,
      sym_binary_operator,
    STATE(548), 1,
      sym_unary_operator,
    STATE(551), 1,
      sym_cell,
    STATE(642), 1,
      sym_not_operator,
    STATE(914), 1,
      sym__binary_expression,
    STATE(1321), 1,
      sym_indirect_access,
    STATE(1465), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(813), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(827), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(829), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(396), 2,
      sym_identifier,
      sym_function_call,
    STATE(550), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(701), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(546), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(695), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [21097] = 27,
    ACTIONS(980), 1,
      anon_sym_LPAREN,
    ACTIONS(984), 1,
      anon_sym_TILDE,
    ACTIONS(986), 1,
      anon_sym_QMARK,
    ACTIONS(988), 1,
      anon_sym_AT,
    ACTIONS(990), 1,
      anon_sym_LBRACK,
    ACTIONS(992), 1,
      anon_sym_LBRACE,
    ACTIONS(996), 1,
      aux_sym_number_token1,
    ACTIONS(1002), 1,
      sym__single_quote_string_start,
    ACTIONS(1004), 1,
      sym__double_quote_string_start,
    STATE(93), 1,
      sym__keywords,
    STATE(95), 1,
      sym_boolean,
    STATE(105), 1,
      sym_unary_operator,
    STATE(107), 1,
      sym_cell,
    STATE(133), 1,
      sym_binary_operator,
    STATE(150), 1,
      sym_not_operator,
    STATE(918), 1,
      sym__binary_expression,
    STATE(1342), 1,
      sym_indirect_access,
    STATE(1470), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(998), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1000), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(74), 2,
      sym_identifier,
      sym_function_call,
    STATE(106), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(154), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(132), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(994), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [21201] = 25,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(980), 1,
      anon_sym_LPAREN,
    ACTIONS(984), 1,
      anon_sym_TILDE,
    ACTIONS(990), 1,
      anon_sym_LBRACK,
    ACTIONS(992), 1,
      anon_sym_LBRACE,
    ACTIONS(996), 1,
      aux_sym_number_token1,
    ACTIONS(1002), 1,
      sym__single_quote_string_start,
    ACTIONS(1004), 1,
      sym__double_quote_string_start,
    STATE(93), 1,
      sym__keywords,
    STATE(98), 1,
      sym_boolean,
    STATE(137), 1,
      sym_cell,
    STATE(140), 1,
      sym_unary_operator,
    STATE(144), 1,
      sym_binary_operator,
    STATE(1342), 1,
      sym_indirect_access,
    STATE(1461), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(998), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1000), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(75), 2,
      sym_identifier,
      sym_function_call,
    STATE(125), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1055), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(139), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(994), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [21301] = 5,
    STATE(367), 1,
      aux_sym__block_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(943), 2,
      anon_sym_end,
      aux_sym_number_token1,
    ACTIONS(1026), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    ACTIONS(939), 40,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      sym__external_identifier,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_return,
      anon_sym_continue,
      anon_sym_break,
      anon_sym_if,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_arguments,
      anon_sym_function,
      anon_sym_endfunction,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_classdef,
      anon_sym_try,
      anon_sym_spmd,
      aux_sym_number_token2,
      aux_sym_number_token3,
      anon_sym_true,
      anon_sym_false,
  [21359] = 5,
    STATE(365), 1,
      aux_sym__block_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(335), 2,
      anon_sym_end,
      aux_sym_number_token1,
    ACTIONS(1028), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    ACTIONS(333), 40,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      sym__external_identifier,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_return,
      anon_sym_continue,
      anon_sym_break,
      anon_sym_if,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_arguments,
      anon_sym_function,
      anon_sym_endfunction,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_classdef,
      anon_sym_try,
      anon_sym_spmd,
      aux_sym_number_token2,
      aux_sym_number_token3,
      anon_sym_true,
      anon_sym_false,
  [21417] = 5,
    STATE(367), 1,
      aux_sym__block_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(947), 2,
      anon_sym_end,
      aux_sym_number_token1,
    ACTIONS(1026), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    ACTIONS(945), 40,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      sym__external_identifier,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_return,
      anon_sym_continue,
      anon_sym_break,
      anon_sym_if,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_arguments,
      anon_sym_function,
      anon_sym_endfunction,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_classdef,
      anon_sym_try,
      anon_sym_spmd,
      aux_sym_number_token2,
      aux_sym_number_token3,
      anon_sym_true,
      anon_sym_false,
  [21475] = 5,
    STATE(363), 1,
      aux_sym__block_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(953), 2,
      anon_sym_end,
      aux_sym_number_token1,
    ACTIONS(1030), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    ACTIONS(949), 40,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      sym__external_identifier,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_return,
      anon_sym_continue,
      anon_sym_break,
      anon_sym_if,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_arguments,
      anon_sym_function,
      anon_sym_endfunction,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_classdef,
      anon_sym_try,
      anon_sym_spmd,
      aux_sym_number_token2,
      aux_sym_number_token3,
      anon_sym_true,
      anon_sym_false,
  [21533] = 5,
    STATE(367), 1,
      aux_sym__block_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(962), 2,
      anon_sym_end,
      aux_sym_number_token1,
    ACTIONS(1032), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    ACTIONS(957), 40,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      sym__external_identifier,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_return,
      anon_sym_continue,
      anon_sym_break,
      anon_sym_if,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_arguments,
      anon_sym_function,
      anon_sym_endfunction,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_classdef,
      anon_sym_try,
      anon_sym_spmd,
      aux_sym_number_token2,
      aux_sym_number_token3,
      anon_sym_true,
      anon_sym_false,
  [21591] = 5,
    ACTIONS(1039), 1,
      anon_sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1037), 2,
      anon_sym_end,
      aux_sym_number_token1,
    STATE(368), 2,
      sym_arguments_statement,
      aux_sym_function_definition_repeat1,
    ACTIONS(1035), 39,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      sym__external_identifier,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_return,
      anon_sym_continue,
      anon_sym_break,
      anon_sym_if,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_endfunction,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_classdef,
      anon_sym_try,
      anon_sym_spmd,
      aux_sym_number_token2,
      aux_sym_number_token3,
      anon_sym_true,
      anon_sym_false,
  [21648] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1044), 2,
      anon_sym_end,
      aux_sym_number_token1,
    ACTIONS(1042), 40,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      sym__external_identifier,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_return,
      anon_sym_continue,
      anon_sym_break,
      anon_sym_if,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_arguments,
      anon_sym_function,
      anon_sym_endfunction,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_classdef,
      anon_sym_try,
      anon_sym_spmd,
      aux_sym_number_token2,
      aux_sym_number_token3,
      anon_sym_true,
      anon_sym_false,
  [21699] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1048), 2,
      anon_sym_end,
      aux_sym_number_token1,
    ACTIONS(1046), 40,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      sym__external_identifier,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_return,
      anon_sym_continue,
      anon_sym_break,
      anon_sym_if,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_arguments,
      anon_sym_function,
      anon_sym_endfunction,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_classdef,
      anon_sym_try,
      anon_sym_spmd,
      aux_sym_number_token2,
      aux_sym_number_token3,
      anon_sym_true,
      anon_sym_false,
  [21750] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1052), 2,
      anon_sym_end,
      aux_sym_number_token1,
    ACTIONS(1050), 40,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      sym__external_identifier,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_return,
      anon_sym_continue,
      anon_sym_break,
      anon_sym_if,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_arguments,
      anon_sym_function,
      anon_sym_endfunction,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_classdef,
      anon_sym_try,
      anon_sym_spmd,
      aux_sym_number_token2,
      aux_sym_number_token3,
      anon_sym_true,
      anon_sym_false,
  [21801] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1056), 2,
      anon_sym_end,
      aux_sym_number_token1,
    ACTIONS(1054), 40,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      sym__external_identifier,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_return,
      anon_sym_continue,
      anon_sym_break,
      anon_sym_if,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_arguments,
      anon_sym_function,
      anon_sym_endfunction,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_classdef,
      anon_sym_try,
      anon_sym_spmd,
      aux_sym_number_token2,
      aux_sym_number_token3,
      anon_sym_true,
      anon_sym_false,
  [21852] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(528), 40,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_vector,
      anon_sym_matrix,
      anon_sym_scalar,
      anon_sym_CR,
  [21899] = 11,
    ACTIONS(453), 1,
      anon_sym_COLON,
    ACTIONS(1058), 1,
      anon_sym_LPAREN,
    ACTIONS(1060), 1,
      anon_sym_DOT,
    ACTIONS(1062), 1,
      anon_sym_AT,
    ACTIONS(1066), 1,
      anon_sym_LBRACE,
    STATE(381), 1,
      sym__args,
    STATE(412), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1064), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(451), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(449), 15,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LF,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [21962] = 9,
    ACTIONS(1058), 1,
      anon_sym_LPAREN,
    ACTIONS(1060), 1,
      anon_sym_DOT,
    ACTIONS(1062), 1,
      anon_sym_AT,
    ACTIONS(1066), 1,
      anon_sym_LBRACE,
    STATE(381), 1,
      sym__args,
    STATE(412), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1064), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(451), 30,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [22021] = 11,
    ACTIONS(1058), 1,
      anon_sym_LPAREN,
    ACTIONS(1060), 1,
      anon_sym_DOT,
    ACTIONS(1062), 1,
      anon_sym_AT,
    ACTIONS(1066), 1,
      anon_sym_LBRACE,
    STATE(381), 1,
      sym__args,
    STATE(412), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1064), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(453), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(458), 8,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
    ACTIONS(451), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [22084] = 11,
    ACTIONS(458), 1,
      anon_sym_COLON,
    ACTIONS(1058), 1,
      anon_sym_LPAREN,
    ACTIONS(1060), 1,
      anon_sym_DOT,
    ACTIONS(1062), 1,
      anon_sym_AT,
    ACTIONS(1066), 1,
      anon_sym_LBRACE,
    STATE(381), 1,
      sym__args,
    STATE(412), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1064), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(451), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(449), 15,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LF,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [22147] = 6,
    ACTIONS(1058), 1,
      anon_sym_LPAREN,
    ACTIONS(1062), 1,
      anon_sym_AT,
    ACTIONS(1066), 1,
      anon_sym_LBRACE,
    STATE(381), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(470), 34,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [22200] = 9,
    ACTIONS(1058), 1,
      anon_sym_LPAREN,
    ACTIONS(1060), 1,
      anon_sym_DOT,
    ACTIONS(1062), 1,
      anon_sym_AT,
    ACTIONS(1066), 1,
      anon_sym_LBRACE,
    STATE(381), 1,
      sym__args,
    STATE(412), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1064), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(435), 30,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [22259] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(512), 37,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [22303] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(534), 37,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [22347] = 10,
    ACTIONS(1068), 1,
      anon_sym_LPAREN,
    ACTIONS(1072), 1,
      anon_sym_else,
    STATE(452), 1,
      sym__keywords,
    STATE(611), 1,
      sym__extended_keywords,
    STATE(1302), 1,
      sym_boolean,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1074), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(454), 3,
      sym_identifier,
      sym_indirect_access,
      sym_function_call,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
    ACTIONS(1070), 19,
      anon_sym_return,
      anon_sym_continue,
      anon_sym_break,
      anon_sym_elseif,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_catch,
      anon_sym_try,
      anon_sym_spmd,
  [22407] = 6,
    ACTIONS(1078), 1,
      anon_sym_LPAREN,
    STATE(1105), 1,
      sym__argument_attributes,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(753), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    ACTIONS(1076), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(1080), 29,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
  [22459] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(516), 37,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [22503] = 10,
    ACTIONS(1082), 1,
      anon_sym_LPAREN,
    ACTIONS(1086), 1,
      anon_sym_else,
    STATE(809), 1,
      sym__keywords,
    STATE(895), 1,
      sym__extended_keywords,
    STATE(1309), 1,
      sym_boolean,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1090), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(818), 3,
      sym_identifier,
      sym_indirect_access,
      sym_function_call,
    ACTIONS(1088), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
    ACTIONS(1084), 19,
      anon_sym_return,
      anon_sym_continue,
      anon_sym_break,
      anon_sym_elseif,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_catch,
      anon_sym_try,
      anon_sym_spmd,
  [22563] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(520), 37,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [22607] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(504), 37,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [22651] = 10,
    ACTIONS(1092), 1,
      anon_sym_LPAREN,
    ACTIONS(1096), 1,
      anon_sym_else,
    STATE(89), 1,
      sym__extended_keywords,
    STATE(93), 1,
      sym__keywords,
    STATE(1344), 1,
      sym_boolean,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1098), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(78), 3,
      sym_identifier,
      sym_indirect_access,
      sym_function_call,
    ACTIONS(994), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
    ACTIONS(1094), 19,
      anon_sym_return,
      anon_sym_continue,
      anon_sym_break,
      anon_sym_elseif,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_catch,
      anon_sym_try,
      anon_sym_spmd,
  [22711] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(524), 37,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [22755] = 10,
    ACTIONS(1100), 1,
      anon_sym_LPAREN,
    ACTIONS(1104), 1,
      anon_sym_else,
    STATE(373), 1,
      sym__keywords,
    STATE(416), 1,
      sym__extended_keywords,
    STATE(1238), 1,
      sym_boolean,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1106), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(378), 3,
      sym_identifier,
      sym_indirect_access,
      sym_function_call,
    ACTIONS(41), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
    ACTIONS(1102), 19,
      anon_sym_return,
      anon_sym_continue,
      anon_sym_break,
      anon_sym_elseif,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_catch,
      anon_sym_try,
      anon_sym_spmd,
  [22815] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(538), 37,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [22859] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(550), 3,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACE,
    ACTIONS(508), 34,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [22905] = 10,
    ACTIONS(1108), 1,
      anon_sym_LPAREN,
    ACTIONS(1112), 1,
      anon_sym_else,
    STATE(445), 1,
      sym__keywords,
    STATE(541), 1,
      sym__extended_keywords,
    STATE(1325), 1,
      sym_boolean,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1114), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(413), 3,
      sym_identifier,
      sym_indirect_access,
      sym_function_call,
    ACTIONS(695), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
    ACTIONS(1110), 19,
      anon_sym_return,
      anon_sym_continue,
      anon_sym_break,
      anon_sym_elseif,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_catch,
      anon_sym_try,
      anon_sym_spmd,
  [22965] = 7,
    ACTIONS(1058), 1,
      anon_sym_LPAREN,
    ACTIONS(1066), 1,
      anon_sym_LBRACE,
    ACTIONS(1116), 1,
      anon_sym_AT,
    STATE(391), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1064), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(451), 30,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [23018] = 10,
    ACTIONS(1118), 1,
      anon_sym_LPAREN,
    ACTIONS(1120), 1,
      anon_sym_DOT,
    ACTIONS(1122), 1,
      anon_sym_AT,
    ACTIONS(1126), 1,
      anon_sym_LBRACE,
    STATE(438), 1,
      sym__args,
    STATE(483), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(460), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1124), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(451), 26,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [23077] = 12,
    ACTIONS(458), 1,
      anon_sym_COLON,
    ACTIONS(1118), 1,
      anon_sym_LPAREN,
    ACTIONS(1120), 1,
      anon_sym_DOT,
    ACTIONS(1122), 1,
      anon_sym_AT,
    ACTIONS(1126), 1,
      anon_sym_LBRACE,
    STATE(438), 1,
      sym__args,
    STATE(483), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(456), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1124), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(449), 11,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(451), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [23140] = 9,
    ACTIONS(458), 1,
      anon_sym_COLON,
    ACTIONS(1058), 1,
      anon_sym_LPAREN,
    ACTIONS(1066), 1,
      anon_sym_LBRACE,
    ACTIONS(1116), 1,
      anon_sym_AT,
    STATE(391), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1064), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(451), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(449), 15,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LF,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [23197] = 12,
    ACTIONS(453), 1,
      anon_sym_COLON,
    ACTIONS(1118), 1,
      anon_sym_LPAREN,
    ACTIONS(1120), 1,
      anon_sym_DOT,
    ACTIONS(1122), 1,
      anon_sym_AT,
    ACTIONS(1126), 1,
      anon_sym_LBRACE,
    STATE(438), 1,
      sym__args,
    STATE(483), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(456), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1124), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(449), 11,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(451), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [23260] = 12,
    ACTIONS(1118), 1,
      anon_sym_LPAREN,
    ACTIONS(1120), 1,
      anon_sym_DOT,
    ACTIONS(1122), 1,
      anon_sym_AT,
    ACTIONS(1126), 1,
      anon_sym_LBRACE,
    STATE(438), 1,
      sym__args,
    STATE(483), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(462), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1124), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(458), 4,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(453), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(451), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [23323] = 10,
    ACTIONS(1118), 1,
      anon_sym_LPAREN,
    ACTIONS(1120), 1,
      anon_sym_DOT,
    ACTIONS(1122), 1,
      anon_sym_AT,
    ACTIONS(1126), 1,
      anon_sym_LBRACE,
    STATE(438), 1,
      sym__args,
    STATE(483), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(447), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1124), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(435), 26,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [23382] = 12,
    ACTIONS(458), 1,
      anon_sym_COLON,
    ACTIONS(1058), 1,
      anon_sym_LPAREN,
    ACTIONS(1060), 1,
      anon_sym_DOT,
    ACTIONS(1062), 1,
      anon_sym_AT,
    ACTIONS(1066), 1,
      anon_sym_LBRACE,
    ACTIONS(1128), 1,
      anon_sym_EQ,
    STATE(381), 1,
      sym__args,
    STATE(412), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1064), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(449), 12,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(451), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [23445] = 9,
    ACTIONS(1058), 1,
      anon_sym_LPAREN,
    ACTIONS(1066), 1,
      anon_sym_LBRACE,
    ACTIONS(1116), 1,
      anon_sym_AT,
    STATE(391), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1064), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(453), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(458), 8,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
    ACTIONS(451), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [23502] = 7,
    ACTIONS(1058), 1,
      anon_sym_LPAREN,
    ACTIONS(1066), 1,
      anon_sym_LBRACE,
    ACTIONS(1116), 1,
      anon_sym_AT,
    STATE(391), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1064), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(435), 30,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [23555] = 9,
    ACTIONS(453), 1,
      anon_sym_COLON,
    ACTIONS(1058), 1,
      anon_sym_LPAREN,
    ACTIONS(1066), 1,
      anon_sym_LBRACE,
    ACTIONS(1116), 1,
      anon_sym_AT,
    STATE(391), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1064), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(451), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(449), 15,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LF,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [23612] = 13,
    ACTIONS(458), 1,
      anon_sym_COLON,
    ACTIONS(1118), 1,
      anon_sym_LPAREN,
    ACTIONS(1120), 1,
      anon_sym_DOT,
    ACTIONS(1122), 1,
      anon_sym_AT,
    ACTIONS(1126), 1,
      anon_sym_LBRACE,
    STATE(438), 1,
      sym__args,
    STATE(483), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1124), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1130), 2,
      anon_sym_SEMI,
      anon_sym_RBRACK,
    ACTIONS(1135), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(449), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1132), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [23676] = 13,
    ACTIONS(1118), 1,
      anon_sym_LPAREN,
    ACTIONS(1120), 1,
      anon_sym_DOT,
    ACTIONS(1122), 1,
      anon_sym_AT,
    ACTIONS(1126), 1,
      anon_sym_LBRACE,
    ACTIONS(1130), 1,
      anon_sym_COLON,
    STATE(438), 1,
      sym__args,
    STATE(483), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1124), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1137), 2,
      anon_sym_SEMI,
      anon_sym_RBRACK,
    ACTIONS(1140), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(449), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1132), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [23740] = 13,
    ACTIONS(1118), 1,
      anon_sym_LPAREN,
    ACTIONS(1120), 1,
      anon_sym_DOT,
    ACTIONS(1122), 1,
      anon_sym_AT,
    ACTIONS(1126), 1,
      anon_sym_LBRACE,
    ACTIONS(1130), 1,
      anon_sym_COLON,
    STATE(438), 1,
      sym__args,
    STATE(483), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1124), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1143), 2,
      anon_sym_SEMI,
      anon_sym_RBRACK,
    ACTIONS(1145), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(449), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1132), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [23804] = 13,
    ACTIONS(458), 1,
      anon_sym_COLON,
    ACTIONS(1118), 1,
      anon_sym_LPAREN,
    ACTIONS(1120), 1,
      anon_sym_DOT,
    ACTIONS(1122), 1,
      anon_sym_AT,
    ACTIONS(1126), 1,
      anon_sym_LBRACE,
    STATE(438), 1,
      sym__args,
    STATE(483), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1124), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1147), 2,
      anon_sym_SEMI,
      anon_sym_RBRACK,
    ACTIONS(1149), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(449), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1132), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [23868] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(550), 35,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_LBRACE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [23910] = 4,
    ACTIONS(1151), 1,
      anon_sym_DOT,
    STATE(410), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(474), 33,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [23956] = 15,
    ACTIONS(1135), 1,
      anon_sym_COLON,
    ACTIONS(1154), 1,
      anon_sym_LPAREN,
    ACTIONS(1159), 1,
      anon_sym_DOT,
    ACTIONS(1161), 1,
      anon_sym_AT,
    ACTIONS(1165), 1,
      anon_sym_LBRACE,
    ACTIONS(1167), 1,
      anon_sym_EQ,
    STATE(465), 1,
      sym__args,
    STATE(568), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(449), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1132), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1163), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1140), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(456), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1156), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [24024] = 4,
    ACTIONS(1060), 1,
      anon_sym_DOT,
    STATE(410), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(500), 33,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [24070] = 7,
    ACTIONS(1118), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_AT,
    ACTIONS(1126), 1,
      anon_sym_LBRACE,
    STATE(438), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(472), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(470), 29,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [24122] = 12,
    ACTIONS(1118), 1,
      anon_sym_LPAREN,
    ACTIONS(1120), 1,
      anon_sym_DOT,
    ACTIONS(1122), 1,
      anon_sym_AT,
    ACTIONS(1126), 1,
      anon_sym_LBRACE,
    STATE(438), 1,
      sym__args,
    STATE(483), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1124), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1135), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1130), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_COLON,
    ACTIONS(449), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1132), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [24184] = 12,
    ACTIONS(1118), 1,
      anon_sym_LPAREN,
    ACTIONS(1120), 1,
      anon_sym_DOT,
    ACTIONS(1122), 1,
      anon_sym_AT,
    ACTIONS(1126), 1,
      anon_sym_LBRACE,
    STATE(438), 1,
      sym__args,
    STATE(483), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1124), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1149), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1147), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_COLON,
    ACTIONS(449), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1132), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [24246] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(470), 34,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [24287] = 8,
    ACTIONS(1118), 1,
      anon_sym_LPAREN,
    ACTIONS(1126), 1,
      anon_sym_LBRACE,
    ACTIONS(1169), 1,
      anon_sym_AT,
    STATE(436), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(447), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1124), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(435), 26,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [24340] = 14,
    ACTIONS(462), 1,
      anon_sym_COLON,
    ACTIONS(1154), 1,
      anon_sym_LPAREN,
    ACTIONS(1159), 1,
      anon_sym_DOT,
    ACTIONS(1161), 1,
      anon_sym_AT,
    ACTIONS(1165), 1,
      anon_sym_LBRACE,
    STATE(465), 1,
      sym__args,
    STATE(568), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(449), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1132), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1163), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1149), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(456), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1156), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [24405] = 13,
    ACTIONS(1154), 1,
      anon_sym_LPAREN,
    ACTIONS(1159), 1,
      anon_sym_DOT,
    ACTIONS(1161), 1,
      anon_sym_AT,
    ACTIONS(1165), 1,
      anon_sym_LBRACE,
    ACTIONS(1171), 1,
      anon_sym_COLON,
    STATE(465), 1,
      sym__args,
    STATE(568), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(449), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(451), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1163), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
    ACTIONS(460), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [24468] = 4,
    ACTIONS(1174), 1,
      anon_sym_DOT,
    STATE(435), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(464), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [24513] = 13,
    ACTIONS(462), 1,
      anon_sym_COLON,
    ACTIONS(1154), 1,
      anon_sym_LPAREN,
    ACTIONS(1159), 1,
      anon_sym_DOT,
    ACTIONS(1161), 1,
      anon_sym_AT,
    ACTIONS(1165), 1,
      anon_sym_LBRACE,
    STATE(465), 1,
      sym__args,
    STATE(568), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(449), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(451), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1163), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
    ACTIONS(460), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [24576] = 10,
    ACTIONS(1154), 1,
      anon_sym_LPAREN,
    ACTIONS(1159), 1,
      anon_sym_DOT,
    ACTIONS(1161), 1,
      anon_sym_AT,
    ACTIONS(1165), 1,
      anon_sym_LBRACE,
    STATE(465), 1,
      sym__args,
    STATE(568), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1163), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(451), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(460), 22,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [24633] = 13,
    ACTIONS(1154), 1,
      anon_sym_LPAREN,
    ACTIONS(1159), 1,
      anon_sym_DOT,
    ACTIONS(1161), 1,
      anon_sym_AT,
    ACTIONS(1165), 1,
      anon_sym_LBRACE,
    STATE(465), 1,
      sym__args,
    STATE(568), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(451), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(453), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1163), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(462), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(1171), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(460), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [24696] = 10,
    ACTIONS(458), 1,
      anon_sym_COLON,
    ACTIONS(1118), 1,
      anon_sym_LPAREN,
    ACTIONS(1126), 1,
      anon_sym_LBRACE,
    ACTIONS(1169), 1,
      anon_sym_AT,
    STATE(436), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(456), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1124), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(449), 11,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(451), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [24753] = 8,
    ACTIONS(1118), 1,
      anon_sym_LPAREN,
    ACTIONS(1126), 1,
      anon_sym_LBRACE,
    ACTIONS(1169), 1,
      anon_sym_AT,
    STATE(436), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(460), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1124), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(451), 26,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [24806] = 10,
    ACTIONS(1154), 1,
      anon_sym_LPAREN,
    ACTIONS(1159), 1,
      anon_sym_DOT,
    ACTIONS(1161), 1,
      anon_sym_AT,
    ACTIONS(1165), 1,
      anon_sym_LBRACE,
    STATE(465), 1,
      sym__args,
    STATE(568), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1163), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(435), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(447), 22,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [24863] = 10,
    ACTIONS(1118), 1,
      anon_sym_LPAREN,
    ACTIONS(1126), 1,
      anon_sym_LBRACE,
    ACTIONS(1169), 1,
      anon_sym_AT,
    STATE(436), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(462), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1124), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(458), 4,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(453), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(451), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [24920] = 4,
    ACTIONS(1174), 1,
      anon_sym_DOT,
    STATE(441), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(489), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [24965] = 13,
    ACTIONS(1154), 1,
      anon_sym_LPAREN,
    ACTIONS(1159), 1,
      anon_sym_DOT,
    ACTIONS(1161), 1,
      anon_sym_AT,
    ACTIONS(1165), 1,
      anon_sym_LBRACE,
    STATE(465), 1,
      sym__args,
    STATE(568), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(449), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1132), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1163), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1135), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(456), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1156), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [25028] = 13,
    ACTIONS(1154), 1,
      anon_sym_LPAREN,
    ACTIONS(1159), 1,
      anon_sym_DOT,
    ACTIONS(1161), 1,
      anon_sym_AT,
    ACTIONS(1165), 1,
      anon_sym_LBRACE,
    STATE(465), 1,
      sym__args,
    STATE(568), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(449), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1132), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1163), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1149), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(456), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1156), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [25091] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(518), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(516), 32,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [25134] = 14,
    ACTIONS(1135), 1,
      anon_sym_COLON,
    ACTIONS(1154), 1,
      anon_sym_LPAREN,
    ACTIONS(1159), 1,
      anon_sym_DOT,
    ACTIONS(1161), 1,
      anon_sym_AT,
    ACTIONS(1165), 1,
      anon_sym_LBRACE,
    STATE(465), 1,
      sym__args,
    STATE(587), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(449), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1132), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1163), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1140), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(456), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1156), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [25199] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(508), 34,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [25240] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(522), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(520), 32,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [25283] = 4,
    ACTIONS(1174), 1,
      anon_sym_DOT,
    STATE(444), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(481), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [25328] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(540), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(538), 32,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [25371] = 15,
    ACTIONS(1135), 1,
      anon_sym_COLON,
    ACTIONS(1154), 1,
      anon_sym_LPAREN,
    ACTIONS(1159), 1,
      anon_sym_DOT,
    ACTIONS(1161), 1,
      anon_sym_AT,
    ACTIONS(1165), 1,
      anon_sym_LBRACE,
    ACTIONS(1167), 1,
      anon_sym_EQ,
    STATE(465), 1,
      sym__args,
    STATE(568), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(449), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1132), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1140), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(1163), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1156), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [25438] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(536), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(534), 32,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [25481] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(526), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(524), 32,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [25524] = 10,
    ACTIONS(453), 1,
      anon_sym_COLON,
    ACTIONS(1118), 1,
      anon_sym_LPAREN,
    ACTIONS(1126), 1,
      anon_sym_LBRACE,
    ACTIONS(1169), 1,
      anon_sym_AT,
    STATE(436), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(456), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1124), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(449), 11,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(451), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [25581] = 4,
    ACTIONS(1174), 1,
      anon_sym_DOT,
    STATE(444), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(485), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [25626] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(514), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(512), 32,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [25669] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(510), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(550), 3,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACE,
    ACTIONS(508), 29,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [25714] = 4,
    ACTIONS(1176), 1,
      anon_sym_DOT,
    STATE(444), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(493), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [25759] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(530), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(528), 32,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [25802] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(506), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(504), 32,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [25845] = 14,
    ACTIONS(462), 1,
      anon_sym_COLON,
    ACTIONS(1154), 1,
      anon_sym_LPAREN,
    ACTIONS(1159), 1,
      anon_sym_DOT,
    ACTIONS(1161), 1,
      anon_sym_AT,
    ACTIONS(1165), 1,
      anon_sym_LBRACE,
    STATE(465), 1,
      sym__args,
    STATE(568), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(449), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1132), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1163), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1135), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(456), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1156), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [25910] = 11,
    ACTIONS(1118), 1,
      anon_sym_LPAREN,
    ACTIONS(1126), 1,
      anon_sym_LBRACE,
    ACTIONS(1130), 1,
      anon_sym_COLON,
    ACTIONS(1169), 1,
      anon_sym_AT,
    STATE(436), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1124), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1143), 2,
      anon_sym_SEMI,
      anon_sym_RBRACK,
    ACTIONS(1145), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(449), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1132), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [25968] = 11,
    ACTIONS(1118), 1,
      anon_sym_LPAREN,
    ACTIONS(1126), 1,
      anon_sym_LBRACE,
    ACTIONS(1130), 1,
      anon_sym_COLON,
    ACTIONS(1169), 1,
      anon_sym_AT,
    STATE(436), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1124), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1137), 2,
      anon_sym_SEMI,
      anon_sym_RBRACK,
    ACTIONS(1140), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(449), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1132), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [26026] = 10,
    ACTIONS(1118), 1,
      anon_sym_LPAREN,
    ACTIONS(1126), 1,
      anon_sym_LBRACE,
    ACTIONS(1169), 1,
      anon_sym_AT,
    STATE(436), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1124), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1135), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1130), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_COLON,
    ACTIONS(449), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1132), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [26082] = 10,
    ACTIONS(1118), 1,
      anon_sym_LPAREN,
    ACTIONS(1126), 1,
      anon_sym_LBRACE,
    ACTIONS(1169), 1,
      anon_sym_AT,
    STATE(436), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1124), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1149), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1147), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_COLON,
    ACTIONS(449), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1132), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [26138] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(528), 6,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
    ACTIONS(530), 27,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_AT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [26180] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(552), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(550), 31,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [26222] = 7,
    ACTIONS(1154), 1,
      anon_sym_LPAREN,
    ACTIONS(1161), 1,
      anon_sym_AT,
    ACTIONS(1165), 1,
      anon_sym_LBRACE,
    STATE(465), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(470), 5,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(472), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [26272] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(493), 33,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [26312] = 14,
    ACTIONS(1135), 1,
      anon_sym_COLON,
    ACTIONS(1154), 1,
      anon_sym_LPAREN,
    ACTIONS(1159), 1,
      anon_sym_DOT,
    ACTIONS(1161), 1,
      anon_sym_AT,
    ACTIONS(1165), 1,
      anon_sym_LBRACE,
    STATE(465), 1,
      sym__args,
    STATE(587), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(449), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1132), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1140), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(1163), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1156), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [26376] = 11,
    ACTIONS(458), 1,
      anon_sym_COLON,
    ACTIONS(1118), 1,
      anon_sym_LPAREN,
    ACTIONS(1126), 1,
      anon_sym_LBRACE,
    ACTIONS(1169), 1,
      anon_sym_AT,
    STATE(436), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1124), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1130), 2,
      anon_sym_SEMI,
      anon_sym_RBRACK,
    ACTIONS(1135), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(449), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1132), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [26434] = 11,
    ACTIONS(458), 1,
      anon_sym_COLON,
    ACTIONS(1118), 1,
      anon_sym_LPAREN,
    ACTIONS(1126), 1,
      anon_sym_LBRACE,
    ACTIONS(1169), 1,
      anon_sym_AT,
    STATE(436), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1124), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1147), 2,
      anon_sym_SEMI,
      anon_sym_RBRACK,
    ACTIONS(1149), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(449), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1132), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [26492] = 13,
    ACTIONS(462), 1,
      anon_sym_COLON,
    ACTIONS(1154), 1,
      anon_sym_LPAREN,
    ACTIONS(1159), 1,
      anon_sym_DOT,
    ACTIONS(1161), 1,
      anon_sym_AT,
    ACTIONS(1165), 1,
      anon_sym_LBRACE,
    STATE(465), 1,
      sym__args,
    STATE(568), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(449), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(451), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1163), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(460), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [26554] = 14,
    ACTIONS(462), 1,
      anon_sym_COLON,
    ACTIONS(1154), 1,
      anon_sym_LPAREN,
    ACTIONS(1159), 1,
      anon_sym_DOT,
    ACTIONS(1161), 1,
      anon_sym_AT,
    ACTIONS(1165), 1,
      anon_sym_LBRACE,
    ACTIONS(1179), 1,
      anon_sym_RPAREN,
    STATE(465), 1,
      sym__args,
    STATE(568), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(449), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(451), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1163), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(460), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [26617] = 5,
    ACTIONS(453), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1064), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(451), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(449), 15,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LF,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [26662] = 5,
    ACTIONS(646), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1064), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(451), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(449), 15,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LF,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [26707] = 4,
    ACTIONS(453), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(451), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(449), 17,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [26750] = 14,
    ACTIONS(462), 1,
      anon_sym_COLON,
    ACTIONS(1154), 1,
      anon_sym_LPAREN,
    ACTIONS(1159), 1,
      anon_sym_DOT,
    ACTIONS(1161), 1,
      anon_sym_AT,
    ACTIONS(1165), 1,
      anon_sym_LBRACE,
    ACTIONS(1181), 1,
      anon_sym_RPAREN,
    STATE(465), 1,
      sym__args,
    STATE(568), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(449), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(451), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1163), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(460), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [26813] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(534), 5,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(536), 27,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_AT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [26854] = 11,
    ACTIONS(1154), 1,
      anon_sym_LPAREN,
    ACTIONS(1165), 1,
      anon_sym_LBRACE,
    ACTIONS(1183), 1,
      anon_sym_AT,
    STATE(467), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(449), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1132), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1163), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1135), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(456), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1156), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [26911] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(538), 5,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(540), 27,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_AT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [26952] = 11,
    ACTIONS(1154), 1,
      anon_sym_LPAREN,
    ACTIONS(1165), 1,
      anon_sym_LBRACE,
    ACTIONS(1183), 1,
      anon_sym_AT,
    STATE(467), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(449), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1132), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1163), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1149), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(456), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1156), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [27009] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(512), 5,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(514), 27,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_AT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [27050] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(552), 3,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACE,
    ACTIONS(508), 5,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(510), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [27093] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1064), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(451), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(449), 16,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [27136] = 3,
    ACTIONS(1185), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(610), 31,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [27177] = 4,
    ACTIONS(637), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(634), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(632), 23,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [27220] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(566), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [27259] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(516), 5,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(518), 27,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_AT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [27300] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(520), 5,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(522), 27,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_AT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [27341] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(524), 5,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(526), 27,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_AT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [27382] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(435), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [27421] = 12,
    ACTIONS(462), 1,
      anon_sym_COLON,
    ACTIONS(1154), 1,
      anon_sym_LPAREN,
    ACTIONS(1165), 1,
      anon_sym_LBRACE,
    ACTIONS(1183), 1,
      anon_sym_AT,
    STATE(467), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(449), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1132), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1163), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1135), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(456), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1156), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [27480] = 12,
    ACTIONS(462), 1,
      anon_sym_COLON,
    ACTIONS(1154), 1,
      anon_sym_LPAREN,
    ACTIONS(1165), 1,
      anon_sym_LBRACE,
    ACTIONS(1183), 1,
      anon_sym_AT,
    STATE(467), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(449), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1132), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1163), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1149), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(456), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1156), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [27539] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(542), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [27578] = 14,
    ACTIONS(462), 1,
      anon_sym_COLON,
    ACTIONS(1154), 1,
      anon_sym_LPAREN,
    ACTIONS(1159), 1,
      anon_sym_DOT,
    ACTIONS(1161), 1,
      anon_sym_AT,
    ACTIONS(1165), 1,
      anon_sym_LBRACE,
    ACTIONS(1187), 1,
      anon_sym_RPAREN,
    STATE(465), 1,
      sym__args,
    STATE(568), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(449), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(451), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1163), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(460), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [27641] = 5,
    ACTIONS(1120), 1,
      anon_sym_DOT,
    STATE(486), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(502), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(500), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [27686] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(556), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [27725] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(574), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [27764] = 5,
    ACTIONS(1189), 1,
      anon_sym_DOT,
    STATE(486), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(479), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(474), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [27809] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(504), 5,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(506), 27,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_AT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [27850] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(71), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [27889] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1192), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(560), 26,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [27930] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(570), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [27969] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1064), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(451), 30,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [28010] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(580), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [28049] = 14,
    ACTIONS(462), 1,
      anon_sym_COLON,
    ACTIONS(1154), 1,
      anon_sym_LPAREN,
    ACTIONS(1159), 1,
      anon_sym_DOT,
    ACTIONS(1161), 1,
      anon_sym_AT,
    ACTIONS(1165), 1,
      anon_sym_LBRACE,
    ACTIONS(1194), 1,
      anon_sym_RPAREN,
    STATE(465), 1,
      sym__args,
    STATE(568), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(449), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(451), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1163), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(460), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [28112] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(584), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [28151] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(546), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [28190] = 11,
    ACTIONS(1154), 1,
      anon_sym_LPAREN,
    ACTIONS(1165), 1,
      anon_sym_LBRACE,
    ACTIONS(1171), 1,
      anon_sym_COLON,
    ACTIONS(1183), 1,
      anon_sym_AT,
    STATE(467), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(449), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(451), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1163), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
    ACTIONS(460), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [28247] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1064), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(435), 30,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [28288] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(451), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(449), 18,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [28329] = 5,
    ACTIONS(1196), 1,
      anon_sym_DOT,
    STATE(501), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(491), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(489), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [28374] = 5,
    ACTIONS(1196), 1,
      anon_sym_DOT,
    STATE(502), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(483), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(481), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [28419] = 5,
    ACTIONS(1196), 1,
      anon_sym_DOT,
    STATE(502), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(487), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(485), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [28464] = 5,
    ACTIONS(1198), 1,
      anon_sym_DOT,
    STATE(502), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(498), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(493), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [28509] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1064), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(451), 30,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [28550] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1064), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(451), 30,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [28591] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1064), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(554), 8,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
    ACTIONS(643), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(451), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [28636] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1064), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(453), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(458), 8,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
    ACTIONS(451), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [28681] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(453), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(458), 10,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
    ACTIONS(451), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [28724] = 8,
    ACTIONS(1154), 1,
      anon_sym_LPAREN,
    ACTIONS(1165), 1,
      anon_sym_LBRACE,
    ACTIONS(1183), 1,
      anon_sym_AT,
    STATE(467), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1163), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(451), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(460), 22,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [28775] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1064), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(451), 30,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [28816] = 11,
    ACTIONS(1154), 1,
      anon_sym_LPAREN,
    ACTIONS(1165), 1,
      anon_sym_LBRACE,
    ACTIONS(1183), 1,
      anon_sym_AT,
    STATE(467), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(451), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(453), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1163), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(462), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(1171), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(460), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [28873] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1064), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(641), 8,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
    ACTIONS(646), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(451), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [28918] = 5,
    ACTIONS(458), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1064), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(451), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(449), 15,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LF,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [28963] = 5,
    ACTIONS(643), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1064), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(451), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(449), 15,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LF,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [29008] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1192), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(653), 26,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [29049] = 4,
    ACTIONS(1201), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1192), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(653), 25,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [29092] = 14,
    ACTIONS(1135), 1,
      anon_sym_COLON,
    ACTIONS(1140), 1,
      anon_sym_RPAREN,
    ACTIONS(1154), 1,
      anon_sym_LPAREN,
    ACTIONS(1159), 1,
      anon_sym_DOT,
    ACTIONS(1161), 1,
      anon_sym_AT,
    ACTIONS(1165), 1,
      anon_sym_LBRACE,
    STATE(465), 1,
      sym__args,
    STATE(568), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(449), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1132), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1163), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1156), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [29155] = 5,
    ACTIONS(1201), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1203), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1192), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(657), 24,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [29200] = 11,
    ACTIONS(462), 1,
      anon_sym_COLON,
    ACTIONS(1154), 1,
      anon_sym_LPAREN,
    ACTIONS(1165), 1,
      anon_sym_LBRACE,
    ACTIONS(1183), 1,
      anon_sym_AT,
    STATE(467), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(449), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(451), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1163), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
    ACTIONS(460), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [29257] = 5,
    ACTIONS(641), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1064), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(451), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(449), 15,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LF,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [29302] = 5,
    ACTIONS(1201), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1203), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1192), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(600), 24,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [29347] = 14,
    ACTIONS(462), 1,
      anon_sym_COLON,
    ACTIONS(1154), 1,
      anon_sym_LPAREN,
    ACTIONS(1159), 1,
      anon_sym_DOT,
    ACTIONS(1161), 1,
      anon_sym_AT,
    ACTIONS(1165), 1,
      anon_sym_LBRACE,
    ACTIONS(1205), 1,
      anon_sym_RPAREN,
    STATE(465), 1,
      sym__args,
    STATE(568), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(449), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(451), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1163), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(460), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [29410] = 8,
    ACTIONS(1154), 1,
      anon_sym_LPAREN,
    ACTIONS(1165), 1,
      anon_sym_LBRACE,
    ACTIONS(1183), 1,
      anon_sym_AT,
    STATE(467), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1163), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(435), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(447), 22,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [29461] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1064), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(435), 30,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [29502] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(616), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [29541] = 12,
    ACTIONS(1135), 1,
      anon_sym_COLON,
    ACTIONS(1154), 1,
      anon_sym_LPAREN,
    ACTIONS(1165), 1,
      anon_sym_LBRACE,
    ACTIONS(1183), 1,
      anon_sym_AT,
    STATE(467), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(449), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1132), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1163), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1140), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(456), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1156), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [29600] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(624), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [29639] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(628), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [29678] = 5,
    ACTIONS(554), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1064), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(451), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(449), 15,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LF,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [29723] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(588), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [29762] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(620), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [29801] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1209), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1207), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
    ACTIONS(592), 24,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [29844] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1209), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(592), 30,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [29885] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1209), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(592), 30,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [29926] = 6,
    ACTIONS(1213), 1,
      anon_sym_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1209), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1211), 4,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
    ACTIONS(1207), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
    ACTIONS(592), 19,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [29973] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1209), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1211), 4,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
    ACTIONS(1207), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
    ACTIONS(592), 20,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [30018] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1064), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(435), 30,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [30059] = 5,
    ACTIONS(1196), 1,
      anon_sym_DOT,
    STATE(500), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(468), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(464), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [30104] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(498), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(493), 29,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [30144] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(510), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(508), 29,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [30184] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(550), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(552), 27,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_AT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [30224] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(472), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(470), 29,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [30264] = 5,
    ACTIONS(1215), 1,
      anon_sym_DOT,
    STATE(564), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(485), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(487), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [30307] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(630), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(628), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [30346] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(548), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(546), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [30385] = 5,
    ACTIONS(637), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(639), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(634), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(632), 19,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [30428] = 6,
    ACTIONS(458), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(456), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1124), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(449), 11,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(451), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [30473] = 6,
    ACTIONS(641), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(456), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1124), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(449), 11,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(451), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [30518] = 6,
    ACTIONS(554), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(456), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1124), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(449), 11,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(451), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [30563] = 4,
    ACTIONS(458), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(451), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(449), 15,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LF,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [30604] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(456), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(449), 14,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(451), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [30645] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(456), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1124), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(449), 12,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(451), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [30688] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(558), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(556), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [30727] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(447), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1124), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(435), 26,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [30768] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(447), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1124), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(435), 26,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [30809] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(447), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(435), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [30848] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(447), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1124), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(435), 26,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [30889] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(564), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1217), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(560), 22,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [30930] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(568), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(566), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [30969] = 6,
    ACTIONS(643), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(456), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1124), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(449), 11,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(451), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [31014] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(544), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(542), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [31053] = 5,
    ACTIONS(1215), 1,
      anon_sym_DOT,
    STATE(563), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(464), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(468), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [31096] = 5,
    ACTIONS(1215), 1,
      anon_sym_DOT,
    STATE(542), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(489), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(491), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [31139] = 5,
    ACTIONS(1215), 1,
      anon_sym_DOT,
    STATE(564), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(481), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(483), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [31182] = 5,
    ACTIONS(1219), 1,
      anon_sym_DOT,
    STATE(564), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(493), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(498), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [31225] = 6,
    ACTIONS(453), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(456), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1124), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(449), 11,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(451), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [31270] = 5,
    ACTIONS(453), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(456), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(449), 13,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(451), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [31313] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(572), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(570), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [31352] = 5,
    ACTIONS(1159), 1,
      anon_sym_DOT,
    STATE(581), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(500), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(502), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [31395] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(460), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1124), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(451), 26,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [31436] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(576), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(574), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [31475] = 6,
    ACTIONS(646), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(456), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1124), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(449), 11,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(451), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [31520] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(578), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(71), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [31559] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(582), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(580), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [31598] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(460), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1124), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(451), 26,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [31639] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(460), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1124), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(451), 26,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [31680] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(462), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1124), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(458), 4,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(453), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(451), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [31725] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(649), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1124), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(554), 4,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(643), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(451), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [31770] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(462), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(458), 6,
      anon_sym_SEMI,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(453), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(451), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [31813] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(460), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1124), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(451), 26,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [31854] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(651), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1124), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(641), 4,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(646), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(451), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [31899] = 5,
    ACTIONS(1222), 1,
      anon_sym_DOT,
    STATE(581), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(474), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(479), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [31942] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(590), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(588), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [31981] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(598), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1227), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1225), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
    ACTIONS(592), 20,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [32024] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(598), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1227), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(592), 26,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [32065] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(598), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1227), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(592), 26,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [32106] = 7,
    ACTIONS(1231), 1,
      anon_sym_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(598), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1227), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1229), 4,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
    ACTIONS(1225), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
    ACTIONS(592), 15,
      anon_sym_SEMI,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [32153] = 5,
    ACTIONS(1159), 1,
      anon_sym_DOT,
    STATE(581), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(500), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(502), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [32196] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(655), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1217), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(653), 22,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [32237] = 5,
    ACTIONS(1233), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(655), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1217), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(653), 21,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [32280] = 6,
    ACTIONS(1233), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1235), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(659), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1217), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(657), 20,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [32325] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(598), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1227), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1229), 4,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
    ACTIONS(1225), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
    ACTIONS(592), 16,
      anon_sym_SEMI,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [32370] = 6,
    ACTIONS(1233), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1235), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(606), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1217), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(600), 20,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [32415] = 4,
    ACTIONS(1237), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(614), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(610), 27,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [32456] = 6,
    ACTIONS(458), 1,
      anon_sym_COLON,
    ACTIONS(1128), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1064), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(449), 12,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(451), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [32501] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(618), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(616), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [32540] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(622), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(620), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [32579] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(626), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(624), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [32618] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(586), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(584), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [32657] = 5,
    ACTIONS(1241), 1,
      anon_sym_LF,
    STATE(599), 1,
      aux_sym_matrix_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1244), 3,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__external_identifier,
    ACTIONS(1239), 24,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_end,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      aux_sym_number_token1,
      aux_sym_number_token2,
      aux_sym_number_token3,
      anon_sym_true,
      anon_sym_false,
  [32699] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1249), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(566), 10,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1246), 17,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_RBRACK,
      anon_sym_COLON,
  [32739] = 7,
    ACTIONS(554), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1124), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1147), 2,
      anon_sym_SEMI,
      anon_sym_RBRACK,
    ACTIONS(1149), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(449), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1132), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [32785] = 7,
    ACTIONS(458), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1124), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1147), 2,
      anon_sym_SEMI,
      anon_sym_RBRACK,
    ACTIONS(1149), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(449), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1132), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [32831] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1255), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(580), 10,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1252), 17,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_RBRACK,
      anon_sym_COLON,
  [32871] = 7,
    ACTIONS(1130), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1124), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1137), 2,
      anon_sym_SEMI,
      anon_sym_RBRACK,
    ACTIONS(1140), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(449), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1132), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [32917] = 7,
    ACTIONS(1258), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1124), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1143), 2,
      anon_sym_SEMI,
      anon_sym_RBRACK,
    ACTIONS(1145), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(449), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1132), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [32963] = 7,
    ACTIONS(1130), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1124), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1143), 2,
      anon_sym_SEMI,
      anon_sym_RBRACK,
    ACTIONS(1145), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(449), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1132), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [33009] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1124), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1149), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1147), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_COLON,
    ACTIONS(449), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1132), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [33053] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(508), 5,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(510), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [33091] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1124), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1260), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1258), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_COLON,
    ACTIONS(449), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1132), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [33135] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1124), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1135), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1130), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_COLON,
    ACTIONS(449), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1132), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [33179] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(470), 5,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(472), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [33217] = 5,
    ACTIONS(1264), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1266), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1262), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(657), 21,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LF,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [33259] = 7,
    ACTIONS(1258), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1124), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1137), 2,
      anon_sym_SEMI,
      anon_sym_RBRACK,
    ACTIONS(1140), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(449), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1132), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [33305] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(493), 5,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(498), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [33343] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1268), 2,
      anon_sym_SEMI,
      anon_sym_RBRACK,
    ACTIONS(1270), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(566), 10,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1246), 15,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_COLON,
  [33385] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1268), 2,
      anon_sym_SEMI,
      anon_sym_RBRACK,
    ACTIONS(1270), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(566), 11,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
    ACTIONS(1246), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [33427] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1272), 2,
      anon_sym_SEMI,
      anon_sym_RBRACK,
    ACTIONS(1274), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(580), 11,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
    ACTIONS(1252), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [33469] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1272), 2,
      anon_sym_SEMI,
      anon_sym_RBRACK,
    ACTIONS(1274), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(580), 10,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1252), 15,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_COLON,
  [33511] = 5,
    ACTIONS(1264), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1266), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1262), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(600), 21,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LF,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [33553] = 7,
    ACTIONS(554), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1124), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1258), 2,
      anon_sym_SEMI,
      anon_sym_RBRACK,
    ACTIONS(1260), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(449), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1132), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [33599] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1124), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1149), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1147), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_COLON,
    ACTIONS(449), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1132), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [33643] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1262), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(653), 23,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LF,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [33681] = 4,
    ACTIONS(1264), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1262), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(653), 22,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LF,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [33721] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1124), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1149), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1147), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_COLON,
    ACTIONS(449), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1132), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [33765] = 7,
    ACTIONS(458), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1124), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1130), 2,
      anon_sym_SEMI,
      anon_sym_RBRACK,
    ACTIONS(1135), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(449), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1132), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [33811] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(616), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(618), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [33848] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(546), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(548), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [33885] = 7,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(449), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1132), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1163), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1149), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(456), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1156), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [33930] = 7,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(451), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(646), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1163), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(651), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(1276), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(460), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [33975] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(580), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1252), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1274), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(582), 9,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
    ACTIONS(1255), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [34018] = 7,
    ACTIONS(1171), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(449), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(451), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1163), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
    ACTIONS(460), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [34063] = 7,
    ACTIONS(462), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(449), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(451), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1163), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
    ACTIONS(460), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [34108] = 7,
    ACTIONS(1279), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(449), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(451), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1163), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
    ACTIONS(460), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [34153] = 7,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(449), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1132), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1163), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1149), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(456), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1156), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [34198] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(449), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(451), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(456), 12,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(460), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [34239] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(449), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(451), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1163), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(460), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [34282] = 7,
    ACTIONS(649), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(449), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(451), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1163), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
    ACTIONS(460), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [34327] = 8,
    ACTIONS(462), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(449), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1132), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1163), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1149), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(456), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1156), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [34374] = 7,
    ACTIONS(651), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(449), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(451), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1163), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
    ACTIONS(460), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [34419] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(456), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1124), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(449), 10,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
    ACTIONS(1132), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [34460] = 6,
    ACTIONS(1171), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(449), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(451), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(456), 11,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
    ACTIONS(460), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [34503] = 5,
    ACTIONS(458), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(456), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(449), 11,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(451), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [34544] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(556), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(558), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [34581] = 7,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(449), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1132), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1163), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1135), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(456), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1156), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [34626] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1163), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(451), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(460), 22,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [34665] = 8,
    ACTIONS(462), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(449), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1132), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1163), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1135), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(456), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1156), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [34712] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(653), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1282), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1284), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
    ACTIONS(655), 20,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [34753] = 6,
    ACTIONS(1286), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(653), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1282), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1284), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
    ACTIONS(655), 19,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [34796] = 7,
    ACTIONS(1286), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1288), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(657), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1282), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1284), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
    ACTIONS(659), 18,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [34841] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(588), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(590), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [34878] = 8,
    ACTIONS(1260), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(449), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1132), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1163), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1140), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(456), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1156), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [34925] = 8,
    ACTIONS(1135), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(449), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1132), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1163), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1140), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(456), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1156), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [34972] = 7,
    ACTIONS(1286), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1288), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(600), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1282), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1284), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
    ACTIONS(606), 18,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [35017] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1163), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(435), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(447), 22,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [35056] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1163), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(435), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(447), 22,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [35095] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(435), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(447), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [35132] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1163), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(435), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(447), 22,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [35171] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(620), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(622), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [35208] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1163), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(451), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(460), 22,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [35247] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(628), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(630), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [35284] = 7,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(451), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(453), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1163), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(462), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(1171), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(460), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [35329] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1292), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(592), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1290), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
    ACTIONS(598), 16,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [35370] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(560), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1282), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1284), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
    ACTIONS(564), 20,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [35411] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(566), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(568), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [35448] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(542), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(544), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [35485] = 7,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(451), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(643), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1163), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(649), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(1279), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(460), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [35530] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(570), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(572), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [35567] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(451), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(453), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(462), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(1171), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(460), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [35610] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1292), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(592), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(598), 22,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [35649] = 7,
    ACTIONS(1296), 1,
      anon_sym_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1292), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(592), 3,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1294), 4,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
    ACTIONS(1290), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
    ACTIONS(598), 12,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [35694] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(624), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(626), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [35731] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1292), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(592), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1294), 4,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
    ACTIONS(1290), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
    ACTIONS(598), 12,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [35774] = 7,
    ACTIONS(1276), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(449), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(451), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1163), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
    ACTIONS(460), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [35819] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(580), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1252), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(582), 8,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1255), 16,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [35860] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(566), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1246), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1270), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(568), 8,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1249), 13,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_COLON,
  [35903] = 7,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(449), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1132), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1163), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1149), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(456), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1156), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [35948] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(566), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1246), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(568), 8,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1249), 16,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [35989] = 7,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(449), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1132), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1163), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1260), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(456), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1156), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [36034] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1163), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(451), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(460), 22,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [36073] = 4,
    ACTIONS(1298), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(610), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(614), 23,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
  [36112] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1163), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(451), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(460), 22,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [36151] = 8,
    ACTIONS(649), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(449), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1132), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1163), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1149), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(456), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1156), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [36198] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(580), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1252), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1274), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(582), 8,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1255), 13,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_COLON,
  [36241] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(574), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(576), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [36278] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(566), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1246), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1270), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(568), 9,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
    ACTIONS(1249), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [36321] = 6,
    ACTIONS(1298), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(632), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(634), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1300), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(639), 17,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
  [36364] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(71), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(578), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [36401] = 8,
    ACTIONS(649), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(449), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1132), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1163), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1260), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(456), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1156), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [36448] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(580), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(582), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [36485] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(584), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(586), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [36522] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1292), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(592), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(598), 22,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [36561] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1135), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1130), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_COLON,
    ACTIONS(449), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1132), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [36601] = 6,
    ACTIONS(458), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1147), 2,
      anon_sym_SEMI,
      anon_sym_RBRACK,
    ACTIONS(1149), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(449), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1132), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [36643] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1149), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1147), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_COLON,
    ACTIONS(449), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1132), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [36683] = 6,
    ACTIONS(1305), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1307), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(659), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1303), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(657), 17,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [36725] = 17,
    ACTIONS(1309), 1,
      anon_sym_COMMA,
    ACTIONS(1311), 1,
      anon_sym_LPAREN,
    ACTIONS(1313), 1,
      anon_sym_DOT,
    ACTIONS(1315), 1,
      anon_sym_TILDE,
    ACTIONS(1317), 1,
      anon_sym_AT,
    ACTIONS(1319), 1,
      anon_sym_RBRACK,
    ACTIONS(1321), 1,
      anon_sym_LBRACE,
    STATE(809), 1,
      sym__keywords,
    STATE(826), 1,
      sym__args,
    STATE(862), 1,
      aux_sym_field_expression_repeat1,
    STATE(1235), 1,
      sym_indirect_access,
    STATE(1309), 1,
      sym_boolean,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(757), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(799), 2,
      sym_identifier,
      sym_function_call,
    STATE(760), 3,
      sym_field_expression,
      sym_ignored_argument,
      aux_sym_multioutput_variable_repeat1,
    ACTIONS(1088), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [36789] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(449), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1132), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1163), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
    ACTIONS(1156), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [36831] = 6,
    ACTIONS(1130), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1143), 2,
      anon_sym_SEMI,
      anon_sym_RBRACK,
    ACTIONS(1145), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(449), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1132), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [36873] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1149), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1147), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_COLON,
    ACTIONS(449), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1132), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [36913] = 8,
    ACTIONS(1260), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(449), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1132), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1140), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(1163), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1156), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [36959] = 6,
    ACTIONS(1305), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1307), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(606), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1303), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(600), 17,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [37001] = 17,
    ACTIONS(1311), 1,
      anon_sym_LPAREN,
    ACTIONS(1313), 1,
      anon_sym_DOT,
    ACTIONS(1315), 1,
      anon_sym_TILDE,
    ACTIONS(1317), 1,
      anon_sym_AT,
    ACTIONS(1321), 1,
      anon_sym_LBRACE,
    ACTIONS(1323), 1,
      anon_sym_COMMA,
    ACTIONS(1325), 1,
      anon_sym_RBRACK,
    STATE(809), 1,
      sym__keywords,
    STATE(826), 1,
      sym__args,
    STATE(862), 1,
      aux_sym_field_expression_repeat1,
    STATE(1235), 1,
      sym_indirect_access,
    STATE(1309), 1,
      sym_boolean,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(757), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(799), 2,
      sym_identifier,
      sym_function_call,
    STATE(759), 3,
      sym_field_expression,
      sym_ignored_argument,
      aux_sym_multioutput_variable_repeat1,
    ACTIONS(1088), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [37065] = 8,
    ACTIONS(1135), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(449), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1132), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1140), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(1163), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1156), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [37111] = 7,
    ACTIONS(462), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(449), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(451), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1163), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(460), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [37155] = 7,
    ACTIONS(651), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(449), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(451), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1163), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(460), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [37199] = 7,
    ACTIONS(649), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(449), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(451), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1163), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(460), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [37243] = 6,
    ACTIONS(1130), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1137), 2,
      anon_sym_SEMI,
      anon_sym_RBRACK,
    ACTIONS(1140), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(449), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1132), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [37285] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(655), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1303), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(653), 19,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [37323] = 5,
    ACTIONS(1305), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(655), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1303), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(653), 18,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [37363] = 6,
    ACTIONS(458), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1130), 2,
      anon_sym_SEMI,
      anon_sym_RBRACK,
    ACTIONS(1135), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(449), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1132), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [37405] = 18,
    ACTIONS(1329), 1,
      anon_sym_LPAREN,
    ACTIONS(1331), 1,
      anon_sym_DOT,
    ACTIONS(1333), 1,
      anon_sym_AT,
    ACTIONS(1335), 1,
      anon_sym_LBRACE,
    ACTIONS(1337), 1,
      anon_sym_EQ,
    ACTIONS(1339), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(1343), 1,
      sym__external_identifier,
    STATE(763), 1,
      sym_dimensions,
    STATE(783), 1,
      sym__keywords,
    STATE(831), 1,
      aux_sym_metaclass_operator_repeat1,
    STATE(951), 1,
      sym_identifier,
    STATE(1033), 1,
      sym_property_name,
    STATE(1065), 1,
      sym_validation_functions,
    STATE(1146), 1,
      sym_default_value,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(860), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    ACTIONS(1327), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(1341), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [37471] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(449), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1132), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1149), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(456), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1156), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [37512] = 8,
    ACTIONS(462), 1,
      anon_sym_COLON,
    ACTIONS(1179), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(449), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(451), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1163), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(460), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [37557] = 8,
    ACTIONS(651), 1,
      anon_sym_COLON,
    ACTIONS(1179), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(449), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(451), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1163), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(460), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [37602] = 8,
    ACTIONS(649), 1,
      anon_sym_COLON,
    ACTIONS(1179), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(449), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(451), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1163), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(460), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [37647] = 8,
    ACTIONS(649), 1,
      anon_sym_COLON,
    ACTIONS(1194), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(449), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(451), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1163), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(460), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [37692] = 8,
    ACTIONS(649), 1,
      anon_sym_COLON,
    ACTIONS(1187), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(449), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(451), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1163), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(460), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [37737] = 8,
    ACTIONS(462), 1,
      anon_sym_COLON,
    ACTIONS(1205), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(449), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(451), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1163), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(460), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [37782] = 8,
    ACTIONS(651), 1,
      anon_sym_COLON,
    ACTIONS(1205), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(449), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(451), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1163), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(460), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [37827] = 8,
    ACTIONS(649), 1,
      anon_sym_COLON,
    ACTIONS(1205), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(449), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(451), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1163), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(460), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [37872] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(449), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1132), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1135), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(456), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1156), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [37913] = 7,
    ACTIONS(1135), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(449), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1132), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1140), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(456), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1156), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [37956] = 8,
    ACTIONS(462), 1,
      anon_sym_COLON,
    ACTIONS(1194), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(449), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(451), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1163), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(460), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [38001] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(449), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1132), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1149), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(456), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1156), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [38042] = 8,
    ACTIONS(462), 1,
      anon_sym_COLON,
    ACTIONS(1181), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(449), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(451), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1163), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(460), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [38087] = 8,
    ACTIONS(651), 1,
      anon_sym_COLON,
    ACTIONS(1181), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(449), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(451), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1163), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(460), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [38132] = 8,
    ACTIONS(649), 1,
      anon_sym_COLON,
    ACTIONS(1181), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(449), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(451), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1163), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(460), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [38177] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(456), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(449), 10,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
    ACTIONS(1132), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [38214] = 6,
    ACTIONS(462), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(449), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(451), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(456), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
    ACTIONS(460), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [38255] = 8,
    ACTIONS(651), 1,
      anon_sym_COLON,
    ACTIONS(1194), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(449), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(451), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1163), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(460), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [38300] = 17,
    ACTIONS(1329), 1,
      anon_sym_LPAREN,
    ACTIONS(1331), 1,
      anon_sym_DOT,
    ACTIONS(1333), 1,
      anon_sym_AT,
    ACTIONS(1335), 1,
      anon_sym_LBRACE,
    ACTIONS(1337), 1,
      anon_sym_EQ,
    ACTIONS(1343), 1,
      sym__external_identifier,
    STATE(763), 1,
      sym_dimensions,
    STATE(783), 1,
      sym__keywords,
    STATE(831), 1,
      aux_sym_metaclass_operator_repeat1,
    STATE(951), 1,
      sym_identifier,
    STATE(1033), 1,
      sym_property_name,
    STATE(1065), 1,
      sym_validation_functions,
    STATE(1146), 1,
      sym_default_value,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(860), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    ACTIONS(1327), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(1341), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [38363] = 7,
    ACTIONS(462), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(449), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1132), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1135), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(456), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1156), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [38406] = 8,
    ACTIONS(462), 1,
      anon_sym_COLON,
    ACTIONS(1187), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(449), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(451), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1163), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(460), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [38451] = 8,
    ACTIONS(651), 1,
      anon_sym_COLON,
    ACTIONS(1187), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(449), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(451), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1163), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(460), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [38496] = 7,
    ACTIONS(462), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(449), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1132), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1149), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(456), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1156), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [38539] = 7,
    ACTIONS(1349), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1351), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(600), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1345), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1347), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
    ACTIONS(606), 15,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_RBRACE,
  [38581] = 7,
    ACTIONS(651), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(449), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(451), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1353), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(460), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [38623] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(653), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1345), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1347), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
    ACTIONS(655), 17,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
  [38661] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(449), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1132), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(456), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
    ACTIONS(1156), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [38699] = 7,
    ACTIONS(462), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(449), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(451), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1355), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(460), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [38741] = 6,
    ACTIONS(1349), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(653), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1345), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1347), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
    ACTIONS(655), 16,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
  [38781] = 7,
    ACTIONS(651), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(449), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(451), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1355), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(460), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [38823] = 7,
    ACTIONS(651), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(449), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(451), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1357), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(460), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [38865] = 7,
    ACTIONS(1349), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1351), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(657), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1345), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1347), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
    ACTIONS(659), 15,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_RBRACE,
  [38907] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(449), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(451), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1357), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(460), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [38946] = 14,
    ACTIONS(753), 1,
      aux_sym_number_token1,
    ACTIONS(759), 1,
      sym__single_quote_string_start,
    ACTIONS(761), 1,
      sym__double_quote_string_start,
    ACTIONS(1068), 1,
      anon_sym_LPAREN,
    STATE(452), 1,
      sym__keywords,
    STATE(1302), 1,
      sym_boolean,
    STATE(1370), 1,
      sym_indirect_access,
    STATE(1453), 1,
      sym_parfor_options,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(755), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(757), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(1199), 2,
      sym_identifier,
      sym_function_call,
    STATE(1519), 2,
      sym_string,
      sym_number,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [39001] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(449), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1132), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1355), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1156), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [39040] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(449), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(451), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1355), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(460), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [39079] = 15,
    ACTIONS(1329), 1,
      anon_sym_LPAREN,
    ACTIONS(1333), 1,
      anon_sym_AT,
    ACTIONS(1335), 1,
      anon_sym_LBRACE,
    ACTIONS(1337), 1,
      anon_sym_EQ,
    ACTIONS(1343), 1,
      sym__external_identifier,
    STATE(763), 1,
      sym_dimensions,
    STATE(783), 1,
      sym__keywords,
    STATE(951), 1,
      sym_identifier,
    STATE(1033), 1,
      sym_property_name,
    STATE(1065), 1,
      sym_validation_functions,
    STATE(1146), 1,
      sym_default_value,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(860), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    ACTIONS(1327), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(1341), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [39136] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(449), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(451), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1353), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(460), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [39175] = 12,
    ACTIONS(1361), 1,
      anon_sym_TILDE,
    ACTIONS(1363), 1,
      anon_sym_end,
    ACTIONS(1367), 1,
      sym__external_identifier,
    STATE(711), 1,
      sym_identifier,
    STATE(822), 1,
      sym__keywords,
    STATE(1138), 1,
      sym_class_property,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(749), 2,
      sym_ignored_argument,
      sym_property_name,
    STATE(858), 2,
      sym_property,
      aux_sym_arguments_statement_repeat1,
    STATE(861), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    ACTIONS(1359), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(1365), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [39225] = 15,
    ACTIONS(1311), 1,
      anon_sym_LPAREN,
    ACTIONS(1317), 1,
      anon_sym_AT,
    ACTIONS(1321), 1,
      anon_sym_LBRACE,
    ACTIONS(1369), 1,
      anon_sym_COMMA,
    ACTIONS(1371), 1,
      anon_sym_RBRACE,
    STATE(807), 1,
      sym_identifier,
    STATE(809), 1,
      sym__keywords,
    STATE(826), 1,
      sym__args,
    STATE(859), 1,
      sym_function_call,
    STATE(1235), 1,
      sym_indirect_access,
    STATE(1309), 1,
      sym_boolean,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(757), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(773), 2,
      sym_property_name,
      aux_sym_validation_functions_repeat1,
    ACTIONS(1088), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [39281] = 12,
    ACTIONS(1361), 1,
      anon_sym_TILDE,
    ACTIONS(1367), 1,
      sym__external_identifier,
    ACTIONS(1373), 1,
      anon_sym_end,
    STATE(711), 1,
      sym_identifier,
    STATE(822), 1,
      sym__keywords,
    STATE(1138), 1,
      sym_class_property,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(749), 2,
      sym_ignored_argument,
      sym_property_name,
    STATE(842), 2,
      sym_property,
      aux_sym_arguments_statement_repeat1,
    STATE(861), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    ACTIONS(1359), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(1365), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [39331] = 14,
    ACTIONS(1088), 1,
      sym__external_identifier,
    ACTIONS(1375), 1,
      anon_sym_LPAREN,
    ACTIONS(1377), 1,
      anon_sym_TILDE,
    ACTIONS(1379), 1,
      anon_sym_LF,
    ACTIONS(1381), 1,
      anon_sym_RBRACK,
    STATE(757), 1,
      aux_sym_matrix_repeat1,
    STATE(809), 1,
      sym__keywords,
    STATE(1235), 1,
      sym_indirect_access,
    STATE(1309), 1,
      sym_boolean,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1385), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(696), 2,
      sym_identifier,
      sym_function_call,
    STATE(755), 2,
      sym_field_expression,
      sym_ignored_argument,
    ACTIONS(1383), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [39384] = 12,
    ACTIONS(1068), 1,
      anon_sym_LPAREN,
    ACTIONS(1309), 1,
      anon_sym_COMMA,
    ACTIONS(1315), 1,
      anon_sym_TILDE,
    ACTIONS(1319), 1,
      anon_sym_RBRACK,
    STATE(809), 1,
      sym__keywords,
    STATE(1235), 1,
      sym_indirect_access,
    STATE(1309), 1,
      sym_boolean,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(757), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(799), 2,
      sym_identifier,
      sym_function_call,
    STATE(760), 3,
      sym_field_expression,
      sym_ignored_argument,
      aux_sym_multioutput_variable_repeat1,
    ACTIONS(1088), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [39433] = 11,
    ACTIONS(1361), 1,
      anon_sym_TILDE,
    ACTIONS(1367), 1,
      sym__external_identifier,
    ACTIONS(1387), 1,
      anon_sym_end,
    STATE(731), 1,
      sym_identifier,
    STATE(822), 1,
      sym__keywords,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(749), 2,
      sym_ignored_argument,
      sym_property_name,
    STATE(861), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    STATE(870), 2,
      sym_property,
      aux_sym_properties_repeat1,
    ACTIONS(1359), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(1365), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [39480] = 14,
    ACTIONS(1088), 1,
      sym__external_identifier,
    ACTIONS(1375), 1,
      anon_sym_LPAREN,
    ACTIONS(1377), 1,
      anon_sym_TILDE,
    ACTIONS(1389), 1,
      anon_sym_LF,
    ACTIONS(1391), 1,
      anon_sym_RBRACK,
    STATE(809), 1,
      sym__keywords,
    STATE(882), 1,
      aux_sym_matrix_repeat1,
    STATE(1235), 1,
      sym_indirect_access,
    STATE(1309), 1,
      sym_boolean,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1385), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(702), 2,
      sym_identifier,
      sym_function_call,
    STATE(758), 2,
      sym_field_expression,
      sym_ignored_argument,
    ACTIONS(1383), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [39533] = 12,
    ACTIONS(1068), 1,
      anon_sym_LPAREN,
    ACTIONS(1315), 1,
      anon_sym_TILDE,
    ACTIONS(1323), 1,
      anon_sym_COMMA,
    ACTIONS(1325), 1,
      anon_sym_RBRACK,
    STATE(809), 1,
      sym__keywords,
    STATE(1235), 1,
      sym_indirect_access,
    STATE(1309), 1,
      sym_boolean,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(757), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(799), 2,
      sym_identifier,
      sym_function_call,
    STATE(759), 3,
      sym_field_expression,
      sym_ignored_argument,
      aux_sym_multioutput_variable_repeat1,
    ACTIONS(1088), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [39582] = 12,
    ACTIONS(1068), 1,
      anon_sym_LPAREN,
    ACTIONS(1315), 1,
      anon_sym_TILDE,
    ACTIONS(1393), 1,
      anon_sym_COMMA,
    ACTIONS(1395), 1,
      anon_sym_RBRACK,
    STATE(809), 1,
      sym__keywords,
    STATE(1235), 1,
      sym_indirect_access,
    STATE(1309), 1,
      sym_boolean,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(757), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(799), 2,
      sym_identifier,
      sym_function_call,
    STATE(761), 3,
      sym_field_expression,
      sym_ignored_argument,
      aux_sym_multioutput_variable_repeat1,
    ACTIONS(1088), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [39631] = 12,
    ACTIONS(1068), 1,
      anon_sym_LPAREN,
    ACTIONS(1315), 1,
      anon_sym_TILDE,
    ACTIONS(1323), 1,
      anon_sym_COMMA,
    ACTIONS(1325), 1,
      anon_sym_RBRACK,
    STATE(809), 1,
      sym__keywords,
    STATE(1235), 1,
      sym_indirect_access,
    STATE(1309), 1,
      sym_boolean,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(757), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(799), 2,
      sym_identifier,
      sym_function_call,
    STATE(761), 3,
      sym_field_expression,
      sym_ignored_argument,
      aux_sym_multioutput_variable_repeat1,
    ACTIONS(1088), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [39680] = 12,
    ACTIONS(1397), 1,
      anon_sym_COMMA,
    ACTIONS(1400), 1,
      anon_sym_LPAREN,
    ACTIONS(1403), 1,
      anon_sym_TILDE,
    ACTIONS(1406), 1,
      anon_sym_RBRACK,
    STATE(809), 1,
      sym__keywords,
    STATE(1235), 1,
      sym_indirect_access,
    STATE(1309), 1,
      sym_boolean,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1411), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(799), 2,
      sym_identifier,
      sym_function_call,
    STATE(761), 3,
      sym_field_expression,
      sym_ignored_argument,
      aux_sym_multioutput_variable_repeat1,
    ACTIONS(1408), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [39729] = 11,
    ACTIONS(1361), 1,
      anon_sym_TILDE,
    ACTIONS(1367), 1,
      sym__external_identifier,
    ACTIONS(1414), 1,
      anon_sym_end,
    STATE(731), 1,
      sym_identifier,
    STATE(822), 1,
      sym__keywords,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(749), 2,
      sym_ignored_argument,
      sym_property_name,
    STATE(861), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    STATE(873), 2,
      sym_property,
      aux_sym_properties_repeat1,
    ACTIONS(1359), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(1365), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [39776] = 12,
    ACTIONS(1335), 1,
      anon_sym_LBRACE,
    ACTIONS(1337), 1,
      anon_sym_EQ,
    ACTIONS(1343), 1,
      sym__external_identifier,
    STATE(783), 1,
      sym__keywords,
    STATE(953), 1,
      sym_identifier,
    STATE(1038), 1,
      sym_property_name,
    STATE(1060), 1,
      sym_validation_functions,
    STATE(1131), 1,
      sym_default_value,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(865), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    ACTIONS(1416), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(1341), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [39824] = 11,
    ACTIONS(1264), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1266), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1420), 1,
      anon_sym_end,
    ACTIONS(1422), 1,
      anon_sym_case,
    ACTIONS(1424), 1,
      anon_sym_otherwise,
    STATE(1491), 1,
      sym_otherwise_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(952), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    STATE(1086), 2,
      sym_case_clause,
      aux_sym_switch_statement_repeat1,
    ACTIONS(1418), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(1262), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
  [39869] = 15,
    ACTIONS(63), 1,
      sym__multioutput_variable_start,
    ACTIONS(211), 1,
      anon_sym_function,
    ACTIONS(1426), 1,
      anon_sym_end,
    ACTIONS(1428), 1,
      anon_sym_arguments,
    ACTIONS(1434), 1,
      sym__external_identifier,
    STATE(452), 1,
      sym__keywords,
    STATE(767), 1,
      aux_sym_methods_repeat1,
    STATE(1090), 1,
      sym_function_signature,
    STATE(1136), 1,
      sym_function_output,
    STATE(1144), 1,
      sym__function_definition_with_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1430), 2,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
    ACTIONS(1432), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(1463), 2,
      sym_identifier,
      sym_multioutput_variable,
    ACTIONS(751), 4,
      anon_sym_properties,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [39922] = 11,
    ACTIONS(1068), 1,
      anon_sym_LPAREN,
    ACTIONS(1315), 1,
      anon_sym_TILDE,
    ACTIONS(1395), 1,
      anon_sym_RBRACK,
    STATE(809), 1,
      sym__keywords,
    STATE(1235), 1,
      sym_indirect_access,
    STATE(1309), 1,
      sym_boolean,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(757), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(777), 2,
      sym_identifier,
      sym_function_call,
    STATE(898), 2,
      sym_field_expression,
      sym_ignored_argument,
    ACTIONS(1088), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [39967] = 15,
    ACTIONS(1436), 1,
      anon_sym_end,
    ACTIONS(1438), 1,
      anon_sym_arguments,
    ACTIONS(1441), 1,
      anon_sym_function,
    ACTIONS(1453), 1,
      sym__multioutput_variable_start,
    ACTIONS(1456), 1,
      sym__external_identifier,
    STATE(452), 1,
      sym__keywords,
    STATE(767), 1,
      aux_sym_methods_repeat1,
    STATE(1090), 1,
      sym_function_signature,
    STATE(1136), 1,
      sym_function_output,
    STATE(1144), 1,
      sym__function_definition_with_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1444), 2,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
    ACTIONS(1450), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(1463), 2,
      sym_identifier,
      sym_multioutput_variable,
    ACTIONS(1447), 4,
      anon_sym_properties,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [40020] = 11,
    ACTIONS(1068), 1,
      anon_sym_LPAREN,
    ACTIONS(1315), 1,
      anon_sym_TILDE,
    ACTIONS(1325), 1,
      anon_sym_RBRACK,
    STATE(809), 1,
      sym__keywords,
    STATE(1235), 1,
      sym_indirect_access,
    STATE(1309), 1,
      sym_boolean,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(757), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(777), 2,
      sym_identifier,
      sym_function_call,
    STATE(898), 2,
      sym_field_expression,
      sym_ignored_argument,
    ACTIONS(1088), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [40065] = 11,
    ACTIONS(1068), 1,
      anon_sym_LPAREN,
    ACTIONS(1315), 1,
      anon_sym_TILDE,
    ACTIONS(1459), 1,
      anon_sym_RBRACK,
    STATE(809), 1,
      sym__keywords,
    STATE(1235), 1,
      sym_indirect_access,
    STATE(1309), 1,
      sym_boolean,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(757), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(777), 2,
      sym_identifier,
      sym_function_call,
    STATE(898), 2,
      sym_field_expression,
      sym_ignored_argument,
    ACTIONS(1088), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [40110] = 15,
    ACTIONS(63), 1,
      sym__multioutput_variable_start,
    ACTIONS(211), 1,
      anon_sym_function,
    ACTIONS(1428), 1,
      anon_sym_arguments,
    ACTIONS(1434), 1,
      sym__external_identifier,
    ACTIONS(1461), 1,
      anon_sym_end,
    STATE(452), 1,
      sym__keywords,
    STATE(776), 1,
      aux_sym_methods_repeat1,
    STATE(1090), 1,
      sym_function_signature,
    STATE(1136), 1,
      sym_function_output,
    STATE(1144), 1,
      sym__function_definition_with_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1430), 2,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
    ACTIONS(1432), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(1463), 2,
      sym_identifier,
      sym_multioutput_variable,
    ACTIONS(751), 4,
      anon_sym_properties,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [40163] = 12,
    ACTIONS(1463), 1,
      anon_sym_COMMA,
    ACTIONS(1466), 1,
      anon_sym_LPAREN,
    ACTIONS(1469), 1,
      anon_sym_RBRACE,
    STATE(807), 1,
      sym_identifier,
    STATE(809), 1,
      sym__keywords,
    STATE(859), 1,
      sym_function_call,
    STATE(1235), 1,
      sym_indirect_access,
    STATE(1309), 1,
      sym_boolean,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1474), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(771), 2,
      sym_property_name,
      aux_sym_validation_functions_repeat1,
    ACTIONS(1471), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [40210] = 15,
    ACTIONS(63), 1,
      sym__multioutput_variable_start,
    ACTIONS(211), 1,
      anon_sym_function,
    ACTIONS(1428), 1,
      anon_sym_arguments,
    ACTIONS(1434), 1,
      sym__external_identifier,
    ACTIONS(1477), 1,
      anon_sym_end,
    STATE(452), 1,
      sym__keywords,
    STATE(765), 1,
      aux_sym_methods_repeat1,
    STATE(1090), 1,
      sym_function_signature,
    STATE(1136), 1,
      sym_function_output,
    STATE(1144), 1,
      sym__function_definition_with_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1430), 2,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
    ACTIONS(1432), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(1463), 2,
      sym_identifier,
      sym_multioutput_variable,
    ACTIONS(751), 4,
      anon_sym_properties,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [40263] = 12,
    ACTIONS(1068), 1,
      anon_sym_LPAREN,
    ACTIONS(1369), 1,
      anon_sym_COMMA,
    ACTIONS(1479), 1,
      anon_sym_RBRACE,
    STATE(807), 1,
      sym_identifier,
    STATE(809), 1,
      sym__keywords,
    STATE(859), 1,
      sym_function_call,
    STATE(1235), 1,
      sym_indirect_access,
    STATE(1309), 1,
      sym_boolean,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(757), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(771), 2,
      sym_property_name,
      aux_sym_validation_functions_repeat1,
    ACTIONS(1088), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [40310] = 12,
    ACTIONS(1068), 1,
      anon_sym_LPAREN,
    ACTIONS(1369), 1,
      anon_sym_COMMA,
    ACTIONS(1371), 1,
      anon_sym_RBRACE,
    STATE(807), 1,
      sym_identifier,
    STATE(809), 1,
      sym__keywords,
    STATE(859), 1,
      sym_function_call,
    STATE(1235), 1,
      sym_indirect_access,
    STATE(1309), 1,
      sym_boolean,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(757), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(773), 2,
      sym_property_name,
      aux_sym_validation_functions_repeat1,
    ACTIONS(1088), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [40357] = 4,
    ACTIONS(1481), 1,
      anon_sym_DOT,
    STATE(775), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(493), 18,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LF,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [40388] = 15,
    ACTIONS(63), 1,
      sym__multioutput_variable_start,
    ACTIONS(211), 1,
      anon_sym_function,
    ACTIONS(1428), 1,
      anon_sym_arguments,
    ACTIONS(1434), 1,
      sym__external_identifier,
    ACTIONS(1477), 1,
      anon_sym_end,
    STATE(452), 1,
      sym__keywords,
    STATE(767), 1,
      aux_sym_methods_repeat1,
    STATE(1090), 1,
      sym_function_signature,
    STATE(1136), 1,
      sym_function_output,
    STATE(1144), 1,
      sym__function_definition_with_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1430), 2,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
    ACTIONS(1432), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(1463), 2,
      sym_identifier,
      sym_multioutput_variable,
    ACTIONS(751), 4,
      anon_sym_properties,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [40441] = 8,
    ACTIONS(1313), 1,
      anon_sym_DOT,
    ACTIONS(1317), 1,
      anon_sym_AT,
    ACTIONS(1321), 1,
      anon_sym_LBRACE,
    ACTIONS(1484), 1,
      anon_sym_LPAREN,
    STATE(826), 1,
      sym__args,
    STATE(862), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1406), 13,
      sym__external_identifier,
      anon_sym_COMMA,
      anon_sym_TILDE,
      anon_sym_RBRACK,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_true,
      anon_sym_false,
  [40479] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1135), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1130), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_COLON,
    ACTIONS(1147), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [40509] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1490), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1486), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_COLON,
    ACTIONS(1488), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [40539] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1496), 2,
      sym__multioutput_variable_start,
      sym__external_identifier,
    STATE(797), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    ACTIONS(1492), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(1494), 11,
      anon_sym_end,
      anon_sym_arguments,
      anon_sym_function,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [40571] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1436), 2,
      sym__multioutput_variable_start,
      sym__external_identifier,
    STATE(797), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    ACTIONS(1492), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(1498), 11,
      anon_sym_end,
      anon_sym_arguments,
      anon_sym_function,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [40603] = 5,
    ACTIONS(1130), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1143), 2,
      anon_sym_SEMI,
      anon_sym_RBRACK,
    ACTIONS(1145), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1147), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [40635] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(528), 19,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LF,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [40661] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1504), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1506), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1502), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
    ACTIONS(1500), 9,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_RBRACK,
      anon_sym_COLON,
  [40693] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1508), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1488), 17,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_RBRACK,
      anon_sym_COLON,
  [40721] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1504), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1506), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1500), 15,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_RBRACK,
      anon_sym_COLON,
  [40751] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1504), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1506), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1500), 15,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_RBRACK,
      anon_sym_COLON,
  [40781] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(493), 19,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LF,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [40807] = 7,
    ACTIONS(1512), 1,
      anon_sym_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1504), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1506), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1500), 4,
      anon_sym_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_COLON,
    ACTIONS(1510), 4,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
    ACTIONS(1502), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
  [40843] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1504), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1506), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1510), 4,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
    ACTIONS(1500), 5,
      anon_sym_SEMI,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_RBRACK,
      anon_sym_COLON,
    ACTIONS(1502), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
  [40877] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1516), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1514), 17,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_RBRACK,
      anon_sym_COLON,
  [40905] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1520), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1518), 17,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_RBRACK,
      anon_sym_COLON,
  [40933] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1524), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1522), 17,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_RBRACK,
      anon_sym_COLON,
  [40961] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1274), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1272), 17,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_RBRACK,
      anon_sym_COLON,
  [40989] = 10,
    ACTIONS(1068), 1,
      anon_sym_LPAREN,
    ACTIONS(1315), 1,
      anon_sym_TILDE,
    STATE(809), 1,
      sym__keywords,
    STATE(1235), 1,
      sym_indirect_access,
    STATE(1309), 1,
      sym_boolean,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(757), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(777), 2,
      sym_identifier,
      sym_function_call,
    STATE(898), 2,
      sym_field_expression,
      sym_ignored_argument,
    ACTIONS(1088), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [41031] = 5,
    ACTIONS(1486), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1526), 2,
      anon_sym_SEMI,
      anon_sym_RBRACK,
    ACTIONS(1528), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1488), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [41063] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(937), 2,
      sym__multioutput_variable_start,
      sym__external_identifier,
    STATE(797), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    ACTIONS(1530), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(935), 11,
      anon_sym_end,
      anon_sym_arguments,
      anon_sym_function,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [41095] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1535), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1533), 17,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_RBRACK,
      anon_sym_COLON,
  [41123] = 8,
    ACTIONS(1313), 1,
      anon_sym_DOT,
    ACTIONS(1317), 1,
      anon_sym_AT,
    ACTIONS(1321), 1,
      anon_sym_LBRACE,
    ACTIONS(1484), 1,
      anon_sym_LPAREN,
    STATE(826), 1,
      sym__args,
    STATE(862), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1537), 13,
      sym__external_identifier,
      anon_sym_COMMA,
      anon_sym_TILDE,
      anon_sym_RBRACK,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_true,
      anon_sym_false,
  [41161] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(514), 18,
      sym__external_identifier,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_AT,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_true,
      anon_sym_false,
  [41186] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1539), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1506), 16,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [41213] = 9,
    ACTIONS(1544), 1,
      anon_sym_end,
    ACTIONS(1549), 1,
      sym__external_identifier,
    STATE(373), 1,
      sym__keywords,
    STATE(1190), 1,
      sym_identifier,
    STATE(1192), 1,
      sym_enum,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(802), 2,
      sym__end_of_line,
      aux_sym_enumeration_repeat1,
    ACTIONS(1541), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(1546), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [41252] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1539), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1552), 4,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
    ACTIONS(1506), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(1554), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
  [41283] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(526), 18,
      sym__external_identifier,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_AT,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_true,
      anon_sym_false,
  [41308] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1535), 18,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [41333] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1520), 18,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [41358] = 8,
    ACTIONS(1317), 1,
      anon_sym_AT,
    ACTIONS(1321), 1,
      anon_sym_LBRACE,
    ACTIONS(1484), 1,
      anon_sym_LPAREN,
    ACTIONS(1558), 1,
      anon_sym_DOT,
    STATE(826), 1,
      sym__args,
    STATE(886), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1556), 12,
      sym__external_identifier,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_true,
      anon_sym_false,
  [41395] = 9,
    ACTIONS(41), 1,
      sym__external_identifier,
    ACTIONS(1562), 1,
      anon_sym_end,
    STATE(373), 1,
      sym__keywords,
    STATE(1190), 1,
      sym_identifier,
    STATE(1192), 1,
      sym_enum,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(812), 2,
      sym__end_of_line,
      aux_sym_enumeration_repeat1,
    ACTIONS(1560), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(105), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [41434] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(530), 18,
      sym__external_identifier,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_AT,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_true,
      anon_sym_false,
  [41459] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1524), 18,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [41484] = 9,
    ACTIONS(41), 1,
      sym__external_identifier,
    ACTIONS(1566), 1,
      anon_sym_end,
    STATE(373), 1,
      sym__keywords,
    STATE(1190), 1,
      sym_identifier,
    STATE(1192), 1,
      sym_enum,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(827), 2,
      sym__end_of_line,
      aux_sym_enumeration_repeat1,
    ACTIONS(1564), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(105), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [41523] = 9,
    ACTIONS(41), 1,
      sym__external_identifier,
    ACTIONS(1566), 1,
      anon_sym_end,
    STATE(373), 1,
      sym__keywords,
    STATE(1190), 1,
      sym_identifier,
    STATE(1192), 1,
      sym_enum,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(802), 2,
      sym__end_of_line,
      aux_sym_enumeration_repeat1,
    ACTIONS(1568), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(105), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [41562] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1506), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1572), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1570), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
    ACTIONS(1500), 8,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_RBRACK,
  [41593] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1506), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1572), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1500), 14,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_RBRACK,
  [41622] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1506), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1572), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1500), 14,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_RBRACK,
  [41651] = 7,
    ACTIONS(1576), 1,
      anon_sym_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1506), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1572), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1500), 3,
      anon_sym_SEMI,
      anon_sym_PIPE,
      anon_sym_RBRACK,
    ACTIONS(1574), 4,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
    ACTIONS(1570), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
  [41686] = 6,
    ACTIONS(1578), 1,
      anon_sym_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1539), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1552), 4,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
    ACTIONS(1506), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(1554), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
  [41719] = 6,
    ACTIONS(1317), 1,
      anon_sym_AT,
    ACTIONS(1321), 1,
      anon_sym_LBRACE,
    ACTIONS(1484), 1,
      anon_sym_LPAREN,
    STATE(826), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(472), 14,
      sym__external_identifier,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_RBRACK,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_true,
      anon_sym_false,
  [41752] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1135), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(1149), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [41779] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1516), 18,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [41804] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1490), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(1508), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [41831] = 3,
    ACTIONS(530), 1,
      sym__external_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(528), 17,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LF,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_DOT_QMARK,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_CR,
  [41858] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(518), 18,
      sym__external_identifier,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_AT,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_true,
      anon_sym_false,
  [41883] = 4,
    ACTIONS(1135), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1145), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(1149), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [41912] = 4,
    ACTIONS(1490), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1528), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(1508), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [41941] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(536), 18,
      sym__external_identifier,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_AT,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_true,
      anon_sym_false,
  [41966] = 9,
    ACTIONS(41), 1,
      sym__external_identifier,
    ACTIONS(1580), 1,
      anon_sym_end,
    STATE(373), 1,
      sym__keywords,
    STATE(1190), 1,
      sym_identifier,
    STATE(1192), 1,
      sym_enum,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(802), 2,
      sym__end_of_line,
      aux_sym_enumeration_repeat1,
    ACTIONS(1568), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(105), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [42005] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(522), 18,
      sym__external_identifier,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_AT,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_true,
      anon_sym_false,
  [42030] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1539), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1554), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
    ACTIONS(1506), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [42059] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1274), 18,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [42084] = 5,
    ACTIONS(1584), 1,
      anon_sym_DOT,
    ACTIONS(1586), 1,
      sym__external_identifier,
    STATE(834), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1582), 15,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LF,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_CR,
  [42115] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1508), 18,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [42140] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(540), 18,
      sym__external_identifier,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_AT,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_true,
      anon_sym_false,
  [42165] = 5,
    ACTIONS(498), 1,
      sym__external_identifier,
    ACTIONS(1588), 1,
      anon_sym_DOT,
    STATE(834), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(493), 15,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LF,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_CR,
  [42196] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1539), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1506), 16,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [42223] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1506), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1572), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1500), 4,
      anon_sym_SEMI,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_RBRACK,
    ACTIONS(1574), 4,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
    ACTIONS(1570), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
  [42256] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1591), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1506), 15,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_RBRACE,
  [42282] = 10,
    ACTIONS(1068), 1,
      anon_sym_LPAREN,
    STATE(752), 1,
      sym_function_call,
    STATE(774), 1,
      sym_property_name,
    STATE(807), 1,
      sym_identifier,
    STATE(809), 1,
      sym__keywords,
    STATE(1235), 1,
      sym_indirect_access,
    STATE(1309), 1,
      sym_boolean,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(757), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1088), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [42322] = 6,
    ACTIONS(1597), 1,
      anon_sym_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1591), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1506), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE,
      anon_sym_RBRACE,
    ACTIONS(1593), 4,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
    ACTIONS(1595), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
  [42354] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1591), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1593), 4,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
    ACTIONS(1506), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_RBRACE,
    ACTIONS(1595), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
  [42384] = 4,
    ACTIONS(1599), 1,
      anon_sym_DOT,
    STATE(855), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(489), 15,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LF,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [42412] = 9,
    ACTIONS(1601), 1,
      anon_sym_TILDE,
    ACTIONS(1603), 1,
      anon_sym_end,
    STATE(711), 1,
      sym_identifier,
    STATE(822), 1,
      sym__keywords,
    STATE(1138), 1,
      sym_class_property,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(749), 2,
      sym_ignored_argument,
      sym_property_name,
    STATE(847), 2,
      sym_property,
      aux_sym_arguments_statement_repeat1,
    ACTIONS(1367), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [42450] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1591), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1595), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
    ACTIONS(1506), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_RBRACE,
  [42478] = 8,
    ACTIONS(41), 1,
      sym__external_identifier,
    ACTIONS(1607), 1,
      anon_sym_end,
    STATE(373), 1,
      sym__keywords,
    STATE(1160), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(848), 2,
      sym__end_of_line,
      aux_sym_events_repeat1,
    ACTIONS(1605), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(105), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [42514] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(552), 2,
      anon_sym_AT,
      anon_sym_LBRACE,
    ACTIONS(510), 15,
      sym__external_identifier,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_RBRACK,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_true,
      anon_sym_false,
  [42540] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1591), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1506), 15,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_RBRACE,
  [42566] = 9,
    ACTIONS(1609), 1,
      anon_sym_TILDE,
    ACTIONS(1612), 1,
      anon_sym_end,
    STATE(711), 1,
      sym_identifier,
    STATE(822), 1,
      sym__keywords,
    STATE(1138), 1,
      sym_class_property,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(749), 2,
      sym_ignored_argument,
      sym_property_name,
    STATE(847), 2,
      sym_property,
      aux_sym_arguments_statement_repeat1,
    ACTIONS(1614), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [42604] = 8,
    ACTIONS(1620), 1,
      anon_sym_end,
    ACTIONS(1625), 1,
      sym__external_identifier,
    STATE(373), 1,
      sym__keywords,
    STATE(1160), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(848), 2,
      sym__end_of_line,
      aux_sym_events_repeat1,
    ACTIONS(1617), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(1622), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [42640] = 10,
    ACTIONS(1068), 1,
      anon_sym_LPAREN,
    STATE(807), 1,
      sym_identifier,
    STATE(809), 1,
      sym__keywords,
    STATE(876), 1,
      sym_function_call,
    STATE(937), 1,
      sym_property_name,
    STATE(1235), 1,
      sym_indirect_access,
    STATE(1309), 1,
      sym_boolean,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(757), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1088), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [42680] = 8,
    ACTIONS(41), 1,
      sym__external_identifier,
    ACTIONS(1630), 1,
      anon_sym_end,
    STATE(373), 1,
      sym__keywords,
    STATE(1160), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(844), 2,
      sym__end_of_line,
      aux_sym_events_repeat1,
    ACTIONS(1628), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(105), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [42716] = 8,
    ACTIONS(41), 1,
      sym__external_identifier,
    ACTIONS(1634), 1,
      anon_sym_end,
    STATE(373), 1,
      sym__keywords,
    STATE(1160), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(854), 2,
      sym__end_of_line,
      aux_sym_events_repeat1,
    ACTIONS(1632), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(105), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [42752] = 4,
    ACTIONS(1599), 1,
      anon_sym_DOT,
    STATE(775), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(481), 15,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LF,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [42780] = 3,
    ACTIONS(498), 1,
      sym__external_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(493), 16,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LF,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_CR,
  [42806] = 8,
    ACTIONS(41), 1,
      sym__external_identifier,
    ACTIONS(1630), 1,
      anon_sym_end,
    STATE(373), 1,
      sym__keywords,
    STATE(1160), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(848), 2,
      sym__end_of_line,
      aux_sym_events_repeat1,
    ACTIONS(1605), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(105), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [42842] = 4,
    ACTIONS(1599), 1,
      anon_sym_DOT,
    STATE(775), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(485), 15,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LF,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [42870] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(506), 17,
      sym__external_identifier,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_AT,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_true,
      anon_sym_false,
  [42894] = 4,
    ACTIONS(1599), 1,
      anon_sym_DOT,
    STATE(852), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(464), 15,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LF,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [42922] = 9,
    ACTIONS(1601), 1,
      anon_sym_TILDE,
    ACTIONS(1636), 1,
      anon_sym_end,
    STATE(711), 1,
      sym_identifier,
    STATE(822), 1,
      sym__keywords,
    STATE(1138), 1,
      sym_class_property,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(749), 2,
      sym_ignored_argument,
      sym_property_name,
    STATE(847), 2,
      sym_property,
      aux_sym_arguments_statement_repeat1,
    ACTIONS(1367), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [42960] = 6,
    ACTIONS(1317), 1,
      anon_sym_AT,
    ACTIONS(1321), 1,
      anon_sym_LBRACE,
    ACTIONS(1484), 1,
      anon_sym_LPAREN,
    STATE(826), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1638), 12,
      sym__external_identifier,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_true,
      anon_sym_false,
  [42991] = 5,
    ACTIONS(1642), 1,
      sym__external_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(861), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    ACTIONS(1359), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(1640), 9,
      anon_sym_TILDE,
      anon_sym_end,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [43020] = 5,
    ACTIONS(937), 1,
      sym__external_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(861), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    ACTIONS(1644), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(935), 9,
      anon_sym_TILDE,
      anon_sym_end,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [43049] = 4,
    ACTIONS(1313), 1,
      anon_sym_DOT,
    STATE(863), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(502), 14,
      sym__external_identifier,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_RBRACK,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_true,
      anon_sym_false,
  [43076] = 4,
    ACTIONS(1647), 1,
      anon_sym_DOT,
    STATE(863), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(479), 14,
      sym__external_identifier,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_RBRACK,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_true,
      anon_sym_false,
  [43103] = 5,
    ACTIONS(1652), 1,
      sym__external_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(861), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    ACTIONS(1359), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(1650), 9,
      anon_sym_TILDE,
      anon_sym_end,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [43132] = 5,
    ACTIONS(1656), 1,
      sym__external_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(861), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    ACTIONS(1359), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(1654), 9,
      anon_sym_TILDE,
      anon_sym_end,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [43161] = 5,
    ACTIONS(1612), 1,
      sym__external_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(861), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    ACTIONS(1359), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(1658), 9,
      anon_sym_TILDE,
      anon_sym_end,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [43190] = 3,
    ACTIONS(1662), 1,
      sym__external_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1660), 15,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LF,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_CR,
  [43215] = 5,
    ACTIONS(1666), 1,
      sym__external_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(861), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    ACTIONS(1359), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(1664), 9,
      anon_sym_TILDE,
      anon_sym_end,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [43244] = 7,
    ACTIONS(41), 1,
      sym__external_identifier,
    STATE(373), 1,
      sym__keywords,
    STATE(1126), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(18), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    ACTIONS(1668), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(105), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [43277] = 8,
    ACTIONS(1601), 1,
      anon_sym_TILDE,
    ACTIONS(1670), 1,
      anon_sym_end,
    STATE(731), 1,
      sym_identifier,
    STATE(822), 1,
      sym__keywords,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(749), 2,
      sym_ignored_argument,
      sym_property_name,
    STATE(871), 2,
      sym_property,
      aux_sym_properties_repeat1,
    ACTIONS(1367), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [43312] = 8,
    ACTIONS(1672), 1,
      anon_sym_TILDE,
    ACTIONS(1675), 1,
      anon_sym_end,
    STATE(731), 1,
      sym_identifier,
    STATE(822), 1,
      sym__keywords,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(749), 2,
      sym_ignored_argument,
      sym_property_name,
    STATE(871), 2,
      sym_property,
      aux_sym_properties_repeat1,
    ACTIONS(1677), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [43347] = 3,
    ACTIONS(918), 1,
      sym__external_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(910), 15,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LF,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_CR,
  [43372] = 8,
    ACTIONS(1601), 1,
      anon_sym_TILDE,
    ACTIONS(1680), 1,
      anon_sym_end,
    STATE(731), 1,
      sym_identifier,
    STATE(822), 1,
      sym__keywords,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(749), 2,
      sym_ignored_argument,
      sym_property_name,
    STATE(871), 2,
      sym_property,
      aux_sym_properties_repeat1,
    ACTIONS(1367), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [43407] = 3,
    ACTIONS(1684), 1,
      sym__external_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1682), 15,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LF,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_CR,
  [43432] = 5,
    ACTIONS(1688), 1,
      sym__external_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(861), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    ACTIONS(1359), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(1686), 9,
      anon_sym_TILDE,
      anon_sym_end,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [43461] = 6,
    ACTIONS(1317), 1,
      anon_sym_AT,
    ACTIONS(1321), 1,
      anon_sym_LBRACE,
    ACTIONS(1484), 1,
      anon_sym_LPAREN,
    STATE(826), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1469), 12,
      sym__external_identifier,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_true,
      anon_sym_false,
  [43492] = 5,
    ACTIONS(1690), 1,
      anon_sym_DOT,
    STATE(893), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(468), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(464), 11,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [43520] = 6,
    ACTIONS(1697), 1,
      sym__external_identifier,
    STATE(822), 1,
      sym__keywords,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(878), 2,
      sym_identifier,
      aux_sym_global_operator_repeat1,
    ACTIONS(1692), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(1694), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [43550] = 6,
    ACTIONS(1367), 1,
      sym__external_identifier,
    STATE(822), 1,
      sym__keywords,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(878), 2,
      sym_identifier,
      aux_sym_global_operator_repeat1,
    ACTIONS(1700), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(1365), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [43580] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(510), 15,
      sym__external_identifier,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_RBRACK,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_true,
      anon_sym_false,
  [43602] = 5,
    ACTIONS(1690), 1,
      anon_sym_DOT,
    STATE(888), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(487), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(485), 11,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [43630] = 5,
    ACTIONS(1244), 1,
      sym__external_identifier,
    ACTIONS(1702), 1,
      anon_sym_LF,
    STATE(882), 1,
      aux_sym_matrix_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1239), 12,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_RBRACK,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_true,
      anon_sym_false,
  [43658] = 9,
    ACTIONS(63), 1,
      sym__multioutput_variable_start,
    STATE(373), 1,
      sym__keywords,
    STATE(943), 1,
      sym_function_output,
    STATE(1057), 1,
      sym_identifier,
    STATE(1463), 1,
      sym_multioutput_variable,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(105), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(1705), 2,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
    ACTIONS(41), 6,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [43694] = 6,
    ACTIONS(1367), 1,
      sym__external_identifier,
    STATE(822), 1,
      sym__keywords,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(878), 2,
      sym_identifier,
      aux_sym_global_operator_repeat1,
    ACTIONS(1707), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(1365), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [43724] = 6,
    ACTIONS(1367), 1,
      sym__external_identifier,
    STATE(822), 1,
      sym__keywords,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(884), 2,
      sym_identifier,
      aux_sym_global_operator_repeat1,
    ACTIONS(1709), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(1365), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [43754] = 4,
    ACTIONS(1711), 1,
      anon_sym_DOT,
    STATE(894), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1586), 13,
      sym__external_identifier,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_true,
      anon_sym_false,
  [43780] = 9,
    ACTIONS(63), 1,
      sym__multioutput_variable_start,
    STATE(373), 1,
      sym__keywords,
    STATE(950), 1,
      sym_function_output,
    STATE(1054), 1,
      sym_identifier,
    STATE(1463), 1,
      sym_multioutput_variable,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(105), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(1713), 2,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
    ACTIONS(41), 6,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [43816] = 5,
    ACTIONS(1715), 1,
      anon_sym_DOT,
    STATE(888), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(498), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(493), 11,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [43844] = 5,
    ACTIONS(1718), 1,
      anon_sym_DOT,
    STATE(889), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(493), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(498), 11,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [43872] = 5,
    ACTIONS(1690), 1,
      anon_sym_DOT,
    STATE(881), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(491), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(489), 11,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [43900] = 6,
    ACTIONS(1367), 1,
      sym__external_identifier,
    STATE(822), 1,
      sym__keywords,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(879), 2,
      sym_identifier,
      aux_sym_global_operator_repeat1,
    ACTIONS(1721), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(1365), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [43930] = 9,
    ACTIONS(63), 1,
      sym__multioutput_variable_start,
    STATE(373), 1,
      sym__keywords,
    STATE(948), 1,
      sym_function_output,
    STATE(1061), 1,
      sym_identifier,
    STATE(1463), 1,
      sym_multioutput_variable,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(105), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(1723), 2,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
    ACTIONS(41), 6,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [43966] = 5,
    ACTIONS(1690), 1,
      anon_sym_DOT,
    STATE(888), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(483), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(481), 11,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [43994] = 4,
    ACTIONS(1725), 1,
      anon_sym_DOT,
    STATE(894), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(498), 13,
      sym__external_identifier,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_true,
      anon_sym_false,
  [44020] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(472), 15,
      sym__external_identifier,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_RBRACK,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_true,
      anon_sym_false,
  [44042] = 7,
    ACTIONS(1728), 1,
      anon_sym_RPAREN,
    ACTIONS(1730), 1,
      anon_sym_TILDE,
    STATE(452), 1,
      sym__keywords,
    STATE(1508), 1,
      sym__lambda_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1384), 2,
      sym_identifier,
      sym_ignored_argument,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [44073] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(918), 14,
      sym__external_identifier,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_RBRACK,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_true,
      anon_sym_false,
  [44094] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1406), 14,
      sym__external_identifier,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_RBRACK,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_true,
      anon_sym_false,
  [44115] = 6,
    ACTIONS(1264), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1266), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(10), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    ACTIONS(1732), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(1262), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
  [44144] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(498), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(493), 12,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [44167] = 8,
    ACTIONS(922), 1,
      aux_sym_matrix_token1,
    ACTIONS(1305), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1307), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1734), 1,
      sym__entry_delimiter,
    STATE(1094), 1,
      aux_sym_row_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(920), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(1303), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
  [44200] = 3,
    ACTIONS(1738), 1,
      sym__external_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1736), 13,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_CR,
  [44223] = 3,
    ACTIONS(1742), 1,
      sym__external_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1740), 13,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_CR,
  [44246] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(528), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(530), 12,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [44269] = 7,
    ACTIONS(1730), 1,
      anon_sym_TILDE,
    ACTIONS(1744), 1,
      anon_sym_RPAREN,
    STATE(452), 1,
      sym__keywords,
    STATE(1492), 1,
      sym__lambda_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1384), 2,
      sym_identifier,
      sym_ignored_argument,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [44300] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(530), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(528), 12,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [44323] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(498), 14,
      sym__external_identifier,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_RBRACE,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_true,
      anon_sym_false,
  [44344] = 6,
    ACTIONS(1746), 1,
      anon_sym_PIPE,
    ACTIONS(1748), 1,
      anon_sym_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1292), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1294), 4,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
    ACTIONS(1290), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
  [44373] = 7,
    ACTIONS(1730), 1,
      anon_sym_TILDE,
    ACTIONS(1750), 1,
      anon_sym_RPAREN,
    STATE(452), 1,
      sym__keywords,
    STATE(1503), 1,
      sym__lambda_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1384), 2,
      sym_identifier,
      sym_ignored_argument,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [44404] = 6,
    ACTIONS(1758), 1,
      anon_sym_PIPE,
    ACTIONS(1760), 1,
      anon_sym_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1756), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1752), 4,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
    ACTIONS(1754), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
  [44433] = 6,
    ACTIONS(1768), 1,
      anon_sym_PIPE,
    ACTIONS(1770), 1,
      anon_sym_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1766), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1762), 4,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
    ACTIONS(1764), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
  [44462] = 7,
    ACTIONS(1730), 1,
      anon_sym_TILDE,
    ACTIONS(1772), 1,
      anon_sym_RPAREN,
    STATE(452), 1,
      sym__keywords,
    STATE(1479), 1,
      sym__lambda_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1384), 2,
      sym_identifier,
      sym_ignored_argument,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [44493] = 6,
    ACTIONS(1578), 1,
      anon_sym_AMP,
    ACTIONS(1774), 1,
      anon_sym_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1539), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1552), 4,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
    ACTIONS(1554), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
  [44522] = 6,
    ACTIONS(1782), 1,
      anon_sym_PIPE,
    ACTIONS(1784), 1,
      anon_sym_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1780), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1776), 4,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
    ACTIONS(1778), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
  [44551] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(493), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(498), 12,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [44574] = 7,
    ACTIONS(1730), 1,
      anon_sym_TILDE,
    ACTIONS(1786), 1,
      anon_sym_RPAREN,
    STATE(452), 1,
      sym__keywords,
    STATE(1458), 1,
      sym__lambda_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1384), 2,
      sym_identifier,
      sym_ignored_argument,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [44605] = 6,
    ACTIONS(1794), 1,
      anon_sym_PIPE,
    ACTIONS(1796), 1,
      anon_sym_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1792), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1788), 4,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
    ACTIONS(1790), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
  [44634] = 6,
    ACTIONS(1804), 1,
      anon_sym_PIPE,
    ACTIONS(1806), 1,
      anon_sym_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1802), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1798), 4,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
    ACTIONS(1800), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
  [44663] = 7,
    ACTIONS(1730), 1,
      anon_sym_TILDE,
    ACTIONS(1808), 1,
      anon_sym_RPAREN,
    STATE(452), 1,
      sym__keywords,
    STATE(1493), 1,
      sym__lambda_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1384), 2,
      sym_identifier,
      sym_ignored_argument,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [44694] = 7,
    ACTIONS(1730), 1,
      anon_sym_TILDE,
    ACTIONS(1810), 1,
      anon_sym_RPAREN,
    STATE(452), 1,
      sym__keywords,
    STATE(1464), 1,
      sym__lambda_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1384), 2,
      sym_identifier,
      sym_ignored_argument,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [44725] = 8,
    ACTIONS(1305), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1307), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1814), 1,
      aux_sym_matrix_token1,
    ACTIONS(1816), 1,
      sym__entry_delimiter,
    STATE(1093), 1,
      aux_sym_row_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1812), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(1303), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
  [44758] = 7,
    ACTIONS(1730), 1,
      anon_sym_TILDE,
    ACTIONS(1818), 1,
      anon_sym_RPAREN,
    STATE(452), 1,
      sym__keywords,
    STATE(1475), 1,
      sym__lambda_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1384), 2,
      sym_identifier,
      sym_ignored_argument,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [44789] = 7,
    ACTIONS(1730), 1,
      anon_sym_TILDE,
    ACTIONS(1820), 1,
      anon_sym_RPAREN,
    STATE(452), 1,
      sym__keywords,
    STATE(1482), 1,
      sym__lambda_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1384), 2,
      sym_identifier,
      sym_ignored_argument,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [44820] = 7,
    ACTIONS(1730), 1,
      anon_sym_TILDE,
    ACTIONS(1822), 1,
      anon_sym_RPAREN,
    STATE(452), 1,
      sym__keywords,
    STATE(1486), 1,
      sym__lambda_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1384), 2,
      sym_identifier,
      sym_ignored_argument,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [44851] = 7,
    ACTIONS(1730), 1,
      anon_sym_TILDE,
    ACTIONS(1824), 1,
      anon_sym_RPAREN,
    STATE(452), 1,
      sym__keywords,
    STATE(1490), 1,
      sym__lambda_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1384), 2,
      sym_identifier,
      sym_ignored_argument,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [44882] = 6,
    ACTIONS(1597), 1,
      anon_sym_AMP,
    ACTIONS(1826), 1,
      anon_sym_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1591), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1593), 4,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
    ACTIONS(1595), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
  [44911] = 7,
    ACTIONS(1730), 1,
      anon_sym_TILDE,
    ACTIONS(1828), 1,
      anon_sym_RPAREN,
    STATE(452), 1,
      sym__keywords,
    STATE(1510), 1,
      sym__lambda_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1384), 2,
      sym_identifier,
      sym_ignored_argument,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [44942] = 7,
    ACTIONS(1730), 1,
      anon_sym_TILDE,
    ACTIONS(1830), 1,
      anon_sym_RPAREN,
    STATE(452), 1,
      sym__keywords,
    STATE(1512), 1,
      sym__lambda_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1384), 2,
      sym_identifier,
      sym_ignored_argument,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [44973] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1684), 13,
      sym__external_identifier,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_true,
      anon_sym_false,
  [44993] = 6,
    ACTIONS(1264), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1266), 1,
      anon_sym_PIPE_PIPE,
    STATE(364), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1832), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(1262), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
  [45021] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1662), 13,
      sym__external_identifier,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_true,
      anon_sym_false,
  [45041] = 6,
    ACTIONS(1305), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1307), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1836), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1834), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(1303), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
  [45069] = 5,
    ACTIONS(1838), 1,
      anon_sym_DOT,
    STATE(889), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(481), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(483), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
  [45095] = 5,
    ACTIONS(1838), 1,
      anon_sym_DOT,
    STATE(889), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(485), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(487), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
  [45121] = 3,
    ACTIONS(1840), 1,
      sym__external_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1544), 12,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_end,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_CR,
  [45143] = 3,
    ACTIONS(1842), 1,
      sym__external_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1620), 12,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_end,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_CR,
  [45165] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1469), 13,
      sym__external_identifier,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_true,
      anon_sym_false,
  [45185] = 6,
    ACTIONS(1264), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1266), 1,
      anon_sym_PIPE_PIPE,
    STATE(248), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1844), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(1262), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
  [45213] = 6,
    ACTIONS(1264), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1266), 1,
      anon_sym_PIPE_PIPE,
    STATE(248), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1844), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(1262), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
  [45241] = 5,
    ACTIONS(1838), 1,
      anon_sym_DOT,
    STATE(934), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(489), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(491), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
  [45267] = 5,
    ACTIONS(1838), 1,
      anon_sym_DOT,
    STATE(933), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(464), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(468), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
  [45293] = 6,
    ACTIONS(1846), 1,
      anon_sym_LPAREN,
    STATE(373), 1,
      sym__keywords,
    STATE(1019), 1,
      sym_attributes,
    STATE(1080), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(41), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [45320] = 6,
    STATE(373), 1,
      sym__keywords,
    STATE(1070), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(105), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(1848), 2,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
    ACTIONS(41), 6,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [45347] = 6,
    ACTIONS(1850), 1,
      anon_sym_LPAREN,
    STATE(11), 1,
      sym_iterator,
    STATE(452), 1,
      sym__keywords,
    STATE(1500), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [45374] = 8,
    ACTIONS(1349), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1351), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1852), 1,
      anon_sym_COMMA,
    STATE(1329), 1,
      aux_sym_arguments_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1345), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1854), 2,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(1347), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [45405] = 8,
    ACTIONS(1349), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1351), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1852), 1,
      anon_sym_COMMA,
    STATE(1287), 1,
      aux_sym_arguments_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1345), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1856), 2,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(1347), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [45436] = 5,
    ACTIONS(1264), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1266), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1858), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(1262), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
  [45461] = 6,
    STATE(373), 1,
      sym__keywords,
    STATE(1076), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(105), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(1860), 2,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
    ACTIONS(41), 6,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [45488] = 5,
    ACTIONS(1264), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1266), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1862), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(1262), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
  [45513] = 6,
    STATE(373), 1,
      sym__keywords,
    STATE(1072), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(105), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(1864), 2,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
    ACTIONS(41), 6,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [45540] = 9,
    ACTIONS(1335), 1,
      anon_sym_LBRACE,
    ACTIONS(1337), 1,
      anon_sym_EQ,
    ACTIONS(1866), 1,
      anon_sym_DOT,
    STATE(1042), 1,
      aux_sym_metaclass_operator_repeat1,
    STATE(1060), 1,
      sym_validation_functions,
    STATE(1131), 1,
      sym_default_value,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(865), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    ACTIONS(1416), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [45573] = 8,
    ACTIONS(1422), 1,
      anon_sym_case,
    ACTIONS(1424), 1,
      anon_sym_otherwise,
    ACTIONS(1870), 1,
      anon_sym_end,
    STATE(1516), 1,
      sym_otherwise_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1049), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    STATE(1106), 2,
      sym_case_clause,
      aux_sym_switch_statement_repeat1,
    ACTIONS(1868), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [45604] = 9,
    ACTIONS(1335), 1,
      anon_sym_LBRACE,
    ACTIONS(1337), 1,
      anon_sym_EQ,
    ACTIONS(1866), 1,
      anon_sym_DOT,
    STATE(1042), 1,
      aux_sym_metaclass_operator_repeat1,
    STATE(1063), 1,
      sym_validation_functions,
    STATE(1098), 1,
      sym_default_value,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(864), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    ACTIONS(1872), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [45637] = 5,
    ACTIONS(1730), 1,
      anon_sym_TILDE,
    STATE(452), 1,
      sym__keywords,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1438), 2,
      sym_identifier,
      sym_ignored_argument,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [45662] = 5,
    ACTIONS(1874), 1,
      anon_sym_LPAREN,
    STATE(904), 1,
      sym__keywords,
    STATE(940), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1876), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [45686] = 5,
    STATE(452), 1,
      sym__keywords,
    STATE(1399), 1,
      sym_attribute,
    STATE(1417), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [45710] = 5,
    STATE(904), 1,
      sym__keywords,
    STATE(1320), 1,
      sym_identifier,
    STATE(1397), 1,
      sym_property_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1876), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [45734] = 6,
    ACTIONS(1337), 1,
      anon_sym_EQ,
    STATE(1098), 1,
      sym_default_value,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(864), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    ACTIONS(1878), 3,
      anon_sym_vector,
      anon_sym_matrix,
      anon_sym_scalar,
    ACTIONS(1872), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [45760] = 8,
    ACTIONS(1349), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1351), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1880), 1,
      anon_sym_COMMA,
    ACTIONS(1882), 1,
      anon_sym_RPAREN,
    STATE(1393), 1,
      aux_sym_enum_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1345), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1347), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [45790] = 6,
    ACTIONS(1349), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1351), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1345), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1884), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(1347), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [45816] = 5,
    ACTIONS(1886), 1,
      anon_sym_LPAREN,
    STATE(373), 1,
      sym__keywords,
    STATE(428), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(41), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [45840] = 5,
    STATE(783), 1,
      sym__keywords,
    STATE(1078), 1,
      sym_identifier,
    STATE(1170), 1,
      sym_property_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1343), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [45864] = 8,
    ACTIONS(1888), 1,
      anon_sym_SEMI,
    ACTIONS(1890), 1,
      anon_sym_end,
    ACTIONS(1892), 1,
      anon_sym_properties,
    ACTIONS(1894), 1,
      anon_sym_methods,
    ACTIONS(1896), 1,
      anon_sym_events,
    ACTIONS(1898), 1,
      anon_sym_enumeration,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(969), 5,
      sym_properties,
      sym_methods,
      sym_events,
      sym_enumeration,
      aux_sym_class_definition_repeat1,
  [45894] = 5,
    STATE(783), 1,
      sym__keywords,
    STATE(1078), 1,
      sym_identifier,
    STATE(1082), 1,
      sym_property_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1343), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [45918] = 8,
    ACTIONS(1892), 1,
      anon_sym_properties,
    ACTIONS(1894), 1,
      anon_sym_methods,
    ACTIONS(1896), 1,
      anon_sym_events,
    ACTIONS(1898), 1,
      anon_sym_enumeration,
    ACTIONS(1900), 1,
      anon_sym_SEMI,
    ACTIONS(1902), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(978), 5,
      sym_properties,
      sym_methods,
      sym_events,
      sym_enumeration,
      aux_sym_class_definition_repeat1,
  [45948] = 8,
    ACTIONS(1888), 1,
      anon_sym_SEMI,
    ACTIONS(1892), 1,
      anon_sym_properties,
    ACTIONS(1894), 1,
      anon_sym_methods,
    ACTIONS(1896), 1,
      anon_sym_events,
    ACTIONS(1898), 1,
      anon_sym_enumeration,
    ACTIONS(1904), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(969), 5,
      sym_properties,
      sym_methods,
      sym_events,
      sym_enumeration,
      aux_sym_class_definition_repeat1,
  [45978] = 5,
    ACTIONS(1906), 1,
      anon_sym_LPAREN,
    STATE(783), 1,
      sym__keywords,
    STATE(841), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1343), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [46002] = 5,
    STATE(11), 1,
      sym_iterator,
    STATE(452), 1,
      sym__keywords,
    STATE(1500), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [46026] = 8,
    ACTIONS(1908), 1,
      anon_sym_SEMI,
    ACTIONS(1911), 1,
      anon_sym_end,
    ACTIONS(1913), 1,
      anon_sym_properties,
    ACTIONS(1916), 1,
      anon_sym_methods,
    ACTIONS(1919), 1,
      anon_sym_events,
    ACTIONS(1922), 1,
      anon_sym_enumeration,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(969), 5,
      sym_properties,
      sym_methods,
      sym_events,
      sym_enumeration,
      aux_sym_class_definition_repeat1,
  [46056] = 8,
    ACTIONS(1892), 1,
      anon_sym_properties,
    ACTIONS(1894), 1,
      anon_sym_methods,
    ACTIONS(1896), 1,
      anon_sym_events,
    ACTIONS(1898), 1,
      anon_sym_enumeration,
    ACTIONS(1925), 1,
      anon_sym_SEMI,
    ACTIONS(1927), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(966), 5,
      sym_properties,
      sym_methods,
      sym_events,
      sym_enumeration,
      aux_sym_class_definition_repeat1,
  [46086] = 8,
    ACTIONS(1888), 1,
      anon_sym_SEMI,
    ACTIONS(1892), 1,
      anon_sym_properties,
    ACTIONS(1894), 1,
      anon_sym_methods,
    ACTIONS(1896), 1,
      anon_sym_events,
    ACTIONS(1898), 1,
      anon_sym_enumeration,
    ACTIONS(1927), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(969), 5,
      sym_properties,
      sym_methods,
      sym_events,
      sym_enumeration,
      aux_sym_class_definition_repeat1,
  [46116] = 6,
    ACTIONS(1349), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1351), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1345), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1929), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(1347), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [46142] = 5,
    ACTIONS(1931), 1,
      anon_sym_STAR,
    STATE(783), 1,
      sym__keywords,
    STATE(788), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1343), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [46166] = 5,
    STATE(452), 1,
      sym__keywords,
    STATE(1494), 1,
      sym_identifier,
    STATE(1504), 1,
      sym_iterator,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [46190] = 5,
    ACTIONS(1933), 1,
      anon_sym_STAR,
    STATE(783), 1,
      sym__keywords,
    STATE(788), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1343), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [46214] = 5,
    STATE(452), 1,
      sym__keywords,
    STATE(1417), 1,
      sym_identifier,
    STATE(1423), 1,
      sym_attribute,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [46238] = 8,
    ACTIONS(1892), 1,
      anon_sym_properties,
    ACTIONS(1894), 1,
      anon_sym_methods,
    ACTIONS(1896), 1,
      anon_sym_events,
    ACTIONS(1898), 1,
      anon_sym_enumeration,
    ACTIONS(1935), 1,
      anon_sym_SEMI,
    ACTIONS(1937), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(963), 5,
      sym_properties,
      sym_methods,
      sym_events,
      sym_enumeration,
      aux_sym_class_definition_repeat1,
  [46268] = 8,
    ACTIONS(1888), 1,
      anon_sym_SEMI,
    ACTIONS(1892), 1,
      anon_sym_properties,
    ACTIONS(1894), 1,
      anon_sym_methods,
    ACTIONS(1896), 1,
      anon_sym_events,
    ACTIONS(1898), 1,
      anon_sym_enumeration,
    ACTIONS(1937), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(969), 5,
      sym_properties,
      sym_methods,
      sym_events,
      sym_enumeration,
      aux_sym_class_definition_repeat1,
  [46298] = 5,
    STATE(904), 1,
      sym__keywords,
    STATE(1320), 1,
      sym_identifier,
    STATE(1402), 1,
      sym_property_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1876), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [46322] = 5,
    ACTIONS(1939), 1,
      anon_sym_LPAREN,
    STATE(890), 1,
      sym_identifier,
    STATE(906), 1,
      sym__keywords,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1941), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [46346] = 5,
    ACTIONS(1943), 1,
      anon_sym_STAR,
    STATE(904), 1,
      sym__keywords,
    STATE(915), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1876), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [46370] = 5,
    ACTIONS(1945), 1,
      anon_sym_STAR,
    STATE(822), 1,
      sym__keywords,
    STATE(853), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1367), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [46394] = 5,
    ACTIONS(1947), 1,
      anon_sym_STAR,
    STATE(822), 1,
      sym__keywords,
    STATE(853), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1367), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [46418] = 5,
    ACTIONS(1949), 1,
      anon_sym_LPAREN,
    STATE(193), 1,
      sym_identifier,
    STATE(197), 1,
      sym__keywords,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1951), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [46442] = 5,
    STATE(904), 1,
      sym__keywords,
    STATE(1320), 1,
      sym_identifier,
    STATE(1388), 1,
      sym_property_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1876), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [46466] = 5,
    ACTIONS(1953), 1,
      anon_sym_STAR,
    STATE(809), 1,
      sym__keywords,
    STATE(907), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1088), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [46490] = 5,
    ACTIONS(1955), 1,
      anon_sym_STAR,
    STATE(809), 1,
      sym__keywords,
    STATE(907), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1088), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [46514] = 5,
    ACTIONS(1957), 1,
      anon_sym_LPAREN,
    STATE(452), 1,
      sym__keywords,
    STATE(562), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [46538] = 5,
    ACTIONS(1959), 1,
      anon_sym_LPAREN,
    STATE(445), 1,
      sym__keywords,
    STATE(499), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(695), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [46562] = 5,
    ACTIONS(1961), 1,
      anon_sym_LPAREN,
    STATE(82), 1,
      sym_identifier,
    STATE(93), 1,
      sym__keywords,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(994), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [46586] = 5,
    ACTIONS(1963), 1,
      anon_sym_STAR,
    STATE(904), 1,
      sym__keywords,
    STATE(915), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1876), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [46610] = 5,
    ACTIONS(1965), 1,
      anon_sym_LPAREN,
    STATE(452), 1,
      sym__keywords,
    STATE(562), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [46634] = 5,
    ACTIONS(1967), 1,
      anon_sym_LPAREN,
    STATE(445), 1,
      sym__keywords,
    STATE(499), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(695), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [46658] = 5,
    ACTIONS(1969), 1,
      anon_sym_LPAREN,
    STATE(82), 1,
      sym_identifier,
    STATE(93), 1,
      sym__keywords,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(994), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [46682] = 5,
    STATE(452), 1,
      sym__keywords,
    STATE(1395), 1,
      sym_attribute,
    STATE(1417), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [46706] = 5,
    STATE(904), 1,
      sym__keywords,
    STATE(1320), 1,
      sym_identifier,
    STATE(1373), 1,
      sym_property_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1876), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [46730] = 5,
    STATE(904), 1,
      sym__keywords,
    STATE(1320), 1,
      sym_identifier,
    STATE(1375), 1,
      sym_property_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1876), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [46754] = 5,
    ACTIONS(1971), 1,
      anon_sym_LPAREN,
    STATE(373), 1,
      sym__keywords,
    STATE(428), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(41), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [46778] = 5,
    STATE(904), 1,
      sym__keywords,
    STATE(1320), 1,
      sym_identifier,
    STATE(1382), 1,
      sym_property_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1876), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [46802] = 5,
    STATE(904), 1,
      sym__keywords,
    STATE(1320), 1,
      sym_identifier,
    STATE(1383), 1,
      sym_property_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1876), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [46826] = 5,
    STATE(904), 1,
      sym__keywords,
    STATE(1320), 1,
      sym_identifier,
    STATE(1390), 1,
      sym_property_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1876), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [46850] = 5,
    STATE(904), 1,
      sym__keywords,
    STATE(1320), 1,
      sym_identifier,
    STATE(1391), 1,
      sym_property_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1876), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [46874] = 5,
    STATE(904), 1,
      sym__keywords,
    STATE(1320), 1,
      sym_identifier,
    STATE(1401), 1,
      sym_property_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1876), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [46898] = 8,
    ACTIONS(1892), 1,
      anon_sym_properties,
    ACTIONS(1894), 1,
      anon_sym_methods,
    ACTIONS(1896), 1,
      anon_sym_events,
    ACTIONS(1898), 1,
      anon_sym_enumeration,
    ACTIONS(1973), 1,
      anon_sym_SEMI,
    ACTIONS(1975), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(971), 5,
      sym_properties,
      sym_methods,
      sym_events,
      sym_enumeration,
      aux_sym_class_definition_repeat1,
  [46928] = 4,
    STATE(93), 1,
      sym__keywords,
    STATE(97), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(994), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [46949] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1979), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(1977), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
      anon_sym_properties,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [46968] = 6,
    ACTIONS(1349), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1351), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1345), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1981), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(1347), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [46993] = 4,
    STATE(373), 1,
      sym__keywords,
    STATE(1074), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(41), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [47014] = 4,
    STATE(373), 1,
      sym__keywords,
    STATE(420), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(41), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [47035] = 4,
    STATE(452), 1,
      sym__keywords,
    STATE(1392), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [47056] = 6,
    ACTIONS(1349), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1351), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1345), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1983), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(1347), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [47081] = 4,
    STATE(373), 1,
      sym__keywords,
    STATE(1073), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(41), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [47102] = 4,
    STATE(373), 1,
      sym__keywords,
    STATE(1076), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(41), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [47123] = 4,
    STATE(904), 1,
      sym__keywords,
    STATE(941), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1876), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [47144] = 7,
    ACTIONS(1349), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1351), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1985), 1,
      anon_sym_COMMA,
    ACTIONS(1987), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1345), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1347), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [47171] = 4,
    STATE(904), 1,
      sym__keywords,
    STATE(915), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1876), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [47192] = 4,
    STATE(373), 1,
      sym__keywords,
    STATE(1070), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(41), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [47213] = 4,
    STATE(783), 1,
      sym__keywords,
    STATE(857), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1343), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [47234] = 4,
    STATE(373), 1,
      sym__keywords,
    STATE(1068), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(41), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [47255] = 4,
    STATE(373), 1,
      sym__keywords,
    STATE(455), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(41), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [47276] = 4,
    STATE(809), 1,
      sym__keywords,
    STATE(907), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1088), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [47297] = 4,
    STATE(452), 1,
      sym__keywords,
    STATE(1456), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [47318] = 4,
    STATE(373), 1,
      sym__keywords,
    STATE(1072), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(41), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [47339] = 4,
    STATE(373), 1,
      sym__keywords,
    STATE(1069), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(41), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [47360] = 4,
    STATE(877), 1,
      sym_identifier,
    STATE(906), 1,
      sym__keywords,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1941), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [47381] = 4,
    STATE(900), 1,
      sym_identifier,
    STATE(906), 1,
      sym__keywords,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1941), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [47402] = 4,
    STATE(192), 1,
      sym_identifier,
    STATE(197), 1,
      sym__keywords,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1951), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [47423] = 4,
    STATE(452), 1,
      sym__keywords,
    STATE(1425), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [47444] = 4,
    STATE(196), 1,
      sym_identifier,
    STATE(197), 1,
      sym__keywords,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1951), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [47465] = 4,
    STATE(783), 1,
      sym__keywords,
    STATE(788), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1343), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [47486] = 4,
    STATE(452), 1,
      sym__keywords,
    STATE(561), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [47507] = 4,
    STATE(452), 1,
      sym__keywords,
    STATE(614), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [47528] = 7,
    ACTIONS(1335), 1,
      anon_sym_LBRACE,
    ACTIONS(1337), 1,
      anon_sym_EQ,
    STATE(1060), 1,
      sym_validation_functions,
    STATE(1131), 1,
      sym_default_value,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(865), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    ACTIONS(1416), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [47555] = 4,
    STATE(445), 1,
      sym__keywords,
    STATE(537), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(695), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [47576] = 4,
    STATE(373), 1,
      sym__keywords,
    STATE(958), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(41), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [47597] = 4,
    STATE(445), 1,
      sym__keywords,
    STATE(538), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(695), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [47618] = 4,
    STATE(77), 1,
      sym_identifier,
    STATE(93), 1,
      sym__keywords,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(994), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [47639] = 7,
    ACTIONS(1335), 1,
      anon_sym_LBRACE,
    ACTIONS(1337), 1,
      anon_sym_EQ,
    STATE(1063), 1,
      sym_validation_functions,
    STATE(1098), 1,
      sym_default_value,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(864), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    ACTIONS(1872), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [47666] = 4,
    STATE(783), 1,
      sym__keywords,
    STATE(1127), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1343), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [47687] = 4,
    STATE(822), 1,
      sym__keywords,
    STATE(853), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1367), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [47708] = 4,
    STATE(452), 1,
      sym__keywords,
    STATE(1496), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(751), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [47729] = 4,
    ACTIONS(1989), 1,
      anon_sym_DOT,
    STATE(775), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1582), 7,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_AMP,
      anon_sym_LF,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_CR,
  [47749] = 6,
    ACTIONS(930), 1,
      anon_sym_COMMA,
    ACTIONS(1349), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1351), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1345), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1347), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [47773] = 6,
    ACTIONS(1349), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1351), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1991), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1345), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1347), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [47797] = 6,
    ACTIONS(1349), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1351), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1993), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1345), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1347), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [47821] = 6,
    ACTIONS(1349), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1351), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1995), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1345), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1347), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [47845] = 6,
    ACTIONS(1349), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1351), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1997), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1345), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1347), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [47869] = 6,
    ACTIONS(1349), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1351), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1999), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1345), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1347), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [47893] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1049), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    ACTIONS(935), 3,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
    ACTIONS(2001), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [47913] = 5,
    ACTIONS(2006), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2008), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1192), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2004), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [47934] = 5,
    ACTIONS(2012), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2014), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1217), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2010), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [47955] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2016), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [47970] = 5,
    ACTIONS(2020), 1,
      anon_sym_LPAREN,
    STATE(1121), 1,
      sym_attributes,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(762), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    ACTIONS(2018), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [47991] = 6,
    ACTIONS(2024), 1,
      anon_sym_LPAREN,
    ACTIONS(2026), 1,
      anon_sym_EQ,
    STATE(48), 1,
      sym__end_of_line,
    STATE(1177), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2022), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [48014] = 5,
    ACTIONS(2030), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2032), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(562), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2028), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [48035] = 5,
    ACTIONS(1078), 1,
      anon_sym_LPAREN,
    STATE(1105), 1,
      sym__argument_attributes,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(753), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    ACTIONS(1076), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [48056] = 6,
    ACTIONS(2024), 1,
      anon_sym_LPAREN,
    ACTIONS(2026), 1,
      anon_sym_EQ,
    STATE(53), 1,
      sym__end_of_line,
    STATE(1175), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2034), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [48079] = 5,
    ACTIONS(1349), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1351), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1345), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1347), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [48100] = 5,
    ACTIONS(2038), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2040), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1303), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2036), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [48121] = 5,
    ACTIONS(1337), 1,
      anon_sym_EQ,
    STATE(1098), 1,
      sym_default_value,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(864), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    ACTIONS(1872), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [48142] = 6,
    ACTIONS(2024), 1,
      anon_sym_LPAREN,
    ACTIONS(2026), 1,
      anon_sym_EQ,
    STATE(62), 1,
      sym__end_of_line,
    STATE(1171), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2042), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [48165] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2044), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [48180] = 5,
    ACTIONS(1337), 1,
      anon_sym_EQ,
    STATE(1122), 1,
      sym_default_value,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(875), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    ACTIONS(2046), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [48201] = 5,
    ACTIONS(1286), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1288), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1282), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1284), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [48222] = 5,
    ACTIONS(1337), 1,
      anon_sym_EQ,
    STATE(1131), 1,
      sym_default_value,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(865), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    ACTIONS(1416), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [48243] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1682), 7,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_AMP,
      anon_sym_LF,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_CR,
  [48257] = 5,
    ACTIONS(528), 1,
      anon_sym_EQ,
    ACTIONS(2024), 1,
      anon_sym_LPAREN,
    STATE(1326), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2048), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [48277] = 5,
    ACTIONS(2052), 1,
      anon_sym_LT,
    STATE(1004), 1,
      sym__end_of_line,
    STATE(1161), 1,
      sym_superclasses,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2050), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [48297] = 5,
    ACTIONS(2024), 1,
      anon_sym_LPAREN,
    STATE(61), 1,
      sym__end_of_line,
    STATE(1202), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2054), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [48317] = 5,
    ACTIONS(2024), 1,
      anon_sym_LPAREN,
    STATE(36), 1,
      sym__end_of_line,
    STATE(1163), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2056), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [48337] = 5,
    ACTIONS(2020), 1,
      anon_sym_LPAREN,
    STATE(851), 1,
      sym__end_of_line,
    STATE(1178), 1,
      sym_attributes,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2058), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [48357] = 5,
    ACTIONS(2024), 1,
      anon_sym_LPAREN,
    STATE(30), 1,
      sym__end_of_line,
    STATE(1164), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2060), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [48377] = 5,
    ACTIONS(2024), 1,
      anon_sym_LPAREN,
    STATE(45), 1,
      sym__end_of_line,
    STATE(1189), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2062), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [48397] = 5,
    ACTIONS(2024), 1,
      anon_sym_LPAREN,
    STATE(34), 1,
      sym__end_of_line,
    STATE(1179), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2064), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [48417] = 5,
    ACTIONS(2020), 1,
      anon_sym_LPAREN,
    STATE(808), 1,
      sym__end_of_line,
    STATE(1173), 1,
      sym_attributes,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2066), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [48437] = 5,
    ACTIONS(2024), 1,
      anon_sym_LPAREN,
    STATE(65), 1,
      sym__end_of_line,
    STATE(1196), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2068), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [48457] = 5,
    ACTIONS(2020), 1,
      anon_sym_LPAREN,
    STATE(770), 1,
      sym__end_of_line,
    STATE(1185), 1,
      sym_attributes,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2070), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [48477] = 4,
    ACTIONS(1866), 1,
      anon_sym_DOT,
    STATE(1042), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2072), 5,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_AMP,
      anon_sym_LF,
      anon_sym_CR,
  [48495] = 5,
    ACTIONS(1080), 1,
      anon_sym_EQ,
    ACTIONS(2024), 1,
      anon_sym_LPAREN,
    STATE(1326), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2048), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [48515] = 5,
    ACTIONS(2052), 1,
      anon_sym_LT,
    STATE(965), 1,
      sym__end_of_line,
    STATE(1197), 1,
      sym_superclasses,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2074), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [48535] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1660), 7,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_AMP,
      anon_sym_LF,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_CR,
  [48549] = 4,
    ACTIONS(2078), 1,
      anon_sym_AMP,
    STATE(1111), 1,
      aux_sym_superclasses_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2076), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [48566] = 6,
    ACTIONS(2083), 1,
      aux_sym_matrix_token1,
    ACTIONS(2086), 1,
      sym__entry_delimiter,
    STATE(1093), 1,
      aux_sym_row_repeat1,
    STATE(1183), 1,
      aux_sym__index_row_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2080), 2,
      anon_sym_SEMI,
      anon_sym_RBRACK,
  [48587] = 6,
    ACTIONS(127), 1,
      anon_sym_else,
    ACTIONS(2088), 1,
      anon_sym_elseif,
    ACTIONS(2090), 1,
      anon_sym_end,
    STATE(1478), 1,
      sym_else_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1200), 2,
      sym_elseif_clause,
      aux_sym_if_statement_repeat1,
  [48608] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2092), 6,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_properties,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [48621] = 6,
    ACTIONS(2094), 1,
      anon_sym_end,
    ACTIONS(2096), 1,
      anon_sym_case,
    ACTIONS(2098), 1,
      anon_sym_otherwise,
    STATE(1516), 1,
      sym_otherwise_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1156), 2,
      sym_case_clause,
      aux_sym_switch_statement_repeat1,
  [48642] = 4,
    ACTIONS(2100), 1,
      ts_builtin_sym_end,
    ACTIONS(2104), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2102), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [48659] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2106), 6,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_properties,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [48672] = 4,
    ACTIONS(2108), 1,
      ts_builtin_sym_end,
    ACTIONS(2112), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2110), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [48689] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(781), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    ACTIONS(2114), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [48704] = 5,
    ACTIONS(747), 1,
      anon_sym_COLON,
    ACTIONS(753), 1,
      aux_sym_number_token1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(755), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    STATE(1437), 2,
      sym_spread_operator,
      sym_number,
  [48723] = 5,
    ACTIONS(237), 1,
      ts_builtin_sym_end,
    ACTIONS(2116), 1,
      anon_sym_SEMI,
    ACTIONS(2120), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2118), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [48742] = 5,
    ACTIONS(922), 1,
      aux_sym_matrix_token1,
    ACTIONS(1734), 1,
      sym__entry_delimiter,
    STATE(1154), 1,
      aux_sym_row_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(920), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [48761] = 5,
    ACTIONS(926), 1,
      aux_sym_matrix_token1,
    ACTIONS(2122), 1,
      sym__entry_delimiter,
    STATE(1154), 1,
      aux_sym_row_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(924), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [48780] = 5,
    ACTIONS(205), 1,
      ts_builtin_sym_end,
    ACTIONS(2124), 1,
      anon_sym_SEMI,
    ACTIONS(2128), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2126), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [48799] = 6,
    ACTIONS(808), 1,
      aux_sym_matrix_token1,
    ACTIONS(2130), 1,
      sym__entry_delimiter,
    STATE(1094), 1,
      aux_sym_row_repeat1,
    STATE(1205), 1,
      aux_sym__index_row_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(805), 2,
      anon_sym_SEMI,
      anon_sym_RBRACK,
  [48820] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2132), 6,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_properties,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [48833] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(875), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    ACTIONS(2046), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [48848] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2134), 6,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_properties,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [48861] = 4,
    ACTIONS(2138), 1,
      sym_command_argument,
    STATE(1100), 1,
      aux_sym_command_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2136), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [48878] = 5,
    ACTIONS(225), 1,
      ts_builtin_sym_end,
    ACTIONS(2141), 1,
      anon_sym_SEMI,
    ACTIONS(2145), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2143), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [48897] = 4,
    ACTIONS(225), 1,
      ts_builtin_sym_end,
    ACTIONS(2145), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2143), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [48914] = 6,
    ACTIONS(127), 1,
      anon_sym_else,
    ACTIONS(2088), 1,
      anon_sym_elseif,
    ACTIONS(2147), 1,
      anon_sym_end,
    STATE(1498), 1,
      sym_else_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1200), 2,
      sym_elseif_clause,
      aux_sym_if_statement_repeat1,
  [48935] = 5,
    ACTIONS(257), 1,
      ts_builtin_sym_end,
    ACTIONS(2149), 1,
      anon_sym_SEMI,
    ACTIONS(2153), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2151), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [48954] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(751), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    ACTIONS(2155), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [48969] = 6,
    ACTIONS(2096), 1,
      anon_sym_case,
    ACTIONS(2098), 1,
      anon_sym_otherwise,
    ACTIONS(2157), 1,
      anon_sym_end,
    STATE(1522), 1,
      sym_otherwise_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1156), 2,
      sym_case_clause,
      aux_sym_switch_statement_repeat1,
  [48990] = 4,
    ACTIONS(2159), 1,
      ts_builtin_sym_end,
    ACTIONS(2163), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2161), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [49007] = 4,
    ACTIONS(1599), 1,
      anon_sym_DOT,
    STATE(775), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2165), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [49024] = 4,
    ACTIONS(2167), 1,
      ts_builtin_sym_end,
    ACTIONS(2171), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2169), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [49041] = 4,
    ACTIONS(2175), 1,
      sym_command_argument,
    STATE(1100), 1,
      aux_sym_command_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2173), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [49058] = 4,
    ACTIONS(2078), 1,
      anon_sym_AMP,
    STATE(1134), 1,
      aux_sym_superclasses_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2177), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [49075] = 5,
    ACTIONS(2159), 1,
      ts_builtin_sym_end,
    ACTIONS(2163), 1,
      anon_sym_function,
    ACTIONS(2179), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2161), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [49094] = 5,
    ACTIONS(2167), 1,
      ts_builtin_sym_end,
    ACTIONS(2171), 1,
      anon_sym_function,
    ACTIONS(2181), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2169), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [49113] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2183), 6,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_properties,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [49126] = 4,
    ACTIONS(2185), 1,
      ts_builtin_sym_end,
    ACTIONS(2189), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2187), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [49143] = 4,
    ACTIONS(275), 1,
      ts_builtin_sym_end,
    ACTIONS(2193), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2191), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [49160] = 5,
    ACTIONS(2185), 1,
      ts_builtin_sym_end,
    ACTIONS(2189), 1,
      anon_sym_function,
    ACTIONS(2195), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2187), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [49179] = 4,
    ACTIONS(2197), 1,
      ts_builtin_sym_end,
    ACTIONS(2201), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2199), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [49196] = 5,
    ACTIONS(275), 1,
      ts_builtin_sym_end,
    ACTIONS(2193), 1,
      anon_sym_function,
    ACTIONS(2203), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2191), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [49215] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2205), 6,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_properties,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [49228] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(756), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    ACTIONS(2207), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [49243] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(868), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    ACTIONS(2209), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [49258] = 4,
    ACTIONS(2211), 1,
      ts_builtin_sym_end,
    ACTIONS(2215), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2213), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [49275] = 6,
    ACTIONS(127), 1,
      anon_sym_else,
    ACTIONS(2088), 1,
      anon_sym_elseif,
    ACTIONS(2090), 1,
      anon_sym_end,
    STATE(1478), 1,
      sym_else_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1103), 2,
      sym_elseif_clause,
      aux_sym_if_statement_repeat1,
  [49296] = 5,
    ACTIONS(2211), 1,
      ts_builtin_sym_end,
    ACTIONS(2215), 1,
      anon_sym_function,
    ACTIONS(2217), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2213), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [49315] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(22), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    ACTIONS(2219), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [49330] = 4,
    ACTIONS(1599), 1,
      anon_sym_DOT,
    STATE(1108), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2221), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [49347] = 4,
    ACTIONS(2225), 1,
      sym_command_argument,
    STATE(1110), 1,
      aux_sym_command_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2223), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [49364] = 4,
    ACTIONS(2227), 1,
      ts_builtin_sym_end,
    ACTIONS(2231), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2229), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [49381] = 5,
    ACTIONS(747), 1,
      anon_sym_COLON,
    ACTIONS(753), 1,
      aux_sym_number_token1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(755), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    STATE(1419), 2,
      sym_spread_operator,
      sym_number,
  [49400] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(864), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    ACTIONS(1872), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [49415] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2233), 6,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_properties,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [49428] = 6,
    ACTIONS(127), 1,
      anon_sym_else,
    ACTIONS(2088), 1,
      anon_sym_elseif,
    ACTIONS(2235), 1,
      anon_sym_end,
    STATE(1501), 1,
      sym_else_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1200), 2,
      sym_elseif_clause,
      aux_sym_if_statement_repeat1,
  [49449] = 4,
    ACTIONS(2239), 1,
      anon_sym_AMP,
    STATE(1134), 1,
      aux_sym_superclasses_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2237), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [49466] = 5,
    ACTIONS(2227), 1,
      ts_builtin_sym_end,
    ACTIONS(2231), 1,
      anon_sym_function,
    ACTIONS(2242), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2229), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [49485] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2244), 2,
      sym__external_identifier,
      anon_sym_arguments,
    ACTIONS(2246), 2,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
    ACTIONS(2248), 2,
      anon_sym_get,
      anon_sym_set,
  [49502] = 4,
    ACTIONS(2250), 1,
      ts_builtin_sym_end,
    ACTIONS(2254), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2252), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [49519] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(866), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    ACTIONS(2256), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [49534] = 5,
    ACTIONS(2250), 1,
      ts_builtin_sym_end,
    ACTIONS(2254), 1,
      anon_sym_function,
    ACTIONS(2258), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2252), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [49553] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2260), 6,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_properties,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [49566] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2262), 6,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_properties,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [49579] = 4,
    ACTIONS(2024), 1,
      anon_sym_LPAREN,
    STATE(1330), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2264), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [49596] = 4,
    ACTIONS(2024), 1,
      anon_sym_LPAREN,
    STATE(1264), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2266), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [49613] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(780), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    ACTIONS(2268), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [49628] = 5,
    ACTIONS(251), 1,
      ts_builtin_sym_end,
    ACTIONS(2270), 1,
      anon_sym_SEMI,
    ACTIONS(2274), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2272), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [49647] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(865), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    ACTIONS(1416), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [49662] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2276), 6,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_properties,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [49675] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2278), 6,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_properties,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [49688] = 5,
    ACTIONS(1814), 1,
      aux_sym_matrix_token1,
    ACTIONS(1816), 1,
      sym__entry_delimiter,
    STATE(1093), 1,
      aux_sym_row_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1812), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [49707] = 4,
    ACTIONS(251), 1,
      ts_builtin_sym_end,
    ACTIONS(2274), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2272), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [49724] = 6,
    ACTIONS(127), 1,
      anon_sym_else,
    ACTIONS(2088), 1,
      anon_sym_elseif,
    ACTIONS(2147), 1,
      anon_sym_end,
    STATE(1498), 1,
      sym_else_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1133), 2,
      sym_elseif_clause,
      aux_sym_if_statement_repeat1,
  [49745] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2280), 6,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_properties,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [49758] = 5,
    ACTIONS(922), 1,
      aux_sym_matrix_token1,
    ACTIONS(1734), 1,
      sym__entry_delimiter,
    STATE(1094), 1,
      aux_sym_row_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(920), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [49777] = 5,
    ACTIONS(1836), 1,
      aux_sym_matrix_token1,
    ACTIONS(2282), 1,
      sym__entry_delimiter,
    STATE(1154), 1,
      aux_sym_row_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1834), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [49796] = 4,
    ACTIONS(2285), 1,
      sym__single_quote_string_end,
    STATE(1193), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2287), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [49812] = 4,
    ACTIONS(2291), 1,
      anon_sym_case,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2289), 2,
      anon_sym_end,
      anon_sym_otherwise,
    STATE(1156), 2,
      sym_case_clause,
      aux_sym_switch_statement_repeat1,
  [49828] = 4,
    ACTIONS(2294), 1,
      sym__single_quote_string_end,
    STATE(1159), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2296), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [49844] = 4,
    ACTIONS(2294), 1,
      sym__double_quote_string_end,
    STATE(1198), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2298), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [49860] = 4,
    ACTIONS(2300), 1,
      sym__single_quote_string_end,
    STATE(1159), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2302), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [49876] = 3,
    STATE(936), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2305), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [49890] = 3,
    STATE(970), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2307), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [49904] = 5,
    ACTIONS(2311), 1,
      aux_sym_matrix_token1,
    ACTIONS(2313), 1,
      sym__entry_delimiter,
    STATE(1162), 1,
      aux_sym__index_row_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2309), 2,
      anon_sym_SEMI,
      anon_sym_RBRACK,
  [49922] = 3,
    STATE(29), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2316), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [49936] = 3,
    STATE(31), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2318), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [49950] = 4,
    ACTIONS(2320), 1,
      sym__single_quote_string_end,
    STATE(1172), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2322), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [49966] = 5,
    ACTIONS(789), 1,
      aux_sym_matrix_token1,
    ACTIONS(2324), 1,
      sym__entry_delimiter,
    STATE(1205), 1,
      aux_sym__index_row_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(787), 2,
      anon_sym_SEMI,
      anon_sym_RBRACK,
  [49984] = 3,
    STATE(248), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1844), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [49998] = 4,
    ACTIONS(2326), 1,
      sym__single_quote_string_end,
    STATE(1180), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2328), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [50014] = 4,
    ACTIONS(2326), 1,
      sym__double_quote_string_end,
    STATE(1181), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2330), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [50030] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2237), 5,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_AMP,
      anon_sym_LF,
      anon_sym_CR,
  [50042] = 3,
    STATE(55), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2332), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [50056] = 4,
    ACTIONS(2334), 1,
      sym__single_quote_string_end,
    STATE(1159), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2296), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [50072] = 3,
    STATE(811), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2336), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [50086] = 3,
    STATE(248), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1844), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [50100] = 3,
    STATE(37), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2338), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [50114] = 4,
    ACTIONS(2344), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2340), 2,
      anon_sym_SEMI,
      anon_sym_RBRACK,
    ACTIONS(2342), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
  [50130] = 3,
    STATE(35), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2346), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [50144] = 3,
    STATE(850), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2348), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [50158] = 3,
    STATE(41), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2350), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [50172] = 4,
    ACTIONS(2352), 1,
      sym__single_quote_string_end,
    STATE(1159), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2296), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [50188] = 4,
    ACTIONS(2352), 1,
      sym__double_quote_string_end,
    STATE(1198), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2298), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [50204] = 4,
    ACTIONS(2285), 1,
      sym__double_quote_string_end,
    STATE(1194), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2354), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [50220] = 5,
    ACTIONS(789), 1,
      aux_sym_matrix_token1,
    ACTIONS(2324), 1,
      sym__entry_delimiter,
    STATE(1162), 1,
      aux_sym__index_row_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(787), 2,
      anon_sym_SEMI,
      anon_sym_RBRACK,
  [50238] = 5,
    ACTIONS(2356), 1,
      anon_sym_SEMI,
    ACTIONS(2359), 1,
      aux_sym_matrix_token1,
    STATE(1184), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2362), 2,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [50256] = 3,
    STATE(772), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2364), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [50270] = 3,
    STATE(364), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1832), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [50284] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2366), 5,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_EQ,
      anon_sym_CR,
  [50296] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1836), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1834), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [50310] = 3,
    STATE(50), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2368), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [50324] = 3,
    ACTIONS(2372), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2370), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [50338] = 3,
    STATE(366), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2374), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [50352] = 3,
    STATE(935), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2376), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [50366] = 4,
    ACTIONS(2378), 1,
      sym__single_quote_string_end,
    STATE(1159), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2296), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [50382] = 4,
    ACTIONS(2378), 1,
      sym__double_quote_string_end,
    STATE(1198), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2298), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [50398] = 5,
    ACTIONS(2382), 1,
      aux_sym_matrix_token1,
    ACTIONS(2384), 1,
      sym__entry_delimiter,
    STATE(1183), 1,
      aux_sym__index_row_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2380), 2,
      anon_sym_SEMI,
      anon_sym_RBRACK,
  [50416] = 3,
    STATE(66), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2386), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [50430] = 3,
    STATE(977), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2388), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [50444] = 4,
    ACTIONS(2300), 1,
      sym__double_quote_string_end,
    STATE(1198), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2390), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [50460] = 6,
    ACTIONS(1154), 1,
      anon_sym_LPAREN,
    ACTIONS(1161), 1,
      anon_sym_AT,
    ACTIONS(1165), 1,
      anon_sym_LBRACE,
    ACTIONS(2393), 1,
      anon_sym_RPAREN,
    STATE(465), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [50480] = 5,
    ACTIONS(2395), 1,
      anon_sym_elseif,
    ACTIONS(2398), 1,
      anon_sym_else,
    ACTIONS(2400), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1200), 2,
      sym_elseif_clause,
      aux_sym_if_statement_repeat1,
  [50498] = 3,
    STATE(247), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2402), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [50512] = 3,
    STATE(58), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2404), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [50526] = 4,
    ACTIONS(2334), 1,
      sym__double_quote_string_end,
    STATE(1198), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2298), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [50542] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2406), 5,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_EQ,
      anon_sym_CR,
  [50554] = 5,
    ACTIONS(799), 1,
      aux_sym_matrix_token1,
    ACTIONS(2408), 1,
      sym__entry_delimiter,
    STATE(1162), 1,
      aux_sym__index_row_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(797), 2,
      anon_sym_SEMI,
      anon_sym_RBRACK,
  [50572] = 4,
    ACTIONS(2410), 1,
      sym__single_quote_string_end,
    STATE(1157), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2412), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [50588] = 4,
    ACTIONS(2410), 1,
      sym__double_quote_string_end,
    STATE(1158), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2414), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [50604] = 4,
    ACTIONS(2320), 1,
      sym__double_quote_string_end,
    STATE(1203), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2416), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [50620] = 3,
    STATE(247), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2402), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [50634] = 5,
    ACTIONS(868), 1,
      anon_sym_RBRACE,
    ACTIONS(2418), 1,
      anon_sym_SEMI,
    ACTIONS(2420), 1,
      aux_sym_matrix_token1,
    STATE(1247), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [50651] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2229), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [50662] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2102), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [50673] = 4,
    ACTIONS(221), 1,
      anon_sym_end,
    ACTIONS(223), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(205), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [50688] = 3,
    ACTIONS(2422), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2229), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [50701] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2424), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [50712] = 4,
    ACTIONS(263), 1,
      anon_sym_end,
    ACTIONS(265), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(225), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [50727] = 4,
    ACTIONS(227), 1,
      anon_sym_end,
    ACTIONS(229), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(225), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [50742] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2426), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [50753] = 3,
    ACTIONS(2428), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2151), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [50766] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2430), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [50777] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2432), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [50788] = 4,
    ACTIONS(2434), 1,
      ts_builtin_sym_end,
    ACTIONS(2436), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1222), 2,
      sym_function_definition,
      aux_sym_source_file_repeat1,
  [50803] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2439), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [50814] = 5,
    ACTIONS(2418), 1,
      anon_sym_SEMI,
    ACTIONS(2420), 1,
      aux_sym_matrix_token1,
    ACTIONS(2441), 1,
      anon_sym_RBRACK,
    STATE(1184), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [50831] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2443), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [50842] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2445), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [50853] = 4,
    ACTIONS(2447), 1,
      anon_sym_COMMA,
    STATE(1227), 1,
      aux_sym_arguments_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2450), 2,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [50868] = 4,
    ACTIONS(287), 1,
      anon_sym_end,
    ACTIONS(289), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(251), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [50883] = 4,
    ACTIONS(2452), 1,
      anon_sym_end,
    ACTIONS(2454), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2227), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [50898] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2456), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [50909] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2458), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [50920] = 4,
    ACTIONS(291), 1,
      anon_sym_end,
    ACTIONS(293), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(257), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [50935] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2460), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [50946] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2462), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [50957] = 5,
    ACTIONS(1317), 1,
      anon_sym_AT,
    ACTIONS(1321), 1,
      anon_sym_LBRACE,
    ACTIONS(1484), 1,
      anon_sym_LPAREN,
    STATE(826), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [50974] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2464), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [50985] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2466), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [50996] = 5,
    ACTIONS(2468), 1,
      anon_sym_LPAREN,
    ACTIONS(2470), 1,
      anon_sym_AT,
    ACTIONS(2472), 1,
      anon_sym_LBRACE,
    STATE(391), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [51013] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2474), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [51024] = 5,
    ACTIONS(866), 1,
      anon_sym_RBRACK,
    ACTIONS(2418), 1,
      anon_sym_SEMI,
    ACTIONS(2420), 1,
      aux_sym_matrix_token1,
    STATE(1245), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [51041] = 3,
    ACTIONS(2476), 1,
      aux_sym_matrix_token1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2362), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [51054] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2478), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [51065] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2480), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [51076] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2482), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [51087] = 5,
    ACTIONS(2418), 1,
      anon_sym_SEMI,
    ACTIONS(2420), 1,
      aux_sym_matrix_token1,
    ACTIONS(2484), 1,
      anon_sym_RBRACK,
    STATE(1184), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [51104] = 5,
    ACTIONS(2418), 1,
      anon_sym_SEMI,
    ACTIONS(2420), 1,
      aux_sym_matrix_token1,
    ACTIONS(2484), 1,
      anon_sym_RBRACK,
    STATE(1255), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [51121] = 5,
    ACTIONS(2418), 1,
      anon_sym_SEMI,
    ACTIONS(2420), 1,
      aux_sym_matrix_token1,
    ACTIONS(2486), 1,
      anon_sym_RBRACE,
    STATE(1184), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [51138] = 5,
    ACTIONS(2418), 1,
      anon_sym_SEMI,
    ACTIONS(2420), 1,
      aux_sym_matrix_token1,
    ACTIONS(2486), 1,
      anon_sym_RBRACE,
    STATE(1256), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [51155] = 5,
    ACTIONS(904), 1,
      anon_sym_RBRACE,
    ACTIONS(2418), 1,
      anon_sym_SEMI,
    ACTIONS(2420), 1,
      aux_sym_matrix_token1,
    STATE(1292), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [51172] = 3,
    ACTIONS(2488), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2126), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [51185] = 4,
    ACTIONS(2490), 1,
      anon_sym_end,
    ACTIONS(2492), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2185), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [51200] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2494), 2,
      anon_sym_SEMI,
      anon_sym_RBRACK,
    ACTIONS(2496), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
  [51213] = 3,
    ACTIONS(2498), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2143), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [51226] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2500), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [51237] = 5,
    ACTIONS(2418), 1,
      anon_sym_SEMI,
    ACTIONS(2420), 1,
      aux_sym_matrix_token1,
    ACTIONS(2502), 1,
      anon_sym_RBRACK,
    STATE(1184), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [51254] = 5,
    ACTIONS(2418), 1,
      anon_sym_SEMI,
    ACTIONS(2420), 1,
      aux_sym_matrix_token1,
    ACTIONS(2504), 1,
      anon_sym_RBRACE,
    STATE(1184), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [51271] = 5,
    ACTIONS(2506), 1,
      anon_sym_SEMI,
    ACTIONS(2508), 1,
      aux_sym_matrix_token1,
    ACTIONS(2510), 1,
      anon_sym_RBRACK,
    STATE(1260), 1,
      aux_sym__index_matrix_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [51288] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2512), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [51299] = 4,
    ACTIONS(2514), 1,
      anon_sym_end,
    ACTIONS(2516), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2250), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [51314] = 5,
    ACTIONS(2506), 1,
      anon_sym_SEMI,
    ACTIONS(2508), 1,
      aux_sym_matrix_token1,
    ACTIONS(2518), 1,
      anon_sym_RBRACK,
    STATE(1319), 1,
      aux_sym__index_matrix_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [51331] = 5,
    ACTIONS(2506), 1,
      anon_sym_SEMI,
    ACTIONS(2508), 1,
      aux_sym_matrix_token1,
    ACTIONS(2518), 1,
      anon_sym_RBRACK,
    STATE(1265), 1,
      aux_sym__index_matrix_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [51348] = 3,
    ACTIONS(2520), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2118), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [51361] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2143), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [51372] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2522), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [51383] = 5,
    ACTIONS(2506), 1,
      anon_sym_SEMI,
    ACTIONS(2508), 1,
      aux_sym_matrix_token1,
    ACTIONS(2524), 1,
      anon_sym_RBRACK,
    STATE(1319), 1,
      aux_sym__index_matrix_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [51400] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2526), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [51411] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2528), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [51422] = 4,
    ACTIONS(2530), 1,
      anon_sym_DOT,
    STATE(889), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1586), 2,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
  [51437] = 4,
    ACTIONS(239), 1,
      anon_sym_end,
    ACTIONS(241), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(237), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [51452] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2532), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [51463] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2534), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [51474] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2187), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [51485] = 3,
    ACTIONS(2536), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2187), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [51498] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2213), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [51509] = 3,
    ACTIONS(2538), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2213), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [51522] = 3,
    ACTIONS(2540), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2191), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [51535] = 5,
    ACTIONS(2506), 1,
      anon_sym_SEMI,
    ACTIONS(2508), 1,
      aux_sym_matrix_token1,
    ACTIONS(2542), 1,
      anon_sym_RBRACK,
    STATE(1319), 1,
      aux_sym__index_matrix_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [51552] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2544), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [51563] = 5,
    ACTIONS(2506), 1,
      anon_sym_SEMI,
    ACTIONS(2508), 1,
      aux_sym_matrix_token1,
    ACTIONS(2542), 1,
      anon_sym_RBRACK,
    STATE(1322), 1,
      aux_sym__index_matrix_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [51580] = 5,
    ACTIONS(2506), 1,
      anon_sym_SEMI,
    ACTIONS(2508), 1,
      aux_sym_matrix_token1,
    ACTIONS(2546), 1,
      anon_sym_RBRACK,
    STATE(1277), 1,
      aux_sym__index_matrix_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [51597] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2191), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [51608] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2548), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [51619] = 3,
    ACTIONS(2550), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2342), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [51632] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2552), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [51643] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2554), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [51654] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2556), 2,
      anon_sym_SEMI,
      anon_sym_RBRACK,
    ACTIONS(2559), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
  [51667] = 4,
    ACTIONS(1852), 1,
      anon_sym_COMMA,
    STATE(1227), 1,
      aux_sym_arguments_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2562), 2,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [51682] = 4,
    ACTIONS(2564), 1,
      anon_sym_end,
    ACTIONS(2566), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2185), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [51697] = 4,
    ACTIONS(430), 1,
      ts_builtin_sym_end,
    ACTIONS(2568), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1222), 2,
      sym_function_definition,
      aux_sym_source_file_repeat1,
  [51712] = 5,
    ACTIONS(2418), 1,
      anon_sym_SEMI,
    ACTIONS(2420), 1,
      aux_sym_matrix_token1,
    ACTIONS(2570), 1,
      anon_sym_RBRACK,
    STATE(1184), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [51729] = 5,
    ACTIONS(2418), 1,
      anon_sym_SEMI,
    ACTIONS(2420), 1,
      aux_sym_matrix_token1,
    ACTIONS(2570), 1,
      anon_sym_RBRACK,
    STATE(1224), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [51746] = 5,
    ACTIONS(2418), 1,
      anon_sym_SEMI,
    ACTIONS(2420), 1,
      aux_sym_matrix_token1,
    ACTIONS(2572), 1,
      anon_sym_RBRACE,
    STATE(1184), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [51763] = 5,
    ACTIONS(2418), 1,
      anon_sym_SEMI,
    ACTIONS(2420), 1,
      aux_sym_matrix_token1,
    ACTIONS(2572), 1,
      anon_sym_RBRACE,
    STATE(1318), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [51780] = 4,
    ACTIONS(295), 1,
      anon_sym_end,
    ACTIONS(297), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(275), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [51795] = 4,
    ACTIONS(2574), 1,
      anon_sym_COMMA,
    STATE(1353), 1,
      aux_sym__index_arguments_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2577), 2,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [51810] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2579), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [51821] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2581), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [51832] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2272), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [51843] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2309), 2,
      anon_sym_SEMI,
      anon_sym_RBRACK,
    ACTIONS(2311), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
  [51856] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2583), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [51867] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2585), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [51878] = 5,
    ACTIONS(1154), 1,
      anon_sym_LPAREN,
    ACTIONS(1165), 1,
      anon_sym_LBRACE,
    ACTIONS(1183), 1,
      anon_sym_AT,
    STATE(467), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [51895] = 4,
    ACTIONS(277), 1,
      anon_sym_end,
    ACTIONS(279), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(275), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [51910] = 4,
    ACTIONS(2587), 1,
      anon_sym_end,
    ACTIONS(2589), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2227), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [51925] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2591), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [51936] = 5,
    ACTIONS(886), 1,
      anon_sym_RBRACK,
    ACTIONS(2418), 1,
      anon_sym_SEMI,
    ACTIONS(2420), 1,
      aux_sym_matrix_token1,
    STATE(1310), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [51953] = 5,
    ACTIONS(888), 1,
      anon_sym_RBRACE,
    ACTIONS(2418), 1,
      anon_sym_SEMI,
    ACTIONS(2420), 1,
      aux_sym_matrix_token1,
    STATE(1312), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [51970] = 4,
    ACTIONS(2593), 1,
      anon_sym_COMMA,
    STATE(1308), 1,
      aux_sym__index_arguments_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2596), 2,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [51985] = 5,
    ACTIONS(1321), 1,
      anon_sym_LBRACE,
    ACTIONS(1484), 1,
      anon_sym_LPAREN,
    ACTIONS(2598), 1,
      anon_sym_AT,
    STATE(833), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [52002] = 5,
    ACTIONS(2418), 1,
      anon_sym_SEMI,
    ACTIONS(2420), 1,
      aux_sym_matrix_token1,
    ACTIONS(2600), 1,
      anon_sym_RBRACK,
    STATE(1184), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [52019] = 5,
    ACTIONS(2418), 1,
      anon_sym_SEMI,
    ACTIONS(2420), 1,
      aux_sym_matrix_token1,
    ACTIONS(2600), 1,
      anon_sym_RBRACK,
    STATE(1314), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [52036] = 5,
    ACTIONS(2418), 1,
      anon_sym_SEMI,
    ACTIONS(2420), 1,
      aux_sym_matrix_token1,
    ACTIONS(2602), 1,
      anon_sym_RBRACE,
    STATE(1184), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [52053] = 5,
    ACTIONS(2418), 1,
      anon_sym_SEMI,
    ACTIONS(2420), 1,
      aux_sym_matrix_token1,
    ACTIONS(2602), 1,
      anon_sym_RBRACE,
    STATE(1315), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [52070] = 5,
    ACTIONS(2418), 1,
      anon_sym_SEMI,
    ACTIONS(2420), 1,
      aux_sym_matrix_token1,
    ACTIONS(2604), 1,
      anon_sym_RBRACK,
    STATE(1184), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [52087] = 5,
    ACTIONS(2418), 1,
      anon_sym_SEMI,
    ACTIONS(2420), 1,
      aux_sym_matrix_token1,
    ACTIONS(2606), 1,
      anon_sym_RBRACE,
    STATE(1184), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [52104] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2608), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [52115] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2610), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [52126] = 5,
    ACTIONS(2418), 1,
      anon_sym_SEMI,
    ACTIONS(2420), 1,
      aux_sym_matrix_token1,
    ACTIONS(2612), 1,
      anon_sym_RBRACE,
    STATE(1184), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [52143] = 5,
    ACTIONS(2614), 1,
      anon_sym_SEMI,
    ACTIONS(2617), 1,
      aux_sym_matrix_token1,
    ACTIONS(2620), 1,
      anon_sym_RBRACK,
    STATE(1319), 1,
      aux_sym__index_matrix_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [52160] = 4,
    ACTIONS(2622), 1,
      anon_sym_DOT,
    STATE(1268), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1556), 2,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
  [52175] = 5,
    ACTIONS(2624), 1,
      anon_sym_LPAREN,
    ACTIONS(2626), 1,
      anon_sym_AT,
    ACTIONS(2628), 1,
      anon_sym_LBRACE,
    STATE(438), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [52192] = 5,
    ACTIONS(2506), 1,
      anon_sym_SEMI,
    ACTIONS(2508), 1,
      aux_sym_matrix_token1,
    ACTIONS(2630), 1,
      anon_sym_RBRACK,
    STATE(1319), 1,
      aux_sym__index_matrix_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [52209] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2632), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [52220] = 4,
    ACTIONS(2568), 1,
      anon_sym_function,
    ACTIONS(2634), 1,
      ts_builtin_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1222), 2,
      sym_function_definition,
      aux_sym_source_file_repeat1,
  [52235] = 5,
    ACTIONS(2624), 1,
      anon_sym_LPAREN,
    ACTIONS(2628), 1,
      anon_sym_LBRACE,
    ACTIONS(2636), 1,
      anon_sym_AT,
    STATE(436), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [52252] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2638), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [52263] = 5,
    ACTIONS(900), 1,
      anon_sym_RBRACK,
    ACTIONS(2418), 1,
      anon_sym_SEMI,
    ACTIONS(2420), 1,
      aux_sym_matrix_token1,
    STATE(1331), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [52280] = 5,
    ACTIONS(902), 1,
      anon_sym_RBRACE,
    ACTIONS(2418), 1,
      anon_sym_SEMI,
    ACTIONS(2420), 1,
      aux_sym_matrix_token1,
    STATE(1333), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [52297] = 4,
    ACTIONS(1852), 1,
      anon_sym_COMMA,
    STATE(1227), 1,
      aux_sym_arguments_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2640), 2,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [52312] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2642), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [52323] = 5,
    ACTIONS(2418), 1,
      anon_sym_SEMI,
    ACTIONS(2420), 1,
      aux_sym_matrix_token1,
    ACTIONS(2644), 1,
      anon_sym_RBRACK,
    STATE(1184), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [52340] = 5,
    ACTIONS(2418), 1,
      anon_sym_SEMI,
    ACTIONS(2420), 1,
      aux_sym_matrix_token1,
    ACTIONS(2644), 1,
      anon_sym_RBRACK,
    STATE(1336), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [52357] = 5,
    ACTIONS(2418), 1,
      anon_sym_SEMI,
    ACTIONS(2420), 1,
      aux_sym_matrix_token1,
    ACTIONS(2646), 1,
      anon_sym_RBRACE,
    STATE(1184), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [52374] = 5,
    ACTIONS(2418), 1,
      anon_sym_SEMI,
    ACTIONS(2420), 1,
      aux_sym_matrix_token1,
    ACTIONS(2646), 1,
      anon_sym_RBRACE,
    STATE(1337), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [52391] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2648), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [52402] = 5,
    ACTIONS(2418), 1,
      anon_sym_SEMI,
    ACTIONS(2420), 1,
      aux_sym_matrix_token1,
    ACTIONS(2650), 1,
      anon_sym_RBRACK,
    STATE(1184), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [52419] = 5,
    ACTIONS(2418), 1,
      anon_sym_SEMI,
    ACTIONS(2420), 1,
      aux_sym_matrix_token1,
    ACTIONS(2652), 1,
      anon_sym_RBRACE,
    STATE(1184), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [52436] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2161), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [52447] = 3,
    ACTIONS(2654), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2161), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [52460] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2199), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [52471] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2252), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [52482] = 5,
    ACTIONS(2656), 1,
      anon_sym_LPAREN,
    ACTIONS(2658), 1,
      anon_sym_AT,
    ACTIONS(2660), 1,
      anon_sym_LBRACE,
    STATE(99), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [52499] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2662), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [52510] = 5,
    ACTIONS(2656), 1,
      anon_sym_LPAREN,
    ACTIONS(2660), 1,
      anon_sym_LBRACE,
    ACTIONS(2664), 1,
      anon_sym_AT,
    STATE(101), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [52527] = 3,
    ACTIONS(2666), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2252), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [52540] = 4,
    ACTIONS(247), 1,
      anon_sym_end,
    ACTIONS(249), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(237), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [52555] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2668), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [52566] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2670), 4,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_get,
      anon_sym_set,
  [52577] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2672), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [52588] = 4,
    ACTIONS(2674), 1,
      anon_sym_end,
    ACTIONS(2676), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2250), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [52603] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2678), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [52614] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2680), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [52625] = 4,
    ACTIONS(2682), 1,
      anon_sym_COMMA,
    STATE(1308), 1,
      aux_sym__index_arguments_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2685), 2,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [52640] = 4,
    ACTIONS(259), 1,
      anon_sym_end,
    ACTIONS(261), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(257), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [52655] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2687), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [52666] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2689), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [52677] = 5,
    ACTIONS(890), 1,
      anon_sym_RBRACK,
    ACTIONS(2418), 1,
      anon_sym_SEMI,
    ACTIONS(2420), 1,
      aux_sym_matrix_token1,
    STATE(1290), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [52694] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2691), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [52705] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2693), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [52716] = 4,
    ACTIONS(207), 1,
      anon_sym_end,
    ACTIONS(213), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(205), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [52731] = 5,
    ACTIONS(2468), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_LBRACE,
    ACTIONS(2695), 1,
      anon_sym_AT,
    STATE(381), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [52748] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2697), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [52759] = 3,
    ACTIONS(2699), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2272), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [52772] = 4,
    ACTIONS(253), 1,
      anon_sym_end,
    ACTIONS(255), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(251), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [52787] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2244), 4,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_get,
      anon_sym_set,
  [52798] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2701), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [52809] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2110), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [52820] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2169), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [52831] = 3,
    ACTIONS(2703), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2169), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [52844] = 5,
    ACTIONS(1154), 1,
      anon_sym_LPAREN,
    ACTIONS(1161), 1,
      anon_sym_AT,
    ACTIONS(1165), 1,
      anon_sym_LBRACE,
    STATE(465), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [52861] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2705), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [52871] = 3,
    ACTIONS(2707), 1,
      anon_sym_COMMA,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2709), 2,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [52883] = 4,
    ACTIONS(1321), 1,
      anon_sym_LBRACE,
    ACTIONS(1484), 1,
      anon_sym_LPAREN,
    STATE(828), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [52897] = 3,
    ACTIONS(2711), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2227), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [52909] = 4,
    ACTIONS(1321), 1,
      anon_sym_LBRACE,
    ACTIONS(1484), 1,
      anon_sym_LPAREN,
    STATE(804), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [52923] = 3,
    ACTIONS(2713), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(225), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [52935] = 4,
    ACTIONS(2715), 1,
      anon_sym_COMMA,
    ACTIONS(2717), 1,
      anon_sym_RPAREN,
    STATE(1389), 1,
      aux_sym_attributes_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [52949] = 3,
    ACTIONS(2719), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(257), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [52961] = 4,
    ACTIONS(2721), 1,
      anon_sym_COMMA,
    ACTIONS(2723), 1,
      anon_sym_RPAREN,
    STATE(1394), 1,
      aux_sym__argument_attributes_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [52975] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2725), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [52985] = 3,
    ACTIONS(2727), 1,
      aux_sym_matrix_token1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2620), 2,
      anon_sym_SEMI,
      anon_sym_RBRACK,
  [52997] = 4,
    ACTIONS(1154), 1,
      anon_sym_LPAREN,
    ACTIONS(1165), 1,
      anon_sym_LBRACE,
    STATE(476), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [53011] = 4,
    ACTIONS(1154), 1,
      anon_sym_LPAREN,
    ACTIONS(1165), 1,
      anon_sym_LBRACE,
    STATE(477), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [53025] = 4,
    ACTIONS(2729), 1,
      anon_sym_COMMA,
    ACTIONS(2731), 1,
      anon_sym_RPAREN,
    STATE(1407), 1,
      aux_sym__lambda_arguments_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [53039] = 4,
    ACTIONS(2733), 1,
      anon_sym_COMMA,
    ACTIONS(2735), 1,
      anon_sym_RPAREN,
    STATE(1406), 1,
      aux_sym_dimensions_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [53053] = 4,
    ACTIONS(2737), 1,
      anon_sym_end,
    ACTIONS(2739), 1,
      anon_sym_catch,
    STATE(1472), 1,
      sym_catch_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [53067] = 3,
    ACTIONS(2741), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2167), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [53079] = 4,
    ACTIONS(2468), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_LBRACE,
    STATE(386), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [53093] = 4,
    ACTIONS(2743), 1,
      anon_sym_COMMA,
    ACTIONS(2746), 1,
      anon_sym_RPAREN,
    STATE(1389), 1,
      aux_sym_attributes_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [53107] = 4,
    ACTIONS(2624), 1,
      anon_sym_LPAREN,
    ACTIONS(2628), 1,
      anon_sym_LBRACE,
    STATE(434), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [53121] = 4,
    ACTIONS(2624), 1,
      anon_sym_LPAREN,
    ACTIONS(2628), 1,
      anon_sym_LBRACE,
    STATE(439), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [53135] = 4,
    ACTIONS(2721), 1,
      anon_sym_COMMA,
    ACTIONS(2748), 1,
      anon_sym_RPAREN,
    STATE(1379), 1,
      aux_sym__argument_attributes_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [53149] = 4,
    ACTIONS(1880), 1,
      anon_sym_COMMA,
    ACTIONS(2750), 1,
      anon_sym_RPAREN,
    STATE(1416), 1,
      aux_sym_enum_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [53163] = 4,
    ACTIONS(2752), 1,
      anon_sym_COMMA,
    ACTIONS(2755), 1,
      anon_sym_RPAREN,
    STATE(1394), 1,
      aux_sym__argument_attributes_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [53177] = 4,
    ACTIONS(2715), 1,
      anon_sym_COMMA,
    ACTIONS(2757), 1,
      anon_sym_RPAREN,
    STATE(1377), 1,
      aux_sym_attributes_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [53191] = 3,
    ACTIONS(2759), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(275), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [53203] = 4,
    ACTIONS(2468), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_LBRACE,
    STATE(389), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [53217] = 3,
    ACTIONS(2761), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(237), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [53229] = 4,
    ACTIONS(2715), 1,
      anon_sym_COMMA,
    ACTIONS(2763), 1,
      anon_sym_RPAREN,
    STATE(1403), 1,
      aux_sym_attributes_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [53243] = 3,
    ACTIONS(151), 1,
      anon_sym_else,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2765), 2,
      anon_sym_elseif,
      anon_sym_end,
  [53255] = 4,
    ACTIONS(2656), 1,
      anon_sym_LPAREN,
    ACTIONS(2660), 1,
      anon_sym_LBRACE,
    STATE(91), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [53269] = 4,
    ACTIONS(2656), 1,
      anon_sym_LPAREN,
    ACTIONS(2660), 1,
      anon_sym_LBRACE,
    STATE(92), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [53283] = 4,
    ACTIONS(2715), 1,
      anon_sym_COMMA,
    ACTIONS(2767), 1,
      anon_sym_RPAREN,
    STATE(1389), 1,
      aux_sym_attributes_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [53297] = 3,
    ACTIONS(2769), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2159), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [53309] = 3,
    ACTIONS(2771), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2250), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [53321] = 4,
    ACTIONS(2773), 1,
      anon_sym_COMMA,
    ACTIONS(2776), 1,
      anon_sym_RPAREN,
    STATE(1406), 1,
      aux_sym_dimensions_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [53335] = 4,
    ACTIONS(2729), 1,
      anon_sym_COMMA,
    ACTIONS(2778), 1,
      anon_sym_RPAREN,
    STATE(1409), 1,
      aux_sym__lambda_arguments_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [53349] = 3,
    ACTIONS(2782), 1,
      anon_sym_else,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2780), 2,
      anon_sym_elseif,
      anon_sym_end,
  [53361] = 4,
    ACTIONS(2784), 1,
      anon_sym_COMMA,
    ACTIONS(2787), 1,
      anon_sym_RPAREN,
    STATE(1409), 1,
      aux_sym__lambda_arguments_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [53375] = 3,
    ACTIONS(2789), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(205), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [53387] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2791), 3,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
  [53397] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2496), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [53407] = 3,
    ACTIONS(2793), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2185), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [53419] = 3,
    ACTIONS(2795), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2211), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [53431] = 3,
    ACTIONS(2797), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(251), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [53443] = 4,
    ACTIONS(1981), 1,
      anon_sym_RPAREN,
    ACTIONS(2799), 1,
      anon_sym_COMMA,
    STATE(1416), 1,
      aux_sym_enum_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [53457] = 3,
    ACTIONS(2804), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2802), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [53469] = 4,
    ACTIONS(2739), 1,
      anon_sym_catch,
    ACTIONS(2806), 1,
      anon_sym_end,
    STATE(1515), 1,
      sym_catch_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [53483] = 4,
    ACTIONS(2733), 1,
      anon_sym_COMMA,
    ACTIONS(2808), 1,
      anon_sym_RPAREN,
    STATE(1385), 1,
      aux_sym_dimensions_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [53497] = 3,
    ACTIONS(422), 1,
      anon_sym_end,
    ACTIONS(424), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [53508] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2108), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [53517] = 3,
    ACTIONS(394), 1,
      anon_sym_end,
    ACTIONS(396), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [53528] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2746), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [53537] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2100), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [53546] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2810), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [53555] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(275), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [53564] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2167), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [53573] = 3,
    ACTIONS(2812), 1,
      anon_sym_end,
    ACTIONS(2814), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [53584] = 3,
    ACTIONS(2816), 1,
      anon_sym_end,
    ACTIONS(2818), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [53595] = 3,
    ACTIONS(2820), 1,
      anon_sym_end,
    ACTIONS(2822), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [53606] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(918), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [53615] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2227), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [53624] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1684), 2,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
  [53633] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2159), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [53642] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2197), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [53651] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2250), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [53660] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2776), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [53669] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2787), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [53678] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1662), 2,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
  [53687] = 3,
    ACTIONS(410), 1,
      anon_sym_end,
    ACTIONS(412), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [53698] = 3,
    ACTIONS(406), 1,
      anon_sym_end,
    ACTIONS(408), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [53709] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(251), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [53718] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2185), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [53727] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(225), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [53736] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2211), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [53745] = 3,
    ACTIONS(402), 1,
      anon_sym_end,
    ACTIONS(404), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [53756] = 3,
    ACTIONS(398), 1,
      anon_sym_end,
    ACTIONS(400), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [53767] = 2,
    ACTIONS(2824), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [53775] = 2,
    ACTIONS(2826), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [53783] = 2,
    ACTIONS(2828), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [53791] = 2,
    ACTIONS(2830), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [53799] = 2,
    ACTIONS(2832), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [53807] = 2,
    ACTIONS(2834), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [53815] = 2,
    ACTIONS(2836), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [53823] = 2,
    ACTIONS(2838), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [53831] = 2,
    ACTIONS(2840), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [53839] = 2,
    ACTIONS(2842), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [53847] = 2,
    ACTIONS(2844), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [53855] = 2,
    ACTIONS(2846), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [53863] = 2,
    ACTIONS(2848), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [53871] = 2,
    ACTIONS(2850), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [53879] = 2,
    ACTIONS(2852), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [53887] = 2,
    ACTIONS(2854), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [53895] = 2,
    ACTIONS(2856), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [53903] = 2,
    ACTIONS(2858), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [53911] = 2,
    ACTIONS(2860), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [53919] = 2,
    ACTIONS(2862), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [53927] = 2,
    ACTIONS(2860), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [53935] = 2,
    ACTIONS(2864), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [53943] = 2,
    ACTIONS(2866), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [53951] = 2,
    ACTIONS(2842), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [53959] = 2,
    ACTIONS(2868), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [53967] = 2,
    ACTIONS(2870), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [53975] = 2,
    ACTIONS(2872), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [53983] = 2,
    ACTIONS(2874), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [53991] = 2,
    ACTIONS(2090), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [53999] = 2,
    ACTIONS(2876), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [54007] = 2,
    ACTIONS(2147), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [54015] = 2,
    ACTIONS(2878), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [54023] = 2,
    ACTIONS(2880), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [54031] = 2,
    ACTIONS(2824), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [54039] = 2,
    ACTIONS(2882), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [54047] = 2,
    ACTIONS(2884), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [54055] = 2,
    ACTIONS(2886), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [54063] = 2,
    ACTIONS(2888), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [54071] = 2,
    ACTIONS(2890), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [54079] = 2,
    ACTIONS(2892), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [54087] = 2,
    ACTIONS(2894), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [54095] = 2,
    ACTIONS(2896), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [54103] = 2,
    ACTIONS(2898), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [54111] = 2,
    ACTIONS(2094), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [54119] = 2,
    ACTIONS(2900), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [54127] = 2,
    ACTIONS(2902), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [54135] = 2,
    ACTIONS(2904), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [54143] = 2,
    ACTIONS(2906), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [54151] = 2,
    ACTIONS(2908), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [54159] = 2,
    ACTIONS(2910), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [54167] = 2,
    ACTIONS(2235), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [54175] = 2,
    ACTIONS(2912), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [54183] = 2,
    ACTIONS(2914), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [54191] = 2,
    ACTIONS(2916), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [54199] = 2,
    ACTIONS(2918), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [54207] = 2,
    ACTIONS(2920), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [54215] = 2,
    ACTIONS(2922), 1,
      anon_sym_COMMA,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [54223] = 2,
    ACTIONS(2924), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [54231] = 2,
    ACTIONS(2926), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [54239] = 2,
    ACTIONS(2928), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [54247] = 2,
    ACTIONS(2930), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [54255] = 2,
    ACTIONS(2932), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [54263] = 2,
    ACTIONS(2934), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [54271] = 2,
    ACTIONS(2936), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [54279] = 2,
    ACTIONS(2938), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [54287] = 2,
    ACTIONS(2940), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [54295] = 2,
    ACTIONS(2806), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [54303] = 2,
    ACTIONS(2737), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [54311] = 2,
    ACTIONS(2157), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [54319] = 2,
    ACTIONS(2942), 1,
      ts_builtin_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [54327] = 2,
    ACTIONS(2936), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [54335] = 2,
    ACTIONS(2393), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [54343] = 2,
    ACTIONS(2944), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [54351] = 2,
    ACTIONS(2870), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [54359] = 2,
    ACTIONS(2946), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
};

static const uint32_t ts_small_parse_table_map[] = {
  [SMALL_STATE(167)] = 0,
  [SMALL_STATE(168)] = 145,
  [SMALL_STATE(169)] = 286,
  [SMALL_STATE(170)] = 429,
  [SMALL_STATE(171)] = 572,
  [SMALL_STATE(172)] = 715,
  [SMALL_STATE(173)] = 858,
  [SMALL_STATE(174)] = 1001,
  [SMALL_STATE(175)] = 1144,
  [SMALL_STATE(176)] = 1287,
  [SMALL_STATE(177)] = 1430,
  [SMALL_STATE(178)] = 1573,
  [SMALL_STATE(179)] = 1716,
  [SMALL_STATE(180)] = 1851,
  [SMALL_STATE(181)] = 1988,
  [SMALL_STATE(182)] = 2123,
  [SMALL_STATE(183)] = 2258,
  [SMALL_STATE(184)] = 2395,
  [SMALL_STATE(185)] = 2527,
  [SMALL_STATE(186)] = 2657,
  [SMALL_STATE(187)] = 2785,
  [SMALL_STATE(188)] = 2913,
  [SMALL_STATE(189)] = 3042,
  [SMALL_STATE(190)] = 3171,
  [SMALL_STATE(191)] = 3240,
  [SMALL_STATE(192)] = 3309,
  [SMALL_STATE(193)] = 3378,
  [SMALL_STATE(194)] = 3447,
  [SMALL_STATE(195)] = 3516,
  [SMALL_STATE(196)] = 3645,
  [SMALL_STATE(197)] = 3709,
  [SMALL_STATE(198)] = 3773,
  [SMALL_STATE(199)] = 3896,
  [SMALL_STATE(200)] = 4017,
  [SMALL_STATE(201)] = 4140,
  [SMALL_STATE(202)] = 4263,
  [SMALL_STATE(203)] = 4386,
  [SMALL_STATE(204)] = 4504,
  [SMALL_STATE(205)] = 4622,
  [SMALL_STATE(206)] = 4744,
  [SMALL_STATE(207)] = 4866,
  [SMALL_STATE(208)] = 4988,
  [SMALL_STATE(209)] = 5110,
  [SMALL_STATE(210)] = 5228,
  [SMALL_STATE(211)] = 5346,
  [SMALL_STATE(212)] = 5464,
  [SMALL_STATE(213)] = 5582,
  [SMALL_STATE(214)] = 5700,
  [SMALL_STATE(215)] = 5818,
  [SMALL_STATE(216)] = 5936,
  [SMALL_STATE(217)] = 6054,
  [SMALL_STATE(218)] = 6172,
  [SMALL_STATE(219)] = 6290,
  [SMALL_STATE(220)] = 6408,
  [SMALL_STATE(221)] = 6526,
  [SMALL_STATE(222)] = 6644,
  [SMALL_STATE(223)] = 6766,
  [SMALL_STATE(224)] = 6888,
  [SMALL_STATE(225)] = 7010,
  [SMALL_STATE(226)] = 7132,
  [SMALL_STATE(227)] = 7254,
  [SMALL_STATE(228)] = 7376,
  [SMALL_STATE(229)] = 7494,
  [SMALL_STATE(230)] = 7612,
  [SMALL_STATE(231)] = 7734,
  [SMALL_STATE(232)] = 7856,
  [SMALL_STATE(233)] = 7978,
  [SMALL_STATE(234)] = 8100,
  [SMALL_STATE(235)] = 8222,
  [SMALL_STATE(236)] = 8340,
  [SMALL_STATE(237)] = 8462,
  [SMALL_STATE(238)] = 8580,
  [SMALL_STATE(239)] = 8698,
  [SMALL_STATE(240)] = 8813,
  [SMALL_STATE(241)] = 8926,
  [SMALL_STATE(242)] = 9041,
  [SMALL_STATE(243)] = 9156,
  [SMALL_STATE(244)] = 9223,
  [SMALL_STATE(245)] = 9287,
  [SMALL_STATE(246)] = 9349,
  [SMALL_STATE(247)] = 9411,
  [SMALL_STATE(248)] = 9473,
  [SMALL_STATE(249)] = 9535,
  [SMALL_STATE(250)] = 9597,
  [SMALL_STATE(251)] = 9704,
  [SMALL_STATE(252)] = 9811,
  [SMALL_STATE(253)] = 9918,
  [SMALL_STATE(254)] = 10027,
  [SMALL_STATE(255)] = 10131,
  [SMALL_STATE(256)] = 10235,
  [SMALL_STATE(257)] = 10339,
  [SMALL_STATE(258)] = 10443,
  [SMALL_STATE(259)] = 10547,
  [SMALL_STATE(260)] = 10653,
  [SMALL_STATE(261)] = 10757,
  [SMALL_STATE(262)] = 10861,
  [SMALL_STATE(263)] = 10965,
  [SMALL_STATE(264)] = 11069,
  [SMALL_STATE(265)] = 11173,
  [SMALL_STATE(266)] = 11277,
  [SMALL_STATE(267)] = 11381,
  [SMALL_STATE(268)] = 11485,
  [SMALL_STATE(269)] = 11589,
  [SMALL_STATE(270)] = 11693,
  [SMALL_STATE(271)] = 11797,
  [SMALL_STATE(272)] = 11901,
  [SMALL_STATE(273)] = 12005,
  [SMALL_STATE(274)] = 12109,
  [SMALL_STATE(275)] = 12209,
  [SMALL_STATE(276)] = 12309,
  [SMALL_STATE(277)] = 12409,
  [SMALL_STATE(278)] = 12509,
  [SMALL_STATE(279)] = 12609,
  [SMALL_STATE(280)] = 12713,
  [SMALL_STATE(281)] = 12817,
  [SMALL_STATE(282)] = 12921,
  [SMALL_STATE(283)] = 13025,
  [SMALL_STATE(284)] = 13129,
  [SMALL_STATE(285)] = 13233,
  [SMALL_STATE(286)] = 13337,
  [SMALL_STATE(287)] = 13441,
  [SMALL_STATE(288)] = 13545,
  [SMALL_STATE(289)] = 13649,
  [SMALL_STATE(290)] = 13749,
  [SMALL_STATE(291)] = 13849,
  [SMALL_STATE(292)] = 13949,
  [SMALL_STATE(293)] = 14049,
  [SMALL_STATE(294)] = 14149,
  [SMALL_STATE(295)] = 14253,
  [SMALL_STATE(296)] = 14357,
  [SMALL_STATE(297)] = 14463,
  [SMALL_STATE(298)] = 14567,
  [SMALL_STATE(299)] = 14671,
  [SMALL_STATE(300)] = 14775,
  [SMALL_STATE(301)] = 14879,
  [SMALL_STATE(302)] = 14983,
  [SMALL_STATE(303)] = 15083,
  [SMALL_STATE(304)] = 15183,
  [SMALL_STATE(305)] = 15283,
  [SMALL_STATE(306)] = 15383,
  [SMALL_STATE(307)] = 15483,
  [SMALL_STATE(308)] = 15587,
  [SMALL_STATE(309)] = 15691,
  [SMALL_STATE(310)] = 15795,
  [SMALL_STATE(311)] = 15899,
  [SMALL_STATE(312)] = 15999,
  [SMALL_STATE(313)] = 16099,
  [SMALL_STATE(314)] = 16199,
  [SMALL_STATE(315)] = 16299,
  [SMALL_STATE(316)] = 16405,
  [SMALL_STATE(317)] = 16509,
  [SMALL_STATE(318)] = 16613,
  [SMALL_STATE(319)] = 16717,
  [SMALL_STATE(320)] = 16821,
  [SMALL_STATE(321)] = 16925,
  [SMALL_STATE(322)] = 17029,
  [SMALL_STATE(323)] = 17135,
  [SMALL_STATE(324)] = 17239,
  [SMALL_STATE(325)] = 17343,
  [SMALL_STATE(326)] = 17447,
  [SMALL_STATE(327)] = 17551,
  [SMALL_STATE(328)] = 17657,
  [SMALL_STATE(329)] = 17761,
  [SMALL_STATE(330)] = 17865,
  [SMALL_STATE(331)] = 17969,
  [SMALL_STATE(332)] = 18073,
  [SMALL_STATE(333)] = 18177,
  [SMALL_STATE(334)] = 18281,
  [SMALL_STATE(335)] = 18385,
  [SMALL_STATE(336)] = 18489,
  [SMALL_STATE(337)] = 18593,
  [SMALL_STATE(338)] = 18697,
  [SMALL_STATE(339)] = 18801,
  [SMALL_STATE(340)] = 18905,
  [SMALL_STATE(341)] = 19009,
  [SMALL_STATE(342)] = 19113,
  [SMALL_STATE(343)] = 19217,
  [SMALL_STATE(344)] = 19321,
  [SMALL_STATE(345)] = 19425,
  [SMALL_STATE(346)] = 19529,
  [SMALL_STATE(347)] = 19633,
  [SMALL_STATE(348)] = 19737,
  [SMALL_STATE(349)] = 19841,
  [SMALL_STATE(350)] = 19945,
  [SMALL_STATE(351)] = 20049,
  [SMALL_STATE(352)] = 20155,
  [SMALL_STATE(353)] = 20259,
  [SMALL_STATE(354)] = 20363,
  [SMALL_STATE(355)] = 20469,
  [SMALL_STATE(356)] = 20575,
  [SMALL_STATE(357)] = 20681,
  [SMALL_STATE(358)] = 20785,
  [SMALL_STATE(359)] = 20889,
  [SMALL_STATE(360)] = 20993,
  [SMALL_STATE(361)] = 21097,
  [SMALL_STATE(362)] = 21201,
  [SMALL_STATE(363)] = 21301,
  [SMALL_STATE(364)] = 21359,
  [SMALL_STATE(365)] = 21417,
  [SMALL_STATE(366)] = 21475,
  [SMALL_STATE(367)] = 21533,
  [SMALL_STATE(368)] = 21591,
  [SMALL_STATE(369)] = 21648,
  [SMALL_STATE(370)] = 21699,
  [SMALL_STATE(371)] = 21750,
  [SMALL_STATE(372)] = 21801,
  [SMALL_STATE(373)] = 21852,
  [SMALL_STATE(374)] = 21899,
  [SMALL_STATE(375)] = 21962,
  [SMALL_STATE(376)] = 22021,
  [SMALL_STATE(377)] = 22084,
  [SMALL_STATE(378)] = 22147,
  [SMALL_STATE(379)] = 22200,
  [SMALL_STATE(380)] = 22259,
  [SMALL_STATE(381)] = 22303,
  [SMALL_STATE(382)] = 22347,
  [SMALL_STATE(383)] = 22407,
  [SMALL_STATE(384)] = 22459,
  [SMALL_STATE(385)] = 22503,
  [SMALL_STATE(386)] = 22563,
  [SMALL_STATE(387)] = 22607,
  [SMALL_STATE(388)] = 22651,
  [SMALL_STATE(389)] = 22711,
  [SMALL_STATE(390)] = 22755,
  [SMALL_STATE(391)] = 22815,
  [SMALL_STATE(392)] = 22859,
  [SMALL_STATE(393)] = 22905,
  [SMALL_STATE(394)] = 22965,
  [SMALL_STATE(395)] = 23018,
  [SMALL_STATE(396)] = 23077,
  [SMALL_STATE(397)] = 23140,
  [SMALL_STATE(398)] = 23197,
  [SMALL_STATE(399)] = 23260,
  [SMALL_STATE(400)] = 23323,
  [SMALL_STATE(401)] = 23382,
  [SMALL_STATE(402)] = 23445,
  [SMALL_STATE(403)] = 23502,
  [SMALL_STATE(404)] = 23555,
  [SMALL_STATE(405)] = 23612,
  [SMALL_STATE(406)] = 23676,
  [SMALL_STATE(407)] = 23740,
  [SMALL_STATE(408)] = 23804,
  [SMALL_STATE(409)] = 23868,
  [SMALL_STATE(410)] = 23910,
  [SMALL_STATE(411)] = 23956,
  [SMALL_STATE(412)] = 24024,
  [SMALL_STATE(413)] = 24070,
  [SMALL_STATE(414)] = 24122,
  [SMALL_STATE(415)] = 24184,
  [SMALL_STATE(416)] = 24246,
  [SMALL_STATE(417)] = 24287,
  [SMALL_STATE(418)] = 24340,
  [SMALL_STATE(419)] = 24405,
  [SMALL_STATE(420)] = 24468,
  [SMALL_STATE(421)] = 24513,
  [SMALL_STATE(422)] = 24576,
  [SMALL_STATE(423)] = 24633,
  [SMALL_STATE(424)] = 24696,
  [SMALL_STATE(425)] = 24753,
  [SMALL_STATE(426)] = 24806,
  [SMALL_STATE(427)] = 24863,
  [SMALL_STATE(428)] = 24920,
  [SMALL_STATE(429)] = 24965,
  [SMALL_STATE(430)] = 25028,
  [SMALL_STATE(431)] = 25091,
  [SMALL_STATE(432)] = 25134,
  [SMALL_STATE(433)] = 25199,
  [SMALL_STATE(434)] = 25240,
  [SMALL_STATE(435)] = 25283,
  [SMALL_STATE(436)] = 25328,
  [SMALL_STATE(437)] = 25371,
  [SMALL_STATE(438)] = 25438,
  [SMALL_STATE(439)] = 25481,
  [SMALL_STATE(440)] = 25524,
  [SMALL_STATE(441)] = 25581,
  [SMALL_STATE(442)] = 25626,
  [SMALL_STATE(443)] = 25669,
  [SMALL_STATE(444)] = 25714,
  [SMALL_STATE(445)] = 25759,
  [SMALL_STATE(446)] = 25802,
  [SMALL_STATE(447)] = 25845,
  [SMALL_STATE(448)] = 25910,
  [SMALL_STATE(449)] = 25968,
  [SMALL_STATE(450)] = 26026,
  [SMALL_STATE(451)] = 26082,
  [SMALL_STATE(452)] = 26138,
  [SMALL_STATE(453)] = 26180,
  [SMALL_STATE(454)] = 26222,
  [SMALL_STATE(455)] = 26272,
  [SMALL_STATE(456)] = 26312,
  [SMALL_STATE(457)] = 26376,
  [SMALL_STATE(458)] = 26434,
  [SMALL_STATE(459)] = 26492,
  [SMALL_STATE(460)] = 26554,
  [SMALL_STATE(461)] = 26617,
  [SMALL_STATE(462)] = 26662,
  [SMALL_STATE(463)] = 26707,
  [SMALL_STATE(464)] = 26750,
  [SMALL_STATE(465)] = 26813,
  [SMALL_STATE(466)] = 26854,
  [SMALL_STATE(467)] = 26911,
  [SMALL_STATE(468)] = 26952,
  [SMALL_STATE(469)] = 27009,
  [SMALL_STATE(470)] = 27050,
  [SMALL_STATE(471)] = 27093,
  [SMALL_STATE(472)] = 27136,
  [SMALL_STATE(473)] = 27177,
  [SMALL_STATE(474)] = 27220,
  [SMALL_STATE(475)] = 27259,
  [SMALL_STATE(476)] = 27300,
  [SMALL_STATE(477)] = 27341,
  [SMALL_STATE(478)] = 27382,
  [SMALL_STATE(479)] = 27421,
  [SMALL_STATE(480)] = 27480,
  [SMALL_STATE(481)] = 27539,
  [SMALL_STATE(482)] = 27578,
  [SMALL_STATE(483)] = 27641,
  [SMALL_STATE(484)] = 27686,
  [SMALL_STATE(485)] = 27725,
  [SMALL_STATE(486)] = 27764,
  [SMALL_STATE(487)] = 27809,
  [SMALL_STATE(488)] = 27850,
  [SMALL_STATE(489)] = 27889,
  [SMALL_STATE(490)] = 27930,
  [SMALL_STATE(491)] = 27969,
  [SMALL_STATE(492)] = 28010,
  [SMALL_STATE(493)] = 28049,
  [SMALL_STATE(494)] = 28112,
  [SMALL_STATE(495)] = 28151,
  [SMALL_STATE(496)] = 28190,
  [SMALL_STATE(497)] = 28247,
  [SMALL_STATE(498)] = 28288,
  [SMALL_STATE(499)] = 28329,
  [SMALL_STATE(500)] = 28374,
  [SMALL_STATE(501)] = 28419,
  [SMALL_STATE(502)] = 28464,
  [SMALL_STATE(503)] = 28509,
  [SMALL_STATE(504)] = 28550,
  [SMALL_STATE(505)] = 28591,
  [SMALL_STATE(506)] = 28636,
  [SMALL_STATE(507)] = 28681,
  [SMALL_STATE(508)] = 28724,
  [SMALL_STATE(509)] = 28775,
  [SMALL_STATE(510)] = 28816,
  [SMALL_STATE(511)] = 28873,
  [SMALL_STATE(512)] = 28918,
  [SMALL_STATE(513)] = 28963,
  [SMALL_STATE(514)] = 29008,
  [SMALL_STATE(515)] = 29049,
  [SMALL_STATE(516)] = 29092,
  [SMALL_STATE(517)] = 29155,
  [SMALL_STATE(518)] = 29200,
  [SMALL_STATE(519)] = 29257,
  [SMALL_STATE(520)] = 29302,
  [SMALL_STATE(521)] = 29347,
  [SMALL_STATE(522)] = 29410,
  [SMALL_STATE(523)] = 29461,
  [SMALL_STATE(524)] = 29502,
  [SMALL_STATE(525)] = 29541,
  [SMALL_STATE(526)] = 29600,
  [SMALL_STATE(527)] = 29639,
  [SMALL_STATE(528)] = 29678,
  [SMALL_STATE(529)] = 29723,
  [SMALL_STATE(530)] = 29762,
  [SMALL_STATE(531)] = 29801,
  [SMALL_STATE(532)] = 29844,
  [SMALL_STATE(533)] = 29885,
  [SMALL_STATE(534)] = 29926,
  [SMALL_STATE(535)] = 29973,
  [SMALL_STATE(536)] = 30018,
  [SMALL_STATE(537)] = 30059,
  [SMALL_STATE(538)] = 30104,
  [SMALL_STATE(539)] = 30144,
  [SMALL_STATE(540)] = 30184,
  [SMALL_STATE(541)] = 30224,
  [SMALL_STATE(542)] = 30264,
  [SMALL_STATE(543)] = 30307,
  [SMALL_STATE(544)] = 30346,
  [SMALL_STATE(545)] = 30385,
  [SMALL_STATE(546)] = 30428,
  [SMALL_STATE(547)] = 30473,
  [SMALL_STATE(548)] = 30518,
  [SMALL_STATE(549)] = 30563,
  [SMALL_STATE(550)] = 30604,
  [SMALL_STATE(551)] = 30645,
  [SMALL_STATE(552)] = 30688,
  [SMALL_STATE(553)] = 30727,
  [SMALL_STATE(554)] = 30768,
  [SMALL_STATE(555)] = 30809,
  [SMALL_STATE(556)] = 30848,
  [SMALL_STATE(557)] = 30889,
  [SMALL_STATE(558)] = 30930,
  [SMALL_STATE(559)] = 30969,
  [SMALL_STATE(560)] = 31014,
  [SMALL_STATE(561)] = 31053,
  [SMALL_STATE(562)] = 31096,
  [SMALL_STATE(563)] = 31139,
  [SMALL_STATE(564)] = 31182,
  [SMALL_STATE(565)] = 31225,
  [SMALL_STATE(566)] = 31270,
  [SMALL_STATE(567)] = 31313,
  [SMALL_STATE(568)] = 31352,
  [SMALL_STATE(569)] = 31395,
  [SMALL_STATE(570)] = 31436,
  [SMALL_STATE(571)] = 31475,
  [SMALL_STATE(572)] = 31520,
  [SMALL_STATE(573)] = 31559,
  [SMALL_STATE(574)] = 31598,
  [SMALL_STATE(575)] = 31639,
  [SMALL_STATE(576)] = 31680,
  [SMALL_STATE(577)] = 31725,
  [SMALL_STATE(578)] = 31770,
  [SMALL_STATE(579)] = 31813,
  [SMALL_STATE(580)] = 31854,
  [SMALL_STATE(581)] = 31899,
  [SMALL_STATE(582)] = 31942,
  [SMALL_STATE(583)] = 31981,
  [SMALL_STATE(584)] = 32024,
  [SMALL_STATE(585)] = 32065,
  [SMALL_STATE(586)] = 32106,
  [SMALL_STATE(587)] = 32153,
  [SMALL_STATE(588)] = 32196,
  [SMALL_STATE(589)] = 32237,
  [SMALL_STATE(590)] = 32280,
  [SMALL_STATE(591)] = 32325,
  [SMALL_STATE(592)] = 32370,
  [SMALL_STATE(593)] = 32415,
  [SMALL_STATE(594)] = 32456,
  [SMALL_STATE(595)] = 32501,
  [SMALL_STATE(596)] = 32540,
  [SMALL_STATE(597)] = 32579,
  [SMALL_STATE(598)] = 32618,
  [SMALL_STATE(599)] = 32657,
  [SMALL_STATE(600)] = 32699,
  [SMALL_STATE(601)] = 32739,
  [SMALL_STATE(602)] = 32785,
  [SMALL_STATE(603)] = 32831,
  [SMALL_STATE(604)] = 32871,
  [SMALL_STATE(605)] = 32917,
  [SMALL_STATE(606)] = 32963,
  [SMALL_STATE(607)] = 33009,
  [SMALL_STATE(608)] = 33053,
  [SMALL_STATE(609)] = 33091,
  [SMALL_STATE(610)] = 33135,
  [SMALL_STATE(611)] = 33179,
  [SMALL_STATE(612)] = 33217,
  [SMALL_STATE(613)] = 33259,
  [SMALL_STATE(614)] = 33305,
  [SMALL_STATE(615)] = 33343,
  [SMALL_STATE(616)] = 33385,
  [SMALL_STATE(617)] = 33427,
  [SMALL_STATE(618)] = 33469,
  [SMALL_STATE(619)] = 33511,
  [SMALL_STATE(620)] = 33553,
  [SMALL_STATE(621)] = 33599,
  [SMALL_STATE(622)] = 33643,
  [SMALL_STATE(623)] = 33681,
  [SMALL_STATE(624)] = 33721,
  [SMALL_STATE(625)] = 33765,
  [SMALL_STATE(626)] = 33811,
  [SMALL_STATE(627)] = 33848,
  [SMALL_STATE(628)] = 33885,
  [SMALL_STATE(629)] = 33930,
  [SMALL_STATE(630)] = 33975,
  [SMALL_STATE(631)] = 34018,
  [SMALL_STATE(632)] = 34063,
  [SMALL_STATE(633)] = 34108,
  [SMALL_STATE(634)] = 34153,
  [SMALL_STATE(635)] = 34198,
  [SMALL_STATE(636)] = 34239,
  [SMALL_STATE(637)] = 34282,
  [SMALL_STATE(638)] = 34327,
  [SMALL_STATE(639)] = 34374,
  [SMALL_STATE(640)] = 34419,
  [SMALL_STATE(641)] = 34460,
  [SMALL_STATE(642)] = 34503,
  [SMALL_STATE(643)] = 34544,
  [SMALL_STATE(644)] = 34581,
  [SMALL_STATE(645)] = 34626,
  [SMALL_STATE(646)] = 34665,
  [SMALL_STATE(647)] = 34712,
  [SMALL_STATE(648)] = 34753,
  [SMALL_STATE(649)] = 34796,
  [SMALL_STATE(650)] = 34841,
  [SMALL_STATE(651)] = 34878,
  [SMALL_STATE(652)] = 34925,
  [SMALL_STATE(653)] = 34972,
  [SMALL_STATE(654)] = 35017,
  [SMALL_STATE(655)] = 35056,
  [SMALL_STATE(656)] = 35095,
  [SMALL_STATE(657)] = 35132,
  [SMALL_STATE(658)] = 35171,
  [SMALL_STATE(659)] = 35208,
  [SMALL_STATE(660)] = 35247,
  [SMALL_STATE(661)] = 35284,
  [SMALL_STATE(662)] = 35329,
  [SMALL_STATE(663)] = 35370,
  [SMALL_STATE(664)] = 35411,
  [SMALL_STATE(665)] = 35448,
  [SMALL_STATE(666)] = 35485,
  [SMALL_STATE(667)] = 35530,
  [SMALL_STATE(668)] = 35567,
  [SMALL_STATE(669)] = 35610,
  [SMALL_STATE(670)] = 35649,
  [SMALL_STATE(671)] = 35694,
  [SMALL_STATE(672)] = 35731,
  [SMALL_STATE(673)] = 35774,
  [SMALL_STATE(674)] = 35819,
  [SMALL_STATE(675)] = 35860,
  [SMALL_STATE(676)] = 35903,
  [SMALL_STATE(677)] = 35948,
  [SMALL_STATE(678)] = 35989,
  [SMALL_STATE(679)] = 36034,
  [SMALL_STATE(680)] = 36073,
  [SMALL_STATE(681)] = 36112,
  [SMALL_STATE(682)] = 36151,
  [SMALL_STATE(683)] = 36198,
  [SMALL_STATE(684)] = 36241,
  [SMALL_STATE(685)] = 36278,
  [SMALL_STATE(686)] = 36321,
  [SMALL_STATE(687)] = 36364,
  [SMALL_STATE(688)] = 36401,
  [SMALL_STATE(689)] = 36448,
  [SMALL_STATE(690)] = 36485,
  [SMALL_STATE(691)] = 36522,
  [SMALL_STATE(692)] = 36561,
  [SMALL_STATE(693)] = 36601,
  [SMALL_STATE(694)] = 36643,
  [SMALL_STATE(695)] = 36683,
  [SMALL_STATE(696)] = 36725,
  [SMALL_STATE(697)] = 36789,
  [SMALL_STATE(698)] = 36831,
  [SMALL_STATE(699)] = 36873,
  [SMALL_STATE(700)] = 36913,
  [SMALL_STATE(701)] = 36959,
  [SMALL_STATE(702)] = 37001,
  [SMALL_STATE(703)] = 37065,
  [SMALL_STATE(704)] = 37111,
  [SMALL_STATE(705)] = 37155,
  [SMALL_STATE(706)] = 37199,
  [SMALL_STATE(707)] = 37243,
  [SMALL_STATE(708)] = 37285,
  [SMALL_STATE(709)] = 37323,
  [SMALL_STATE(710)] = 37363,
  [SMALL_STATE(711)] = 37405,
  [SMALL_STATE(712)] = 37471,
  [SMALL_STATE(713)] = 37512,
  [SMALL_STATE(714)] = 37557,
  [SMALL_STATE(715)] = 37602,
  [SMALL_STATE(716)] = 37647,
  [SMALL_STATE(717)] = 37692,
  [SMALL_STATE(718)] = 37737,
  [SMALL_STATE(719)] = 37782,
  [SMALL_STATE(720)] = 37827,
  [SMALL_STATE(721)] = 37872,
  [SMALL_STATE(722)] = 37913,
  [SMALL_STATE(723)] = 37956,
  [SMALL_STATE(724)] = 38001,
  [SMALL_STATE(725)] = 38042,
  [SMALL_STATE(726)] = 38087,
  [SMALL_STATE(727)] = 38132,
  [SMALL_STATE(728)] = 38177,
  [SMALL_STATE(729)] = 38214,
  [SMALL_STATE(730)] = 38255,
  [SMALL_STATE(731)] = 38300,
  [SMALL_STATE(732)] = 38363,
  [SMALL_STATE(733)] = 38406,
  [SMALL_STATE(734)] = 38451,
  [SMALL_STATE(735)] = 38496,
  [SMALL_STATE(736)] = 38539,
  [SMALL_STATE(737)] = 38581,
  [SMALL_STATE(738)] = 38623,
  [SMALL_STATE(739)] = 38661,
  [SMALL_STATE(740)] = 38699,
  [SMALL_STATE(741)] = 38741,
  [SMALL_STATE(742)] = 38781,
  [SMALL_STATE(743)] = 38823,
  [SMALL_STATE(744)] = 38865,
  [SMALL_STATE(745)] = 38907,
  [SMALL_STATE(746)] = 38946,
  [SMALL_STATE(747)] = 39001,
  [SMALL_STATE(748)] = 39040,
  [SMALL_STATE(749)] = 39079,
  [SMALL_STATE(750)] = 39136,
  [SMALL_STATE(751)] = 39175,
  [SMALL_STATE(752)] = 39225,
  [SMALL_STATE(753)] = 39281,
  [SMALL_STATE(754)] = 39331,
  [SMALL_STATE(755)] = 39384,
  [SMALL_STATE(756)] = 39433,
  [SMALL_STATE(757)] = 39480,
  [SMALL_STATE(758)] = 39533,
  [SMALL_STATE(759)] = 39582,
  [SMALL_STATE(760)] = 39631,
  [SMALL_STATE(761)] = 39680,
  [SMALL_STATE(762)] = 39729,
  [SMALL_STATE(763)] = 39776,
  [SMALL_STATE(764)] = 39824,
  [SMALL_STATE(765)] = 39869,
  [SMALL_STATE(766)] = 39922,
  [SMALL_STATE(767)] = 39967,
  [SMALL_STATE(768)] = 40020,
  [SMALL_STATE(769)] = 40065,
  [SMALL_STATE(770)] = 40110,
  [SMALL_STATE(771)] = 40163,
  [SMALL_STATE(772)] = 40210,
  [SMALL_STATE(773)] = 40263,
  [SMALL_STATE(774)] = 40310,
  [SMALL_STATE(775)] = 40357,
  [SMALL_STATE(776)] = 40388,
  [SMALL_STATE(777)] = 40441,
  [SMALL_STATE(778)] = 40479,
  [SMALL_STATE(779)] = 40509,
  [SMALL_STATE(780)] = 40539,
  [SMALL_STATE(781)] = 40571,
  [SMALL_STATE(782)] = 40603,
  [SMALL_STATE(783)] = 40635,
  [SMALL_STATE(784)] = 40661,
  [SMALL_STATE(785)] = 40693,
  [SMALL_STATE(786)] = 40721,
  [SMALL_STATE(787)] = 40751,
  [SMALL_STATE(788)] = 40781,
  [SMALL_STATE(789)] = 40807,
  [SMALL_STATE(790)] = 40843,
  [SMALL_STATE(791)] = 40877,
  [SMALL_STATE(792)] = 40905,
  [SMALL_STATE(793)] = 40933,
  [SMALL_STATE(794)] = 40961,
  [SMALL_STATE(795)] = 40989,
  [SMALL_STATE(796)] = 41031,
  [SMALL_STATE(797)] = 41063,
  [SMALL_STATE(798)] = 41095,
  [SMALL_STATE(799)] = 41123,
  [SMALL_STATE(800)] = 41161,
  [SMALL_STATE(801)] = 41186,
  [SMALL_STATE(802)] = 41213,
  [SMALL_STATE(803)] = 41252,
  [SMALL_STATE(804)] = 41283,
  [SMALL_STATE(805)] = 41308,
  [SMALL_STATE(806)] = 41333,
  [SMALL_STATE(807)] = 41358,
  [SMALL_STATE(808)] = 41395,
  [SMALL_STATE(809)] = 41434,
  [SMALL_STATE(810)] = 41459,
  [SMALL_STATE(811)] = 41484,
  [SMALL_STATE(812)] = 41523,
  [SMALL_STATE(813)] = 41562,
  [SMALL_STATE(814)] = 41593,
  [SMALL_STATE(815)] = 41622,
  [SMALL_STATE(816)] = 41651,
  [SMALL_STATE(817)] = 41686,
  [SMALL_STATE(818)] = 41719,
  [SMALL_STATE(819)] = 41752,
  [SMALL_STATE(820)] = 41779,
  [SMALL_STATE(821)] = 41804,
  [SMALL_STATE(822)] = 41831,
  [SMALL_STATE(823)] = 41858,
  [SMALL_STATE(824)] = 41883,
  [SMALL_STATE(825)] = 41912,
  [SMALL_STATE(826)] = 41941,
  [SMALL_STATE(827)] = 41966,
  [SMALL_STATE(828)] = 42005,
  [SMALL_STATE(829)] = 42030,
  [SMALL_STATE(830)] = 42059,
  [SMALL_STATE(831)] = 42084,
  [SMALL_STATE(832)] = 42115,
  [SMALL_STATE(833)] = 42140,
  [SMALL_STATE(834)] = 42165,
  [SMALL_STATE(835)] = 42196,
  [SMALL_STATE(836)] = 42223,
  [SMALL_STATE(837)] = 42256,
  [SMALL_STATE(838)] = 42282,
  [SMALL_STATE(839)] = 42322,
  [SMALL_STATE(840)] = 42354,
  [SMALL_STATE(841)] = 42384,
  [SMALL_STATE(842)] = 42412,
  [SMALL_STATE(843)] = 42450,
  [SMALL_STATE(844)] = 42478,
  [SMALL_STATE(845)] = 42514,
  [SMALL_STATE(846)] = 42540,
  [SMALL_STATE(847)] = 42566,
  [SMALL_STATE(848)] = 42604,
  [SMALL_STATE(849)] = 42640,
  [SMALL_STATE(850)] = 42680,
  [SMALL_STATE(851)] = 42716,
  [SMALL_STATE(852)] = 42752,
  [SMALL_STATE(853)] = 42780,
  [SMALL_STATE(854)] = 42806,
  [SMALL_STATE(855)] = 42842,
  [SMALL_STATE(856)] = 42870,
  [SMALL_STATE(857)] = 42894,
  [SMALL_STATE(858)] = 42922,
  [SMALL_STATE(859)] = 42960,
  [SMALL_STATE(860)] = 42991,
  [SMALL_STATE(861)] = 43020,
  [SMALL_STATE(862)] = 43049,
  [SMALL_STATE(863)] = 43076,
  [SMALL_STATE(864)] = 43103,
  [SMALL_STATE(865)] = 43132,
  [SMALL_STATE(866)] = 43161,
  [SMALL_STATE(867)] = 43190,
  [SMALL_STATE(868)] = 43215,
  [SMALL_STATE(869)] = 43244,
  [SMALL_STATE(870)] = 43277,
  [SMALL_STATE(871)] = 43312,
  [SMALL_STATE(872)] = 43347,
  [SMALL_STATE(873)] = 43372,
  [SMALL_STATE(874)] = 43407,
  [SMALL_STATE(875)] = 43432,
  [SMALL_STATE(876)] = 43461,
  [SMALL_STATE(877)] = 43492,
  [SMALL_STATE(878)] = 43520,
  [SMALL_STATE(879)] = 43550,
  [SMALL_STATE(880)] = 43580,
  [SMALL_STATE(881)] = 43602,
  [SMALL_STATE(882)] = 43630,
  [SMALL_STATE(883)] = 43658,
  [SMALL_STATE(884)] = 43694,
  [SMALL_STATE(885)] = 43724,
  [SMALL_STATE(886)] = 43754,
  [SMALL_STATE(887)] = 43780,
  [SMALL_STATE(888)] = 43816,
  [SMALL_STATE(889)] = 43844,
  [SMALL_STATE(890)] = 43872,
  [SMALL_STATE(891)] = 43900,
  [SMALL_STATE(892)] = 43930,
  [SMALL_STATE(893)] = 43966,
  [SMALL_STATE(894)] = 43994,
  [SMALL_STATE(895)] = 44020,
  [SMALL_STATE(896)] = 44042,
  [SMALL_STATE(897)] = 44073,
  [SMALL_STATE(898)] = 44094,
  [SMALL_STATE(899)] = 44115,
  [SMALL_STATE(900)] = 44144,
  [SMALL_STATE(901)] = 44167,
  [SMALL_STATE(902)] = 44200,
  [SMALL_STATE(903)] = 44223,
  [SMALL_STATE(904)] = 44246,
  [SMALL_STATE(905)] = 44269,
  [SMALL_STATE(906)] = 44300,
  [SMALL_STATE(907)] = 44323,
  [SMALL_STATE(908)] = 44344,
  [SMALL_STATE(909)] = 44373,
  [SMALL_STATE(910)] = 44404,
  [SMALL_STATE(911)] = 44433,
  [SMALL_STATE(912)] = 44462,
  [SMALL_STATE(913)] = 44493,
  [SMALL_STATE(914)] = 44522,
  [SMALL_STATE(915)] = 44551,
  [SMALL_STATE(916)] = 44574,
  [SMALL_STATE(917)] = 44605,
  [SMALL_STATE(918)] = 44634,
  [SMALL_STATE(919)] = 44663,
  [SMALL_STATE(920)] = 44694,
  [SMALL_STATE(921)] = 44725,
  [SMALL_STATE(922)] = 44758,
  [SMALL_STATE(923)] = 44789,
  [SMALL_STATE(924)] = 44820,
  [SMALL_STATE(925)] = 44851,
  [SMALL_STATE(926)] = 44882,
  [SMALL_STATE(927)] = 44911,
  [SMALL_STATE(928)] = 44942,
  [SMALL_STATE(929)] = 44973,
  [SMALL_STATE(930)] = 44993,
  [SMALL_STATE(931)] = 45021,
  [SMALL_STATE(932)] = 45041,
  [SMALL_STATE(933)] = 45069,
  [SMALL_STATE(934)] = 45095,
  [SMALL_STATE(935)] = 45121,
  [SMALL_STATE(936)] = 45143,
  [SMALL_STATE(937)] = 45165,
  [SMALL_STATE(938)] = 45185,
  [SMALL_STATE(939)] = 45213,
  [SMALL_STATE(940)] = 45241,
  [SMALL_STATE(941)] = 45267,
  [SMALL_STATE(942)] = 45293,
  [SMALL_STATE(943)] = 45320,
  [SMALL_STATE(944)] = 45347,
  [SMALL_STATE(945)] = 45374,
  [SMALL_STATE(946)] = 45405,
  [SMALL_STATE(947)] = 45436,
  [SMALL_STATE(948)] = 45461,
  [SMALL_STATE(949)] = 45488,
  [SMALL_STATE(950)] = 45513,
  [SMALL_STATE(951)] = 45540,
  [SMALL_STATE(952)] = 45573,
  [SMALL_STATE(953)] = 45604,
  [SMALL_STATE(954)] = 45637,
  [SMALL_STATE(955)] = 45662,
  [SMALL_STATE(956)] = 45686,
  [SMALL_STATE(957)] = 45710,
  [SMALL_STATE(958)] = 45734,
  [SMALL_STATE(959)] = 45760,
  [SMALL_STATE(960)] = 45790,
  [SMALL_STATE(961)] = 45816,
  [SMALL_STATE(962)] = 45840,
  [SMALL_STATE(963)] = 45864,
  [SMALL_STATE(964)] = 45894,
  [SMALL_STATE(965)] = 45918,
  [SMALL_STATE(966)] = 45948,
  [SMALL_STATE(967)] = 45978,
  [SMALL_STATE(968)] = 46002,
  [SMALL_STATE(969)] = 46026,
  [SMALL_STATE(970)] = 46056,
  [SMALL_STATE(971)] = 46086,
  [SMALL_STATE(972)] = 46116,
  [SMALL_STATE(973)] = 46142,
  [SMALL_STATE(974)] = 46166,
  [SMALL_STATE(975)] = 46190,
  [SMALL_STATE(976)] = 46214,
  [SMALL_STATE(977)] = 46238,
  [SMALL_STATE(978)] = 46268,
  [SMALL_STATE(979)] = 46298,
  [SMALL_STATE(980)] = 46322,
  [SMALL_STATE(981)] = 46346,
  [SMALL_STATE(982)] = 46370,
  [SMALL_STATE(983)] = 46394,
  [SMALL_STATE(984)] = 46418,
  [SMALL_STATE(985)] = 46442,
  [SMALL_STATE(986)] = 46466,
  [SMALL_STATE(987)] = 46490,
  [SMALL_STATE(988)] = 46514,
  [SMALL_STATE(989)] = 46538,
  [SMALL_STATE(990)] = 46562,
  [SMALL_STATE(991)] = 46586,
  [SMALL_STATE(992)] = 46610,
  [SMALL_STATE(993)] = 46634,
  [SMALL_STATE(994)] = 46658,
  [SMALL_STATE(995)] = 46682,
  [SMALL_STATE(996)] = 46706,
  [SMALL_STATE(997)] = 46730,
  [SMALL_STATE(998)] = 46754,
  [SMALL_STATE(999)] = 46778,
  [SMALL_STATE(1000)] = 46802,
  [SMALL_STATE(1001)] = 46826,
  [SMALL_STATE(1002)] = 46850,
  [SMALL_STATE(1003)] = 46874,
  [SMALL_STATE(1004)] = 46898,
  [SMALL_STATE(1005)] = 46928,
  [SMALL_STATE(1006)] = 46949,
  [SMALL_STATE(1007)] = 46968,
  [SMALL_STATE(1008)] = 46993,
  [SMALL_STATE(1009)] = 47014,
  [SMALL_STATE(1010)] = 47035,
  [SMALL_STATE(1011)] = 47056,
  [SMALL_STATE(1012)] = 47081,
  [SMALL_STATE(1013)] = 47102,
  [SMALL_STATE(1014)] = 47123,
  [SMALL_STATE(1015)] = 47144,
  [SMALL_STATE(1016)] = 47171,
  [SMALL_STATE(1017)] = 47192,
  [SMALL_STATE(1018)] = 47213,
  [SMALL_STATE(1019)] = 47234,
  [SMALL_STATE(1020)] = 47255,
  [SMALL_STATE(1021)] = 47276,
  [SMALL_STATE(1022)] = 47297,
  [SMALL_STATE(1023)] = 47318,
  [SMALL_STATE(1024)] = 47339,
  [SMALL_STATE(1025)] = 47360,
  [SMALL_STATE(1026)] = 47381,
  [SMALL_STATE(1027)] = 47402,
  [SMALL_STATE(1028)] = 47423,
  [SMALL_STATE(1029)] = 47444,
  [SMALL_STATE(1030)] = 47465,
  [SMALL_STATE(1031)] = 47486,
  [SMALL_STATE(1032)] = 47507,
  [SMALL_STATE(1033)] = 47528,
  [SMALL_STATE(1034)] = 47555,
  [SMALL_STATE(1035)] = 47576,
  [SMALL_STATE(1036)] = 47597,
  [SMALL_STATE(1037)] = 47618,
  [SMALL_STATE(1038)] = 47639,
  [SMALL_STATE(1039)] = 47666,
  [SMALL_STATE(1040)] = 47687,
  [SMALL_STATE(1041)] = 47708,
  [SMALL_STATE(1042)] = 47729,
  [SMALL_STATE(1043)] = 47749,
  [SMALL_STATE(1044)] = 47773,
  [SMALL_STATE(1045)] = 47797,
  [SMALL_STATE(1046)] = 47821,
  [SMALL_STATE(1047)] = 47845,
  [SMALL_STATE(1048)] = 47869,
  [SMALL_STATE(1049)] = 47893,
  [SMALL_STATE(1050)] = 47913,
  [SMALL_STATE(1051)] = 47934,
  [SMALL_STATE(1052)] = 47955,
  [SMALL_STATE(1053)] = 47970,
  [SMALL_STATE(1054)] = 47991,
  [SMALL_STATE(1055)] = 48014,
  [SMALL_STATE(1056)] = 48035,
  [SMALL_STATE(1057)] = 48056,
  [SMALL_STATE(1058)] = 48079,
  [SMALL_STATE(1059)] = 48100,
  [SMALL_STATE(1060)] = 48121,
  [SMALL_STATE(1061)] = 48142,
  [SMALL_STATE(1062)] = 48165,
  [SMALL_STATE(1063)] = 48180,
  [SMALL_STATE(1064)] = 48201,
  [SMALL_STATE(1065)] = 48222,
  [SMALL_STATE(1066)] = 48243,
  [SMALL_STATE(1067)] = 48257,
  [SMALL_STATE(1068)] = 48277,
  [SMALL_STATE(1069)] = 48297,
  [SMALL_STATE(1070)] = 48317,
  [SMALL_STATE(1071)] = 48337,
  [SMALL_STATE(1072)] = 48357,
  [SMALL_STATE(1073)] = 48377,
  [SMALL_STATE(1074)] = 48397,
  [SMALL_STATE(1075)] = 48417,
  [SMALL_STATE(1076)] = 48437,
  [SMALL_STATE(1077)] = 48457,
  [SMALL_STATE(1078)] = 48477,
  [SMALL_STATE(1079)] = 48495,
  [SMALL_STATE(1080)] = 48515,
  [SMALL_STATE(1081)] = 48535,
  [SMALL_STATE(1082)] = 48549,
  [SMALL_STATE(1083)] = 48566,
  [SMALL_STATE(1084)] = 48587,
  [SMALL_STATE(1085)] = 48608,
  [SMALL_STATE(1086)] = 48621,
  [SMALL_STATE(1087)] = 48642,
  [SMALL_STATE(1088)] = 48659,
  [SMALL_STATE(1089)] = 48672,
  [SMALL_STATE(1090)] = 48689,
  [SMALL_STATE(1091)] = 48704,
  [SMALL_STATE(1092)] = 48723,
  [SMALL_STATE(1093)] = 48742,
  [SMALL_STATE(1094)] = 48761,
  [SMALL_STATE(1095)] = 48780,
  [SMALL_STATE(1096)] = 48799,
  [SMALL_STATE(1097)] = 48820,
  [SMALL_STATE(1098)] = 48833,
  [SMALL_STATE(1099)] = 48848,
  [SMALL_STATE(1100)] = 48861,
  [SMALL_STATE(1101)] = 48878,
  [SMALL_STATE(1102)] = 48897,
  [SMALL_STATE(1103)] = 48914,
  [SMALL_STATE(1104)] = 48935,
  [SMALL_STATE(1105)] = 48954,
  [SMALL_STATE(1106)] = 48969,
  [SMALL_STATE(1107)] = 48990,
  [SMALL_STATE(1108)] = 49007,
  [SMALL_STATE(1109)] = 49024,
  [SMALL_STATE(1110)] = 49041,
  [SMALL_STATE(1111)] = 49058,
  [SMALL_STATE(1112)] = 49075,
  [SMALL_STATE(1113)] = 49094,
  [SMALL_STATE(1114)] = 49113,
  [SMALL_STATE(1115)] = 49126,
  [SMALL_STATE(1116)] = 49143,
  [SMALL_STATE(1117)] = 49160,
  [SMALL_STATE(1118)] = 49179,
  [SMALL_STATE(1119)] = 49196,
  [SMALL_STATE(1120)] = 49215,
  [SMALL_STATE(1121)] = 49228,
  [SMALL_STATE(1122)] = 49243,
  [SMALL_STATE(1123)] = 49258,
  [SMALL_STATE(1124)] = 49275,
  [SMALL_STATE(1125)] = 49296,
  [SMALL_STATE(1126)] = 49315,
  [SMALL_STATE(1127)] = 49330,
  [SMALL_STATE(1128)] = 49347,
  [SMALL_STATE(1129)] = 49364,
  [SMALL_STATE(1130)] = 49381,
  [SMALL_STATE(1131)] = 49400,
  [SMALL_STATE(1132)] = 49415,
  [SMALL_STATE(1133)] = 49428,
  [SMALL_STATE(1134)] = 49449,
  [SMALL_STATE(1135)] = 49466,
  [SMALL_STATE(1136)] = 49485,
  [SMALL_STATE(1137)] = 49502,
  [SMALL_STATE(1138)] = 49519,
  [SMALL_STATE(1139)] = 49534,
  [SMALL_STATE(1140)] = 49553,
  [SMALL_STATE(1141)] = 49566,
  [SMALL_STATE(1142)] = 49579,
  [SMALL_STATE(1143)] = 49596,
  [SMALL_STATE(1144)] = 49613,
  [SMALL_STATE(1145)] = 49628,
  [SMALL_STATE(1146)] = 49647,
  [SMALL_STATE(1147)] = 49662,
  [SMALL_STATE(1148)] = 49675,
  [SMALL_STATE(1149)] = 49688,
  [SMALL_STATE(1150)] = 49707,
  [SMALL_STATE(1151)] = 49724,
  [SMALL_STATE(1152)] = 49745,
  [SMALL_STATE(1153)] = 49758,
  [SMALL_STATE(1154)] = 49777,
  [SMALL_STATE(1155)] = 49796,
  [SMALL_STATE(1156)] = 49812,
  [SMALL_STATE(1157)] = 49828,
  [SMALL_STATE(1158)] = 49844,
  [SMALL_STATE(1159)] = 49860,
  [SMALL_STATE(1160)] = 49876,
  [SMALL_STATE(1161)] = 49890,
  [SMALL_STATE(1162)] = 49904,
  [SMALL_STATE(1163)] = 49922,
  [SMALL_STATE(1164)] = 49936,
  [SMALL_STATE(1165)] = 49950,
  [SMALL_STATE(1166)] = 49966,
  [SMALL_STATE(1167)] = 49984,
  [SMALL_STATE(1168)] = 49998,
  [SMALL_STATE(1169)] = 50014,
  [SMALL_STATE(1170)] = 50030,
  [SMALL_STATE(1171)] = 50042,
  [SMALL_STATE(1172)] = 50056,
  [SMALL_STATE(1173)] = 50072,
  [SMALL_STATE(1174)] = 50086,
  [SMALL_STATE(1175)] = 50100,
  [SMALL_STATE(1176)] = 50114,
  [SMALL_STATE(1177)] = 50130,
  [SMALL_STATE(1178)] = 50144,
  [SMALL_STATE(1179)] = 50158,
  [SMALL_STATE(1180)] = 50172,
  [SMALL_STATE(1181)] = 50188,
  [SMALL_STATE(1182)] = 50204,
  [SMALL_STATE(1183)] = 50220,
  [SMALL_STATE(1184)] = 50238,
  [SMALL_STATE(1185)] = 50256,
  [SMALL_STATE(1186)] = 50270,
  [SMALL_STATE(1187)] = 50284,
  [SMALL_STATE(1188)] = 50296,
  [SMALL_STATE(1189)] = 50310,
  [SMALL_STATE(1190)] = 50324,
  [SMALL_STATE(1191)] = 50338,
  [SMALL_STATE(1192)] = 50352,
  [SMALL_STATE(1193)] = 50366,
  [SMALL_STATE(1194)] = 50382,
  [SMALL_STATE(1195)] = 50398,
  [SMALL_STATE(1196)] = 50416,
  [SMALL_STATE(1197)] = 50430,
  [SMALL_STATE(1198)] = 50444,
  [SMALL_STATE(1199)] = 50460,
  [SMALL_STATE(1200)] = 50480,
  [SMALL_STATE(1201)] = 50498,
  [SMALL_STATE(1202)] = 50512,
  [SMALL_STATE(1203)] = 50526,
  [SMALL_STATE(1204)] = 50542,
  [SMALL_STATE(1205)] = 50554,
  [SMALL_STATE(1206)] = 50572,
  [SMALL_STATE(1207)] = 50588,
  [SMALL_STATE(1208)] = 50604,
  [SMALL_STATE(1209)] = 50620,
  [SMALL_STATE(1210)] = 50634,
  [SMALL_STATE(1211)] = 50651,
  [SMALL_STATE(1212)] = 50662,
  [SMALL_STATE(1213)] = 50673,
  [SMALL_STATE(1214)] = 50688,
  [SMALL_STATE(1215)] = 50701,
  [SMALL_STATE(1216)] = 50712,
  [SMALL_STATE(1217)] = 50727,
  [SMALL_STATE(1218)] = 50742,
  [SMALL_STATE(1219)] = 50753,
  [SMALL_STATE(1220)] = 50766,
  [SMALL_STATE(1221)] = 50777,
  [SMALL_STATE(1222)] = 50788,
  [SMALL_STATE(1223)] = 50803,
  [SMALL_STATE(1224)] = 50814,
  [SMALL_STATE(1225)] = 50831,
  [SMALL_STATE(1226)] = 50842,
  [SMALL_STATE(1227)] = 50853,
  [SMALL_STATE(1228)] = 50868,
  [SMALL_STATE(1229)] = 50883,
  [SMALL_STATE(1230)] = 50898,
  [SMALL_STATE(1231)] = 50909,
  [SMALL_STATE(1232)] = 50920,
  [SMALL_STATE(1233)] = 50935,
  [SMALL_STATE(1234)] = 50946,
  [SMALL_STATE(1235)] = 50957,
  [SMALL_STATE(1236)] = 50974,
  [SMALL_STATE(1237)] = 50985,
  [SMALL_STATE(1238)] = 50996,
  [SMALL_STATE(1239)] = 51013,
  [SMALL_STATE(1240)] = 51024,
  [SMALL_STATE(1241)] = 51041,
  [SMALL_STATE(1242)] = 51054,
  [SMALL_STATE(1243)] = 51065,
  [SMALL_STATE(1244)] = 51076,
  [SMALL_STATE(1245)] = 51087,
  [SMALL_STATE(1246)] = 51104,
  [SMALL_STATE(1247)] = 51121,
  [SMALL_STATE(1248)] = 51138,
  [SMALL_STATE(1249)] = 51155,
  [SMALL_STATE(1250)] = 51172,
  [SMALL_STATE(1251)] = 51185,
  [SMALL_STATE(1252)] = 51200,
  [SMALL_STATE(1253)] = 51213,
  [SMALL_STATE(1254)] = 51226,
  [SMALL_STATE(1255)] = 51237,
  [SMALL_STATE(1256)] = 51254,
  [SMALL_STATE(1257)] = 51271,
  [SMALL_STATE(1258)] = 51288,
  [SMALL_STATE(1259)] = 51299,
  [SMALL_STATE(1260)] = 51314,
  [SMALL_STATE(1261)] = 51331,
  [SMALL_STATE(1262)] = 51348,
  [SMALL_STATE(1263)] = 51361,
  [SMALL_STATE(1264)] = 51372,
  [SMALL_STATE(1265)] = 51383,
  [SMALL_STATE(1266)] = 51400,
  [SMALL_STATE(1267)] = 51411,
  [SMALL_STATE(1268)] = 51422,
  [SMALL_STATE(1269)] = 51437,
  [SMALL_STATE(1270)] = 51452,
  [SMALL_STATE(1271)] = 51463,
  [SMALL_STATE(1272)] = 51474,
  [SMALL_STATE(1273)] = 51485,
  [SMALL_STATE(1274)] = 51498,
  [SMALL_STATE(1275)] = 51509,
  [SMALL_STATE(1276)] = 51522,
  [SMALL_STATE(1277)] = 51535,
  [SMALL_STATE(1278)] = 51552,
  [SMALL_STATE(1279)] = 51563,
  [SMALL_STATE(1280)] = 51580,
  [SMALL_STATE(1281)] = 51597,
  [SMALL_STATE(1282)] = 51608,
  [SMALL_STATE(1283)] = 51619,
  [SMALL_STATE(1284)] = 51632,
  [SMALL_STATE(1285)] = 51643,
  [SMALL_STATE(1286)] = 51654,
  [SMALL_STATE(1287)] = 51667,
  [SMALL_STATE(1288)] = 51682,
  [SMALL_STATE(1289)] = 51697,
  [SMALL_STATE(1290)] = 51712,
  [SMALL_STATE(1291)] = 51729,
  [SMALL_STATE(1292)] = 51746,
  [SMALL_STATE(1293)] = 51763,
  [SMALL_STATE(1294)] = 51780,
  [SMALL_STATE(1295)] = 51795,
  [SMALL_STATE(1296)] = 51810,
  [SMALL_STATE(1297)] = 51821,
  [SMALL_STATE(1298)] = 51832,
  [SMALL_STATE(1299)] = 51843,
  [SMALL_STATE(1300)] = 51856,
  [SMALL_STATE(1301)] = 51867,
  [SMALL_STATE(1302)] = 51878,
  [SMALL_STATE(1303)] = 51895,
  [SMALL_STATE(1304)] = 51910,
  [SMALL_STATE(1305)] = 51925,
  [SMALL_STATE(1306)] = 51936,
  [SMALL_STATE(1307)] = 51953,
  [SMALL_STATE(1308)] = 51970,
  [SMALL_STATE(1309)] = 51985,
  [SMALL_STATE(1310)] = 52002,
  [SMALL_STATE(1311)] = 52019,
  [SMALL_STATE(1312)] = 52036,
  [SMALL_STATE(1313)] = 52053,
  [SMALL_STATE(1314)] = 52070,
  [SMALL_STATE(1315)] = 52087,
  [SMALL_STATE(1316)] = 52104,
  [SMALL_STATE(1317)] = 52115,
  [SMALL_STATE(1318)] = 52126,
  [SMALL_STATE(1319)] = 52143,
  [SMALL_STATE(1320)] = 52160,
  [SMALL_STATE(1321)] = 52175,
  [SMALL_STATE(1322)] = 52192,
  [SMALL_STATE(1323)] = 52209,
  [SMALL_STATE(1324)] = 52220,
  [SMALL_STATE(1325)] = 52235,
  [SMALL_STATE(1326)] = 52252,
  [SMALL_STATE(1327)] = 52263,
  [SMALL_STATE(1328)] = 52280,
  [SMALL_STATE(1329)] = 52297,
  [SMALL_STATE(1330)] = 52312,
  [SMALL_STATE(1331)] = 52323,
  [SMALL_STATE(1332)] = 52340,
  [SMALL_STATE(1333)] = 52357,
  [SMALL_STATE(1334)] = 52374,
  [SMALL_STATE(1335)] = 52391,
  [SMALL_STATE(1336)] = 52402,
  [SMALL_STATE(1337)] = 52419,
  [SMALL_STATE(1338)] = 52436,
  [SMALL_STATE(1339)] = 52447,
  [SMALL_STATE(1340)] = 52460,
  [SMALL_STATE(1341)] = 52471,
  [SMALL_STATE(1342)] = 52482,
  [SMALL_STATE(1343)] = 52499,
  [SMALL_STATE(1344)] = 52510,
  [SMALL_STATE(1345)] = 52527,
  [SMALL_STATE(1346)] = 52540,
  [SMALL_STATE(1347)] = 52555,
  [SMALL_STATE(1348)] = 52566,
  [SMALL_STATE(1349)] = 52577,
  [SMALL_STATE(1350)] = 52588,
  [SMALL_STATE(1351)] = 52603,
  [SMALL_STATE(1352)] = 52614,
  [SMALL_STATE(1353)] = 52625,
  [SMALL_STATE(1354)] = 52640,
  [SMALL_STATE(1355)] = 52655,
  [SMALL_STATE(1356)] = 52666,
  [SMALL_STATE(1357)] = 52677,
  [SMALL_STATE(1358)] = 52694,
  [SMALL_STATE(1359)] = 52705,
  [SMALL_STATE(1360)] = 52716,
  [SMALL_STATE(1361)] = 52731,
  [SMALL_STATE(1362)] = 52748,
  [SMALL_STATE(1363)] = 52759,
  [SMALL_STATE(1364)] = 52772,
  [SMALL_STATE(1365)] = 52787,
  [SMALL_STATE(1366)] = 52798,
  [SMALL_STATE(1367)] = 52809,
  [SMALL_STATE(1368)] = 52820,
  [SMALL_STATE(1369)] = 52831,
  [SMALL_STATE(1370)] = 52844,
  [SMALL_STATE(1371)] = 52861,
  [SMALL_STATE(1372)] = 52871,
  [SMALL_STATE(1373)] = 52883,
  [SMALL_STATE(1374)] = 52897,
  [SMALL_STATE(1375)] = 52909,
  [SMALL_STATE(1376)] = 52923,
  [SMALL_STATE(1377)] = 52935,
  [SMALL_STATE(1378)] = 52949,
  [SMALL_STATE(1379)] = 52961,
  [SMALL_STATE(1380)] = 52975,
  [SMALL_STATE(1381)] = 52985,
  [SMALL_STATE(1382)] = 52997,
  [SMALL_STATE(1383)] = 53011,
  [SMALL_STATE(1384)] = 53025,
  [SMALL_STATE(1385)] = 53039,
  [SMALL_STATE(1386)] = 53053,
  [SMALL_STATE(1387)] = 53067,
  [SMALL_STATE(1388)] = 53079,
  [SMALL_STATE(1389)] = 53093,
  [SMALL_STATE(1390)] = 53107,
  [SMALL_STATE(1391)] = 53121,
  [SMALL_STATE(1392)] = 53135,
  [SMALL_STATE(1393)] = 53149,
  [SMALL_STATE(1394)] = 53163,
  [SMALL_STATE(1395)] = 53177,
  [SMALL_STATE(1396)] = 53191,
  [SMALL_STATE(1397)] = 53203,
  [SMALL_STATE(1398)] = 53217,
  [SMALL_STATE(1399)] = 53229,
  [SMALL_STATE(1400)] = 53243,
  [SMALL_STATE(1401)] = 53255,
  [SMALL_STATE(1402)] = 53269,
  [SMALL_STATE(1403)] = 53283,
  [SMALL_STATE(1404)] = 53297,
  [SMALL_STATE(1405)] = 53309,
  [SMALL_STATE(1406)] = 53321,
  [SMALL_STATE(1407)] = 53335,
  [SMALL_STATE(1408)] = 53349,
  [SMALL_STATE(1409)] = 53361,
  [SMALL_STATE(1410)] = 53375,
  [SMALL_STATE(1411)] = 53387,
  [SMALL_STATE(1412)] = 53397,
  [SMALL_STATE(1413)] = 53407,
  [SMALL_STATE(1414)] = 53419,
  [SMALL_STATE(1415)] = 53431,
  [SMALL_STATE(1416)] = 53443,
  [SMALL_STATE(1417)] = 53457,
  [SMALL_STATE(1418)] = 53469,
  [SMALL_STATE(1419)] = 53483,
  [SMALL_STATE(1420)] = 53497,
  [SMALL_STATE(1421)] = 53508,
  [SMALL_STATE(1422)] = 53517,
  [SMALL_STATE(1423)] = 53528,
  [SMALL_STATE(1424)] = 53537,
  [SMALL_STATE(1425)] = 53546,
  [SMALL_STATE(1426)] = 53555,
  [SMALL_STATE(1427)] = 53564,
  [SMALL_STATE(1428)] = 53573,
  [SMALL_STATE(1429)] = 53584,
  [SMALL_STATE(1430)] = 53595,
  [SMALL_STATE(1431)] = 53606,
  [SMALL_STATE(1432)] = 53615,
  [SMALL_STATE(1433)] = 53624,
  [SMALL_STATE(1434)] = 53633,
  [SMALL_STATE(1435)] = 53642,
  [SMALL_STATE(1436)] = 53651,
  [SMALL_STATE(1437)] = 53660,
  [SMALL_STATE(1438)] = 53669,
  [SMALL_STATE(1439)] = 53678,
  [SMALL_STATE(1440)] = 53687,
  [SMALL_STATE(1441)] = 53698,
  [SMALL_STATE(1442)] = 53709,
  [SMALL_STATE(1443)] = 53718,
  [SMALL_STATE(1444)] = 53727,
  [SMALL_STATE(1445)] = 53736,
  [SMALL_STATE(1446)] = 53745,
  [SMALL_STATE(1447)] = 53756,
  [SMALL_STATE(1448)] = 53767,
  [SMALL_STATE(1449)] = 53775,
  [SMALL_STATE(1450)] = 53783,
  [SMALL_STATE(1451)] = 53791,
  [SMALL_STATE(1452)] = 53799,
  [SMALL_STATE(1453)] = 53807,
  [SMALL_STATE(1454)] = 53815,
  [SMALL_STATE(1455)] = 53823,
  [SMALL_STATE(1456)] = 53831,
  [SMALL_STATE(1457)] = 53839,
  [SMALL_STATE(1458)] = 53847,
  [SMALL_STATE(1459)] = 53855,
  [SMALL_STATE(1460)] = 53863,
  [SMALL_STATE(1461)] = 53871,
  [SMALL_STATE(1462)] = 53879,
  [SMALL_STATE(1463)] = 53887,
  [SMALL_STATE(1464)] = 53895,
  [SMALL_STATE(1465)] = 53903,
  [SMALL_STATE(1466)] = 53911,
  [SMALL_STATE(1467)] = 53919,
  [SMALL_STATE(1468)] = 53927,
  [SMALL_STATE(1469)] = 53935,
  [SMALL_STATE(1470)] = 53943,
  [SMALL_STATE(1471)] = 53951,
  [SMALL_STATE(1472)] = 53959,
  [SMALL_STATE(1473)] = 53967,
  [SMALL_STATE(1474)] = 53975,
  [SMALL_STATE(1475)] = 53983,
  [SMALL_STATE(1476)] = 53991,
  [SMALL_STATE(1477)] = 53999,
  [SMALL_STATE(1478)] = 54007,
  [SMALL_STATE(1479)] = 54015,
  [SMALL_STATE(1480)] = 54023,
  [SMALL_STATE(1481)] = 54031,
  [SMALL_STATE(1482)] = 54039,
  [SMALL_STATE(1483)] = 54047,
  [SMALL_STATE(1484)] = 54055,
  [SMALL_STATE(1485)] = 54063,
  [SMALL_STATE(1486)] = 54071,
  [SMALL_STATE(1487)] = 54079,
  [SMALL_STATE(1488)] = 54087,
  [SMALL_STATE(1489)] = 54095,
  [SMALL_STATE(1490)] = 54103,
  [SMALL_STATE(1491)] = 54111,
  [SMALL_STATE(1492)] = 54119,
  [SMALL_STATE(1493)] = 54127,
  [SMALL_STATE(1494)] = 54135,
  [SMALL_STATE(1495)] = 54143,
  [SMALL_STATE(1496)] = 54151,
  [SMALL_STATE(1497)] = 54159,
  [SMALL_STATE(1498)] = 54167,
  [SMALL_STATE(1499)] = 54175,
  [SMALL_STATE(1500)] = 54183,
  [SMALL_STATE(1501)] = 54191,
  [SMALL_STATE(1502)] = 54199,
  [SMALL_STATE(1503)] = 54207,
  [SMALL_STATE(1504)] = 54215,
  [SMALL_STATE(1505)] = 54223,
  [SMALL_STATE(1506)] = 54231,
  [SMALL_STATE(1507)] = 54239,
  [SMALL_STATE(1508)] = 54247,
  [SMALL_STATE(1509)] = 54255,
  [SMALL_STATE(1510)] = 54263,
  [SMALL_STATE(1511)] = 54271,
  [SMALL_STATE(1512)] = 54279,
  [SMALL_STATE(1513)] = 54287,
  [SMALL_STATE(1514)] = 54295,
  [SMALL_STATE(1515)] = 54303,
  [SMALL_STATE(1516)] = 54311,
  [SMALL_STATE(1517)] = 54319,
  [SMALL_STATE(1518)] = 54327,
  [SMALL_STATE(1519)] = 54335,
  [SMALL_STATE(1520)] = 54343,
  [SMALL_STATE(1521)] = 54351,
  [SMALL_STATE(1522)] = 54359,
};

static const TSParseActionEntry ts_parse_actions[] = {
  [0] = {.entry = {.count = 0, .reusable = false}},
  [1] = {.entry = {.count = 1, .reusable = false}}, RECOVER(),
  [3] = {.entry = {.count = 1, .reusable = true}}, SHIFT_EXTRA(),
  [5] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_file, 0, 0, 0),
  [7] = {.entry = {.count = 1, .reusable = true}}, SHIFT(322),
  [9] = {.entry = {.count = 1, .reusable = true}}, SHIFT(254),
  [11] = {.entry = {.count = 1, .reusable = true}}, SHIFT(252),
  [13] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1018),
  [15] = {.entry = {.count = 1, .reusable = true}}, SHIFT(967),
  [17] = {.entry = {.count = 1, .reusable = true}}, SHIFT(222),
  [19] = {.entry = {.count = 1, .reusable = true}}, SHIFT(223),
  [21] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1284),
  [23] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1225),
  [25] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1233),
  [27] = {.entry = {.count = 1, .reusable = true}}, SHIFT(266),
  [29] = {.entry = {.count = 1, .reusable = true}}, SHIFT(968),
  [31] = {.entry = {.count = 1, .reusable = true}}, SHIFT(944),
  [33] = {.entry = {.count = 1, .reusable = true}}, SHIFT(282),
  [35] = {.entry = {.count = 1, .reusable = true}}, SHIFT(283),
  [37] = {.entry = {.count = 1, .reusable = true}}, SHIFT(891),
  [39] = {.entry = {.count = 1, .reusable = true}}, SHIFT(885),
  [41] = {.entry = {.count = 1, .reusable = true}}, SHIFT(373),
  [43] = {.entry = {.count = 1, .reusable = true}}, SHIFT(887),
  [45] = {.entry = {.count = 1, .reusable = true}}, SHIFT(942),
  [47] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7),
  [49] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12),
  [51] = {.entry = {.count = 1, .reusable = false}}, SHIFT(495),
  [53] = {.entry = {.count = 1, .reusable = true}}, SHIFT(495),
  [55] = {.entry = {.count = 1, .reusable = true}}, SHIFT(409),
  [57] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1128),
  [59] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1165),
  [61] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1208),
  [63] = {.entry = {.count = 1, .reusable = true}}, SHIFT(754),
  [65] = {.entry = {.count = 1, .reusable = false}}, SHIFT(23),
  [67] = {.entry = {.count = 1, .reusable = false}}, SHIFT(322),
  [69] = {.entry = {.count = 1, .reusable = false}}, SHIFT(254),
  [71] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parenthesis, 3, 0, 0),
  [73] = {.entry = {.count = 1, .reusable = false}}, SHIFT(252),
  [75] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1018),
  [77] = {.entry = {.count = 1, .reusable = false}}, SHIFT(967),
  [79] = {.entry = {.count = 1, .reusable = false}}, SHIFT(222),
  [81] = {.entry = {.count = 1, .reusable = false}}, SHIFT(223),
  [83] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1284),
  [85] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1225),
  [87] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1233),
  [89] = {.entry = {.count = 1, .reusable = false}}, SHIFT(266),
  [91] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1267),
  [93] = {.entry = {.count = 1, .reusable = false}}, SHIFT(968),
  [95] = {.entry = {.count = 1, .reusable = false}}, SHIFT(944),
  [97] = {.entry = {.count = 1, .reusable = false}}, SHIFT(282),
  [99] = {.entry = {.count = 1, .reusable = false}}, SHIFT(283),
  [101] = {.entry = {.count = 1, .reusable = false}}, SHIFT(891),
  [103] = {.entry = {.count = 1, .reusable = false}}, SHIFT(885),
  [105] = {.entry = {.count = 1, .reusable = false}}, SHIFT(373),
  [107] = {.entry = {.count = 1, .reusable = false}}, SHIFT(892),
  [109] = {.entry = {.count = 1, .reusable = false}}, SHIFT(942),
  [111] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7),
  [113] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12),
  [115] = {.entry = {.count = 1, .reusable = false}}, SHIFT(409),
  [117] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6),
  [119] = {.entry = {.count = 1, .reusable = false}}, SHIFT(308),
  [121] = {.entry = {.count = 1, .reusable = false}}, SHIFT(309),
  [123] = {.entry = {.count = 1, .reusable = false}}, SHIFT(310),
  [125] = {.entry = {.count = 1, .reusable = false}}, SHIFT(321),
  [127] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13),
  [129] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1297),
  [131] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9),
  [133] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_elseif_clause, 2, 0, 7),
  [135] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16),
  [137] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1316),
  [139] = {.entry = {.count = 1, .reusable = false}}, SHIFT(244),
  [141] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1271),
  [143] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8),
  [145] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1220),
  [147] = {.entry = {.count = 1, .reusable = false}}, SHIFT(869),
  [149] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1230),
  [151] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_elseif_clause, 3, 0, 7),
  [153] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_case_clause, 3, 0, 7),
  [155] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15),
  [157] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1305),
  [159] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14),
  [161] = {.entry = {.count = 1, .reusable = false}}, SHIFT(253),
  [163] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1296),
  [165] = {.entry = {.count = 1, .reusable = false}}, SHIFT(21),
  [167] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_else_clause, 1, 0, 0),
  [169] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1242),
  [171] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1355),
  [173] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1223),
  [175] = {.entry = {.count = 1, .reusable = false}}, SHIFT(20),
  [177] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_otherwise_clause, 1, 0, 0),
  [179] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_catch_clause, 2, 0, 0),
  [181] = {.entry = {.count = 1, .reusable = false}}, SHIFT(26),
  [183] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1343),
  [185] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_otherwise_clause, 2, 0, 0),
  [187] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_else_clause, 2, 0, 0),
  [189] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_catch_clause, 3, 0, 0),
  [191] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1270),
  [193] = {.entry = {.count = 1, .reusable = false}}, SHIFT(27),
  [195] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1237),
  [197] = {.entry = {.count = 1, .reusable = false}}, SHIFT(28),
  [199] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1221),
  [201] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1234),
  [203] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1285),
  [205] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 5, 0, 16),
  [207] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1415),
  [209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(383),
  [211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(892),
  [213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1415),
  [215] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 4, 0, 16),
  [217] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1095),
  [219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1095),
  [221] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1145),
  [223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1145),
  [225] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 5, 0, 8),
  [227] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1135),
  [229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1135),
  [231] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 5, 0, 22),
  [233] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1104),
  [235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1104),
  [237] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 4, 0, 8),
  [239] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1101),
  [241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1101),
  [243] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1410),
  [245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1410),
  [247] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1376),
  [249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1376),
  [251] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 6, 0, 16),
  [253] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1117),
  [255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1117),
  [257] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 6, 0, 22),
  [259] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1119),
  [261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1119),
  [263] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1374),
  [265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1374),
  [267] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1378),
  [269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1378),
  [271] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_block, 1, 0, 0),
  [273] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_block, 1, 0, 0),
  [275] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 7, 0, 22),
  [277] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1139),
  [279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1139),
  [281] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 3, 0, 8),
  [283] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1092),
  [285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1092),
  [287] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1413),
  [289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1413),
  [291] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1396),
  [293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1396),
  [295] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1405),
  [297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1405),
  [299] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1398),
  [301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1398),
  [303] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(322),
  [306] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(254),
  [309] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(252),
  [312] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(1018),
  [315] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(967),
  [318] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(222),
  [321] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(223),
  [324] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(1284),
  [327] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(1225),
  [330] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(1233),
  [333] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0),
  [335] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__block, 2, 0, 0),
  [337] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(266),
  [340] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(968),
  [343] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(944),
  [346] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(282),
  [349] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(283),
  [352] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(891),
  [355] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(885),
  [358] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(373),
  [361] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(892),
  [364] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(942),
  [367] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(7),
  [370] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(12),
  [373] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(495),
  [376] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(495),
  [379] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(409),
  [382] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(1128),
  [385] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(1165),
  [388] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(1208),
  [391] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(754),
  [394] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1253),
  [396] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1253),
  [398] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1363),
  [400] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1363),
  [402] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1273),
  [404] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1273),
  [406] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1276),
  [408] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1276),
  [410] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1214),
  [412] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1214),
  [414] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1219),
  [416] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1219),
  [418] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1262),
  [420] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1262),
  [422] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1345),
  [424] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1345),
  [426] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1250),
  [428] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1250),
  [430] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_file, 1, 0, 0),
  [432] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_block, 1, 0, 0), SHIFT(892),
  [435] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_unary_operator, 2, 0, 1),
  [437] = {.entry = {.count = 1, .reusable = false}}, SHIFT(174),
  [439] = {.entry = {.count = 1, .reusable = false}}, SHIFT(388),
  [441] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1003),
  [443] = {.entry = {.count = 1, .reusable = false}}, SHIFT(115),
  [445] = {.entry = {.count = 1, .reusable = false}}, SHIFT(177),
  [447] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_unary_operator, 2, 0, 1),
  [449] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__expression, 1, 0, 0),
  [451] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__binary_expression, 1, 0, 0),
  [453] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__expression, 1, 0, 0), REDUCE(sym__range_element, 1, 0, 0),
  [456] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expression, 1, 0, 0),
  [458] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__range_element, 1, 0, 0),
  [460] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__binary_expression, 1, 0, 0),
  [462] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__range_element, 1, 0, 0),
  [464] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_metaclass_operator, 2, 0, 0),
  [466] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1005),
  [468] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_metaclass_operator, 2, 0, 0),
  [470] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_field_expression_repeat1, 2, 0, 12),
  [472] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_field_expression_repeat1, 2, 0, 12),
  [474] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_field_expression_repeat1, 2, 0, 14),
  [476] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_field_expression_repeat1, 2, 0, 14), SHIFT_REPEAT(388),
  [479] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_field_expression_repeat1, 2, 0, 14),
  [481] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_metaclass_operator, 3, 0, 0),
  [483] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_metaclass_operator, 3, 0, 0),
  [485] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_handle_operator, 3, 0, 0),
  [487] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_handle_operator, 3, 0, 0),
  [489] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_handle_operator, 2, 0, 0),
  [491] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_handle_operator, 2, 0, 0),
  [493] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_metaclass_operator_repeat1, 2, 0, 0),
  [495] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_metaclass_operator_repeat1, 2, 0, 0), SHIFT_REPEAT(1005),
  [498] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_metaclass_operator_repeat1, 2, 0, 0),
  [500] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_expression, 2, 0, 4),
  [502] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_expression, 2, 0, 4),
  [504] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_indirect_access, 3, 0, 0),
  [506] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_indirect_access, 3, 0, 0),
  [508] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__extended_keywords, 1, 0, 0),
  [510] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__extended_keywords, 1, 0, 0),
  [512] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__args, 2, 0, 0),
  [514] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__args, 2, 0, 0),
  [516] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__args, 3, 0, 0),
  [518] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__args, 3, 0, 0),
  [520] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_call, 4, 0, 18),
  [522] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_call, 4, 0, 18),
  [524] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_call, 4, 0, 19),
  [526] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_call, 4, 0, 19),
  [528] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_identifier, 1, 0, 0),
  [530] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_identifier, 1, 0, 0),
  [532] = {.entry = {.count = 1, .reusable = false}}, SHIFT(979),
  [534] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_call, 2, 0, 3),
  [536] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_call, 2, 0, 3),
  [538] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_call, 2, 0, 6),
  [540] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_call, 2, 0, 6),
  [542] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_cell, 2, 0, 0),
  [544] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_cell, 2, 0, 0),
  [546] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_number, 1, 0, 0),
  [548] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_number, 1, 0, 0),
  [550] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_boolean, 1, 0, 0),
  [552] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_boolean, 1, 0, 0),
  [554] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__range_element, 1, -1, 0),
  [556] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string, 2, 0, 0),
  [558] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string, 2, 0, 0),
  [560] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_not_operator, 2, 0, 0),
  [562] = {.entry = {.count = 1, .reusable = false}}, SHIFT(344),
  [564] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_not_operator, 2, 0, 0),
  [566] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_matrix, 2, 0, 0),
  [568] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_matrix, 2, 0, 0),
  [570] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_postfix_operator, 2, 0, 2),
  [572] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_postfix_operator, 2, 0, 2),
  [574] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string, 3, 0, 0),
  [576] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string, 3, 0, 0),
  [578] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parenthesis, 3, 0, 0),
  [580] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_matrix, 3, 0, 0),
  [582] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_matrix, 3, 0, 0),
  [584] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_cell, 3, 0, 0),
  [586] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_cell, 3, 0, 0),
  [588] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_comparison_operator, 3, 0, 0),
  [590] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_comparison_operator, 3, 0, 0),
  [592] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_binary_operator, 3, 0, 13),
  [594] = {.entry = {.count = 1, .reusable = false}}, SHIFT(312),
  [596] = {.entry = {.count = 1, .reusable = false}}, SHIFT(313),
  [598] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_binary_operator, 3, 0, 13),
  [600] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lambda, 5, 0, 20),
  [602] = {.entry = {.count = 1, .reusable = false}}, SHIFT(345),
  [604] = {.entry = {.count = 1, .reusable = false}}, SHIFT(346),
  [606] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lambda, 5, 0, 20),
  [608] = {.entry = {.count = 1, .reusable = false}}, SHIFT(311),
  [610] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_range, 3, 0, 0),
  [612] = {.entry = {.count = 1, .reusable = false}}, SHIFT(320),
  [614] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_range, 3, 0, 0),
  [616] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_matrix, 4, 0, 0),
  [618] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_matrix, 4, 0, 0),
  [620] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_cell, 4, 0, 0),
  [622] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_cell, 4, 0, 0),
  [624] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_matrix, 5, 0, 0),
  [626] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_matrix, 5, 0, 0),
  [628] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_cell, 5, 0, 0),
  [630] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_cell, 5, 0, 0),
  [632] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_range, 5, 0, 0),
  [634] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_range, 3, 0, 0), REDUCE(sym_range, 5, 0, 0),
  [637] = {.entry = {.count = 1, .reusable = false}}, SHIFT(284),
  [639] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_range, 5, 0, 0),
  [641] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__range_element, 1, 1, 0),
  [643] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__expression, 1, 0, 0), REDUCE(sym__range_element, 1, -1, 0),
  [646] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__expression, 1, 0, 0), REDUCE(sym__range_element, 1, 1, 0),
  [649] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__range_element, 1, -1, 0),
  [651] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__range_element, 1, 1, 0),
  [653] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_boolean_operator, 3, 0, 13),
  [655] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_boolean_operator, 3, 0, 13),
  [657] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lambda, 4, 0, 15),
  [659] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lambda, 4, 0, 15),
  [661] = {.entry = {.count = 1, .reusable = false}}, SHIFT(362),
  [663] = {.entry = {.count = 1, .reusable = false}}, SHIFT(185),
  [665] = {.entry = {.count = 1, .reusable = false}}, SHIFT(195),
  [667] = {.entry = {.count = 1, .reusable = false}}, SHIFT(333),
  [669] = {.entry = {.count = 1, .reusable = false}}, SHIFT(240),
  [671] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1025),
  [673] = {.entry = {.count = 1, .reusable = false}}, SHIFT(980),
  [675] = {.entry = {.count = 1, .reusable = false}}, SHIFT(156),
  [677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(161),
  [679] = {.entry = {.count = 1, .reusable = false}}, SHIFT(615),
  [681] = {.entry = {.count = 1, .reusable = false}}, SHIFT(225),
  [683] = {.entry = {.count = 1, .reusable = false}}, SHIFT(798),
  [685] = {.entry = {.count = 1, .reusable = false}}, SHIFT(445),
  [687] = {.entry = {.count = 1, .reusable = false}}, SHIFT(544),
  [689] = {.entry = {.count = 1, .reusable = false}}, SHIFT(453),
  [691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1155),
  [693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1182),
  [695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(445),
  [697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(158),
  [699] = {.entry = {.count = 1, .reusable = false}}, SHIFT(600),
  [701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(599),
  [703] = {.entry = {.count = 1, .reusable = false}}, SHIFT(674),
  [705] = {.entry = {.count = 1, .reusable = false}}, SHIFT(603),
  [707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(157),
  [709] = {.entry = {.count = 1, .reusable = false}}, SHIFT(677),
  [711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(164),
  [713] = {.entry = {.count = 1, .reusable = false}}, SHIFT(685),
  [715] = {.entry = {.count = 1, .reusable = false}}, SHIFT(618),
  [717] = {.entry = {.count = 1, .reusable = false}}, SHIFT(683),
  [719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(162),
  [721] = {.entry = {.count = 1, .reusable = false}}, SHIFT(675),
  [723] = {.entry = {.count = 1, .reusable = false}}, SHIFT(630),
  [725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(166),
  [727] = {.entry = {.count = 1, .reusable = false}}, SHIFT(616),
  [729] = {.entry = {.count = 1, .reusable = false}}, SHIFT(617),
  [731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(188),
  [733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(800),
  [735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(269),
  [737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(261),
  [739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1014),
  [741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(955),
  [743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(159),
  [745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(206),
  [747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1380),
  [749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(805),
  [751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(452),
  [753] = {.entry = {.count = 1, .reusable = false}}, SHIFT(627),
  [755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(627),
  [757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(540),
  [759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1168),
  [761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1169),
  [763] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__index_matrix_repeat1, 1, 0, 0),
  [765] = {.entry = {.count = 1, .reusable = false}}, SHIFT(187),
  [767] = {.entry = {.count = 1, .reusable = false}}, SHIFT(189),
  [769] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1014),
  [771] = {.entry = {.count = 1, .reusable = false}}, SHIFT(955),
  [773] = {.entry = {.count = 1, .reusable = false}}, SHIFT(155),
  [775] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__index_matrix_repeat1, 1, 0, 0),
  [777] = {.entry = {.count = 1, .reusable = false}}, SHIFT(206),
  [779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(380),
  [781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(469),
  [783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(87),
  [785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(442),
  [787] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__index_row, 2, 0, 0),
  [789] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__index_row, 2, 0, 0),
  [791] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_row, 3, 0, 0), REDUCE(sym__index_row, 3, 0, 0),
  [794] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_row, 3, 0, 0), REDUCE(sym__index_row, 3, 0, 0),
  [797] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__index_row, 3, 0, 0),
  [799] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__index_row, 3, 0, 0),
  [801] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__index_row, 4, 0, 0),
  [803] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__index_row, 4, 0, 0),
  [805] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_row, 2, 0, 0), REDUCE(sym__index_row, 2, 0, 0),
  [808] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_row, 2, 0, 0), REDUCE(sym__index_row, 2, 0, 0),
  [811] = {.entry = {.count = 1, .reusable = true}}, SHIFT(195),
  [813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(333),
  [815] = {.entry = {.count = 1, .reusable = true}}, SHIFT(240),
  [817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1025),
  [819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(980),
  [821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(156),
  [823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(225),
  [825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(798),
  [827] = {.entry = {.count = 1, .reusable = true}}, SHIFT(544),
  [829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(453),
  [831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(189),
  [833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(155),
  [835] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1029),
  [837] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_metaclass_operator_repeat1, 2, 0, 0), SHIFT_REPEAT(1029),
  [840] = {.entry = {.count = 1, .reusable = true}}, SHIFT(352),
  [842] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_matrix_repeat2, 1, 0, 0),
  [844] = {.entry = {.count = 1, .reusable = false}}, SHIFT(251),
  [846] = {.entry = {.count = 1, .reusable = false}}, SHIFT(315),
  [848] = {.entry = {.count = 1, .reusable = false}}, SHIFT(224),
  [850] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_matrix_repeat2, 1, 0, 0),
  [852] = {.entry = {.count = 1, .reusable = true}}, SHIFT(165),
  [854] = {.entry = {.count = 1, .reusable = true}}, SHIFT(160),
  [856] = {.entry = {.count = 1, .reusable = true}}, SHIFT(163),
  [858] = {.entry = {.count = 1, .reusable = true}}, SHIFT(207),
  [860] = {.entry = {.count = 1, .reusable = false}}, SHIFT(664),
  [862] = {.entry = {.count = 1, .reusable = true}}, SHIFT(208),
  [864] = {.entry = {.count = 1, .reusable = false}}, SHIFT(665),
  [866] = {.entry = {.count = 1, .reusable = false}}, SHIFT(689),
  [868] = {.entry = {.count = 1, .reusable = false}}, SHIFT(690),
  [870] = {.entry = {.count = 1, .reusable = true}}, SHIFT(230),
  [872] = {.entry = {.count = 1, .reusable = false}}, SHIFT(474),
  [874] = {.entry = {.count = 1, .reusable = true}}, SHIFT(236),
  [876] = {.entry = {.count = 1, .reusable = false}}, SHIFT(481),
  [878] = {.entry = {.count = 1, .reusable = true}}, SHIFT(226),
  [880] = {.entry = {.count = 1, .reusable = false}}, SHIFT(558),
  [882] = {.entry = {.count = 1, .reusable = true}}, SHIFT(227),
  [884] = {.entry = {.count = 1, .reusable = false}}, SHIFT(560),
  [886] = {.entry = {.count = 1, .reusable = false}}, SHIFT(573),
  [888] = {.entry = {.count = 1, .reusable = false}}, SHIFT(598),
  [890] = {.entry = {.count = 1, .reusable = false}}, SHIFT(492),
  [892] = {.entry = {.count = 1, .reusable = true}}, SHIFT(233),
  [894] = {.entry = {.count = 1, .reusable = false}}, SHIFT(114),
  [896] = {.entry = {.count = 1, .reusable = true}}, SHIFT(234),
  [898] = {.entry = {.count = 1, .reusable = false}}, SHIFT(102),
  [900] = {.entry = {.count = 1, .reusable = false}}, SHIFT(118),
  [902] = {.entry = {.count = 1, .reusable = false}}, SHIFT(119),
  [904] = {.entry = {.count = 1, .reusable = false}}, SHIFT(494),
  [906] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_row, 4, 0, 0),
  [908] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_row, 4, 0, 0),
  [910] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_ignored_argument, 1, 0, 0),
  [912] = {.entry = {.count = 1, .reusable = false}}, SHIFT(352),
  [914] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1034),
  [916] = {.entry = {.count = 1, .reusable = false}}, SHIFT(989),
  [918] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_ignored_argument, 1, 0, 0),
  [920] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_row, 2, 0, 0),
  [922] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_row, 2, 0, 0),
  [924] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_row, 3, 0, 0),
  [926] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_row, 3, 0, 0),
  [928] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_iterator, 3, 0, 0),
  [930] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_iterator, 3, 0, 0),
  [932] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_elseif_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(244),
  [935] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_elseif_clause_repeat1, 2, 0, 0),
  [937] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_elseif_clause_repeat1, 2, 0, 0),
  [939] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__block, 3, 0, 5),
  [941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(249),
  [943] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__block, 3, 0, 5),
  [945] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__block, 3, 0, 0),
  [947] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__block, 3, 0, 0),
  [949] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 5),
  [951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(245),
  [953] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__block, 2, 0, 5),
  [955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(246),
  [957] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__block_repeat1, 2, 0, 0),
  [959] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block_repeat1, 2, 0, 0), SHIFT_REPEAT(249),
  [962] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__block_repeat1, 2, 0, 0),
  [964] = {.entry = {.count = 1, .reusable = true}}, SHIFT(315),
  [966] = {.entry = {.count = 1, .reusable = true}}, SHIFT(224),
  [968] = {.entry = {.count = 1, .reusable = true}}, SHIFT(270),
  [970] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1009),
  [972] = {.entry = {.count = 1, .reusable = true}}, SHIFT(961),
  [974] = {.entry = {.count = 1, .reusable = true}}, SHIFT(356),
  [976] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19),
  [978] = {.entry = {.count = 1, .reusable = true}}, SHIFT(205),
  [980] = {.entry = {.count = 1, .reusable = true}}, SHIFT(296),
  [982] = {.entry = {.count = 1, .reusable = true}}, SHIFT(353),
  [984] = {.entry = {.count = 1, .reusable = true}}, SHIFT(328),
  [986] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1037),
  [988] = {.entry = {.count = 1, .reusable = true}}, SHIFT(994),
  [990] = {.entry = {.count = 1, .reusable = true}}, SHIFT(231),
  [992] = {.entry = {.count = 1, .reusable = true}}, SHIFT(232),
  [994] = {.entry = {.count = 1, .reusable = true}}, SHIFT(93),
  [996] = {.entry = {.count = 1, .reusable = false}}, SHIFT(103),
  [998] = {.entry = {.count = 1, .reusable = true}}, SHIFT(103),
  [1000] = {.entry = {.count = 1, .reusable = true}}, SHIFT(104),
  [1002] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1206),
  [1004] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1207),
  [1006] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1031),
  [1008] = {.entry = {.count = 1, .reusable = true}}, SHIFT(988),
  [1010] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1027),
  [1012] = {.entry = {.count = 1, .reusable = true}}, SHIFT(984),
  [1014] = {.entry = {.count = 1, .reusable = true}}, SHIFT(992),
  [1016] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1034),
  [1018] = {.entry = {.count = 1, .reusable = true}}, SHIFT(993),
  [1020] = {.entry = {.count = 1, .reusable = true}}, SHIFT(998),
  [1022] = {.entry = {.count = 1, .reusable = true}}, SHIFT(990),
  [1024] = {.entry = {.count = 1, .reusable = true}}, SHIFT(989),
  [1026] = {.entry = {.count = 1, .reusable = true}}, SHIFT(367),
  [1028] = {.entry = {.count = 1, .reusable = true}}, SHIFT(365),
  [1030] = {.entry = {.count = 1, .reusable = true}}, SHIFT(363),
  [1032] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block_repeat1, 2, 0, 0), SHIFT_REPEAT(367),
  [1035] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_function_definition_repeat1, 2, 0, 0),
  [1037] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_function_definition_repeat1, 2, 0, 0),
  [1039] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_function_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(1056),
  [1042] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments_statement, 5, 0, 25),
  [1044] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_arguments_statement, 5, 0, 25),
  [1046] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments_statement, 4, 0, 0),
  [1048] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_arguments_statement, 4, 0, 0),
  [1050] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments_statement, 3, 0, 0),
  [1052] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_arguments_statement, 3, 0, 0),
  [1054] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments_statement, 4, 0, 25),
  [1056] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_arguments_statement, 4, 0, 25),
  [1058] = {.entry = {.count = 1, .reusable = false}}, SHIFT(172),
  [1060] = {.entry = {.count = 1, .reusable = false}}, SHIFT(390),
  [1062] = {.entry = {.count = 1, .reusable = false}}, SHIFT(985),
  [1064] = {.entry = {.count = 1, .reusable = false}}, SHIFT(490),
  [1066] = {.entry = {.count = 1, .reusable = false}}, SHIFT(169),
  [1068] = {.entry = {.count = 1, .reusable = true}}, SHIFT(259),
  [1070] = {.entry = {.count = 1, .reusable = true}}, SHIFT(608),
  [1072] = {.entry = {.count = 1, .reusable = false}}, SHIFT(608),
  [1074] = {.entry = {.count = 1, .reusable = true}}, SHIFT(470),
  [1076] = {.entry = {.count = 1, .reusable = false}}, SHIFT(753),
  [1078] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1010),
  [1080] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__keywords, 1, 0, 0),
  [1082] = {.entry = {.count = 1, .reusable = true}}, SHIFT(351),
  [1084] = {.entry = {.count = 1, .reusable = true}}, SHIFT(880),
  [1086] = {.entry = {.count = 1, .reusable = false}}, SHIFT(880),
  [1088] = {.entry = {.count = 1, .reusable = true}}, SHIFT(809),
  [1090] = {.entry = {.count = 1, .reusable = true}}, SHIFT(845),
  [1092] = {.entry = {.count = 1, .reusable = true}}, SHIFT(355),
  [1094] = {.entry = {.count = 1, .reusable = true}}, SHIFT(88),
  [1096] = {.entry = {.count = 1, .reusable = false}}, SHIFT(88),
  [1098] = {.entry = {.count = 1, .reusable = true}}, SHIFT(86),
  [1100] = {.entry = {.count = 1, .reusable = true}}, SHIFT(327),
  [1102] = {.entry = {.count = 1, .reusable = true}}, SHIFT(433),
  [1104] = {.entry = {.count = 1, .reusable = false}}, SHIFT(433),
  [1106] = {.entry = {.count = 1, .reusable = true}}, SHIFT(392),
  [1108] = {.entry = {.count = 1, .reusable = true}}, SHIFT(354),
  [1110] = {.entry = {.count = 1, .reusable = true}}, SHIFT(539),
  [1112] = {.entry = {.count = 1, .reusable = false}}, SHIFT(539),
  [1114] = {.entry = {.count = 1, .reusable = true}}, SHIFT(443),
  [1116] = {.entry = {.count = 1, .reusable = false}}, SHIFT(957),
  [1118] = {.entry = {.count = 1, .reusable = false}}, SHIFT(175),
  [1120] = {.entry = {.count = 1, .reusable = false}}, SHIFT(393),
  [1122] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1001),
  [1124] = {.entry = {.count = 1, .reusable = false}}, SHIFT(567),
  [1126] = {.entry = {.count = 1, .reusable = false}}, SHIFT(176),
  [1128] = {.entry = {.count = 1, .reusable = false}}, SHIFT(285),
  [1130] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__index_range_element, 1, 0, 0),
  [1132] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__binary_expression, 1, 0, 0), REDUCE(sym__index_binary_expression, 1, 0, 0),
  [1135] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__index_range_element, 1, 0, 0),
  [1137] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__expression, 1, 0, 0), REDUCE(sym__index_expression, 1, 0, 0),
  [1140] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__expression, 1, 0, 0), REDUCE(sym__index_expression, 1, 0, 0),
  [1143] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__index_expression, 1, 0, 0),
  [1145] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__index_expression, 1, 0, 0),
  [1147] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__index_binary_expression, 1, 0, 0),
  [1149] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__index_binary_expression, 1, 0, 0),
  [1151] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_field_expression_repeat1, 2, 0, 14), SHIFT_REPEAT(390),
  [1154] = {.entry = {.count = 1, .reusable = true}}, SHIFT(178),
  [1156] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__binary_expression, 1, 0, 0), REDUCE(sym__index_binary_expression, 1, 0, 0),
  [1159] = {.entry = {.count = 1, .reusable = false}}, SHIFT(382),
  [1161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(999),
  [1163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(667),
  [1165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(173),
  [1167] = {.entry = {.count = 1, .reusable = false}}, SHIFT(260),
  [1169] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1002),
  [1171] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__expression, 1, 0, 0), REDUCE(sym__range_element, 1, 0, 0),
  [1174] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1020),
  [1176] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_metaclass_operator_repeat1, 2, 0, 0), SHIFT_REPEAT(1020),
  [1179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(85),
  [1181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(387),
  [1183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1000),
  [1185] = {.entry = {.count = 1, .reusable = false}}, SHIFT(262),
  [1187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(856),
  [1189] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_field_expression_repeat1, 2, 0, 14), SHIFT_REPEAT(393),
  [1192] = {.entry = {.count = 1, .reusable = false}}, SHIFT(329),
  [1194] = {.entry = {.count = 1, .reusable = true}}, SHIFT(446),
  [1196] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1036),
  [1198] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_metaclass_operator_repeat1, 2, 0, 0), SHIFT_REPEAT(1036),
  [1201] = {.entry = {.count = 1, .reusable = false}}, SHIFT(330),
  [1203] = {.entry = {.count = 1, .reusable = false}}, SHIFT(331),
  [1205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(487),
  [1207] = {.entry = {.count = 1, .reusable = false}}, SHIFT(303),
  [1209] = {.entry = {.count = 1, .reusable = false}}, SHIFT(304),
  [1211] = {.entry = {.count = 1, .reusable = false}}, SHIFT(302),
  [1213] = {.entry = {.count = 1, .reusable = false}}, SHIFT(306),
  [1215] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1032),
  [1217] = {.entry = {.count = 1, .reusable = false}}, SHIFT(339),
  [1219] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_metaclass_operator_repeat1, 2, 0, 0), SHIFT_REPEAT(1032),
  [1222] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_field_expression_repeat1, 2, 0, 14), SHIFT_REPEAT(382),
  [1225] = {.entry = {.count = 1, .reusable = false}}, SHIFT(290),
  [1227] = {.entry = {.count = 1, .reusable = false}}, SHIFT(291),
  [1229] = {.entry = {.count = 1, .reusable = false}}, SHIFT(289),
  [1231] = {.entry = {.count = 1, .reusable = false}}, SHIFT(293),
  [1233] = {.entry = {.count = 1, .reusable = false}}, SHIFT(340),
  [1235] = {.entry = {.count = 1, .reusable = false}}, SHIFT(341),
  [1237] = {.entry = {.count = 1, .reusable = false}}, SHIFT(298),
  [1239] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_matrix_repeat1, 2, 0, 0),
  [1241] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_matrix_repeat1, 2, 0, 0), SHIFT_REPEAT(599),
  [1244] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_matrix_repeat1, 2, 0, 0),
  [1246] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_matrix, 2, 0, 0), REDUCE(sym__index_matrix, 2, 0, 0),
  [1249] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_matrix, 2, 0, 0), REDUCE(sym__index_matrix, 2, 0, 0),
  [1252] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_matrix, 3, 0, 0), REDUCE(sym__index_matrix, 3, 0, 0),
  [1255] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_matrix, 3, 0, 0), REDUCE(sym__index_matrix, 3, 0, 0),
  [1258] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__index_range_element, 1, -1, 0),
  [1260] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__index_range_element, 1, -1, 0),
  [1262] = {.entry = {.count = 1, .reusable = false}}, SHIFT(299),
  [1264] = {.entry = {.count = 1, .reusable = false}}, SHIFT(300),
  [1266] = {.entry = {.count = 1, .reusable = false}}, SHIFT(301),
  [1268] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__index_matrix, 2, 0, 0),
  [1270] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__index_matrix, 2, 0, 0),
  [1272] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__index_matrix, 3, 0, 0),
  [1274] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__index_matrix, 3, 0, 0),
  [1276] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__expression, 1, 0, 0), REDUCE(sym__range_element, 1, 1, 0),
  [1279] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__expression, 1, 0, 0), REDUCE(sym__range_element, 1, -1, 0),
  [1282] = {.entry = {.count = 1, .reusable = false}}, SHIFT(334),
  [1284] = {.entry = {.count = 1, .reusable = true}}, SHIFT(334),
  [1286] = {.entry = {.count = 1, .reusable = true}}, SHIFT(335),
  [1288] = {.entry = {.count = 1, .reusable = true}}, SHIFT(336),
  [1290] = {.entry = {.count = 1, .reusable = true}}, SHIFT(275),
  [1292] = {.entry = {.count = 1, .reusable = true}}, SHIFT(276),
  [1294] = {.entry = {.count = 1, .reusable = true}}, SHIFT(274),
  [1296] = {.entry = {.count = 1, .reusable = false}}, SHIFT(278),
  [1298] = {.entry = {.count = 1, .reusable = true}}, SHIFT(284),
  [1300] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_range, 3, 0, 0), REDUCE(sym_range, 5, 0, 0),
  [1303] = {.entry = {.count = 1, .reusable = false}}, SHIFT(286),
  [1305] = {.entry = {.count = 1, .reusable = false}}, SHIFT(287),
  [1307] = {.entry = {.count = 1, .reusable = false}}, SHIFT(288),
  [1309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(768),
  [1311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(167),
  [1313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(385),
  [1315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(897),
  [1317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(996),
  [1319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1459),
  [1321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(170),
  [1323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(766),
  [1325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1449),
  [1327] = {.entry = {.count = 1, .reusable = false}}, SHIFT(860),
  [1329] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1130),
  [1331] = {.entry = {.count = 1, .reusable = false}}, SHIFT(982),
  [1333] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1035),
  [1335] = {.entry = {.count = 1, .reusable = false}}, SHIFT(838),
  [1337] = {.entry = {.count = 1, .reusable = false}}, SHIFT(264),
  [1339] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1039),
  [1341] = {.entry = {.count = 1, .reusable = false}}, SHIFT(783),
  [1343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(783),
  [1345] = {.entry = {.count = 1, .reusable = false}}, SHIFT(271),
  [1347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(271),
  [1349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(272),
  [1351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(273),
  [1353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(490),
  [1355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(567),
  [1357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(115),
  [1359] = {.entry = {.count = 1, .reusable = false}}, SHIFT(861),
  [1361] = {.entry = {.count = 1, .reusable = false}}, SHIFT(872),
  [1363] = {.entry = {.count = 1, .reusable = false}}, SHIFT(372),
  [1365] = {.entry = {.count = 1, .reusable = false}}, SHIFT(822),
  [1367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(822),
  [1369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(849),
  [1371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1204),
  [1373] = {.entry = {.count = 1, .reusable = false}}, SHIFT(371),
  [1375] = {.entry = {.count = 1, .reusable = false}}, SHIFT(259),
  [1377] = {.entry = {.count = 1, .reusable = false}}, SHIFT(897),
  [1379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(757),
  [1381] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1460),
  [1383] = {.entry = {.count = 1, .reusable = false}}, SHIFT(809),
  [1385] = {.entry = {.count = 1, .reusable = false}}, SHIFT(540),
  [1387] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1099),
  [1389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(882),
  [1391] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1459),
  [1393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(769),
  [1395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1480),
  [1397] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_multioutput_variable_repeat1, 2, 0, 0), SHIFT_REPEAT(795),
  [1400] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_multioutput_variable_repeat1, 2, 0, 0), SHIFT_REPEAT(259),
  [1403] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_multioutput_variable_repeat1, 2, 0, 0), SHIFT_REPEAT(897),
  [1406] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_multioutput_variable_repeat1, 2, 0, 0),
  [1408] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_multioutput_variable_repeat1, 2, 0, 0), SHIFT_REPEAT(809),
  [1411] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_multioutput_variable_repeat1, 2, 0, 0), SHIFT_REPEAT(540),
  [1414] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1152),
  [1416] = {.entry = {.count = 1, .reusable = false}}, SHIFT(865),
  [1418] = {.entry = {.count = 1, .reusable = false}}, SHIFT(952),
  [1420] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1349),
  [1422] = {.entry = {.count = 1, .reusable = false}}, SHIFT(326),
  [1424] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17),
  [1426] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1141),
  [1428] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1079),
  [1430] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1365),
  [1432] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1079),
  [1434] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1067),
  [1436] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_methods_repeat1, 2, 0, 0),
  [1438] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_methods_repeat1, 2, 0, 0), SHIFT_REPEAT(1079),
  [1441] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_methods_repeat1, 2, 0, 0), SHIFT_REPEAT(892),
  [1444] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_methods_repeat1, 2, 0, 0), SHIFT_REPEAT(1365),
  [1447] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_methods_repeat1, 2, 0, 0), SHIFT_REPEAT(452),
  [1450] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_methods_repeat1, 2, 0, 0), SHIFT_REPEAT(1079),
  [1453] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_methods_repeat1, 2, 0, 0), SHIFT_REPEAT(754),
  [1456] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_methods_repeat1, 2, 0, 0), SHIFT_REPEAT(1067),
  [1459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1477),
  [1461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1120),
  [1463] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_validation_functions_repeat1, 2, 0, 0), SHIFT_REPEAT(849),
  [1466] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_validation_functions_repeat1, 2, 0, 0), SHIFT_REPEAT(259),
  [1469] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_validation_functions_repeat1, 2, 0, 0),
  [1471] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_validation_functions_repeat1, 2, 0, 0), SHIFT_REPEAT(809),
  [1474] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_validation_functions_repeat1, 2, 0, 0), SHIFT_REPEAT(540),
  [1477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1114),
  [1479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1187),
  [1481] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_metaclass_operator_repeat1, 2, 0, 0), SHIFT_REPEAT(1030),
  [1484] = {.entry = {.count = 1, .reusable = true}}, SHIFT(171),
  [1486] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__index_range_element, 1, 1, 9),
  [1488] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__index_binary_expression, 1, 0, 9),
  [1490] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__index_range_element, 1, 1, 9),
  [1492] = {.entry = {.count = 1, .reusable = false}}, SHIFT(797),
  [1494] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_methods_repeat1, 2, 0, 5),
  [1496] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_methods_repeat1, 2, 0, 5),
  [1498] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_methods_repeat1, 2, 0, 0),
  [1500] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__index_binary_operator, 3, 0, 13),
  [1502] = {.entry = {.count = 1, .reusable = false}}, SHIFT(221),
  [1504] = {.entry = {.count = 1, .reusable = false}}, SHIFT(229),
  [1506] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__index_binary_operator, 3, 0, 13),
  [1508] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__index_binary_expression, 1, 0, 9),
  [1510] = {.entry = {.count = 1, .reusable = false}}, SHIFT(203),
  [1512] = {.entry = {.count = 1, .reusable = false}}, SHIFT(210),
  [1514] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__index_matrix, 4, 0, 0),
  [1516] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__index_matrix, 4, 0, 0),
  [1518] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__index_matrix, 5, 0, 0),
  [1520] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__index_matrix, 5, 0, 0),
  [1522] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__index_parenthesis, 3, 0, 0),
  [1524] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__index_parenthesis, 3, 0, 0),
  [1526] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__index_expression, 1, 0, 9),
  [1528] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__index_expression, 1, 0, 9),
  [1530] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_elseif_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(797),
  [1533] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_end_keyword, 1, 0, 0),
  [1535] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_end_keyword, 1, 0, 0),
  [1537] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_multioutput_variable_repeat1, 1, 0, 0),
  [1539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(235),
  [1541] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enumeration_repeat1, 2, 0, 0), SHIFT_REPEAT(802),
  [1544] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_enumeration_repeat1, 2, 0, 0),
  [1546] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enumeration_repeat1, 2, 0, 0), SHIFT_REPEAT(373),
  [1549] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_enumeration_repeat1, 2, 0, 0), SHIFT_REPEAT(373),
  [1552] = {.entry = {.count = 1, .reusable = true}}, SHIFT(209),
  [1554] = {.entry = {.count = 1, .reusable = true}}, SHIFT(238),
  [1556] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_name, 1, -1, 0),
  [1558] = {.entry = {.count = 1, .reusable = true}}, SHIFT(986),
  [1560] = {.entry = {.count = 1, .reusable = false}}, SHIFT(812),
  [1562] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1132),
  [1564] = {.entry = {.count = 1, .reusable = false}}, SHIFT(827),
  [1566] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1088),
  [1568] = {.entry = {.count = 1, .reusable = false}}, SHIFT(802),
  [1570] = {.entry = {.count = 1, .reusable = false}}, SHIFT(217),
  [1572] = {.entry = {.count = 1, .reusable = false}}, SHIFT(218),
  [1574] = {.entry = {.count = 1, .reusable = false}}, SHIFT(216),
  [1576] = {.entry = {.count = 1, .reusable = false}}, SHIFT(220),
  [1578] = {.entry = {.count = 1, .reusable = true}}, SHIFT(228),
  [1580] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1148),
  [1582] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property_name, 2, -1, 0),
  [1584] = {.entry = {.count = 1, .reusable = false}}, SHIFT(983),
  [1586] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_name, 2, -1, 0),
  [1588] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_metaclass_operator_repeat1, 2, 0, 0), SHIFT_REPEAT(1040),
  [1591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(213),
  [1593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(211),
  [1595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(212),
  [1597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(215),
  [1599] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1030),
  [1601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(872),
  [1603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(370),
  [1605] = {.entry = {.count = 1, .reusable = false}}, SHIFT(848),
  [1607] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1147),
  [1609] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_arguments_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(872),
  [1612] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_arguments_statement_repeat1, 2, 0, 0),
  [1614] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_arguments_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(822),
  [1617] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_events_repeat1, 2, 0, 0), SHIFT_REPEAT(848),
  [1620] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_events_repeat1, 2, 0, 0),
  [1622] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_events_repeat1, 2, 0, 0), SHIFT_REPEAT(373),
  [1625] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_events_repeat1, 2, 0, 0), SHIFT_REPEAT(373),
  [1628] = {.entry = {.count = 1, .reusable = false}}, SHIFT(844),
  [1630] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1085),
  [1632] = {.entry = {.count = 1, .reusable = false}}, SHIFT(854),
  [1634] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1097),
  [1636] = {.entry = {.count = 1, .reusable = true}}, SHIFT(369),
  [1638] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_validation_functions_repeat1, 1, 0, 0),
  [1640] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property, 2, 0, 3),
  [1642] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property, 2, 0, 3),
  [1644] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_elseif_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(861),
  [1647] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_field_expression_repeat1, 2, 0, 14), SHIFT_REPEAT(385),
  [1650] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property, 4, 0, 3),
  [1652] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property, 4, 0, 3),
  [1654] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property, 3, 0, 3),
  [1656] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property, 3, 0, 3),
  [1658] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_arguments_statement_repeat1, 2, 0, 0),
  [1660] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property_name, 4, -1, 0),
  [1662] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_name, 4, -1, 0),
  [1664] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property, 6, 0, 3),
  [1666] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property, 6, 0, 3),
  [1668] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18),
  [1670] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1140),
  [1672] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_properties_repeat1, 2, 0, 0), SHIFT_REPEAT(872),
  [1675] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_properties_repeat1, 2, 0, 0),
  [1677] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_properties_repeat1, 2, 0, 0), SHIFT_REPEAT(822),
  [1680] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1099),
  [1682] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property_name, 3, -1, 0),
  [1684] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_name, 3, -1, 0),
  [1686] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property, 5, 0, 3),
  [1688] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property, 5, 0, 3),
  [1690] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1026),
  [1692] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_global_operator_repeat1, 2, 0, 0),
  [1694] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_global_operator_repeat1, 2, 0, 0), SHIFT_REPEAT(822),
  [1697] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_global_operator_repeat1, 2, 0, 0), SHIFT_REPEAT(822),
  [1700] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_global_operator, 2, 0, 0),
  [1702] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_matrix_repeat1, 2, 0, 0), SHIFT_REPEAT(882),
  [1705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1017),
  [1707] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_persistent_operator, 2, 0, 0),
  [1709] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_persistent_operator, 1, 0, 0),
  [1711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(987),
  [1713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1023),
  [1715] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_metaclass_operator_repeat1, 2, 0, 0), SHIFT_REPEAT(1026),
  [1718] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_metaclass_operator_repeat1, 2, 0, 0), SHIFT_REPEAT(1016),
  [1721] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_global_operator, 1, 0, 0),
  [1723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1013),
  [1725] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_metaclass_operator_repeat1, 2, 0, 0), SHIFT_REPEAT(1021),
  [1728] = {.entry = {.count = 1, .reusable = true}}, SHIFT(357),
  [1730] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1431),
  [1732] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10),
  [1734] = {.entry = {.count = 1, .reusable = true}}, SHIFT(242),
  [1736] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_dimensions, 3, 0, 0),
  [1738] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_dimensions, 3, 0, 0),
  [1740] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_dimensions, 4, 0, 0),
  [1742] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_dimensions, 4, 0, 0),
  [1744] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1244),
  [1746] = {.entry = {.count = 1, .reusable = true}}, SHIFT(277),
  [1748] = {.entry = {.count = 1, .reusable = true}}, SHIFT(278),
  [1750] = {.entry = {.count = 1, .reusable = true}}, SHIFT(280),
  [1752] = {.entry = {.count = 1, .reusable = true}}, SHIFT(302),
  [1754] = {.entry = {.count = 1, .reusable = true}}, SHIFT(303),
  [1756] = {.entry = {.count = 1, .reusable = true}}, SHIFT(304),
  [1758] = {.entry = {.count = 1, .reusable = true}}, SHIFT(305),
  [1760] = {.entry = {.count = 1, .reusable = true}}, SHIFT(306),
  [1762] = {.entry = {.count = 1, .reusable = true}}, SHIFT(203),
  [1764] = {.entry = {.count = 1, .reusable = true}}, SHIFT(221),
  [1766] = {.entry = {.count = 1, .reusable = true}}, SHIFT(229),
  [1768] = {.entry = {.count = 1, .reusable = true}}, SHIFT(204),
  [1770] = {.entry = {.count = 1, .reusable = true}}, SHIFT(210),
  [1772] = {.entry = {.count = 1, .reusable = true}}, SHIFT(319),
  [1774] = {.entry = {.count = 1, .reusable = true}}, SHIFT(237),
  [1776] = {.entry = {.count = 1, .reusable = true}}, SHIFT(289),
  [1778] = {.entry = {.count = 1, .reusable = true}}, SHIFT(290),
  [1780] = {.entry = {.count = 1, .reusable = true}}, SHIFT(291),
  [1782] = {.entry = {.count = 1, .reusable = true}}, SHIFT(292),
  [1784] = {.entry = {.count = 1, .reusable = true}}, SHIFT(293),
  [1786] = {.entry = {.count = 1, .reusable = true}}, SHIFT(295),
  [1788] = {.entry = {.count = 1, .reusable = true}}, SHIFT(216),
  [1790] = {.entry = {.count = 1, .reusable = true}}, SHIFT(217),
  [1792] = {.entry = {.count = 1, .reusable = true}}, SHIFT(218),
  [1794] = {.entry = {.count = 1, .reusable = true}}, SHIFT(219),
  [1796] = {.entry = {.count = 1, .reusable = true}}, SHIFT(220),
  [1798] = {.entry = {.count = 1, .reusable = true}}, SHIFT(311),
  [1800] = {.entry = {.count = 1, .reusable = true}}, SHIFT(312),
  [1802] = {.entry = {.count = 1, .reusable = true}}, SHIFT(313),
  [1804] = {.entry = {.count = 1, .reusable = true}}, SHIFT(314),
  [1806] = {.entry = {.count = 1, .reusable = true}}, SHIFT(362),
  [1808] = {.entry = {.count = 1, .reusable = true}}, SHIFT(317),
  [1810] = {.entry = {.count = 1, .reusable = true}}, SHIFT(323),
  [1812] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_row, 1, 0, 0),
  [1814] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_row, 1, 0, 0),
  [1816] = {.entry = {.count = 1, .reusable = true}}, SHIFT(241),
  [1818] = {.entry = {.count = 1, .reusable = true}}, SHIFT(337),
  [1820] = {.entry = {.count = 1, .reusable = true}}, SHIFT(347),
  [1822] = {.entry = {.count = 1, .reusable = true}}, SHIFT(349),
  [1824] = {.entry = {.count = 1, .reusable = true}}, SHIFT(342),
  [1826] = {.entry = {.count = 1, .reusable = true}}, SHIFT(214),
  [1828] = {.entry = {.count = 1, .reusable = true}}, SHIFT(359),
  [1830] = {.entry = {.count = 1, .reusable = true}}, SHIFT(361),
  [1832] = {.entry = {.count = 1, .reusable = false}}, SHIFT(364),
  [1834] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_row_repeat1, 2, 0, 0),
  [1836] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_row_repeat1, 2, 0, 0),
  [1838] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1016),
  [1840] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_enumeration_repeat1, 2, 0, 0),
  [1842] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_events_repeat1, 2, 0, 0),
  [1844] = {.entry = {.count = 1, .reusable = false}}, SHIFT(248),
  [1846] = {.entry = {.count = 1, .reusable = true}}, SHIFT(956),
  [1848] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1012),
  [1850] = {.entry = {.count = 1, .reusable = true}}, SHIFT(974),
  [1852] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1041),
  [1854] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments, 3, 0, 0),
  [1856] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments, 5, 0, 11),
  [1858] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_assignment, 3, 0, 13),
  [1860] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1024),
  [1862] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_default_value, 2, 0, 0),
  [1864] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1008),
  [1866] = {.entry = {.count = 1, .reusable = false}}, SHIFT(973),
  [1868] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1049),
  [1870] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1218),
  [1872] = {.entry = {.count = 1, .reusable = false}}, SHIFT(864),
  [1874] = {.entry = {.count = 1, .reusable = true}}, SHIFT(909),
  [1876] = {.entry = {.count = 1, .reusable = true}}, SHIFT(904),
  [1878] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1063),
  [1880] = {.entry = {.count = 1, .reusable = true}}, SHIFT(268),
  [1882] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1335),
  [1884] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_arguments_repeat1, 4, 0, 0),
  [1886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(916),
  [1888] = {.entry = {.count = 1, .reusable = true}}, SHIFT(969),
  [1890] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1351),
  [1892] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1053),
  [1894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1077),
  [1896] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1071),
  [1898] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1075),
  [1900] = {.entry = {.count = 1, .reusable = true}}, SHIFT(978),
  [1902] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1282),
  [1904] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1362),
  [1906] = {.entry = {.count = 1, .reusable = true}}, SHIFT(912),
  [1908] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(969),
  [1911] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_class_definition_repeat1, 2, 0, 0),
  [1913] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(1053),
  [1916] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(1077),
  [1919] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(1071),
  [1922] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(1075),
  [1925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(966),
  [1927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1231),
  [1929] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__index_argument, 1, -1, 0),
  [1931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1066),
  [1933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1081),
  [1935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(963),
  [1937] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1226),
  [1939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(919),
  [1941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(906),
  [1943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1439),
  [1945] = {.entry = {.count = 1, .reusable = true}}, SHIFT(874),
  [1947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(867),
  [1949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(920),
  [1951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(197),
  [1953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(929),
  [1955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(931),
  [1957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(922),
  [1959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(923),
  [1961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(924),
  [1963] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1433),
  [1965] = {.entry = {.count = 1, .reusable = true}}, SHIFT(896),
  [1967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(927),
  [1969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(928),
  [1971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(925),
  [1973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(971),
  [1975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1258),
  [1977] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_output, 2, 0, 0),
  [1979] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_output, 2, 0, 0),
  [1981] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_enum_repeat1, 2, 0, 0),
  [1983] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attribute, 3, 0, 0),
  [1985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(258),
  [1987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2),
  [1989] = {.entry = {.count = 1, .reusable = false}}, SHIFT(975),
  [1991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(687),
  [1993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(572),
  [1995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(488),
  [1997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(117),
  [1999] = {.entry = {.count = 1, .reusable = true}}, SHIFT(25),
  [2001] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_elseif_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1049),
  [2004] = {.entry = {.count = 1, .reusable = true}}, SHIFT(329),
  [2006] = {.entry = {.count = 1, .reusable = true}}, SHIFT(330),
  [2008] = {.entry = {.count = 1, .reusable = true}}, SHIFT(331),
  [2010] = {.entry = {.count = 1, .reusable = true}}, SHIFT(339),
  [2012] = {.entry = {.count = 1, .reusable = true}}, SHIFT(340),
  [2014] = {.entry = {.count = 1, .reusable = true}}, SHIFT(341),
  [2016] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attributes, 4, 0, 0),
  [2018] = {.entry = {.count = 1, .reusable = false}}, SHIFT(762),
  [2020] = {.entry = {.count = 1, .reusable = false}}, SHIFT(995),
  [2022] = {.entry = {.count = 1, .reusable = false}}, SHIFT(48),
  [2024] = {.entry = {.count = 1, .reusable = false}}, SHIFT(905),
  [2026] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1006),
  [2028] = {.entry = {.count = 1, .reusable = true}}, SHIFT(344),
  [2030] = {.entry = {.count = 1, .reusable = true}}, SHIFT(345),
  [2032] = {.entry = {.count = 1, .reusable = true}}, SHIFT(346),
  [2034] = {.entry = {.count = 1, .reusable = false}}, SHIFT(53),
  [2036] = {.entry = {.count = 1, .reusable = true}}, SHIFT(286),
  [2038] = {.entry = {.count = 1, .reusable = true}}, SHIFT(287),
  [2040] = {.entry = {.count = 1, .reusable = true}}, SHIFT(288),
  [2042] = {.entry = {.count = 1, .reusable = false}}, SHIFT(62),
  [2044] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attributes, 3, 0, 0),
  [2046] = {.entry = {.count = 1, .reusable = false}}, SHIFT(875),
  [2048] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_signature, 1, 0, 6),
  [2050] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1004),
  [2052] = {.entry = {.count = 1, .reusable = false}}, SHIFT(964),
  [2054] = {.entry = {.count = 1, .reusable = false}}, SHIFT(61),
  [2056] = {.entry = {.count = 1, .reusable = false}}, SHIFT(36),
  [2058] = {.entry = {.count = 1, .reusable = false}}, SHIFT(851),
  [2060] = {.entry = {.count = 1, .reusable = false}}, SHIFT(30),
  [2062] = {.entry = {.count = 1, .reusable = false}}, SHIFT(45),
  [2064] = {.entry = {.count = 1, .reusable = false}}, SHIFT(34),
  [2066] = {.entry = {.count = 1, .reusable = false}}, SHIFT(808),
  [2068] = {.entry = {.count = 1, .reusable = false}}, SHIFT(65),
  [2070] = {.entry = {.count = 1, .reusable = false}}, SHIFT(770),
  [2072] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property_name, 1, -1, 0),
  [2074] = {.entry = {.count = 1, .reusable = false}}, SHIFT(965),
  [2076] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_superclasses, 2, 0, 0),
  [2078] = {.entry = {.count = 1, .reusable = false}}, SHIFT(962),
  [2080] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_row, 1, 0, 0), REDUCE(sym__index_row, 1, 0, 0),
  [2083] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_row, 1, 0, 0), REDUCE(sym__index_row, 1, 0, 0),
  [2086] = {.entry = {.count = 1, .reusable = true}}, SHIFT(183),
  [2088] = {.entry = {.count = 1, .reusable = true}}, SHIFT(321),
  [2090] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1271),
  [2092] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_events, 4, 0, 0),
  [2094] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1218),
  [2096] = {.entry = {.count = 1, .reusable = true}}, SHIFT(326),
  [2098] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17),
  [2100] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 10, 0, 22),
  [2102] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 10, 0, 22),
  [2104] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 10, 0, 22),
  [2106] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enumeration, 4, 0, 0),
  [2108] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 9, 0, 16),
  [2110] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 9, 0, 16),
  [2112] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 9, 0, 16),
  [2114] = {.entry = {.count = 1, .reusable = false}}, SHIFT(781),
  [2116] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1102),
  [2118] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 4, 0, 8),
  [2120] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 4, 0, 8),
  [2122] = {.entry = {.count = 1, .reusable = true}}, SHIFT(239),
  [2124] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1150),
  [2126] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 5, 0, 16),
  [2128] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 5, 0, 16),
  [2130] = {.entry = {.count = 1, .reusable = true}}, SHIFT(180),
  [2132] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_events, 3, 0, 0),
  [2134] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_properties, 4, 0, 0),
  [2136] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_command_repeat1, 2, 0, 0),
  [2138] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_command_repeat1, 2, 0, 0), SHIFT_REPEAT(1100),
  [2141] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1129),
  [2143] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 5, 0, 8),
  [2145] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 5, 0, 8),
  [2147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1243),
  [2149] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1116),
  [2151] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 6, 0, 22),
  [2153] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 6, 0, 22),
  [2155] = {.entry = {.count = 1, .reusable = false}}, SHIFT(751),
  [2157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1352),
  [2159] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 8, 0, 16),
  [2161] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 8, 0, 16),
  [2163] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 8, 0, 16),
  [2165] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_property, 4, 0, 0),
  [2167] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 9, 0, 22),
  [2169] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 9, 0, 22),
  [2171] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 9, 0, 22),
  [2173] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_command, 2, 0, 0),
  [2175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1100),
  [2177] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_superclasses, 3, 0, 0),
  [2179] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1089),
  [2181] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1087),
  [2183] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_methods, 4, 0, 0),
  [2185] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 7, 0, 16),
  [2187] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 7, 0, 16),
  [2189] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 7, 0, 16),
  [2191] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 7, 0, 22),
  [2193] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 7, 0, 22),
  [2195] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1107),
  [2197] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 8, 0, 8),
  [2199] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 8, 0, 8),
  [2201] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 8, 0, 8),
  [2203] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1137),
  [2205] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_methods, 3, 0, 0),
  [2207] = {.entry = {.count = 1, .reusable = false}}, SHIFT(756),
  [2209] = {.entry = {.count = 1, .reusable = false}}, SHIFT(868),
  [2211] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 7, 0, 8),
  [2213] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 7, 0, 8),
  [2215] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 7, 0, 8),
  [2217] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1118),
  [2219] = {.entry = {.count = 1, .reusable = false}}, SHIFT(22),
  [2221] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_property, 3, 0, 0),
  [2223] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_command, 1, 0, 0),
  [2225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1110),
  [2227] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 6, 0, 8),
  [2229] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 6, 0, 8),
  [2231] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 6, 0, 8),
  [2233] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enumeration, 3, 0, 0),
  [2235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1356),
  [2237] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_superclasses_repeat1, 2, 0, 0),
  [2239] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_superclasses_repeat1, 2, 0, 0), SHIFT_REPEAT(962),
  [2242] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1123),
  [2244] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1143),
  [2246] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1348),
  [2248] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1143),
  [2250] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 8, 0, 22),
  [2252] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 8, 0, 22),
  [2254] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 8, 0, 22),
  [2256] = {.entry = {.count = 1, .reusable = false}}, SHIFT(866),
  [2258] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1109),
  [2260] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_properties, 5, 0, 0),
  [2262] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_methods, 5, 0, 0),
  [2264] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_signature, 3, 0, 28),
  [2266] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_signature, 2, 0, 26),
  [2268] = {.entry = {.count = 1, .reusable = false}}, SHIFT(780),
  [2270] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1115),
  [2272] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 6, 0, 16),
  [2274] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 6, 0, 16),
  [2276] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_events, 5, 0, 0),
  [2278] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enumeration, 5, 0, 0),
  [2280] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_properties, 3, 0, 0),
  [2282] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_row_repeat1, 2, 0, 0), SHIFT_REPEAT(250),
  [2285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(552),
  [2287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1193),
  [2289] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_switch_statement_repeat1, 2, 0, 0),
  [2291] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_switch_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(326),
  [2294] = {.entry = {.count = 1, .reusable = true}}, SHIFT(116),
  [2296] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1159),
  [2298] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1198),
  [2300] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_string_repeat1, 2, 0, 0),
  [2302] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_string_repeat1, 2, 0, 0), SHIFT_REPEAT(1159),
  [2305] = {.entry = {.count = 1, .reusable = false}}, SHIFT(936),
  [2307] = {.entry = {.count = 1, .reusable = false}}, SHIFT(970),
  [2309] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__index_row_repeat1, 2, 0, 0),
  [2311] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__index_row_repeat1, 2, 0, 0),
  [2313] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__index_row_repeat1, 2, 0, 0), SHIFT_REPEAT(186),
  [2316] = {.entry = {.count = 1, .reusable = false}}, SHIFT(29),
  [2318] = {.entry = {.count = 1, .reusable = false}}, SHIFT(31),
  [2320] = {.entry = {.count = 1, .reusable = true}}, SHIFT(484),
  [2322] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1172),
  [2324] = {.entry = {.count = 1, .reusable = true}}, SHIFT(181),
  [2326] = {.entry = {.count = 1, .reusable = true}}, SHIFT(643),
  [2328] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1180),
  [2330] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1181),
  [2332] = {.entry = {.count = 1, .reusable = false}}, SHIFT(55),
  [2334] = {.entry = {.count = 1, .reusable = true}}, SHIFT(485),
  [2336] = {.entry = {.count = 1, .reusable = false}}, SHIFT(811),
  [2338] = {.entry = {.count = 1, .reusable = false}}, SHIFT(37),
  [2340] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__index_range, 3, 0, 0),
  [2342] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__index_range, 3, 0, 0),
  [2344] = {.entry = {.count = 1, .reusable = false}}, SHIFT(200),
  [2346] = {.entry = {.count = 1, .reusable = false}}, SHIFT(35),
  [2348] = {.entry = {.count = 1, .reusable = false}}, SHIFT(850),
  [2350] = {.entry = {.count = 1, .reusable = false}}, SHIFT(41),
  [2352] = {.entry = {.count = 1, .reusable = true}}, SHIFT(684),
  [2354] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1194),
  [2356] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_matrix_repeat2, 2, 0, 0), SHIFT_REPEAT(199),
  [2359] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_matrix_repeat2, 2, 0, 0), SHIFT_REPEAT(199),
  [2362] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_matrix_repeat2, 2, 0, 0),
  [2364] = {.entry = {.count = 1, .reusable = false}}, SHIFT(772),
  [2366] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_validation_functions, 4, 0, 0),
  [2368] = {.entry = {.count = 1, .reusable = false}}, SHIFT(50),
  [2370] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum, 1, 0, 0),
  [2372] = {.entry = {.count = 1, .reusable = false}}, SHIFT(265),
  [2374] = {.entry = {.count = 1, .reusable = false}}, SHIFT(366),
  [2376] = {.entry = {.count = 1, .reusable = false}}, SHIFT(935),
  [2378] = {.entry = {.count = 1, .reusable = true}}, SHIFT(570),
  [2380] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__index_row, 1, 0, 0),
  [2382] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__index_row, 1, 0, 0),
  [2384] = {.entry = {.count = 1, .reusable = true}}, SHIFT(179),
  [2386] = {.entry = {.count = 1, .reusable = false}}, SHIFT(66),
  [2388] = {.entry = {.count = 1, .reusable = false}}, SHIFT(977),
  [2390] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_string_repeat1, 2, 0, 0), SHIFT_REPEAT(1198),
  [2393] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parfor_options, 1, 0, 0),
  [2395] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_if_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(321),
  [2398] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_if_statement_repeat1, 2, 0, 0),
  [2400] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_if_statement_repeat1, 2, 0, 0),
  [2402] = {.entry = {.count = 1, .reusable = false}}, SHIFT(247),
  [2404] = {.entry = {.count = 1, .reusable = false}}, SHIFT(58),
  [2406] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_validation_functions, 3, 0, 0),
  [2408] = {.entry = {.count = 1, .reusable = true}}, SHIFT(182),
  [2410] = {.entry = {.count = 1, .reusable = true}}, SHIFT(108),
  [2412] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1157),
  [2414] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1158),
  [2416] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1203),
  [2418] = {.entry = {.count = 1, .reusable = false}}, SHIFT(199),
  [2420] = {.entry = {.count = 1, .reusable = true}}, SHIFT(199),
  [2422] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1274),
  [2424] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_arguments, 3, 0, 21),
  [2426] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_switch_statement, 4, 0, 7),
  [2428] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1281),
  [2430] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_try_statement, 2, 0, 0),
  [2432] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_spmd_statement, 7, 0, 0),
  [2434] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0),
  [2436] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(883),
  [2439] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_while_statement, 4, 0, 7),
  [2441] = {.entry = {.count = 1, .reusable = false}}, SHIFT(526),
  [2443] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_continue_statement, 1, 0, 0),
  [2445] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_definition, 5, 0, 8),
  [2447] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_arguments_repeat1, 2, 0, 0), SHIFT_REPEAT(1041),
  [2450] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_arguments_repeat1, 2, 0, 0),
  [2452] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1414),
  [2454] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1414),
  [2456] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_try_statement, 3, 0, 0),
  [2458] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_definition, 6, 0, 16),
  [2460] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_break_statement, 1, 0, 0),
  [2462] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 8, 0, 0),
  [2464] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 7, 0, 7),
  [2466] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 7, 0, 0),
  [2468] = {.entry = {.count = 1, .reusable = true}}, SHIFT(172),
  [2470] = {.entry = {.count = 1, .reusable = true}}, SHIFT(957),
  [2472] = {.entry = {.count = 1, .reusable = true}}, SHIFT(169),
  [2474] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__argument_attributes, 4, 0, 27),
  [2476] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_matrix_repeat2, 2, 0, 0),
  [2478] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_spmd_statement, 3, 0, 0),
  [2480] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 5, 0, 7),
  [2482] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_arguments, 2, 0, 0),
  [2484] = {.entry = {.count = 1, .reusable = false}}, SHIFT(626),
  [2486] = {.entry = {.count = 1, .reusable = false}}, SHIFT(658),
  [2488] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1298),
  [2490] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1112),
  [2492] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1112),
  [2494] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__index_range, 5, 0, 0),
  [2496] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__index_range, 5, 0, 0),
  [2498] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1211),
  [2500] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__argument_attributes, 3, 0, 23),
  [2502] = {.entry = {.count = 1, .reusable = false}}, SHIFT(671),
  [2504] = {.entry = {.count = 1, .reusable = false}}, SHIFT(660),
  [2506] = {.entry = {.count = 1, .reusable = false}}, SHIFT(168),
  [2508] = {.entry = {.count = 1, .reusable = true}}, SHIFT(168),
  [2510] = {.entry = {.count = 1, .reusable = false}}, SHIFT(794),
  [2512] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_definition, 5, 0, 16),
  [2514] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1113),
  [2516] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1113),
  [2518] = {.entry = {.count = 1, .reusable = false}}, SHIFT(791),
  [2520] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1263),
  [2522] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_signature, 3, 0, 26),
  [2524] = {.entry = {.count = 1, .reusable = false}}, SHIFT(792),
  [2526] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_try_statement, 5, 0, 0),
  [2528] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_spmd_statement, 5, 0, 0),
  [2530] = {.entry = {.count = 1, .reusable = true}}, SHIFT(981),
  [2532] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_spmd_statement, 6, 0, 0),
  [2534] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 4, 0, 7),
  [2536] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1338),
  [2538] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1340),
  [2540] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1341),
  [2542] = {.entry = {.count = 1, .reusable = false}}, SHIFT(820),
  [2544] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 5, 0, 0),
  [2546] = {.entry = {.count = 1, .reusable = false}}, SHIFT(830),
  [2548] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_definition, 4, 0, 8),
  [2550] = {.entry = {.count = 1, .reusable = true}}, SHIFT(201),
  [2552] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_return_statement, 1, 0, 0),
  [2554] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_spmd_statement, 8, 0, 0),
  [2556] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_row_repeat1, 2, 0, 0), REDUCE(aux_sym__index_row_repeat1, 2, 0, 0),
  [2559] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_row_repeat1, 2, 0, 0), REDUCE(aux_sym__index_row_repeat1, 2, 0, 0),
  [2562] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments, 6, 0, 11),
  [2564] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1404),
  [2566] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1404),
  [2568] = {.entry = {.count = 1, .reusable = true}}, SHIFT(883),
  [2570] = {.entry = {.count = 1, .reusable = false}}, SHIFT(524),
  [2572] = {.entry = {.count = 1, .reusable = false}}, SHIFT(530),
  [2574] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__index_arguments, 1, 0, 10), SHIFT(184),
  [2577] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__index_arguments, 1, 0, 10),
  [2579] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_spmd_statement, 2, 0, 0),
  [2581] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 3, 0, 7),
  [2583] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 9, 0, 0),
  [2585] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_try_statement, 4, 0, 0),
  [2587] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1125),
  [2589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1125),
  [2591] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 3, 0, 0),
  [2593] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__index_arguments_repeat1, 2, 0, 24), SHIFT_REPEAT(184),
  [2596] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__index_arguments_repeat1, 2, 0, 24),
  [2598] = {.entry = {.count = 1, .reusable = true}}, SHIFT(997),
  [2600] = {.entry = {.count = 1, .reusable = false}}, SHIFT(595),
  [2602] = {.entry = {.count = 1, .reusable = false}}, SHIFT(596),
  [2604] = {.entry = {.count = 1, .reusable = false}}, SHIFT(597),
  [2606] = {.entry = {.count = 1, .reusable = false}}, SHIFT(543),
  [2608] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_while_statement, 3, 0, 7),
  [2610] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_attributes, 3, 0, 0),
  [2612] = {.entry = {.count = 1, .reusable = false}}, SHIFT(527),
  [2614] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__index_matrix_repeat1, 2, 0, 0), SHIFT_REPEAT(168),
  [2617] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__index_matrix_repeat1, 2, 0, 0), SHIFT_REPEAT(168),
  [2620] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__index_matrix_repeat1, 2, 0, 0),
  [2622] = {.entry = {.count = 1, .reusable = true}}, SHIFT(991),
  [2624] = {.entry = {.count = 1, .reusable = true}}, SHIFT(175),
  [2626] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1001),
  [2628] = {.entry = {.count = 1, .reusable = true}}, SHIFT(176),
  [2630] = {.entry = {.count = 1, .reusable = false}}, SHIFT(806),
  [2632] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_while_statement, 5, 0, 7),
  [2634] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_file, 2, 0, 0),
  [2636] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1002),
  [2638] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_signature, 2, 0, 6),
  [2640] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments, 4, 0, 0),
  [2642] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_signature, 4, 0, 28),
  [2644] = {.entry = {.count = 1, .reusable = false}}, SHIFT(127),
  [2646] = {.entry = {.count = 1, .reusable = false}}, SHIFT(128),
  [2648] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum, 4, 0, 0),
  [2650] = {.entry = {.count = 1, .reusable = false}}, SHIFT(129),
  [2652] = {.entry = {.count = 1, .reusable = false}}, SHIFT(130),
  [2654] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1367),
  [2656] = {.entry = {.count = 1, .reusable = true}}, SHIFT(174),
  [2658] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1003),
  [2660] = {.entry = {.count = 1, .reusable = true}}, SHIFT(177),
  [2662] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_spmd_statement, 4, 0, 0),
  [2664] = {.entry = {.count = 1, .reusable = true}}, SHIFT(979),
  [2666] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1368),
  [2668] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_spmd_statement, 9, 0, 0),
  [2670] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1142),
  [2672] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_switch_statement, 3, 0, 7),
  [2674] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1387),
  [2676] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1387),
  [2678] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_definition, 6, 0, 8),
  [2680] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_switch_statement, 5, 0, 7),
  [2682] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__index_arguments, 2, 0, 17), SHIFT(184),
  [2685] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__index_arguments, 2, 0, 17),
  [2687] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 4, 0, 0),
  [2689] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 6, 0, 7),
  [2691] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_attributes, 4, 0, 0),
  [2693] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_switch_statement, 6, 0, 7),
  [2695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(985),
  [2697] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_definition, 7, 0, 16),
  [2699] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1272),
  [2701] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum, 5, 0, 0),
  [2703] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1212),
  [2705] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__index_arguments_repeat1, 2, 0, 23),
  [2707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1022),
  [2709] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments, 1, 0, 11),
  [2711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1445),
  [2713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1432),
  [2715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(976),
  [2717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1358),
  [2719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1426),
  [2721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1028),
  [2723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1239),
  [2725] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_spread_operator, 1, 0, 0),
  [2727] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__index_matrix_repeat1, 2, 0, 0),
  [2729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(954),
  [2731] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__lambda_arguments, 1, 0, 0),
  [2733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1091),
  [2735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(903),
  [2737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1301),
  [2739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(869),
  [2741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1424),
  [2743] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attributes_repeat1, 2, 0, 0), SHIFT_REPEAT(976),
  [2746] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_attributes_repeat1, 2, 0, 0),
  [2748] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1254),
  [2750] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1366),
  [2752] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__argument_attributes_repeat1, 2, 0, 24), SHIFT_REPEAT(1028),
  [2755] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__argument_attributes_repeat1, 2, 0, 24),
  [2757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1317),
  [2759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1436),
  [2761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1444),
  [2763] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1062),
  [2765] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_elseif_clause, 3, 0, 7),
  [2767] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1052),
  [2769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1421),
  [2771] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1427),
  [2773] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_dimensions_repeat1, 2, 0, 0), SHIFT_REPEAT(1091),
  [2776] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_dimensions_repeat1, 2, 0, 0),
  [2778] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__lambda_arguments, 2, 0, 0),
  [2780] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_elseif_clause, 4, 0, 7),
  [2782] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_elseif_clause, 4, 0, 7),
  [2784] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__lambda_arguments_repeat1, 2, 0, 0), SHIFT_REPEAT(954),
  [2787] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__lambda_arguments_repeat1, 2, 0, 0),
  [2789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1442),
  [2791] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_clause, 4, 0, 7),
  [2793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1434),
  [2795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1435),
  [2797] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1443),
  [2799] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_enum_repeat1, 2, 0, 0), SHIFT_REPEAT(268),
  [2802] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attribute, 1, 0, 0),
  [2804] = {.entry = {.count = 1, .reusable = true}}, SHIFT(257),
  [2806] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1230),
  [2808] = {.entry = {.count = 1, .reusable = true}}, SHIFT(902),
  [2810] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__argument_attributes_repeat1, 2, 0, 23),
  [2812] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1339),
  [2814] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1339),
  [2816] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1275),
  [2818] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1275),
  [2820] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1369),
  [2822] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1369),
  [2824] = {.entry = {.count = 1, .reusable = true}}, SHIFT(475),
  [2826] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_multioutput_variable, 4, 0, 0),
  [2828] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1242),
  [2830] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_catch_clause, 4, 0, 0),
  [2832] = {.entry = {.count = 1, .reusable = true}}, SHIFT(793),
  [2834] = {.entry = {.count = 1, .reusable = true}}, SHIFT(24),
  [2836] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1234),
  [2838] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_otherwise_clause, 2, 0, 0),
  [2840] = {.entry = {.count = 1, .reusable = true}}, SHIFT(263),
  [2842] = {.entry = {.count = 1, .reusable = true}}, SHIFT(823),
  [2844] = {.entry = {.count = 1, .reusable = true}}, SHIFT(297),
  [2846] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_multioutput_variable, 3, 0, 0),
  [2848] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_multioutput_variable, 2, 0, 0),
  [2850] = {.entry = {.count = 1, .reusable = true}}, SHIFT(279),
  [2852] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1221),
  [2854] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1006),
  [2856] = {.entry = {.count = 1, .reusable = true}}, SHIFT(325),
  [2858] = {.entry = {.count = 1, .reusable = true}}, SHIFT(294),
  [2860] = {.entry = {.count = 1, .reusable = true}}, SHIFT(90),
  [2862] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_else_clause, 2, 0, 0),
  [2864] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1285),
  [2866] = {.entry = {.count = 1, .reusable = true}}, SHIFT(316),
  [2868] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1266),
  [2870] = {.entry = {.count = 1, .reusable = true}}, SHIFT(384),
  [2872] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1270),
  [2874] = {.entry = {.count = 1, .reusable = true}}, SHIFT(338),
  [2876] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_multioutput_variable, 6, 0, 0),
  [2878] = {.entry = {.count = 1, .reusable = true}}, SHIFT(256),
  [2880] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_multioutput_variable, 5, 0, 0),
  [2882] = {.entry = {.count = 1, .reusable = true}}, SHIFT(348),
  [2884] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1343),
  [2886] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_else_clause, 3, 0, 0),
  [2888] = {.entry = {.count = 1, .reusable = true}}, SHIFT(198),
  [2890] = {.entry = {.count = 1, .reusable = true}}, SHIFT(350),
  [2892] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1267),
  [2894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(285),
  [2896] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_otherwise_clause, 3, 0, 0),
  [2898] = {.entry = {.count = 1, .reusable = true}}, SHIFT(343),
  [2900] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1215),
  [2902] = {.entry = {.count = 1, .reusable = true}}, SHIFT(318),
  [2904] = {.entry = {.count = 1, .reusable = true}}, SHIFT(332),
  [2906] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1355),
  [2908] = {.entry = {.count = 1, .reusable = true}}, SHIFT(267),
  [2910] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1300),
  [2912] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1278),
  [2914] = {.entry = {.count = 1, .reusable = true}}, SHIFT(324),
  [2916] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1236),
  [2918] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1347),
  [2920] = {.entry = {.count = 1, .reusable = true}}, SHIFT(281),
  [2922] = {.entry = {.count = 1, .reusable = true}}, SHIFT(746),
  [2924] = {.entry = {.count = 1, .reusable = true}}, SHIFT(810),
  [2926] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1323),
  [2928] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1223),
  [2930] = {.entry = {.count = 1, .reusable = true}}, SHIFT(358),
  [2932] = {.entry = {.count = 1, .reusable = true}}, SHIFT(307),
  [2934] = {.entry = {.count = 1, .reusable = true}}, SHIFT(360),
  [2936] = {.entry = {.count = 1, .reusable = true}}, SHIFT(431),
  [2938] = {.entry = {.count = 1, .reusable = true}}, SHIFT(255),
  [2940] = {.entry = {.count = 1, .reusable = true}}, SHIFT(202),
  [2942] = {.entry = {.count = 1, .reusable = true}},  ACCEPT_INPUT(),
  [2944] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_catch_clause, 3, 0, 0),
  [2946] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1359),
};

enum ts_external_scanner_symbol_identifiers {
  ts_external_token_comment = 0,
  ts_external_token_line_continuation = 1,
  ts_external_token_command_name = 2,
  ts_external_token_command_argument = 3,
  ts_external_token__single_quote_string_start = 4,
  ts_external_token__single_quote_string_end = 5,
  ts_external_token__double_quote_string_start = 6,
  ts_external_token__double_quote_string_end = 7,
  ts_external_token_formatting_sequence = 8,
  ts_external_token_escape_sequence = 9,
  ts_external_token_string_content = 10,
  ts_external_token__entry_delimiter = 11,
  ts_external_token__multioutput_variable_start = 12,
  ts_external_token__external_identifier = 13,
  ts_external_token_error_sentinel = 14,
};

static const TSSymbol ts_external_scanner_symbol_map[EXTERNAL_TOKEN_COUNT] = {
  [ts_external_token_comment] = sym_comment,
  [ts_external_token_line_continuation] = sym_line_continuation,
  [ts_external_token_command_name] = sym_command_name,
  [ts_external_token_command_argument] = sym_command_argument,
  [ts_external_token__single_quote_string_start] = sym__single_quote_string_start,
  [ts_external_token__single_quote_string_end] = sym__single_quote_string_end,
  [ts_external_token__double_quote_string_start] = sym__double_quote_string_start,
  [ts_external_token__double_quote_string_end] = sym__double_quote_string_end,
  [ts_external_token_formatting_sequence] = sym_formatting_sequence,
  [ts_external_token_escape_sequence] = sym_escape_sequence,
  [ts_external_token_string_content] = sym_string_content,
  [ts_external_token__entry_delimiter] = sym__entry_delimiter,
  [ts_external_token__multioutput_variable_start] = sym__multioutput_variable_start,
  [ts_external_token__external_identifier] = sym__external_identifier,
  [ts_external_token_error_sentinel] = sym_error_sentinel,
};

static const bool ts_external_scanner_states[12][EXTERNAL_TOKEN_COUNT] = {
  [1] = {
    [ts_external_token_comment] = true,
    [ts_external_token_line_continuation] = true,
    [ts_external_token_command_name] = true,
    [ts_external_token_command_argument] = true,
    [ts_external_token__single_quote_string_start] = true,
    [ts_external_token__single_quote_string_end] = true,
    [ts_external_token__double_quote_string_start] = true,
    [ts_external_token__double_quote_string_end] = true,
    [ts_external_token_formatting_sequence] = true,
    [ts_external_token_escape_sequence] = true,
    [ts_external_token_string_content] = true,
    [ts_external_token__entry_delimiter] = true,
    [ts_external_token__multioutput_variable_start] = true,
    [ts_external_token__external_identifier] = true,
    [ts_external_token_error_sentinel] = true,
  },
  [2] = {
    [ts_external_token_comment] = true,
    [ts_external_token_line_continuation] = true,
    [ts_external_token_command_name] = true,
    [ts_external_token__single_quote_string_start] = true,
    [ts_external_token__double_quote_string_start] = true,
    [ts_external_token__multioutput_variable_start] = true,
    [ts_external_token__external_identifier] = true,
  },
  [3] = {
    [ts_external_token_comment] = true,
    [ts_external_token_line_continuation] = true,
    [ts_external_token__single_quote_string_start] = true,
    [ts_external_token__double_quote_string_start] = true,
    [ts_external_token__external_identifier] = true,
  },
  [4] = {
    [ts_external_token_comment] = true,
    [ts_external_token_line_continuation] = true,
    [ts_external_token__single_quote_string_start] = true,
    [ts_external_token__double_quote_string_start] = true,
    [ts_external_token__entry_delimiter] = true,
    [ts_external_token__external_identifier] = true,
  },
  [5] = {
    [ts_external_token_comment] = true,
    [ts_external_token_line_continuation] = true,
  },
  [6] = {
    [ts_external_token_comment] = true,
    [ts_external_token_line_continuation] = true,
    [ts_external_token__external_identifier] = true,
  },
  [7] = {
    [ts_external_token_comment] = true,
    [ts_external_token_line_continuation] = true,
    [ts_external_token__entry_delimiter] = true,
  },
  [8] = {
    [ts_external_token_comment] = true,
    [ts_external_token_line_continuation] = true,
    [ts_external_token__multioutput_variable_start] = true,
    [ts_external_token__external_identifier] = true,
  },
  [9] = {
    [ts_external_token_comment] = true,
    [ts_external_token_line_continuation] = true,
    [ts_external_token_command_argument] = true,
  },
  [10] = {
    [ts_external_token_comment] = true,
    [ts_external_token_line_continuation] = true,
    [ts_external_token__single_quote_string_end] = true,
    [ts_external_token_formatting_sequence] = true,
    [ts_external_token_escape_sequence] = true,
    [ts_external_token_string_content] = true,
  },
  [11] = {
    [ts_external_token_comment] = true,
    [ts_external_token_line_continuation] = true,
    [ts_external_token__double_quote_string_end] = true,
    [ts_external_token_formatting_sequence] = true,
    [ts_external_token_escape_sequence] = true,
    [ts_external_token_string_content] = true,
  },
};

#ifdef __cplusplus
extern "C" {
#endif
void *tree_sitter_matlab_external_scanner_create(void);
void tree_sitter_matlab_external_scanner_destroy(void *);
bool tree_sitter_matlab_external_scanner_scan(void *, TSLexer *, const bool *);
unsigned tree_sitter_matlab_external_scanner_serialize(void *, char *);
void tree_sitter_matlab_external_scanner_deserialize(void *, const char *, unsigned);

#ifdef TREE_SITTER_HIDE_SYMBOLS
#define TS_PUBLIC
#elif defined(_WIN32)
#define TS_PUBLIC __declspec(dllexport)
#else
#define TS_PUBLIC __attribute__((visibility("default")))
#endif

TS_PUBLIC const TSLanguage *tree_sitter_matlab(void) {
  static const TSLanguage language = {
    .abi_version = LANGUAGE_VERSION,
    .symbol_count = SYMBOL_COUNT,
    .alias_count = ALIAS_COUNT,
    .token_count = TOKEN_COUNT,
    .external_token_count = EXTERNAL_TOKEN_COUNT,
    .state_count = STATE_COUNT,
    .large_state_count = LARGE_STATE_COUNT,
    .production_id_count = PRODUCTION_ID_COUNT,
    .supertype_count = SUPERTYPE_COUNT,
    .field_count = FIELD_COUNT,
    .max_alias_sequence_length = MAX_ALIAS_SEQUENCE_LENGTH,
    .parse_table = &ts_parse_table[0][0],
    .small_parse_table = ts_small_parse_table,
    .small_parse_table_map = ts_small_parse_table_map,
    .parse_actions = ts_parse_actions,
    .symbol_names = ts_symbol_names,
    .field_names = ts_field_names,
    .field_map_slices = ts_field_map_slices,
    .field_map_entries = ts_field_map_entries,
    .symbol_metadata = ts_symbol_metadata,
    .public_symbol_map = ts_symbol_map,
    .alias_map = ts_non_terminal_alias_map,
    .alias_sequences = &ts_alias_sequences[0][0],
    .lex_modes = (const void*)ts_lex_modes,
    .lex_fn = ts_lex,
    .external_scanner = {
      &ts_external_scanner_states[0][0],
      ts_external_scanner_symbol_map,
      tree_sitter_matlab_external_scanner_create,
      tree_sitter_matlab_external_scanner_destroy,
      tree_sitter_matlab_external_scanner_scan,
      tree_sitter_matlab_external_scanner_serialize,
      tree_sitter_matlab_external_scanner_deserialize,
    },
    .primary_state_ids = ts_primary_state_ids,
    .name = "matlab",
    .max_reserved_word_set_size = 0,
    .metadata = {
      .major_version = 1,
      .minor_version = 0,
      .patch_version = 10,
    },
  };
  return &language;
}
#ifdef __cplusplus
}
#endif
